Interface IncreaseClient
-
- All Implemented Interfaces:
public interface IncreaseClientA client for interacting with the Increase REST API synchronously. You can also switch to asynchronous execution via the async method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIncreaseClient.WithRawResponseA view of IncreaseClient that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
async
abstract IncreaseClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract IncreaseClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract IncreaseClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
abstract AccountService accounts()
-
accountNumbers
abstract AccountNumberService accountNumbers()
-
accountTransfers
abstract AccountTransferService accountTransfers()
-
cards
abstract CardService cards()
-
cardPayments
abstract CardPaymentService cardPayments()
-
cardPurchaseSupplements
abstract CardPurchaseSupplementService cardPurchaseSupplements()
-
cardDisputes
abstract CardDisputeService cardDisputes()
-
physicalCards
abstract PhysicalCardService physicalCards()
-
digitalCardProfiles
abstract DigitalCardProfileService digitalCardProfiles()
-
physicalCardProfiles
abstract PhysicalCardProfileService physicalCardProfiles()
-
digitalWalletTokens
abstract DigitalWalletTokenService digitalWalletTokens()
-
transactions
abstract TransactionService transactions()
-
pendingTransactions
abstract PendingTransactionService pendingTransactions()
-
declinedTransactions
abstract DeclinedTransactionService declinedTransactions()
-
achTransfers
abstract AchTransferService achTransfers()
-
inboundAchTransfers
abstract InboundAchTransferService inboundAchTransfers()
-
achPrenotifications
abstract AchPrenotificationService achPrenotifications()
-
wireTransfers
abstract WireTransferService wireTransfers()
-
inboundWireTransfers
abstract InboundWireTransferService inboundWireTransfers()
-
wireDrawdownRequests
abstract WireDrawdownRequestService wireDrawdownRequests()
-
inboundWireDrawdownRequests
abstract InboundWireDrawdownRequestService inboundWireDrawdownRequests()
-
checkTransfers
abstract CheckTransferService checkTransfers()
-
inboundCheckDeposits
abstract InboundCheckDepositService inboundCheckDeposits()
-
realTimePaymentsTransfers
abstract RealTimePaymentsTransferService realTimePaymentsTransfers()
-
inboundRealTimePaymentsTransfers
abstract InboundRealTimePaymentsTransferService inboundRealTimePaymentsTransfers()
-
fednowTransfers
abstract FednowTransferService fednowTransfers()
-
inboundFednowTransfers
abstract InboundFednowTransferService inboundFednowTransfers()
-
swiftTransfers
abstract SwiftTransferService swiftTransfers()
-
checkDeposits
abstract CheckDepositService checkDeposits()
-
lockboxAddresses
abstract LockboxAddressService lockboxAddresses()
-
lockboxRecipients
abstract LockboxRecipientService lockboxRecipients()
-
inboundMailItems
abstract InboundMailItemService inboundMailItems()
-
routingNumbers
abstract RoutingNumberService routingNumbers()
-
externalAccounts
abstract ExternalAccountService externalAccounts()
-
entities
abstract EntityService entities()
-
beneficialOwners
abstract BeneficialOwnerService beneficialOwners()
-
supplementalDocuments
abstract SupplementalDocumentService supplementalDocuments()
-
entityOnboardingSessions
abstract EntityOnboardingSessionService entityOnboardingSessions()
-
programs
abstract ProgramService programs()
-
accountStatements
abstract AccountStatementService accountStatements()
-
files
abstract FileService files()
-
fileLinks
abstract FileLinkService fileLinks()
-
exports
abstract ExportService exports()
-
events
abstract EventService events()
-
eventSubscriptions
abstract EventSubscriptionService eventSubscriptions()
-
realTimeDecisions
abstract RealTimeDecisionService realTimeDecisions()
-
groups
abstract GroupService groups()
-
oauthApplications
abstract OAuthApplicationService oauthApplications()
-
oauthConnections
abstract OAuthConnectionService oauthConnections()
-
oauthTokens
abstract OAuthTokenService oauthTokens()
-
intrafiAccountEnrollments
abstract IntrafiAccountEnrollmentService intrafiAccountEnrollments()
-
intrafiBalances
abstract IntrafiBalanceService intrafiBalances()
-
intrafiExclusions
abstract IntrafiExclusionService intrafiExclusions()
-
cardTokens
abstract CardTokenService cardTokens()
-
cardPushTransfers
abstract CardPushTransferService cardPushTransfers()
-
cardValidations
abstract CardValidationService cardValidations()
-
simulations
abstract SimulationService simulations()
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-