Interface IncreaseClientAsync
-
- All Implemented Interfaces:
public interface IncreaseClientAsyncA client for interacting with the Increase REST API asynchronously. You can also switch to synchronous execution via the sync method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIncreaseClientAsync.WithRawResponseA view of IncreaseClientAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
sync
abstract IncreaseClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract IncreaseClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract IncreaseClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
abstract AccountServiceAsync accounts()
-
accountNumbers
abstract AccountNumberServiceAsync accountNumbers()
-
accountTransfers
abstract AccountTransferServiceAsync accountTransfers()
-
cards
abstract CardServiceAsync cards()
-
cardPayments
abstract CardPaymentServiceAsync cardPayments()
-
cardPurchaseSupplements
abstract CardPurchaseSupplementServiceAsync cardPurchaseSupplements()
-
cardDisputes
abstract CardDisputeServiceAsync cardDisputes()
-
physicalCards
abstract PhysicalCardServiceAsync physicalCards()
-
digitalCardProfiles
abstract DigitalCardProfileServiceAsync digitalCardProfiles()
-
physicalCardProfiles
abstract PhysicalCardProfileServiceAsync physicalCardProfiles()
-
digitalWalletTokens
abstract DigitalWalletTokenServiceAsync digitalWalletTokens()
-
transactions
abstract TransactionServiceAsync transactions()
-
pendingTransactions
abstract PendingTransactionServiceAsync pendingTransactions()
-
declinedTransactions
abstract DeclinedTransactionServiceAsync declinedTransactions()
-
achTransfers
abstract AchTransferServiceAsync achTransfers()
-
inboundAchTransfers
abstract InboundAchTransferServiceAsync inboundAchTransfers()
-
achPrenotifications
abstract AchPrenotificationServiceAsync achPrenotifications()
-
wireTransfers
abstract WireTransferServiceAsync wireTransfers()
-
inboundWireTransfers
abstract InboundWireTransferServiceAsync inboundWireTransfers()
-
wireDrawdownRequests
abstract WireDrawdownRequestServiceAsync wireDrawdownRequests()
-
inboundWireDrawdownRequests
abstract InboundWireDrawdownRequestServiceAsync inboundWireDrawdownRequests()
-
checkTransfers
abstract CheckTransferServiceAsync checkTransfers()
-
inboundCheckDeposits
abstract InboundCheckDepositServiceAsync inboundCheckDeposits()
-
realTimePaymentsTransfers
abstract RealTimePaymentsTransferServiceAsync realTimePaymentsTransfers()
-
inboundRealTimePaymentsTransfers
abstract InboundRealTimePaymentsTransferServiceAsync inboundRealTimePaymentsTransfers()
-
fednowTransfers
abstract FednowTransferServiceAsync fednowTransfers()
-
inboundFednowTransfers
abstract InboundFednowTransferServiceAsync inboundFednowTransfers()
-
swiftTransfers
abstract SwiftTransferServiceAsync swiftTransfers()
-
checkDeposits
abstract CheckDepositServiceAsync checkDeposits()
-
lockboxAddresses
abstract LockboxAddressServiceAsync lockboxAddresses()
-
lockboxRecipients
abstract LockboxRecipientServiceAsync lockboxRecipients()
-
inboundMailItems
abstract InboundMailItemServiceAsync inboundMailItems()
-
routingNumbers
abstract RoutingNumberServiceAsync routingNumbers()
-
externalAccounts
abstract ExternalAccountServiceAsync externalAccounts()
-
entities
abstract EntityServiceAsync entities()
-
beneficialOwners
abstract BeneficialOwnerServiceAsync beneficialOwners()
-
supplementalDocuments
abstract SupplementalDocumentServiceAsync supplementalDocuments()
-
entityOnboardingSessions
abstract EntityOnboardingSessionServiceAsync entityOnboardingSessions()
-
programs
abstract ProgramServiceAsync programs()
-
accountStatements
abstract AccountStatementServiceAsync accountStatements()
-
files
abstract FileServiceAsync files()
-
fileLinks
abstract FileLinkServiceAsync fileLinks()
-
exports
abstract ExportServiceAsync exports()
-
events
abstract EventServiceAsync events()
-
eventSubscriptions
abstract EventSubscriptionServiceAsync eventSubscriptions()
-
realTimeDecisions
abstract RealTimeDecisionServiceAsync realTimeDecisions()
-
groups
abstract GroupServiceAsync groups()
-
oauthApplications
abstract OAuthApplicationServiceAsync oauthApplications()
-
oauthConnections
abstract OAuthConnectionServiceAsync oauthConnections()
-
oauthTokens
abstract OAuthTokenServiceAsync oauthTokens()
-
intrafiAccountEnrollments
abstract IntrafiAccountEnrollmentServiceAsync intrafiAccountEnrollments()
-
intrafiBalances
abstract IntrafiBalanceServiceAsync intrafiBalances()
-
intrafiExclusions
abstract IntrafiExclusionServiceAsync intrafiExclusions()
-
cardTokens
abstract CardTokenServiceAsync cardTokens()
-
cardPushTransfers
abstract CardPushTransferServiceAsync cardPushTransfers()
-
cardValidations
abstract CardValidationServiceAsync cardValidations()
-
simulations
abstract SimulationServiceAsync simulations()
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-