Class IncreaseClientAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.client.IncreaseClientAsync
public final class IncreaseClientAsyncImpl implements IncreaseClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIncreaseClientAsyncImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description IncreaseClientAsyncImpl(ClientOptions clientOptions)
-
Method Summary
-
-
Constructor Detail
-
IncreaseClientAsyncImpl
IncreaseClientAsyncImpl(ClientOptions clientOptions)
-
-
Method Detail
-
sync
IncreaseClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
IncreaseClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IncreaseClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
AccountServiceAsync accounts()
-
accountNumbers
AccountNumberServiceAsync accountNumbers()
-
accountTransfers
AccountTransferServiceAsync accountTransfers()
-
cards
CardServiceAsync cards()
-
cardPayments
CardPaymentServiceAsync cardPayments()
-
cardPurchaseSupplements
CardPurchaseSupplementServiceAsync cardPurchaseSupplements()
-
cardDisputes
CardDisputeServiceAsync cardDisputes()
-
physicalCards
PhysicalCardServiceAsync physicalCards()
-
digitalCardProfiles
DigitalCardProfileServiceAsync digitalCardProfiles()
-
physicalCardProfiles
PhysicalCardProfileServiceAsync physicalCardProfiles()
-
digitalWalletTokens
DigitalWalletTokenServiceAsync digitalWalletTokens()
-
transactions
TransactionServiceAsync transactions()
-
pendingTransactions
PendingTransactionServiceAsync pendingTransactions()
-
declinedTransactions
DeclinedTransactionServiceAsync declinedTransactions()
-
achTransfers
AchTransferServiceAsync achTransfers()
-
inboundAchTransfers
InboundAchTransferServiceAsync inboundAchTransfers()
-
achPrenotifications
AchPrenotificationServiceAsync achPrenotifications()
-
wireTransfers
WireTransferServiceAsync wireTransfers()
-
inboundWireTransfers
InboundWireTransferServiceAsync inboundWireTransfers()
-
wireDrawdownRequests
WireDrawdownRequestServiceAsync wireDrawdownRequests()
-
inboundWireDrawdownRequests
InboundWireDrawdownRequestServiceAsync inboundWireDrawdownRequests()
-
checkTransfers
CheckTransferServiceAsync checkTransfers()
-
inboundCheckDeposits
InboundCheckDepositServiceAsync inboundCheckDeposits()
-
realTimePaymentsTransfers
RealTimePaymentsTransferServiceAsync realTimePaymentsTransfers()
-
inboundRealTimePaymentsTransfers
InboundRealTimePaymentsTransferServiceAsync inboundRealTimePaymentsTransfers()
-
fednowTransfers
FednowTransferServiceAsync fednowTransfers()
-
inboundFednowTransfers
InboundFednowTransferServiceAsync inboundFednowTransfers()
-
swiftTransfers
SwiftTransferServiceAsync swiftTransfers()
-
checkDeposits
CheckDepositServiceAsync checkDeposits()
-
lockboxAddresses
LockboxAddressServiceAsync lockboxAddresses()
-
lockboxRecipients
LockboxRecipientServiceAsync lockboxRecipients()
-
inboundMailItems
InboundMailItemServiceAsync inboundMailItems()
-
routingNumbers
RoutingNumberServiceAsync routingNumbers()
-
externalAccounts
ExternalAccountServiceAsync externalAccounts()
-
entities
EntityServiceAsync entities()
-
beneficialOwners
BeneficialOwnerServiceAsync beneficialOwners()
-
supplementalDocuments
SupplementalDocumentServiceAsync supplementalDocuments()
-
entityOnboardingSessions
EntityOnboardingSessionServiceAsync entityOnboardingSessions()
-
programs
ProgramServiceAsync programs()
-
accountStatements
AccountStatementServiceAsync accountStatements()
-
files
FileServiceAsync files()
-
fileLinks
FileLinkServiceAsync fileLinks()
-
exports
ExportServiceAsync exports()
-
events
EventServiceAsync events()
-
eventSubscriptions
EventSubscriptionServiceAsync eventSubscriptions()
-
realTimeDecisions
RealTimeDecisionServiceAsync realTimeDecisions()
-
groups
GroupServiceAsync groups()
-
oauthApplications
OAuthApplicationServiceAsync oauthApplications()
-
oauthConnections
OAuthConnectionServiceAsync oauthConnections()
-
oauthTokens
OAuthTokenServiceAsync oauthTokens()
-
intrafiAccountEnrollments
IntrafiAccountEnrollmentServiceAsync intrafiAccountEnrollments()
-
intrafiBalances
IntrafiBalanceServiceAsync intrafiBalances()
-
intrafiExclusions
IntrafiExclusionServiceAsync intrafiExclusions()
-
cardTokens
CardTokenServiceAsync cardTokens()
-
cardPushTransfers
CardPushTransferServiceAsync cardPushTransfers()
-
cardValidations
CardValidationServiceAsync cardValidations()
-
simulations
SimulationServiceAsync simulations()
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-