Class IncreaseClientImpl
-
- All Implemented Interfaces:
-
com.increase.api.client.IncreaseClient
public final class IncreaseClientImpl implements IncreaseClient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIncreaseClientImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description IncreaseClientImpl(ClientOptions clientOptions)
-
Method Summary
-
-
Constructor Detail
-
IncreaseClientImpl
IncreaseClientImpl(ClientOptions clientOptions)
-
-
Method Detail
-
async
IncreaseClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
IncreaseClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IncreaseClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
accounts
AccountService accounts()
-
accountNumbers
AccountNumberService accountNumbers()
-
accountTransfers
AccountTransferService accountTransfers()
-
cards
CardService cards()
-
cardPayments
CardPaymentService cardPayments()
-
cardPurchaseSupplements
CardPurchaseSupplementService cardPurchaseSupplements()
-
cardDisputes
CardDisputeService cardDisputes()
-
physicalCards
PhysicalCardService physicalCards()
-
digitalCardProfiles
DigitalCardProfileService digitalCardProfiles()
-
physicalCardProfiles
PhysicalCardProfileService physicalCardProfiles()
-
digitalWalletTokens
DigitalWalletTokenService digitalWalletTokens()
-
transactions
TransactionService transactions()
-
pendingTransactions
PendingTransactionService pendingTransactions()
-
declinedTransactions
DeclinedTransactionService declinedTransactions()
-
achTransfers
AchTransferService achTransfers()
-
achPrenotifications
AchPrenotificationService achPrenotifications()
-
inboundAchTransfers
InboundAchTransferService inboundAchTransfers()
-
wireTransfers
WireTransferService wireTransfers()
-
inboundWireTransfers
InboundWireTransferService inboundWireTransfers()
-
wireDrawdownRequests
WireDrawdownRequestService wireDrawdownRequests()
-
inboundWireDrawdownRequests
InboundWireDrawdownRequestService inboundWireDrawdownRequests()
-
checkTransfers
CheckTransferService checkTransfers()
-
inboundCheckDeposits
InboundCheckDepositService inboundCheckDeposits()
-
realTimePaymentsTransfers
RealTimePaymentsTransferService realTimePaymentsTransfers()
-
inboundRealTimePaymentsTransfers
InboundRealTimePaymentsTransferService inboundRealTimePaymentsTransfers()
-
fednowTransfers
FednowTransferService fednowTransfers()
-
inboundFednowTransfers
InboundFednowTransferService inboundFednowTransfers()
-
swiftTransfers
SwiftTransferService swiftTransfers()
-
checkDeposits
CheckDepositService checkDeposits()
-
lockboxes
LockboxService lockboxes()
-
inboundMailItems
InboundMailItemService inboundMailItems()
-
routingNumbers
RoutingNumberService routingNumbers()
-
externalAccounts
ExternalAccountService externalAccounts()
-
entities
EntityService entities()
-
beneficialOwners
BeneficialOwnerService beneficialOwners()
-
supplementalDocuments
SupplementalDocumentService supplementalDocuments()
-
programs
ProgramService programs()
-
accountStatements
AccountStatementService accountStatements()
-
files
FileService files()
-
fileLinks
FileLinkService fileLinks()
-
exports
ExportService exports()
-
events
EventService events()
-
eventSubscriptions
EventSubscriptionService eventSubscriptions()
-
realTimeDecisions
RealTimeDecisionService realTimeDecisions()
-
bookkeepingAccounts
BookkeepingAccountService bookkeepingAccounts()
-
bookkeepingEntrySets
BookkeepingEntrySetService bookkeepingEntrySets()
-
bookkeepingEntries
BookkeepingEntryService bookkeepingEntries()
-
groups
GroupService groups()
-
oauthApplications
OAuthApplicationService oauthApplications()
-
oauthConnections
OAuthConnectionService oauthConnections()
-
oauthTokens
OAuthTokenService oauthTokens()
-
intrafiAccountEnrollments
IntrafiAccountEnrollmentService intrafiAccountEnrollments()
-
intrafiBalances
IntrafiBalanceService intrafiBalances()
-
intrafiExclusions
IntrafiExclusionService intrafiExclusions()
-
cardTokens
CardTokenService cardTokens()
-
cardPushTransfers
CardPushTransferService cardPushTransfers()
-
cardValidations
CardValidationService cardValidations()
-
simulations
SimulationService simulations()
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-