Class IncreaseOkHttpClient.Builder
-
- All Implemented Interfaces:
public final class IncreaseOkHttpClient.BuilderA builder for IncreaseOkHttpClient.
-
-
Method Summary
Modifier and Type Method Description final IncreaseOkHttpClient.BuilderdispatcherExecutorService(ExecutorService dispatcherExecutorService)The executor service to use for running HTTP requests. final IncreaseOkHttpClient.BuilderdispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)Alias for calling Builder.dispatcherExecutorService with dispatcherExecutorService.orElse(null).final IncreaseOkHttpClient.Builderproxy(Proxy proxy)final IncreaseOkHttpClient.Builderproxy(Optional<Proxy> proxy)Alias for calling Builder.proxy with proxy.orElse(null).final IncreaseOkHttpClient.BuilderproxyAuthenticator(ProxyAuthenticator proxyAuthenticator)Provides credentials when an HTTP proxy responds with 407 Proxy Authentication Required.final IncreaseOkHttpClient.BuilderproxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)Alias for calling Builder.proxyAuthenticator with proxyAuthenticator.orElse(null).final IncreaseOkHttpClient.BuildermaxIdleConnections(Integer maxIdleConnections)The maximum number of idle connections kept by the underlying OkHttp connection pool. final IncreaseOkHttpClient.BuildermaxIdleConnections(Integer maxIdleConnections)Alias for Builder.maxIdleConnections. final IncreaseOkHttpClient.BuildermaxIdleConnections(Optional<Integer> maxIdleConnections)Alias for calling Builder.maxIdleConnections with maxIdleConnections.orElse(null).final IncreaseOkHttpClient.BuilderkeepAliveDuration(Duration keepAliveDuration)The keep-alive duration for idle connections in the underlying OkHttp connection pool. final IncreaseOkHttpClient.BuilderkeepAliveDuration(Optional<Duration> keepAliveDuration)Alias for calling Builder.keepAliveDuration with keepAliveDuration.orElse(null).final IncreaseOkHttpClient.BuildersslSocketFactory(SSLSocketFactory sslSocketFactory)The socket factory used to secure HTTPS connections. final IncreaseOkHttpClient.BuildersslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)Alias for calling Builder.sslSocketFactory with sslSocketFactory.orElse(null).final IncreaseOkHttpClient.BuildertrustManager(X509TrustManager trustManager)The trust manager used to secure HTTPS connections. final IncreaseOkHttpClient.BuildertrustManager(Optional<X509TrustManager> trustManager)Alias for calling Builder.trustManager with trustManager.orElse(null).final IncreaseOkHttpClient.BuilderhostnameVerifier(HostnameVerifier hostnameVerifier)The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections. final IncreaseOkHttpClient.BuilderhostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)Alias for calling Builder.hostnameVerifier with hostnameVerifier.orElse(null).final IncreaseOkHttpClient.BuildercheckJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4). final IncreaseOkHttpClient.BuilderjsonMapper(JsonMapper jsonMapper)The Jackson JSON mapper to use for serializing and deserializing JSON. final IncreaseOkHttpClient.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)The executor to use for running AsyncStreamResponse.Handler callbacks. final IncreaseOkHttpClient.Buildersleeper(Sleeper sleeper)The interface to use for delaying execution, like during retries. final IncreaseOkHttpClient.Builderclock(Clock clock)The clock to use for operations that require timing, like retries. final IncreaseOkHttpClient.BuilderbaseUrl(String baseUrl)The base URL to use for every request. final IncreaseOkHttpClient.BuilderbaseUrl(Optional<String> baseUrl)Alias for calling Builder.baseUrl with baseUrl.orElse(null).final IncreaseOkHttpClient.Buildersandbox()Sets baseUrl to https://sandbox.increase.com.final IncreaseOkHttpClient.BuilderresponseValidation(Boolean responseValidation)Whether to call validateon every response before returning it.final IncreaseOkHttpClient.Buildertimeout(Timeout timeout)Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries. final IncreaseOkHttpClient.Buildertimeout(Duration timeout)Sets the maximum time allowed for a complete HTTP call, not including retries. final IncreaseOkHttpClient.BuildermaxRetries(Integer maxRetries)The maximum number of times to retry failed requests, with a short exponential backoff between requests. final IncreaseOkHttpClient.BuilderlogLevel(LogLevel logLevel)The level at which to log request and response information. final IncreaseOkHttpClient.BuilderapiKey(String apiKey)final IncreaseOkHttpClient.BuilderwebhookSecret(String webhookSecret)final IncreaseOkHttpClient.BuilderwebhookSecret(Optional<String> webhookSecret)Alias for calling Builder.webhookSecret with webhookSecret.orElse(null).final IncreaseOkHttpClient.Builderheaders(Headers headers)final IncreaseOkHttpClient.Builderheaders(Map<String, Iterable<String>> headers)final IncreaseOkHttpClient.BuilderputHeader(String name, String value)final IncreaseOkHttpClient.BuilderputHeaders(String name, Iterable<String> values)final IncreaseOkHttpClient.BuilderputAllHeaders(Headers headers)final IncreaseOkHttpClient.BuilderputAllHeaders(Map<String, Iterable<String>> headers)final IncreaseOkHttpClient.BuilderreplaceHeaders(String name, String value)final IncreaseOkHttpClient.BuilderreplaceHeaders(String name, Iterable<String> values)final IncreaseOkHttpClient.BuilderreplaceAllHeaders(Headers headers)final IncreaseOkHttpClient.BuilderreplaceAllHeaders(Map<String, Iterable<String>> headers)final IncreaseOkHttpClient.BuilderremoveHeaders(String name)final IncreaseOkHttpClient.BuilderremoveAllHeaders(Set<String> names)final IncreaseOkHttpClient.BuilderqueryParams(QueryParams queryParams)final IncreaseOkHttpClient.BuilderqueryParams(Map<String, Iterable<String>> queryParams)final IncreaseOkHttpClient.BuilderputQueryParam(String key, String value)final IncreaseOkHttpClient.BuilderputQueryParams(String key, Iterable<String> values)final IncreaseOkHttpClient.BuilderputAllQueryParams(QueryParams queryParams)final IncreaseOkHttpClient.BuilderputAllQueryParams(Map<String, Iterable<String>> queryParams)final IncreaseOkHttpClient.BuilderreplaceQueryParams(String key, String value)final IncreaseOkHttpClient.BuilderreplaceQueryParams(String key, Iterable<String> values)final IncreaseOkHttpClient.BuilderreplaceAllQueryParams(QueryParams queryParams)final IncreaseOkHttpClient.BuilderreplaceAllQueryParams(Map<String, Iterable<String>> queryParams)final IncreaseOkHttpClient.BuilderremoveQueryParams(String key)final IncreaseOkHttpClient.BuilderremoveAllQueryParams(Set<String> keys)final IncreaseOkHttpClient.BuilderfromEnv()Updates configuration using system properties and environment variables. final IncreaseClientbuild()Returns an immutable instance of IncreaseClient. -
-
Method Detail
-
dispatcherExecutorService
final IncreaseOkHttpClient.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final IncreaseOkHttpClient.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final IncreaseOkHttpClient.Builder proxy(Proxy proxy)
-
proxy
final IncreaseOkHttpClient.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
proxyAuthenticator
final IncreaseOkHttpClient.Builder proxyAuthenticator(ProxyAuthenticator proxyAuthenticator)
Provides credentials when an HTTP proxy responds with
407 Proxy Authentication Required.
-
proxyAuthenticator
final IncreaseOkHttpClient.Builder proxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)
Alias for calling Builder.proxyAuthenticator with
proxyAuthenticator.orElse(null).
-
maxIdleConnections
final IncreaseOkHttpClient.Builder maxIdleConnections(Integer maxIdleConnections)
The maximum number of idle connections kept by the underlying OkHttp connection pool.
If this is set, then keepAliveDuration must also be set.
If unset, then OkHttp's default is used.
-
maxIdleConnections
final IncreaseOkHttpClient.Builder maxIdleConnections(Integer maxIdleConnections)
Alias for Builder.maxIdleConnections.
This unboxed primitive overload exists for backwards compatibility.
-
maxIdleConnections
final IncreaseOkHttpClient.Builder maxIdleConnections(Optional<Integer> maxIdleConnections)
Alias for calling Builder.maxIdleConnections with
maxIdleConnections.orElse(null).
-
keepAliveDuration
final IncreaseOkHttpClient.Builder keepAliveDuration(Duration keepAliveDuration)
The keep-alive duration for idle connections in the underlying OkHttp connection pool.
If this is set, then maxIdleConnections must also be set.
If unset, then OkHttp's default is used.
-
keepAliveDuration
final IncreaseOkHttpClient.Builder keepAliveDuration(Optional<Duration> keepAliveDuration)
Alias for calling Builder.keepAliveDuration with
keepAliveDuration.orElse(null).
-
sslSocketFactory
final IncreaseOkHttpClient.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final IncreaseOkHttpClient.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final IncreaseOkHttpClient.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final IncreaseOkHttpClient.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final IncreaseOkHttpClient.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final IncreaseOkHttpClient.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final IncreaseOkHttpClient.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final IncreaseOkHttpClient.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to com.increase.api.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
streamHandlerExecutor
final IncreaseOkHttpClient.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
The executor to use for running AsyncStreamResponse.Handler callbacks.
Defaults to a dedicated cached thread pool.
This class takes ownership of the executor and shuts it down, if possible, when closed.
-
sleeper
final IncreaseOkHttpClient.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final IncreaseOkHttpClient.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final IncreaseOkHttpClient.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.increase.com.The following other environments, with dedicated builder methods, are available:
sandbox:
https://sandbox.increase.com
-
baseUrl
final IncreaseOkHttpClient.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
sandbox
final IncreaseOkHttpClient.Builder sandbox()
Sets baseUrl to
https://sandbox.increase.com.
-
responseValidation
final IncreaseOkHttpClient.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Setting this to
trueis not forwards compatible with new types from the API for existing fields.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final IncreaseOkHttpClient.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final IncreaseOkHttpClient.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final IncreaseOkHttpClient.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
logLevel
final IncreaseOkHttpClient.Builder logLevel(LogLevel logLevel)
The level at which to log request and response information.
fromEnv will set the level from environment variables. See LogLevel.fromEnv.
Defaults to LogLevel.fromEnv.
-
apiKey
final IncreaseOkHttpClient.Builder apiKey(String apiKey)
-
webhookSecret
final IncreaseOkHttpClient.Builder webhookSecret(String webhookSecret)
-
webhookSecret
final IncreaseOkHttpClient.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final IncreaseOkHttpClient.Builder headers(Headers headers)
-
putHeader
final IncreaseOkHttpClient.Builder putHeader(String name, String value)
-
putHeaders
final IncreaseOkHttpClient.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final IncreaseOkHttpClient.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final IncreaseOkHttpClient.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final IncreaseOkHttpClient.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final IncreaseOkHttpClient.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final IncreaseOkHttpClient.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final IncreaseOkHttpClient.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final IncreaseOkHttpClient.Builder removeHeaders(String name)
-
removeAllHeaders
final IncreaseOkHttpClient.Builder removeAllHeaders(Set<String> names)
-
queryParams
final IncreaseOkHttpClient.Builder queryParams(QueryParams queryParams)
-
queryParams
final IncreaseOkHttpClient.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final IncreaseOkHttpClient.Builder putQueryParam(String key, String value)
-
putQueryParams
final IncreaseOkHttpClient.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final IncreaseOkHttpClient.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final IncreaseOkHttpClient.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final IncreaseOkHttpClient.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final IncreaseOkHttpClient.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final IncreaseOkHttpClient.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final IncreaseOkHttpClient.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final IncreaseOkHttpClient.Builder removeQueryParams(String key)
-
removeAllQueryParams
final IncreaseOkHttpClient.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final IncreaseOkHttpClient.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final IncreaseClient build()
Returns an immutable instance of IncreaseClient.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-