Package com.increase.api.client.okhttp
Class IncreaseOkHttpClientAsync
-
- All Implemented Interfaces:
public final class IncreaseOkHttpClientAsyncA class that allows building an instance of IncreaseClientAsync with OkHttpClient as the underlying HttpClient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIncreaseOkHttpClientAsync.BuilderA builder for IncreaseOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static IncreaseOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of IncreaseClientAsync. final static IncreaseClientAsyncfromEnv()Returns a client configured using system properties and environment variables. -
-
Method Detail
-
builder
final static IncreaseOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of IncreaseClientAsync.
-
fromEnv
final static IncreaseClientAsync fromEnv()
Returns a client configured using system properties and environment variables.
-
-
-
-