Class IncreaseOkHttpClientAsync.Builder
-
- All Implemented Interfaces:
public final class IncreaseOkHttpClientAsync.BuilderA builder for IncreaseOkHttpClientAsync.
-
-
Method Summary
-
-
Method Detail
-
dispatcherExecutorService
final IncreaseOkHttpClientAsync.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final IncreaseOkHttpClientAsync.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final IncreaseOkHttpClientAsync.Builder proxy(Proxy proxy)
-
proxy
final IncreaseOkHttpClientAsync.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
maxIdleConnections
final IncreaseOkHttpClientAsync.Builder maxIdleConnections(Integer maxIdleConnections)
The maximum number of idle connections kept by the underlying OkHttp connection pool.
If this is set, then keepAliveDuration must also be set.
If unset, then OkHttp's default is used.
-
maxIdleConnections
final IncreaseOkHttpClientAsync.Builder maxIdleConnections(Integer maxIdleConnections)
Alias for Builder.maxIdleConnections.
This unboxed primitive overload exists for backwards compatibility.
-
maxIdleConnections
final IncreaseOkHttpClientAsync.Builder maxIdleConnections(Optional<Integer> maxIdleConnections)
Alias for calling Builder.maxIdleConnections with
maxIdleConnections.orElse(null).
-
keepAliveDuration
final IncreaseOkHttpClientAsync.Builder keepAliveDuration(Duration keepAliveDuration)
The keep-alive duration for idle connections in the underlying OkHttp connection pool.
If this is set, then maxIdleConnections must also be set.
If unset, then OkHttp's default is used.
-
keepAliveDuration
final IncreaseOkHttpClientAsync.Builder keepAliveDuration(Optional<Duration> keepAliveDuration)
Alias for calling Builder.keepAliveDuration with
keepAliveDuration.orElse(null).
-
sslSocketFactory
final IncreaseOkHttpClientAsync.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final IncreaseOkHttpClientAsync.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final IncreaseOkHttpClientAsync.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final IncreaseOkHttpClientAsync.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final IncreaseOkHttpClientAsync.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final IncreaseOkHttpClientAsync.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final IncreaseOkHttpClientAsync.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final IncreaseOkHttpClientAsync.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to com.increase.api.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
streamHandlerExecutor
final IncreaseOkHttpClientAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
The executor to use for running AsyncStreamResponse.Handler callbacks.
Defaults to a dedicated cached thread pool.
This class takes ownership of the executor and shuts it down, if possible, when closed.
-
sleeper
final IncreaseOkHttpClientAsync.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final IncreaseOkHttpClientAsync.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final IncreaseOkHttpClientAsync.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.increase.com.The following other environments, with dedicated builder methods, are available:
sandbox:
https://sandbox.increase.com
-
baseUrl
final IncreaseOkHttpClientAsync.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
sandbox
final IncreaseOkHttpClientAsync.Builder sandbox()
Sets baseUrl to
https://sandbox.increase.com.
-
responseValidation
final IncreaseOkHttpClientAsync.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final IncreaseOkHttpClientAsync.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final IncreaseOkHttpClientAsync.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final IncreaseOkHttpClientAsync.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
apiKey
final IncreaseOkHttpClientAsync.Builder apiKey(String apiKey)
-
webhookSecret
final IncreaseOkHttpClientAsync.Builder webhookSecret(String webhookSecret)
-
webhookSecret
final IncreaseOkHttpClientAsync.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final IncreaseOkHttpClientAsync.Builder headers(Headers headers)
-
putHeader
final IncreaseOkHttpClientAsync.Builder putHeader(String name, String value)
-
putHeaders
final IncreaseOkHttpClientAsync.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final IncreaseOkHttpClientAsync.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final IncreaseOkHttpClientAsync.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final IncreaseOkHttpClientAsync.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final IncreaseOkHttpClientAsync.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final IncreaseOkHttpClientAsync.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final IncreaseOkHttpClientAsync.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final IncreaseOkHttpClientAsync.Builder removeHeaders(String name)
-
removeAllHeaders
final IncreaseOkHttpClientAsync.Builder removeAllHeaders(Set<String> names)
-
queryParams
final IncreaseOkHttpClientAsync.Builder queryParams(QueryParams queryParams)
-
queryParams
final IncreaseOkHttpClientAsync.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final IncreaseOkHttpClientAsync.Builder putQueryParam(String key, String value)
-
putQueryParams
final IncreaseOkHttpClientAsync.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final IncreaseOkHttpClientAsync.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final IncreaseOkHttpClientAsync.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final IncreaseOkHttpClientAsync.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final IncreaseOkHttpClientAsync.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final IncreaseOkHttpClientAsync.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final IncreaseOkHttpClientAsync.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final IncreaseOkHttpClientAsync.Builder removeQueryParams(String key)
-
removeAllQueryParams
final IncreaseOkHttpClientAsync.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final IncreaseOkHttpClientAsync.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final IncreaseClientAsync build()
Returns an immutable instance of IncreaseClientAsync.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-