Class Account
-
- All Implemented Interfaces:
public final class AccountAccounts are your bank accounts with Increase. They store money, receive transfers, and send payments. They earn interest and have depository insurance.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.BuilderA builder for Account.
public final classAccount.BankThe bank the Account is with.
public final classAccount.CurrencyThe ISO 4217 code for the Account currency.
public final classAccount.StatusThe status of the Account.
public final classAccount.TypeA constant representing the object's type. For this resource it will always be
account.
-
Method Summary
Modifier and Type Method Description final Stringid()The Account identifier. final Account.Bankbank()The bank the Account is with. final Optional<OffsetDateTime>closedAt()The ISO 8601 time at which the Account was closed. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Account was created. final Account.Currencycurrency()The ISO 4217 code for the Account currency. final Optional<String>entityId()The identifier for the Entity the Account belongs to. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final StringinterestAccrued()The interest accrued but not yet paid, expressed as a string containing a floating-point value. final Optional<LocalDate>interestAccruedAt()The latest ISO 8601 date on which interest was accrued. final StringinterestRate()The Interest Rate currently being earned on the account, as a string containing a decimal number. final Stringname()The name you choose for the Account. final StringprogramId()The identifier of the Program determining the compliance and commercial terms of this Account. final Account.Statusstatus()The status of the Account. final Account.Typetype()A constant representing the object's type. final JsonField<String>_id()The Account identifier. final JsonField<Account.Bank>_bank()The bank the Account is with. final JsonField<OffsetDateTime>_closedAt()The ISO 8601 time at which the Account was closed. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Account was created. final JsonField<Account.Currency>_currency()The ISO 4217 code for the Account currency. final JsonField<String>_entityId()The identifier for the Entity the Account belongs to. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final JsonField<String>_interestAccrued()The interest accrued but not yet paid, expressed as a string containing a floating-point value. final JsonField<LocalDate>_interestAccruedAt()The latest ISO 8601 date on which interest was accrued. final JsonField<String>_interestRate()The Interest Rate currently being earned on the account, as a string containing a decimal number. final JsonField<String>_name()The name you choose for the Account. final JsonField<String>_programId()The identifier of the Program determining the compliance and commercial terms of this Account. final JsonField<Account.Status>_status()The status of the Account. final JsonField<Account.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Accountvalidate()final Account.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.Builderbuilder()-
-
Method Detail
-
bank
final Account.Bank bank()
The bank the Account is with.
-
closedAt
final Optional<OffsetDateTime> closedAt()
The ISO 8601 time at which the Account was closed.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Account was created.
-
currency
final Account.Currency currency()
The ISO 4217 code for the Account currency.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
informationalEntityId
final Optional<String> informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
interestAccrued
final String interestAccrued()
The interest accrued but not yet paid, expressed as a string containing a floating-point value.
-
interestAccruedAt
final Optional<LocalDate> interestAccruedAt()
The latest ISO 8601 date on which interest was accrued.
-
interestRate
final String interestRate()
The Interest Rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
programId
final String programId()
The identifier of the Program determining the compliance and commercial terms of this Account.
-
status
final Account.Status status()
The status of the Account.
-
type
final Account.Type type()
A constant representing the object's type. For this resource it will always be
account.
-
_bank
final JsonField<Account.Bank> _bank()
The bank the Account is with.
-
_closedAt
final JsonField<OffsetDateTime> _closedAt()
The ISO 8601 time at which the Account was closed.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Account was created.
-
_currency
final JsonField<Account.Currency> _currency()
The ISO 4217 code for the Account currency.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_informationalEntityId
final JsonField<String> _informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
_interestAccrued
final JsonField<String> _interestAccrued()
The interest accrued but not yet paid, expressed as a string containing a floating-point value.
-
_interestAccruedAt
final JsonField<LocalDate> _interestAccruedAt()
The latest ISO 8601 date on which interest was accrued.
-
_interestRate
final JsonField<String> _interestRate()
The Interest Rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
_programId
final JsonField<String> _programId()
The identifier of the Program determining the compliance and commercial terms of this Account.
-
_status
final JsonField<Account.Status> _status()
The status of the Account.
-
_type
final JsonField<Account.Type> _type()
A constant representing the object's type. For this resource it will always be
account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Account.Builder toBuilder()
-
builder
final static Account.Builder builder()
-
-
-
-