Class Account.Builder
-
- All Implemented Interfaces:
public final class Account.BuilderA builder for Account.
-
-
Method Summary
Modifier and Type Method Description final Account.Builderid(String id)The Account identifier. final Account.Builderid(JsonField<String> id)The Account identifier. final Account.Builderbank(Account.Bank bank)The bank the Account is with. final Account.Builderbank(JsonField<Account.Bank> bank)The bank the Account is with. final Account.BuilderclosedAt(OffsetDateTime closedAt)The ISO 8601 time at which the Account was closed. final Account.BuilderclosedAt(Optional<OffsetDateTime> closedAt)The ISO 8601 time at which the Account was closed. final Account.BuilderclosedAt(JsonField<OffsetDateTime> closedAt)The ISO 8601 time at which the Account was closed. final Account.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Account was created. final Account.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 time at which the Account was created. final Account.Buildercurrency(Account.Currency currency)The ISO 4217 code for the Account currency. final Account.Buildercurrency(JsonField<Account.Currency> currency)The ISO 4217 code for the Account currency. final Account.BuilderentityId(String entityId)The identifier for the Entity the Account belongs to. final Account.BuilderentityId(Optional<String> entityId)The identifier for the Entity the Account belongs to. final Account.BuilderentityId(JsonField<String> entityId)The identifier for the Entity the Account belongs to. final Account.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Account.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final Account.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final Account.BuilderinformationalEntityId(String informationalEntityId)The identifier of an Entity that, while not owning the Account, is associated with its activity. final Account.BuilderinformationalEntityId(Optional<String> informationalEntityId)The identifier of an Entity that, while not owning the Account, is associated with its activity. final Account.BuilderinformationalEntityId(JsonField<String> informationalEntityId)The identifier of an Entity that, while not owning the Account, is associated with its activity. final Account.BuilderinterestAccrued(String interestAccrued)The interest accrued but not yet paid, expressed as a string containing a floating-point value. final Account.BuilderinterestAccrued(JsonField<String> interestAccrued)The interest accrued but not yet paid, expressed as a string containing a floating-point value. final Account.BuilderinterestAccruedAt(LocalDate interestAccruedAt)The latest ISO 8601 date on which interest was accrued. final Account.BuilderinterestAccruedAt(Optional<LocalDate> interestAccruedAt)The latest ISO 8601 date on which interest was accrued. final Account.BuilderinterestAccruedAt(JsonField<LocalDate> interestAccruedAt)The latest ISO 8601 date on which interest was accrued. final Account.BuilderinterestRate(String interestRate)The Interest Rate currently being earned on the account, as a string containing a decimal number. final Account.BuilderinterestRate(JsonField<String> interestRate)The Interest Rate currently being earned on the account, as a string containing a decimal number. final Account.Buildername(String name)The name you choose for the Account. final Account.Buildername(JsonField<String> name)The name you choose for the Account. final Account.BuilderprogramId(String programId)The identifier of the Program determining the compliance and commercial terms of this Account. final Account.BuilderprogramId(JsonField<String> programId)The identifier of the Program determining the compliance and commercial terms of this Account. final Account.Builderstatus(Account.Status status)The status of the Account. final Account.Builderstatus(JsonField<Account.Status> status)The status of the Account. final Account.Buildertype(Account.Type type)A constant representing the object's type. final Account.Buildertype(JsonField<Account.Type> type)A constant representing the object's type. final Account.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Account.BuilderputAdditionalProperty(String key, JsonValue value)final Account.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Account.BuilderremoveAdditionalProperty(String key)final Account.BuilderremoveAllAdditionalProperties(Set<String> keys)final Accountbuild()-
-
Method Detail
-
id
final Account.Builder id(String id)
The Account identifier.
-
id
final Account.Builder id(JsonField<String> id)
The Account identifier.
-
bank
final Account.Builder bank(Account.Bank bank)
The bank the Account is with.
-
bank
final Account.Builder bank(JsonField<Account.Bank> bank)
The bank the Account is with.
-
closedAt
final Account.Builder closedAt(OffsetDateTime closedAt)
The ISO 8601 time at which the Account was closed.
-
closedAt
final Account.Builder closedAt(Optional<OffsetDateTime> closedAt)
The ISO 8601 time at which the Account was closed.
-
closedAt
final Account.Builder closedAt(JsonField<OffsetDateTime> closedAt)
The ISO 8601 time at which the Account was closed.
-
createdAt
final Account.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Account was created.
-
createdAt
final Account.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Account was created.
-
currency
final Account.Builder currency(Account.Currency currency)
The ISO 4217 code for the Account currency.
-
currency
final Account.Builder currency(JsonField<Account.Currency> currency)
The ISO 4217 code for the Account currency.
-
entityId
final Account.Builder entityId(String entityId)
The identifier for the Entity the Account belongs to.
-
entityId
final Account.Builder entityId(Optional<String> entityId)
The identifier for the Entity the Account belongs to.
-
entityId
final Account.Builder entityId(JsonField<String> entityId)
The identifier for the Entity the Account belongs to.
-
idempotencyKey
final Account.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Account.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Account.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
informationalEntityId
final Account.Builder informationalEntityId(String informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
informationalEntityId
final Account.Builder informationalEntityId(Optional<String> informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
informationalEntityId
final Account.Builder informationalEntityId(JsonField<String> informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
interestAccrued
final Account.Builder interestAccrued(String interestAccrued)
The interest accrued but not yet paid, expressed as a string containing a floating-point value.
-
interestAccrued
final Account.Builder interestAccrued(JsonField<String> interestAccrued)
The interest accrued but not yet paid, expressed as a string containing a floating-point value.
-
interestAccruedAt
final Account.Builder interestAccruedAt(LocalDate interestAccruedAt)
The latest ISO 8601 date on which interest was accrued.
-
interestAccruedAt
final Account.Builder interestAccruedAt(Optional<LocalDate> interestAccruedAt)
The latest ISO 8601 date on which interest was accrued.
-
interestAccruedAt
final Account.Builder interestAccruedAt(JsonField<LocalDate> interestAccruedAt)
The latest ISO 8601 date on which interest was accrued.
-
interestRate
final Account.Builder interestRate(String interestRate)
The Interest Rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
interestRate
final Account.Builder interestRate(JsonField<String> interestRate)
The Interest Rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
name
final Account.Builder name(String name)
The name you choose for the Account.
-
name
final Account.Builder name(JsonField<String> name)
The name you choose for the Account.
-
programId
final Account.Builder programId(String programId)
The identifier of the Program determining the compliance and commercial terms of this Account.
-
programId
final Account.Builder programId(JsonField<String> programId)
The identifier of the Program determining the compliance and commercial terms of this Account.
-
status
final Account.Builder status(Account.Status status)
The status of the Account.
-
status
final Account.Builder status(JsonField<Account.Status> status)
The status of the Account.
-
type
final Account.Builder type(Account.Type type)
A constant representing the object's type. For this resource it will always be
account.
-
type
final Account.Builder type(JsonField<Account.Type> type)
A constant representing the object's type. For this resource it will always be
account.
-
additionalProperties
final Account.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Account.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Account.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Account.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Account.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-