Enum Account.Currency.Known

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      CAD

      Canadian Dollar (CAD)

      CHF

      Swiss Franc (CHF)

      EUR

      Euro (EUR)

      GBP

      British Pound (GBP)

      JPY

      Japanese Yen (JPY)

      USD

      US Dollar (USD)

    • Method Summary

      Modifier and Type Method Description
      final Account.Currency.Known valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<Account.Currency.Known> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<Account.Currency.Known> getEntries() An enum containing Currency's known values.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait