Package com.increase.api.models
Class AccountCreateParams.Body
-
- All Implemented Interfaces:
public final class AccountCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()The name you choose for the Account. final Optional<String>entityId()The identifier for the Entity that will own the Account. final Optional<String>informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final Optional<String>programId()The identifier for the Program that this Account falls under. final JsonField<String>_name()The name you choose for the Account. final JsonField<String>_entityId()The identifier for the Entity that will own the Account. final JsonField<String>_informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final JsonField<String>_programId()The identifier for the Program that this Account falls under. final Map<String, JsonValue>_additionalProperties()final AccountCreateParams.Bodyvalidate()final AccountCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountCreateParams.Body.Builderbuilder()-
-
Method Detail
-
informationalEntityId
final Optional<String> informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity. Its relationship to your group must be
informational.
-
programId
final Optional<String> programId()
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
_entityId
final JsonField<String> _entityId()
The identifier for the Entity that will own the Account.
-
_informationalEntityId
final JsonField<String> _informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity. Its relationship to your group must be
informational.
-
_programId
final JsonField<String> _programId()
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountCreateParams.Body validate()
-
toBuilder
final AccountCreateParams.Body.Builder toBuilder()
-
builder
final static AccountCreateParams.Body.Builder builder()
-
-
-
-