Package com.increase.api.models
Class AccountCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final AccountCreateParams.Body.Buildername(String name)The name you choose for the Account. final AccountCreateParams.Body.Buildername(JsonField<String> name)The name you choose for the Account. final AccountCreateParams.Body.BuilderentityId(String entityId)The identifier for the Entity that will own the Account. final AccountCreateParams.Body.BuilderentityId(JsonField<String> entityId)The identifier for the Entity that will own the Account. final AccountCreateParams.Body.BuilderinformationalEntityId(String informationalEntityId)The identifier of an Entity that, while not owning the Account, is associated with its activity. final AccountCreateParams.Body.BuilderinformationalEntityId(JsonField<String> informationalEntityId)The identifier of an Entity that, while not owning the Account, is associated with its activity. final AccountCreateParams.Body.BuilderprogramId(String programId)The identifier for the Program that this Account falls under. final AccountCreateParams.Body.BuilderprogramId(JsonField<String> programId)The identifier for the Program that this Account falls under. final AccountCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final AccountCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountCreateParams.Body.BuilderremoveAdditionalProperty(String key)final AccountCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountCreateParams.Bodybuild()-
-
Method Detail
-
name
final AccountCreateParams.Body.Builder name(String name)
The name you choose for the Account.
-
name
final AccountCreateParams.Body.Builder name(JsonField<String> name)
The name you choose for the Account.
-
entityId
final AccountCreateParams.Body.Builder entityId(String entityId)
The identifier for the Entity that will own the Account.
-
entityId
final AccountCreateParams.Body.Builder entityId(JsonField<String> entityId)
The identifier for the Entity that will own the Account.
-
informationalEntityId
final AccountCreateParams.Body.Builder informationalEntityId(String informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity. Its relationship to your group must be
informational.
-
informationalEntityId
final AccountCreateParams.Body.Builder informationalEntityId(JsonField<String> informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity. Its relationship to your group must be
informational.
-
programId
final AccountCreateParams.Body.Builder programId(String programId)
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
programId
final AccountCreateParams.Body.Builder programId(JsonField<String> programId)
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
additionalProperties
final AccountCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountCreateParams.Body build()
-
-
-
-