Class AccountNumber
-
- All Implemented Interfaces:
public final class AccountNumberEach account can have multiple account and routing numbers. We recommend that you use a set per vendor. This is similar to how you use different passwords for different websites. Account numbers can also be used to seamlessly reconcile inbound payments. Generating a unique account number per vendor ensures you always know the originator of an incoming payment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumber.BuilderA builder for AccountNumber.
public final classAccountNumber.InboundAchProperties related to how this Account Number handles inbound ACH transfers.
public final classAccountNumber.InboundChecksProperties related to how this Account Number should handle inbound check withdrawals.
public final classAccountNumber.StatusThis indicates if payments can be made to the Account Number.
public final classAccountNumber.TypeA constant representing the object's type. For this resource it will always be
account_number.
-
Method Summary
Modifier and Type Method Description final Stringid()The Account Number identifier. final StringaccountId()The identifier for the account this Account Number belongs to. final StringaccountNumber()The account number. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Account Number was created. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final AccountNumber.InboundAchinboundAch()Properties related to how this Account Number handles inbound ACH transfers. final AccountNumber.InboundChecksinboundChecks()Properties related to how this Account Number should handle inbound check withdrawals. final Stringname()The name you choose for the Account Number. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final AccountNumber.Statusstatus()This indicates if payments can be made to the Account Number. final AccountNumber.Typetype()A constant representing the object's type. final JsonField<String>_id()The Account Number identifier. final JsonField<String>_accountId()The identifier for the account this Account Number belongs to. final JsonField<String>_accountNumber()The account number. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Account Number was created. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<AccountNumber.InboundAch>_inboundAch()Properties related to how this Account Number handles inbound ACH transfers. final JsonField<AccountNumber.InboundChecks>_inboundChecks()Properties related to how this Account Number should handle inbound check withdrawals. final JsonField<String>_name()The name you choose for the Account Number. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<AccountNumber.Status>_status()This indicates if payments can be made to the Account Number. final JsonField<AccountNumber.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final AccountNumbervalidate()final AccountNumber.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumber.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Account Number was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundAch
final AccountNumber.InboundAch inboundAch()
Properties related to how this Account Number handles inbound ACH transfers.
-
inboundChecks
final AccountNumber.InboundChecks inboundChecks()
Properties related to how this Account Number should handle inbound check withdrawals.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final AccountNumber.Status status()
This indicates if payments can be made to the Account Number.
-
type
final AccountNumber.Type type()
A constant representing the object's type. For this resource it will always be
account_number.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account this Account Number belongs to.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Account Number was created.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_inboundAch
final JsonField<AccountNumber.InboundAch> _inboundAch()
Properties related to how this Account Number handles inbound ACH transfers.
-
_inboundChecks
final JsonField<AccountNumber.InboundChecks> _inboundChecks()
Properties related to how this Account Number should handle inbound check withdrawals.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_status
final JsonField<AccountNumber.Status> _status()
This indicates if payments can be made to the Account Number.
-
_type
final JsonField<AccountNumber.Type> _type()
A constant representing the object's type. For this resource it will always be
account_number.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountNumber validate()
-
toBuilder
final AccountNumber.Builder toBuilder()
-
builder
final static AccountNumber.Builder builder()
-
-
-
-