Class AccountNumber.Builder
-
- All Implemented Interfaces:
public final class AccountNumber.BuilderA builder for AccountNumber.
-
-
Method Summary
Modifier and Type Method Description final AccountNumber.Builderid(String id)The Account Number identifier. final AccountNumber.Builderid(JsonField<String> id)The Account Number identifier. final AccountNumber.BuilderaccountId(String accountId)The identifier for the account this Account Number belongs to. final AccountNumber.BuilderaccountId(JsonField<String> accountId)The identifier for the account this Account Number belongs to. final AccountNumber.BuilderaccountNumber(String accountNumber)The account number. final AccountNumber.BuilderaccountNumber(JsonField<String> accountNumber)The account number. final AccountNumber.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Account Number was created. final AccountNumber.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 time at which the Account Number was created. final AccountNumber.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AccountNumber.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final AccountNumber.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final AccountNumber.BuilderinboundAch(AccountNumber.InboundAch inboundAch)Properties related to how this Account Number handles inbound ACH transfers. final AccountNumber.BuilderinboundAch(JsonField<AccountNumber.InboundAch> inboundAch)Properties related to how this Account Number handles inbound ACH transfers. final AccountNumber.BuilderinboundChecks(AccountNumber.InboundChecks inboundChecks)Properties related to how this Account Number should handle inbound check withdrawals. final AccountNumber.BuilderinboundChecks(JsonField<AccountNumber.InboundChecks> inboundChecks)Properties related to how this Account Number should handle inbound check withdrawals. final AccountNumber.Buildername(String name)The name you choose for the Account Number. final AccountNumber.Buildername(JsonField<String> name)The name you choose for the Account Number. final AccountNumber.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AccountNumber.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AccountNumber.Builderstatus(AccountNumber.Status status)This indicates if payments can be made to the Account Number. final AccountNumber.Builderstatus(JsonField<AccountNumber.Status> status)This indicates if payments can be made to the Account Number. final AccountNumber.Buildertype(AccountNumber.Type type)A constant representing the object's type. final AccountNumber.Buildertype(JsonField<AccountNumber.Type> type)A constant representing the object's type. final AccountNumber.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.BuilderputAdditionalProperty(String key, JsonValue value)final AccountNumber.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.BuilderremoveAdditionalProperty(String key)final AccountNumber.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountNumberbuild()-
-
Method Detail
-
id
final AccountNumber.Builder id(String id)
The Account Number identifier.
-
id
final AccountNumber.Builder id(JsonField<String> id)
The Account Number identifier.
-
accountId
final AccountNumber.Builder accountId(String accountId)
The identifier for the account this Account Number belongs to.
-
accountId
final AccountNumber.Builder accountId(JsonField<String> accountId)
The identifier for the account this Account Number belongs to.
-
accountNumber
final AccountNumber.Builder accountNumber(String accountNumber)
The account number.
-
accountNumber
final AccountNumber.Builder accountNumber(JsonField<String> accountNumber)
The account number.
-
createdAt
final AccountNumber.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Account Number was created.
-
createdAt
final AccountNumber.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Account Number was created.
-
idempotencyKey
final AccountNumber.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AccountNumber.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AccountNumber.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundAch
final AccountNumber.Builder inboundAch(AccountNumber.InboundAch inboundAch)
Properties related to how this Account Number handles inbound ACH transfers.
-
inboundAch
final AccountNumber.Builder inboundAch(JsonField<AccountNumber.InboundAch> inboundAch)
Properties related to how this Account Number handles inbound ACH transfers.
-
inboundChecks
final AccountNumber.Builder inboundChecks(AccountNumber.InboundChecks inboundChecks)
Properties related to how this Account Number should handle inbound check withdrawals.
-
inboundChecks
final AccountNumber.Builder inboundChecks(JsonField<AccountNumber.InboundChecks> inboundChecks)
Properties related to how this Account Number should handle inbound check withdrawals.
-
name
final AccountNumber.Builder name(String name)
The name you choose for the Account Number.
-
name
final AccountNumber.Builder name(JsonField<String> name)
The name you choose for the Account Number.
-
routingNumber
final AccountNumber.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final AccountNumber.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final AccountNumber.Builder status(AccountNumber.Status status)
This indicates if payments can be made to the Account Number.
-
status
final AccountNumber.Builder status(JsonField<AccountNumber.Status> status)
This indicates if payments can be made to the Account Number.
-
type
final AccountNumber.Builder type(AccountNumber.Type type)
A constant representing the object's type. For this resource it will always be
account_number.
-
type
final AccountNumber.Builder type(JsonField<AccountNumber.Type> type)
A constant representing the object's type. For this resource it will always be
account_number.
-
additionalProperties
final AccountNumber.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumber.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumber.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumber.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumber.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumber build()
-
-
-
-