Package com.increase.api.models
Class AccountNumber.InboundAch
-
- All Implemented Interfaces:
public final class AccountNumber.InboundAchProperties related to how this Account Number handles inbound ACH transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumber.InboundAch.BuilderA builder for InboundAch.
public final classAccountNumber.InboundAch.DebitStatusWhether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundAch.DebitStatusdebitStatus()Whether ACH debits are allowed against this Account Number. final JsonField<AccountNumber.InboundAch.DebitStatus>_debitStatus()Whether ACH debits are allowed against this Account Number. final Map<String, JsonValue>_additionalProperties()final AccountNumber.InboundAchvalidate()final AccountNumber.InboundAch.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumber.InboundAch.Builderbuilder()-
-
Method Detail
-
debitStatus
final AccountNumber.InboundAch.DebitStatus debitStatus()
Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
_debitStatus
final JsonField<AccountNumber.InboundAch.DebitStatus> _debitStatus()
Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountNumber.InboundAch validate()
-
toBuilder
final AccountNumber.InboundAch.Builder toBuilder()
-
builder
final static AccountNumber.InboundAch.Builder builder()
-
-
-
-