Package com.increase.api.models
Class AccountNumber.InboundAch.Builder
-
- All Implemented Interfaces:
public final class AccountNumber.InboundAch.BuilderA builder for InboundAch.
-
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundAch.BuilderdebitStatus(AccountNumber.InboundAch.DebitStatus debitStatus)Whether ACH debits are allowed against this Account Number. final AccountNumber.InboundAch.BuilderdebitStatus(JsonField<AccountNumber.InboundAch.DebitStatus> debitStatus)Whether ACH debits are allowed against this Account Number. final AccountNumber.InboundAch.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.InboundAch.BuilderputAdditionalProperty(String key, JsonValue value)final AccountNumber.InboundAch.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.InboundAch.BuilderremoveAdditionalProperty(String key)final AccountNumber.InboundAch.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountNumber.InboundAchbuild()-
-
Method Detail
-
debitStatus
final AccountNumber.InboundAch.Builder debitStatus(AccountNumber.InboundAch.DebitStatus debitStatus)
Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
debitStatus
final AccountNumber.InboundAch.Builder debitStatus(JsonField<AccountNumber.InboundAch.DebitStatus> debitStatus)
Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
additionalProperties
final AccountNumber.InboundAch.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumber.InboundAch.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumber.InboundAch.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumber.InboundAch.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumber.InboundAch.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumber.InboundAch build()
-
-
-
-