Class AccountNumber.InboundAch.DebitStatus

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class AccountNumber.InboundAch.DebitStatus
     implements Enum
                        

    Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is allowed if the Account Number is not active.

    • Constructor Detail

    • Method Detail

      • _value

         final JsonField<String> _value()

        Returns this class instance's raw value.

        This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

      • asString

         final String asString()

        Returns this class instance's primitive wire representation.

        This differs from the toString method because that method is primarily for debugging and generally doesn't throw.