Package com.increase.api.models
Class AccountNumber.InboundChecks
-
- All Implemented Interfaces:
public final class AccountNumber.InboundChecksProperties related to how this Account Number should handle inbound check withdrawals.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumber.InboundChecks.BuilderA builder for InboundChecks.
public final classAccountNumber.InboundChecks.StatusHow Increase should process checks with this account number printed on them.
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundChecks.Statusstatus()How Increase should process checks with this account number printed on them. final JsonField<AccountNumber.InboundChecks.Status>_status()How Increase should process checks with this account number printed on them. final Map<String, JsonValue>_additionalProperties()final AccountNumber.InboundChecksvalidate()final AccountNumber.InboundChecks.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumber.InboundChecks.Builderbuilder()-
-
Method Detail
-
status
final AccountNumber.InboundChecks.Status status()
How Increase should process checks with this account number printed on them.
-
_status
final JsonField<AccountNumber.InboundChecks.Status> _status()
How Increase should process checks with this account number printed on them.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountNumber.InboundChecks validate()
-
toBuilder
final AccountNumber.InboundChecks.Builder toBuilder()
-
builder
final static AccountNumber.InboundChecks.Builder builder()
-
-
-
-