Class AccountNumberCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountNumberCreateParams implements Params
Create an Account Number
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.Bodypublic final classAccountNumberCreateParams.BuilderA builder for AccountNumberCreateParams.
public final classAccountNumberCreateParams.InboundAchOptions related to how this Account Number should handle inbound ACH transfers.
public final classAccountNumberCreateParams.InboundChecksOptions related to how this Account Number should handle inbound check withdrawals.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the Account Number should belong to. final Stringname()The name you choose for the Account Number. final Optional<AccountNumberCreateParams.InboundAch>inboundAch()Options related to how this Account Number should handle inbound ACH transfers. final Optional<AccountNumberCreateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final JsonField<String>_accountId()The Account the Account Number should belong to. final JsonField<String>_name()The name you choose for the Account Number. final JsonField<AccountNumberCreateParams.InboundAch>_inboundAch()Options related to how this Account Number should handle inbound ACH transfers. final JsonField<AccountNumberCreateParams.InboundChecks>_inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final AccountNumberCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.Builderbuilder()-
-
Method Detail
-
inboundAch
final Optional<AccountNumberCreateParams.InboundAch> inboundAch()
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberCreateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_accountId
final JsonField<String> _accountId()
The Account the Account Number should belong to.
-
_inboundAch
final JsonField<AccountNumberCreateParams.InboundAch> _inboundAch()
Options related to how this Account Number should handle inbound ACH transfers.
-
_inboundChecks
final JsonField<AccountNumberCreateParams.InboundChecks> _inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final AccountNumberCreateParams.Builder toBuilder()
-
builder
final static AccountNumberCreateParams.Builder builder()
-
-
-
-