Package com.increase.api.models
Class AccountNumberCreateParams.Body
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the Account Number should belong to. final Stringname()The name you choose for the Account Number. final Optional<AccountNumberCreateParams.InboundAch>inboundAch()Options related to how this Account Number should handle inbound ACH transfers. final Optional<AccountNumberCreateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final JsonField<String>_accountId()The Account the Account Number should belong to. final JsonField<String>_name()The name you choose for the Account Number. final JsonField<AccountNumberCreateParams.InboundAch>_inboundAch()Options related to how this Account Number should handle inbound ACH transfers. final JsonField<AccountNumberCreateParams.InboundChecks>_inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final Map<String, JsonValue>_additionalProperties()final AccountNumberCreateParams.Bodyvalidate()final AccountNumberCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.Body.Builderbuilder()-
-
Method Detail
-
inboundAch
final Optional<AccountNumberCreateParams.InboundAch> inboundAch()
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberCreateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_accountId
final JsonField<String> _accountId()
The Account the Account Number should belong to.
-
_inboundAch
final JsonField<AccountNumberCreateParams.InboundAch> _inboundAch()
Options related to how this Account Number should handle inbound ACH transfers.
-
_inboundChecks
final JsonField<AccountNumberCreateParams.InboundChecks> _inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountNumberCreateParams.Body validate()
-
toBuilder
final AccountNumberCreateParams.Body.Builder toBuilder()
-
builder
final static AccountNumberCreateParams.Body.Builder builder()
-
-
-
-