Package com.increase.api.models
Class AccountNumberCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final AccountNumberCreateParams.Body.Builder accountId(String accountId)
The Account the Account Number should belong to.
-
accountId
final AccountNumberCreateParams.Body.Builder accountId(JsonField<String> accountId)
The Account the Account Number should belong to.
-
name
final AccountNumberCreateParams.Body.Builder name(String name)
The name you choose for the Account Number.
-
name
final AccountNumberCreateParams.Body.Builder name(JsonField<String> name)
The name you choose for the Account Number.
-
inboundAch
final AccountNumberCreateParams.Body.Builder inboundAch(AccountNumberCreateParams.InboundAch inboundAch)
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundAch
final AccountNumberCreateParams.Body.Builder inboundAch(JsonField<AccountNumberCreateParams.InboundAch> inboundAch)
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundChecks
final AccountNumberCreateParams.Body.Builder inboundChecks(AccountNumberCreateParams.InboundChecks inboundChecks)
Options related to how this Account Number should handle inbound check withdrawals.
-
inboundChecks
final AccountNumberCreateParams.Body.Builder inboundChecks(JsonField<AccountNumberCreateParams.InboundChecks> inboundChecks)
Options related to how this Account Number should handle inbound check withdrawals.
-
additionalProperties
final AccountNumberCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberCreateParams.Body build()
-
-
-
-