Package com.increase.api.models
Class AccountNumberCreateParams.InboundAch.Builder
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.InboundAch.BuilderA builder for InboundAch.
-
-
Method Summary
Modifier and Type Method Description final AccountNumberCreateParams.InboundAch.BuilderdebitStatus(AccountNumberCreateParams.InboundAch.DebitStatus debitStatus)Whether ACH debits are allowed against this Account Number. final AccountNumberCreateParams.InboundAch.BuilderdebitStatus(JsonField<AccountNumberCreateParams.InboundAch.DebitStatus> debitStatus)Whether ACH debits are allowed against this Account Number. final AccountNumberCreateParams.InboundAch.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumberCreateParams.InboundAch.BuilderputAdditionalProperty(String key, JsonValue value)final AccountNumberCreateParams.InboundAch.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumberCreateParams.InboundAch.BuilderremoveAdditionalProperty(String key)final AccountNumberCreateParams.InboundAch.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountNumberCreateParams.InboundAchbuild()-
-
Method Detail
-
debitStatus
final AccountNumberCreateParams.InboundAch.Builder debitStatus(AccountNumberCreateParams.InboundAch.DebitStatus debitStatus)
Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active. If you do not specify this field, the default isallowed.
-
debitStatus
final AccountNumberCreateParams.InboundAch.Builder debitStatus(JsonField<AccountNumberCreateParams.InboundAch.DebitStatus> debitStatus)
Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active. If you do not specify this field, the default isallowed.
-
additionalProperties
final AccountNumberCreateParams.InboundAch.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberCreateParams.InboundAch.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberCreateParams.InboundAch.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberCreateParams.InboundAch.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberCreateParams.InboundAch.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberCreateParams.InboundAch build()
-
-
-
-