Package com.increase.api.models
Class AccountNumberCreateParams.InboundChecks
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.InboundChecksOptions related to how this Account Number should handle inbound check withdrawals.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.InboundChecks.BuilderA builder for InboundChecks.
public final classAccountNumberCreateParams.InboundChecks.StatusHow Increase should process checks with this account number printed on them. If you do not specify this field, the default is
check_transfers_only.
-
Method Summary
Modifier and Type Method Description final AccountNumberCreateParams.InboundChecks.Statusstatus()How Increase should process checks with this account number printed on them. final JsonField<AccountNumberCreateParams.InboundChecks.Status>_status()How Increase should process checks with this account number printed on them. final Map<String, JsonValue>_additionalProperties()final AccountNumberCreateParams.InboundChecksvalidate()final AccountNumberCreateParams.InboundChecks.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.InboundChecks.Builderbuilder()-
-
Method Detail
-
status
final AccountNumberCreateParams.InboundChecks.Status status()
How Increase should process checks with this account number printed on them. If you do not specify this field, the default is
check_transfers_only.
-
_status
final JsonField<AccountNumberCreateParams.InboundChecks.Status> _status()
How Increase should process checks with this account number printed on them. If you do not specify this field, the default is
check_transfers_only.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountNumberCreateParams.InboundChecks validate()
-
toBuilder
final AccountNumberCreateParams.InboundChecks.Builder toBuilder()
-
builder
final static AccountNumberCreateParams.InboundChecks.Builder builder()
-
-
-
-