Class AccountNumberUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountNumberUpdateParams implements Params
Update an Account Number
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberUpdateParams.Bodypublic final classAccountNumberUpdateParams.BuilderA builder for AccountNumberUpdateParams.
public final classAccountNumberUpdateParams.InboundAchOptions related to how this Account Number handles inbound ACH transfers.
public final classAccountNumberUpdateParams.InboundChecksOptions related to how this Account Number should handle inbound check withdrawals.
public final classAccountNumberUpdateParams.StatusThis indicates if transfers can be made to the Account Number.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number. final Optional<AccountNumberUpdateParams.InboundAch>inboundAch()Options related to how this Account Number handles inbound ACH transfers. final Optional<AccountNumberUpdateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final Optional<String>name()The name you choose for the Account Number. final Optional<AccountNumberUpdateParams.Status>status()This indicates if transfers can be made to the Account Number. final JsonField<AccountNumberUpdateParams.InboundAch>_inboundAch()Options related to how this Account Number handles inbound ACH transfers. final JsonField<AccountNumberUpdateParams.InboundChecks>_inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final JsonField<String>_name()The name you choose for the Account Number. final JsonField<AccountNumberUpdateParams.Status>_status()This indicates if transfers can be made to the Account Number. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final AccountNumberUpdateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberUpdateParams.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number.
-
inboundAch
final Optional<AccountNumberUpdateParams.InboundAch> inboundAch()
Options related to how this Account Number handles inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberUpdateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
status
final Optional<AccountNumberUpdateParams.Status> status()
This indicates if transfers can be made to the Account Number.
-
_inboundAch
final JsonField<AccountNumberUpdateParams.InboundAch> _inboundAch()
Options related to how this Account Number handles inbound ACH transfers.
-
_inboundChecks
final JsonField<AccountNumberUpdateParams.InboundChecks> _inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_status
final JsonField<AccountNumberUpdateParams.Status> _status()
This indicates if transfers can be made to the Account Number.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final AccountNumberUpdateParams.Builder toBuilder()
-
builder
final static AccountNumberUpdateParams.Builder builder()
-
-
-
-