Package com.increase.api.models
Class AccountNumberUpdateParams.InboundChecks.Builder
-
- All Implemented Interfaces:
public final class AccountNumberUpdateParams.InboundChecks.BuilderA builder for InboundChecks.
-
-
Method Summary
-
-
Method Detail
-
status
final AccountNumberUpdateParams.InboundChecks.Builder status(AccountNumberUpdateParams.InboundChecks.Status status)
How Increase should process checks with this account number printed on them.
-
status
final AccountNumberUpdateParams.InboundChecks.Builder status(JsonField<AccountNumberUpdateParams.InboundChecks.Status> status)
How Increase should process checks with this account number printed on them.
-
additionalProperties
final AccountNumberUpdateParams.InboundChecks.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberUpdateParams.InboundChecks.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberUpdateParams.InboundChecks.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberUpdateParams.InboundChecks.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberUpdateParams.InboundChecks.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberUpdateParams.InboundChecks build()
-
-
-
-