Class AccountStatement
-
- All Implemented Interfaces:
public final class AccountStatementAccount Statements are generated monthly for every active Account. You can access the statement's data via the API or retrieve a PDF with its details via its associated File.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatement.BuilderA builder for AccountStatement.
public final classAccountStatement.TypeA constant representing the object's type. For this resource it will always be
account_statement.
-
Method Summary
Modifier and Type Method Description final Stringid()The Account Statement identifier. final StringaccountId()The identifier for the Account this Account Statement belongs to. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Account Statement was created. final LongendingBalance()The Account's balance at the start of its statement period. final StringfileId()The identifier of the File containing a PDF of the statement. final LongstartingBalance()The Account's balance at the start of its statement period. final OffsetDateTimestatementPeriodEnd()The ISO 8601 time representing the end of the period the Account Statement covers. final OffsetDateTimestatementPeriodStart()The ISO 8601 time representing the start of the period the Account Statement covers. final AccountStatement.Typetype()A constant representing the object's type. final JsonField<String>_id()The Account Statement identifier. final JsonField<String>_accountId()The identifier for the Account this Account Statement belongs to. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Account Statement was created. final JsonField<Long>_endingBalance()The Account's balance at the start of its statement period. final JsonField<String>_fileId()The identifier of the File containing a PDF of the statement. final JsonField<Long>_startingBalance()The Account's balance at the start of its statement period. final JsonField<OffsetDateTime>_statementPeriodEnd()The ISO 8601 time representing the end of the period the Account Statement covers. final JsonField<OffsetDateTime>_statementPeriodStart()The ISO 8601 time representing the start of the period the Account Statement covers. final JsonField<AccountStatement.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final AccountStatementvalidate()final AccountStatement.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatement.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account this Account Statement belongs to.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Account Statement was created.
-
endingBalance
final Long endingBalance()
The Account's balance at the start of its statement period.
-
startingBalance
final Long startingBalance()
The Account's balance at the start of its statement period.
-
statementPeriodEnd
final OffsetDateTime statementPeriodEnd()
The ISO 8601 time representing the end of the period the Account Statement covers.
-
statementPeriodStart
final OffsetDateTime statementPeriodStart()
The ISO 8601 time representing the start of the period the Account Statement covers.
-
type
final AccountStatement.Type type()
A constant representing the object's type. For this resource it will always be
account_statement.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Account this Account Statement belongs to.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Account Statement was created.
-
_endingBalance
final JsonField<Long> _endingBalance()
The Account's balance at the start of its statement period.
-
_fileId
final JsonField<String> _fileId()
The identifier of the File containing a PDF of the statement.
-
_startingBalance
final JsonField<Long> _startingBalance()
The Account's balance at the start of its statement period.
-
_statementPeriodEnd
final JsonField<OffsetDateTime> _statementPeriodEnd()
The ISO 8601 time representing the end of the period the Account Statement covers.
-
_statementPeriodStart
final JsonField<OffsetDateTime> _statementPeriodStart()
The ISO 8601 time representing the start of the period the Account Statement covers.
-
_type
final JsonField<AccountStatement.Type> _type()
A constant representing the object's type. For this resource it will always be
account_statement.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountStatement validate()
-
toBuilder
final AccountStatement.Builder toBuilder()
-
builder
final static AccountStatement.Builder builder()
-
-
-
-