Class AccountStatement.Builder
-
- All Implemented Interfaces:
public final class AccountStatement.BuilderA builder for AccountStatement.
-
-
Method Summary
Modifier and Type Method Description final AccountStatement.Builderid(String id)The Account Statement identifier. final AccountStatement.Builderid(JsonField<String> id)The Account Statement identifier. final AccountStatement.BuilderaccountId(String accountId)The identifier for the Account this Account Statement belongs to. final AccountStatement.BuilderaccountId(JsonField<String> accountId)The identifier for the Account this Account Statement belongs to. final AccountStatement.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Account Statement was created. final AccountStatement.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 time at which the Account Statement was created. final AccountStatement.BuilderendingBalance(Long endingBalance)The Account's balance at the start of its statement period. final AccountStatement.BuilderendingBalance(JsonField<Long> endingBalance)The Account's balance at the start of its statement period. final AccountStatement.BuilderfileId(String fileId)The identifier of the File containing a PDF of the statement. final AccountStatement.BuilderfileId(JsonField<String> fileId)The identifier of the File containing a PDF of the statement. final AccountStatement.BuilderstartingBalance(Long startingBalance)The Account's balance at the start of its statement period. final AccountStatement.BuilderstartingBalance(JsonField<Long> startingBalance)The Account's balance at the start of its statement period. final AccountStatement.BuilderstatementPeriodEnd(OffsetDateTime statementPeriodEnd)The ISO 8601 time representing the end of the period the Account Statement covers. final AccountStatement.BuilderstatementPeriodEnd(JsonField<OffsetDateTime> statementPeriodEnd)The ISO 8601 time representing the end of the period the Account Statement covers. final AccountStatement.BuilderstatementPeriodStart(OffsetDateTime statementPeriodStart)The ISO 8601 time representing the start of the period the Account Statement covers. final AccountStatement.BuilderstatementPeriodStart(JsonField<OffsetDateTime> statementPeriodStart)The ISO 8601 time representing the start of the period the Account Statement covers. final AccountStatement.Buildertype(AccountStatement.Type type)A constant representing the object's type. final AccountStatement.Buildertype(JsonField<AccountStatement.Type> type)A constant representing the object's type. final AccountStatement.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountStatement.BuilderputAdditionalProperty(String key, JsonValue value)final AccountStatement.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountStatement.BuilderremoveAdditionalProperty(String key)final AccountStatement.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountStatementbuild()-
-
Method Detail
-
id
final AccountStatement.Builder id(String id)
The Account Statement identifier.
-
id
final AccountStatement.Builder id(JsonField<String> id)
The Account Statement identifier.
-
accountId
final AccountStatement.Builder accountId(String accountId)
The identifier for the Account this Account Statement belongs to.
-
accountId
final AccountStatement.Builder accountId(JsonField<String> accountId)
The identifier for the Account this Account Statement belongs to.
-
createdAt
final AccountStatement.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Account Statement was created.
-
createdAt
final AccountStatement.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Account Statement was created.
-
endingBalance
final AccountStatement.Builder endingBalance(Long endingBalance)
The Account's balance at the start of its statement period.
-
endingBalance
final AccountStatement.Builder endingBalance(JsonField<Long> endingBalance)
The Account's balance at the start of its statement period.
-
fileId
final AccountStatement.Builder fileId(String fileId)
The identifier of the File containing a PDF of the statement.
-
fileId
final AccountStatement.Builder fileId(JsonField<String> fileId)
The identifier of the File containing a PDF of the statement.
-
startingBalance
final AccountStatement.Builder startingBalance(Long startingBalance)
The Account's balance at the start of its statement period.
-
startingBalance
final AccountStatement.Builder startingBalance(JsonField<Long> startingBalance)
The Account's balance at the start of its statement period.
-
statementPeriodEnd
final AccountStatement.Builder statementPeriodEnd(OffsetDateTime statementPeriodEnd)
The ISO 8601 time representing the end of the period the Account Statement covers.
-
statementPeriodEnd
final AccountStatement.Builder statementPeriodEnd(JsonField<OffsetDateTime> statementPeriodEnd)
The ISO 8601 time representing the end of the period the Account Statement covers.
-
statementPeriodStart
final AccountStatement.Builder statementPeriodStart(OffsetDateTime statementPeriodStart)
The ISO 8601 time representing the start of the period the Account Statement covers.
-
statementPeriodStart
final AccountStatement.Builder statementPeriodStart(JsonField<OffsetDateTime> statementPeriodStart)
The ISO 8601 time representing the start of the period the Account Statement covers.
-
type
final AccountStatement.Builder type(AccountStatement.Type type)
A constant representing the object's type. For this resource it will always be
account_statement.
-
type
final AccountStatement.Builder type(JsonField<AccountStatement.Type> type)
A constant representing the object's type. For this resource it will always be
account_statement.
-
additionalProperties
final AccountStatement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountStatement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountStatement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountStatement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountStatement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountStatement build()
-
-
-
-