Class AccountTransfer
-
- All Implemented Interfaces:
public final class AccountTransferAccount transfers move funds between your own accounts at Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransfer.BuilderA builder for AccountTransfer.
public final classAccountTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classAccountTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classAccountTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classAccountTransfer.CurrencyThe ISO 4217 code for the destination account currency.
public final classAccountTransfer.NetworkThe transfer's network.
public final classAccountTransfer.StatusThe lifecycle status of the transfer.
public final classAccountTransfer.TypeA constant representing the object's type. For this resource it will always be
account_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The account transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final Longamount()The transfer amount in the minor unit of the destination account currency. final Optional<AccountTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<AccountTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<AccountTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final AccountTransfer.Currencycurrency()The ISO 4217 code for the destination account currency. final Stringdescription()The description that will show on the transactions. final StringdestinationAccountId()The destination account's identifier. final Optional<String>destinationTransactionId()The ID for the transaction receiving the transfer. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final AccountTransfer.Networknetwork()The transfer's network. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final AccountTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<String>transactionId()The ID for the transaction funding the transfer. final AccountTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The account transfer's identifier. final JsonField<String>_accountId()The Account to which the transfer belongs. final JsonField<Long>_amount()The transfer amount in the minor unit of the destination account currency. final JsonField<AccountTransfer.Approval>_approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final JsonField<AccountTransfer.Cancellation>_cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<AccountTransfer.CreatedBy>_createdBy()What object created the transfer, either via the API or the dashboard. final JsonField<AccountTransfer.Currency>_currency()The ISO 4217 code for the destination account currency. final JsonField<String>_description()The description that will show on the transactions. final JsonField<String>_destinationAccountId()The destination account's identifier. final JsonField<String>_destinationTransactionId()The ID for the transaction receiving the transfer. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<AccountTransfer.Network>_network()The transfer's network. final JsonField<String>_pendingTransactionId()The ID for the pending transaction representing the transfer. final JsonField<AccountTransfer.Status>_status()The lifecycle status of the transfer. final JsonField<String>_transactionId()The ID for the transaction funding the transfer. final JsonField<AccountTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final AccountTransfervalidate()final AccountTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransfer.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The transfer amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
approval
final Optional<AccountTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final Optional<AccountTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<AccountTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final AccountTransfer.Currency currency()
The ISO 4217 code for the destination account currency.
-
description
final String description()
The description that will show on the transactions.
-
destinationAccountId
final String destinationAccountId()
The destination account's identifier.
-
destinationTransactionId
final Optional<String> destinationTransactionId()
The ID for the transaction receiving the transfer.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
network
final AccountTransfer.Network network()
The transfer's network.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
status
final AccountTransfer.Status status()
The lifecycle status of the transfer.
-
transactionId
final Optional<String> transactionId()
The ID for the transaction funding the transfer.
-
type
final AccountTransfer.Type type()
A constant representing the object's type. For this resource it will always be
account_transfer.
-
_accountId
final JsonField<String> _accountId()
The Account to which the transfer belongs.
-
_amount
final JsonField<Long> _amount()
The transfer amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
_approval
final JsonField<AccountTransfer.Approval> _approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
_cancellation
final JsonField<AccountTransfer.Cancellation> _cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_createdBy
final JsonField<AccountTransfer.CreatedBy> _createdBy()
What object created the transfer, either via the API or the dashboard.
-
_currency
final JsonField<AccountTransfer.Currency> _currency()
The ISO 4217 code for the destination account currency.
-
_description
final JsonField<String> _description()
The description that will show on the transactions.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
The destination account's identifier.
-
_destinationTransactionId
final JsonField<String> _destinationTransactionId()
The ID for the transaction receiving the transfer.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_network
final JsonField<AccountTransfer.Network> _network()
The transfer's network.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
_status
final JsonField<AccountTransfer.Status> _status()
The lifecycle status of the transfer.
-
_transactionId
final JsonField<String> _transactionId()
The ID for the transaction funding the transfer.
-
_type
final JsonField<AccountTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
account_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountTransfer validate()
-
toBuilder
final AccountTransfer.Builder toBuilder()
-
builder
final static AccountTransfer.Builder builder()
-
-
-
-