Class AccountTransfer.Builder
-
- All Implemented Interfaces:
public final class AccountTransfer.BuilderA builder for AccountTransfer.
-
-
Method Summary
Modifier and Type Method Description final AccountTransfer.Builderid(String id)The account transfer's identifier. final AccountTransfer.Builderid(JsonField<String> id)The account transfer's identifier. final AccountTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final AccountTransfer.BuilderaccountId(JsonField<String> accountId)The Account to which the transfer belongs. final AccountTransfer.Builderamount(Long amount)The transfer amount in the minor unit of the destination account currency. final AccountTransfer.Builderamount(JsonField<Long> amount)The transfer amount in the minor unit of the destination account currency. final AccountTransfer.Builderapproval(AccountTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AccountTransfer.Builderapproval(Optional<AccountTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AccountTransfer.Builderapproval(JsonField<AccountTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AccountTransfer.Buildercancellation(AccountTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AccountTransfer.Buildercancellation(Optional<AccountTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AccountTransfer.Buildercancellation(JsonField<AccountTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AccountTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final AccountTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the transfer was created. final AccountTransfer.BuildercreatedBy(AccountTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final AccountTransfer.BuildercreatedBy(Optional<AccountTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final AccountTransfer.BuildercreatedBy(JsonField<AccountTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final AccountTransfer.Buildercurrency(AccountTransfer.Currency currency)The ISO 4217 code for the destination account currency. final AccountTransfer.Buildercurrency(JsonField<AccountTransfer.Currency> currency)The ISO 4217 code for the destination account currency. final AccountTransfer.Builderdescription(String description)The description that will show on the transactions. final AccountTransfer.Builderdescription(JsonField<String> description)The description that will show on the transactions. final AccountTransfer.BuilderdestinationAccountId(String destinationAccountId)The destination account's identifier. final AccountTransfer.BuilderdestinationAccountId(JsonField<String> destinationAccountId)The destination account's identifier. final AccountTransfer.BuilderdestinationTransactionId(String destinationTransactionId)The ID for the transaction receiving the transfer. final AccountTransfer.BuilderdestinationTransactionId(Optional<String> destinationTransactionId)The ID for the transaction receiving the transfer. final AccountTransfer.BuilderdestinationTransactionId(JsonField<String> destinationTransactionId)The ID for the transaction receiving the transfer. final AccountTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AccountTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final AccountTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final AccountTransfer.Buildernetwork(AccountTransfer.Network network)The transfer's network. final AccountTransfer.Buildernetwork(JsonField<AccountTransfer.Network> network)The transfer's network. final AccountTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final AccountTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final AccountTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final AccountTransfer.Builderstatus(AccountTransfer.Status status)The lifecycle status of the transfer. final AccountTransfer.Builderstatus(JsonField<AccountTransfer.Status> status)The lifecycle status of the transfer. final AccountTransfer.BuildertransactionId(String transactionId)The ID for the transaction funding the transfer. final AccountTransfer.BuildertransactionId(Optional<String> transactionId)The ID for the transaction funding the transfer. final AccountTransfer.BuildertransactionId(JsonField<String> transactionId)The ID for the transaction funding the transfer. final AccountTransfer.Buildertype(AccountTransfer.Type type)A constant representing the object's type. final AccountTransfer.Buildertype(JsonField<AccountTransfer.Type> type)A constant representing the object's type. final AccountTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final AccountTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountTransfer.BuilderremoveAdditionalProperty(String key)final AccountTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountTransferbuild()-
-
Method Detail
-
id
final AccountTransfer.Builder id(String id)
The account transfer's identifier.
-
id
final AccountTransfer.Builder id(JsonField<String> id)
The account transfer's identifier.
-
accountId
final AccountTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final AccountTransfer.Builder accountId(JsonField<String> accountId)
The Account to which the transfer belongs.
-
amount
final AccountTransfer.Builder amount(Long amount)
The transfer amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
amount
final AccountTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
approval
final AccountTransfer.Builder approval(AccountTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final AccountTransfer.Builder approval(Optional<AccountTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final AccountTransfer.Builder approval(JsonField<AccountTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final AccountTransfer.Builder cancellation(AccountTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final AccountTransfer.Builder cancellation(Optional<AccountTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final AccountTransfer.Builder cancellation(JsonField<AccountTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final AccountTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final AccountTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final AccountTransfer.Builder createdBy(AccountTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final AccountTransfer.Builder createdBy(Optional<AccountTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final AccountTransfer.Builder createdBy(JsonField<AccountTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
currency
final AccountTransfer.Builder currency(AccountTransfer.Currency currency)
The ISO 4217 code for the destination account currency.
-
currency
final AccountTransfer.Builder currency(JsonField<AccountTransfer.Currency> currency)
The ISO 4217 code for the destination account currency.
-
description
final AccountTransfer.Builder description(String description)
The description that will show on the transactions.
-
description
final AccountTransfer.Builder description(JsonField<String> description)
The description that will show on the transactions.
-
destinationAccountId
final AccountTransfer.Builder destinationAccountId(String destinationAccountId)
The destination account's identifier.
-
destinationAccountId
final AccountTransfer.Builder destinationAccountId(JsonField<String> destinationAccountId)
The destination account's identifier.
-
destinationTransactionId
final AccountTransfer.Builder destinationTransactionId(String destinationTransactionId)
The ID for the transaction receiving the transfer.
-
destinationTransactionId
final AccountTransfer.Builder destinationTransactionId(Optional<String> destinationTransactionId)
The ID for the transaction receiving the transfer.
-
destinationTransactionId
final AccountTransfer.Builder destinationTransactionId(JsonField<String> destinationTransactionId)
The ID for the transaction receiving the transfer.
-
idempotencyKey
final AccountTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AccountTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AccountTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
network
final AccountTransfer.Builder network(AccountTransfer.Network network)
The transfer's network.
-
network
final AccountTransfer.Builder network(JsonField<AccountTransfer.Network> network)
The transfer's network.
-
pendingTransactionId
final AccountTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final AccountTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final AccountTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
status
final AccountTransfer.Builder status(AccountTransfer.Status status)
The lifecycle status of the transfer.
-
status
final AccountTransfer.Builder status(JsonField<AccountTransfer.Status> status)
The lifecycle status of the transfer.
-
transactionId
final AccountTransfer.Builder transactionId(String transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final AccountTransfer.Builder transactionId(Optional<String> transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final AccountTransfer.Builder transactionId(JsonField<String> transactionId)
The ID for the transaction funding the transfer.
-
type
final AccountTransfer.Builder type(AccountTransfer.Type type)
A constant representing the object's type. For this resource it will always be
account_transfer.
-
type
final AccountTransfer.Builder type(JsonField<AccountTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
account_transfer.
-
additionalProperties
final AccountTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountTransfer build()
-
-
-
-