Class AccountTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class AccountTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classAccountTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classAccountTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classAccountTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classAccountTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final Optional<AccountTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final AccountTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<AccountTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<AccountTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<AccountTransfer.CreatedBy.ApiKey>_apiKey()If present, details about the API key that created the transfer. final JsonField<AccountTransfer.CreatedBy.Category>_category()The type of object that created this transfer. final JsonField<AccountTransfer.CreatedBy.OAuthApplication>_oauthApplication()If present, details about the OAuth Application that created the transfer. final JsonField<AccountTransfer.CreatedBy.User>_user()If present, details about the User that created the transfer. final Map<String, JsonValue>_additionalProperties()final AccountTransfer.CreatedByvalidate()final AccountTransfer.CreatedBy.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransfer.CreatedBy.Builderbuilder()-
-
Method Detail
-
apiKey
final Optional<AccountTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
category
final AccountTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
oauthApplication
final Optional<AccountTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<AccountTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_apiKey
final JsonField<AccountTransfer.CreatedBy.ApiKey> _apiKey()
If present, details about the API key that created the transfer.
-
_category
final JsonField<AccountTransfer.CreatedBy.Category> _category()
The type of object that created this transfer.
-
_oauthApplication
final JsonField<AccountTransfer.CreatedBy.OAuthApplication> _oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
_user
final JsonField<AccountTransfer.CreatedBy.User> _user()
If present, details about the User that created the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountTransfer.CreatedBy validate()
-
toBuilder
final AccountTransfer.CreatedBy.Builder toBuilder()
-
builder
final static AccountTransfer.CreatedBy.Builder builder()
-
-
-
-