Package com.increase.api.models
Class AccountTransfer.CreatedBy.Builder
-
- All Implemented Interfaces:
public final class AccountTransfer.CreatedBy.BuilderA builder for CreatedBy.
-
-
Method Summary
-
-
Method Detail
-
apiKey
final AccountTransfer.CreatedBy.Builder apiKey(AccountTransfer.CreatedBy.ApiKey apiKey)
If present, details about the API key that created the transfer.
-
apiKey
final AccountTransfer.CreatedBy.Builder apiKey(Optional<AccountTransfer.CreatedBy.ApiKey> apiKey)
If present, details about the API key that created the transfer.
-
apiKey
final AccountTransfer.CreatedBy.Builder apiKey(JsonField<AccountTransfer.CreatedBy.ApiKey> apiKey)
If present, details about the API key that created the transfer.
-
category
final AccountTransfer.CreatedBy.Builder category(AccountTransfer.CreatedBy.Category category)
The type of object that created this transfer.
-
category
final AccountTransfer.CreatedBy.Builder category(JsonField<AccountTransfer.CreatedBy.Category> category)
The type of object that created this transfer.
-
oauthApplication
final AccountTransfer.CreatedBy.Builder oauthApplication(AccountTransfer.CreatedBy.OAuthApplication oauthApplication)
If present, details about the OAuth Application that created the transfer.
-
oauthApplication
final AccountTransfer.CreatedBy.Builder oauthApplication(Optional<AccountTransfer.CreatedBy.OAuthApplication> oauthApplication)
If present, details about the OAuth Application that created the transfer.
-
oauthApplication
final AccountTransfer.CreatedBy.Builder oauthApplication(JsonField<AccountTransfer.CreatedBy.OAuthApplication> oauthApplication)
If present, details about the OAuth Application that created the transfer.
-
user
final AccountTransfer.CreatedBy.Builder user(AccountTransfer.CreatedBy.User user)
If present, details about the User that created the transfer.
-
user
final AccountTransfer.CreatedBy.Builder user(Optional<AccountTransfer.CreatedBy.User> user)
If present, details about the User that created the transfer.
-
user
final AccountTransfer.CreatedBy.Builder user(JsonField<AccountTransfer.CreatedBy.User> user)
If present, details about the User that created the transfer.
-
additionalProperties
final AccountTransfer.CreatedBy.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountTransfer.CreatedBy.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountTransfer.CreatedBy.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountTransfer.CreatedBy.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountTransfer.CreatedBy.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountTransfer.CreatedBy build()
-
-
-
-