Package com.increase.api.models
Class AccountTransferApproveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountTransferApproveParams implements Params
Approve an Account Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferApproveParams.BuilderA builder for AccountTransferApproveParams.
-
Method Summary
Modifier and Type Method Description final StringaccountTransferId()The identifier of the Account Transfer to approve. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final Map<String, JsonValue>_additionalBodyProperties()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final AccountTransferApproveParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransferApproveParams.Builderbuilder()-
-
Method Detail
-
accountTransferId
final String accountTransferId()
The identifier of the Account Transfer to approve.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final AccountTransferApproveParams.Builder toBuilder()
-
builder
final static AccountTransferApproveParams.Builder builder()
-
-
-
-