Class AccountTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountTransferCreateParams implements Params
Create an Account Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferCreateParams.Bodypublic final classAccountTransferCreateParams.BuilderA builder for AccountTransferCreateParams.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in the minor unit of the account currency. final Stringdescription()The description you choose to give the transfer. final StringdestinationAccountId()The identifier for the account that will receive the transfer. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<String>_accountId()The identifier for the account that will send the transfer. final JsonField<Long>_amount()The transfer amount in the minor unit of the account currency. final JsonField<String>_description()The description you choose to give the transfer. final JsonField<String>_destinationAccountId()The identifier for the account that will receive the transfer. final JsonField<Boolean>_requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final AccountTransferCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransferCreateParams.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
description
final String description()
The description you choose to give the transfer.
-
destinationAccountId
final String destinationAccountId()
The identifier for the account that will receive the transfer.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account that will send the transfer.
-
_amount
final JsonField<Long> _amount()
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
_description
final JsonField<String> _description()
The description you choose to give the transfer.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
The identifier for the account that will receive the transfer.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final AccountTransferCreateParams.Builder toBuilder()
-
builder
final static AccountTransferCreateParams.Builder builder()
-
-
-
-