Package com.increase.api.models
Class AccountTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class AccountTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in the minor unit of the account currency. final Stringdescription()The description you choose to give the transfer. final StringdestinationAccountId()The identifier for the account that will receive the transfer. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<String>_accountId()The identifier for the account that will send the transfer. final JsonField<Long>_amount()The transfer amount in the minor unit of the account currency. final JsonField<String>_description()The description you choose to give the transfer. final JsonField<String>_destinationAccountId()The identifier for the account that will receive the transfer. final JsonField<Boolean>_requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Map<String, JsonValue>_additionalProperties()final AccountTransferCreateParams.Bodyvalidate()final AccountTransferCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransferCreateParams.Body.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
description
final String description()
The description you choose to give the transfer.
-
destinationAccountId
final String destinationAccountId()
The identifier for the account that will receive the transfer.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account that will send the transfer.
-
_amount
final JsonField<Long> _amount()
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
_description
final JsonField<String> _description()
The description you choose to give the transfer.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
The identifier for the account that will receive the transfer.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountTransferCreateParams.Body validate()
-
toBuilder
final AccountTransferCreateParams.Body.Builder toBuilder()
-
builder
final static AccountTransferCreateParams.Body.Builder builder()
-
-
-
-