Class AchPrenotification
-
- All Implemented Interfaces:
public final class AchPrenotificationACH Prenotifications are one way you can verify account and routing numbers by Automated Clearing House (ACH).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotification.BuilderA builder for AchPrenotification.
public final classAchPrenotification.CreditDebitIndicatorIf the notification is for a future credit or debit.
public final classAchPrenotification.NotificationsOfChangepublic final classAchPrenotification.PrenotificationReturnIf your prenotification is returned, this will contain details of the return.
public final classAchPrenotification.StatusThe lifecycle status of the ACH Prenotification.
public final classAchPrenotification.TypeA constant representing the object's type. For this resource it will always be
ach_prenotification.
-
Method Summary
Modifier and Type Method Description final Stringid()The ACH Prenotification's identifier. final StringaccountNumber()The destination account number. final Optional<String>addendum()Additional information for the recipient. final Optional<String>companyDescriptiveDate()The description of the date of the notification. final Optional<String>companyDiscretionaryData()Optional data associated with the notification. final Optional<String>companyEntryDescription()The description of the notification. final Optional<String>companyName()The name by which you know the company. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the prenotification was created. final Optional<AchPrenotification.CreditDebitIndicator>creditDebitIndicator()If the notification is for a future credit or debit. final Optional<OffsetDateTime>effectiveDate()The effective date in ISO 8601 format. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final List<AchPrenotification.NotificationsOfChange>notificationsOfChange()If the receiving bank notifies that future transfers should use different details, this will contain those details. final Optional<AchPrenotification.PrenotificationReturn>prenotificationReturn()If your prenotification is returned, this will contain details of the return. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final AchPrenotification.Statusstatus()The lifecycle status of the ACH Prenotification. final AchPrenotification.Typetype()A constant representing the object's type. final JsonField<String>_id()The ACH Prenotification's identifier. final JsonField<String>_accountNumber()The destination account number. final JsonField<String>_addendum()Additional information for the recipient. final JsonField<String>_companyDescriptiveDate()The description of the date of the notification. final JsonField<String>_companyDiscretionaryData()Optional data associated with the notification. final JsonField<String>_companyEntryDescription()The description of the notification. final JsonField<String>_companyName()The name by which you know the company. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the prenotification was created. final JsonField<AchPrenotification.CreditDebitIndicator>_creditDebitIndicator()If the notification is for a future credit or debit. final JsonField<OffsetDateTime>_effectiveDate()The effective date in ISO 8601 format. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<List<AchPrenotification.NotificationsOfChange>>_notificationsOfChange()If the receiving bank notifies that future transfers should use different details, this will contain those details. final JsonField<AchPrenotification.PrenotificationReturn>_prenotificationReturn()If your prenotification is returned, this will contain details of the return. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<AchPrenotification.Status>_status()The lifecycle status of the ACH Prenotification. final JsonField<AchPrenotification.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final AchPrenotificationvalidate()final AchPrenotification.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchPrenotification.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the notification.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
Optional data associated with the notification.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the notification.
-
companyName
final Optional<String> companyName()
The name by which you know the company.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the prenotification was created.
-
creditDebitIndicator
final Optional<AchPrenotification.CreditDebitIndicator> creditDebitIndicator()
If the notification is for a future credit or debit.
-
effectiveDate
final Optional<OffsetDateTime> effectiveDate()
The effective date in ISO 8601 format.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
notificationsOfChange
final List<AchPrenotification.NotificationsOfChange> notificationsOfChange()
If the receiving bank notifies that future transfers should use different details, this will contain those details.
-
prenotificationReturn
final Optional<AchPrenotification.PrenotificationReturn> prenotificationReturn()
If your prenotification is returned, this will contain details of the return.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final AchPrenotification.Status status()
The lifecycle status of the ACH Prenotification.
-
type
final AchPrenotification.Type type()
A constant representing the object's type. For this resource it will always be
ach_prenotification.
-
_accountNumber
final JsonField<String> _accountNumber()
The destination account number.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
The description of the date of the notification.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Optional data associated with the notification.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
The description of the notification.
-
_companyName
final JsonField<String> _companyName()
The name by which you know the company.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the prenotification was created.
-
_creditDebitIndicator
final JsonField<AchPrenotification.CreditDebitIndicator> _creditDebitIndicator()
If the notification is for a future credit or debit.
-
_effectiveDate
final JsonField<OffsetDateTime> _effectiveDate()
The effective date in ISO 8601 format.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_notificationsOfChange
final JsonField<List<AchPrenotification.NotificationsOfChange>> _notificationsOfChange()
If the receiving bank notifies that future transfers should use different details, this will contain those details.
-
_prenotificationReturn
final JsonField<AchPrenotification.PrenotificationReturn> _prenotificationReturn()
If your prenotification is returned, this will contain details of the return.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_status
final JsonField<AchPrenotification.Status> _status()
The lifecycle status of the ACH Prenotification.
-
_type
final JsonField<AchPrenotification.Type> _type()
A constant representing the object's type. For this resource it will always be
ach_prenotification.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchPrenotification validate()
-
toBuilder
final AchPrenotification.Builder toBuilder()
-
builder
final static AchPrenotification.Builder builder()
-
-
-
-