Class AchPrenotification.Builder
-
- All Implemented Interfaces:
public final class AchPrenotification.BuilderA builder for AchPrenotification.
-
-
Method Summary
Modifier and Type Method Description final AchPrenotification.Builderid(String id)The ACH Prenotification's identifier. final AchPrenotification.Builderid(JsonField<String> id)The ACH Prenotification's identifier. final AchPrenotification.BuilderaccountNumber(String accountNumber)The destination account number. final AchPrenotification.BuilderaccountNumber(JsonField<String> accountNumber)The destination account number. final AchPrenotification.Builderaddendum(String addendum)Additional information for the recipient. final AchPrenotification.Builderaddendum(Optional<String> addendum)Additional information for the recipient. final AchPrenotification.Builderaddendum(JsonField<String> addendum)Additional information for the recipient. final AchPrenotification.BuildercompanyDescriptiveDate(String companyDescriptiveDate)The description of the date of the notification. final AchPrenotification.BuildercompanyDescriptiveDate(Optional<String> companyDescriptiveDate)The description of the date of the notification. final AchPrenotification.BuildercompanyDescriptiveDate(JsonField<String> companyDescriptiveDate)The description of the date of the notification. final AchPrenotification.BuildercompanyDiscretionaryData(String companyDiscretionaryData)Optional data associated with the notification. final AchPrenotification.BuildercompanyDiscretionaryData(Optional<String> companyDiscretionaryData)Optional data associated with the notification. final AchPrenotification.BuildercompanyDiscretionaryData(JsonField<String> companyDiscretionaryData)Optional data associated with the notification. final AchPrenotification.BuildercompanyEntryDescription(String companyEntryDescription)The description of the notification. final AchPrenotification.BuildercompanyEntryDescription(Optional<String> companyEntryDescription)The description of the notification. final AchPrenotification.BuildercompanyEntryDescription(JsonField<String> companyEntryDescription)The description of the notification. final AchPrenotification.BuildercompanyName(String companyName)The name by which you know the company. final AchPrenotification.BuildercompanyName(Optional<String> companyName)The name by which you know the company. final AchPrenotification.BuildercompanyName(JsonField<String> companyName)The name by which you know the company. final AchPrenotification.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the prenotification was created. final AchPrenotification.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the prenotification was created. final AchPrenotification.BuildercreditDebitIndicator(AchPrenotification.CreditDebitIndicator creditDebitIndicator)If the notification is for a future credit or debit. final AchPrenotification.BuildercreditDebitIndicator(Optional<AchPrenotification.CreditDebitIndicator> creditDebitIndicator)If the notification is for a future credit or debit. final AchPrenotification.BuildercreditDebitIndicator(JsonField<AchPrenotification.CreditDebitIndicator> creditDebitIndicator)If the notification is for a future credit or debit. final AchPrenotification.BuildereffectiveDate(OffsetDateTime effectiveDate)The effective date in ISO 8601 format. final AchPrenotification.BuildereffectiveDate(Optional<OffsetDateTime> effectiveDate)The effective date in ISO 8601 format. final AchPrenotification.BuildereffectiveDate(JsonField<OffsetDateTime> effectiveDate)The effective date in ISO 8601 format. final AchPrenotification.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AchPrenotification.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final AchPrenotification.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final AchPrenotification.BuildernotificationsOfChange(List<AchPrenotification.NotificationsOfChange> notificationsOfChange)If the receiving bank notifies that future transfers should use different details, this will contain those details. final AchPrenotification.BuildernotificationsOfChange(JsonField<List<AchPrenotification.NotificationsOfChange>> notificationsOfChange)If the receiving bank notifies that future transfers should use different details, this will contain those details. final AchPrenotification.BuilderaddNotificationsOfChange(AchPrenotification.NotificationsOfChange notificationsOfChange)If the receiving bank notifies that future transfers should use different details, this will contain those details. final AchPrenotification.BuilderprenotificationReturn(AchPrenotification.PrenotificationReturn prenotificationReturn)If your prenotification is returned, this will contain details of the return. final AchPrenotification.BuilderprenotificationReturn(Optional<AchPrenotification.PrenotificationReturn> prenotificationReturn)If your prenotification is returned, this will contain details of the return. final AchPrenotification.BuilderprenotificationReturn(JsonField<AchPrenotification.PrenotificationReturn> prenotificationReturn)If your prenotification is returned, this will contain details of the return. final AchPrenotification.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AchPrenotification.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AchPrenotification.Builderstatus(AchPrenotification.Status status)The lifecycle status of the ACH Prenotification. final AchPrenotification.Builderstatus(JsonField<AchPrenotification.Status> status)The lifecycle status of the ACH Prenotification. final AchPrenotification.Buildertype(AchPrenotification.Type type)A constant representing the object's type. final AchPrenotification.Buildertype(JsonField<AchPrenotification.Type> type)A constant representing the object's type. final AchPrenotification.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchPrenotification.BuilderputAdditionalProperty(String key, JsonValue value)final AchPrenotification.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchPrenotification.BuilderremoveAdditionalProperty(String key)final AchPrenotification.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchPrenotificationbuild()-
-
Method Detail
-
id
final AchPrenotification.Builder id(String id)
The ACH Prenotification's identifier.
-
id
final AchPrenotification.Builder id(JsonField<String> id)
The ACH Prenotification's identifier.
-
accountNumber
final AchPrenotification.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final AchPrenotification.Builder accountNumber(JsonField<String> accountNumber)
The destination account number.
-
addendum
final AchPrenotification.Builder addendum(String addendum)
Additional information for the recipient.
-
addendum
final AchPrenotification.Builder addendum(Optional<String> addendum)
Additional information for the recipient.
-
addendum
final AchPrenotification.Builder addendum(JsonField<String> addendum)
Additional information for the recipient.
-
companyDescriptiveDate
final AchPrenotification.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the notification.
-
companyDescriptiveDate
final AchPrenotification.Builder companyDescriptiveDate(Optional<String> companyDescriptiveDate)
The description of the date of the notification.
-
companyDescriptiveDate
final AchPrenotification.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
The description of the date of the notification.
-
companyDiscretionaryData
final AchPrenotification.Builder companyDiscretionaryData(String companyDiscretionaryData)
Optional data associated with the notification.
-
companyDiscretionaryData
final AchPrenotification.Builder companyDiscretionaryData(Optional<String> companyDiscretionaryData)
Optional data associated with the notification.
-
companyDiscretionaryData
final AchPrenotification.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
Optional data associated with the notification.
-
companyEntryDescription
final AchPrenotification.Builder companyEntryDescription(String companyEntryDescription)
The description of the notification.
-
companyEntryDescription
final AchPrenotification.Builder companyEntryDescription(Optional<String> companyEntryDescription)
The description of the notification.
-
companyEntryDescription
final AchPrenotification.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
The description of the notification.
-
companyName
final AchPrenotification.Builder companyName(String companyName)
The name by which you know the company.
-
companyName
final AchPrenotification.Builder companyName(Optional<String> companyName)
The name by which you know the company.
-
companyName
final AchPrenotification.Builder companyName(JsonField<String> companyName)
The name by which you know the company.
-
createdAt
final AchPrenotification.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the prenotification was created.
-
createdAt
final AchPrenotification.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the prenotification was created.
-
creditDebitIndicator
final AchPrenotification.Builder creditDebitIndicator(AchPrenotification.CreditDebitIndicator creditDebitIndicator)
If the notification is for a future credit or debit.
-
creditDebitIndicator
final AchPrenotification.Builder creditDebitIndicator(Optional<AchPrenotification.CreditDebitIndicator> creditDebitIndicator)
If the notification is for a future credit or debit.
-
creditDebitIndicator
final AchPrenotification.Builder creditDebitIndicator(JsonField<AchPrenotification.CreditDebitIndicator> creditDebitIndicator)
If the notification is for a future credit or debit.
-
effectiveDate
final AchPrenotification.Builder effectiveDate(OffsetDateTime effectiveDate)
The effective date in ISO 8601 format.
-
effectiveDate
final AchPrenotification.Builder effectiveDate(Optional<OffsetDateTime> effectiveDate)
The effective date in ISO 8601 format.
-
effectiveDate
final AchPrenotification.Builder effectiveDate(JsonField<OffsetDateTime> effectiveDate)
The effective date in ISO 8601 format.
-
idempotencyKey
final AchPrenotification.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AchPrenotification.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AchPrenotification.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
notificationsOfChange
final AchPrenotification.Builder notificationsOfChange(List<AchPrenotification.NotificationsOfChange> notificationsOfChange)
If the receiving bank notifies that future transfers should use different details, this will contain those details.
-
notificationsOfChange
final AchPrenotification.Builder notificationsOfChange(JsonField<List<AchPrenotification.NotificationsOfChange>> notificationsOfChange)
If the receiving bank notifies that future transfers should use different details, this will contain those details.
-
addNotificationsOfChange
final AchPrenotification.Builder addNotificationsOfChange(AchPrenotification.NotificationsOfChange notificationsOfChange)
If the receiving bank notifies that future transfers should use different details, this will contain those details.
-
prenotificationReturn
final AchPrenotification.Builder prenotificationReturn(AchPrenotification.PrenotificationReturn prenotificationReturn)
If your prenotification is returned, this will contain details of the return.
-
prenotificationReturn
final AchPrenotification.Builder prenotificationReturn(Optional<AchPrenotification.PrenotificationReturn> prenotificationReturn)
If your prenotification is returned, this will contain details of the return.
-
prenotificationReturn
final AchPrenotification.Builder prenotificationReturn(JsonField<AchPrenotification.PrenotificationReturn> prenotificationReturn)
If your prenotification is returned, this will contain details of the return.
-
routingNumber
final AchPrenotification.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final AchPrenotification.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final AchPrenotification.Builder status(AchPrenotification.Status status)
The lifecycle status of the ACH Prenotification.
-
status
final AchPrenotification.Builder status(JsonField<AchPrenotification.Status> status)
The lifecycle status of the ACH Prenotification.
-
type
final AchPrenotification.Builder type(AchPrenotification.Type type)
A constant representing the object's type. For this resource it will always be
ach_prenotification.
-
type
final AchPrenotification.Builder type(JsonField<AchPrenotification.Type> type)
A constant representing the object's type. For this resource it will always be
ach_prenotification.
-
additionalProperties
final AchPrenotification.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchPrenotification.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchPrenotification.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchPrenotification.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchPrenotification.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchPrenotification build()
-
-
-
-