Class AchPrenotification.NotificationsOfChange
-
- All Implemented Interfaces:
public final class AchPrenotification.NotificationsOfChange
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotification.NotificationsOfChange.BuilderA builder for NotificationsOfChange.
public final classAchPrenotification.NotificationsOfChange.ChangeCodeThe required type of change that is being signaled by the receiving financial institution.
-
Method Summary
Modifier and Type Method Description final AchPrenotification.NotificationsOfChange.ChangeCodechangeCode()The required type of change that is being signaled by the receiving financial institution. final StringcorrectedData()The corrected data that should be used in future ACHs to this account. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the notification occurred. final JsonField<AchPrenotification.NotificationsOfChange.ChangeCode>_changeCode()The required type of change that is being signaled by the receiving financial institution. final JsonField<String>_correctedData()The corrected data that should be used in future ACHs to this account. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the notification occurred. final Map<String, JsonValue>_additionalProperties()final AchPrenotification.NotificationsOfChangevalidate()final AchPrenotification.NotificationsOfChange.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchPrenotification.NotificationsOfChange.Builderbuilder()-
-
Method Detail
-
changeCode
final AchPrenotification.NotificationsOfChange.ChangeCode changeCode()
The required type of change that is being signaled by the receiving financial institution.
-
correctedData
final String correctedData()
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the notification occurred.
-
_changeCode
final JsonField<AchPrenotification.NotificationsOfChange.ChangeCode> _changeCode()
The required type of change that is being signaled by the receiving financial institution.
-
_correctedData
final JsonField<String> _correctedData()
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the notification occurred.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchPrenotification.NotificationsOfChange validate()
-
toBuilder
final AchPrenotification.NotificationsOfChange.Builder toBuilder()
-
builder
final static AchPrenotification.NotificationsOfChange.Builder builder()
-
-
-
-