Class AchPrenotification.NotificationsOfChange.Builder
-
- All Implemented Interfaces:
public final class AchPrenotification.NotificationsOfChange.BuilderA builder for NotificationsOfChange.
-
-
Method Summary
-
-
Method Detail
-
changeCode
final AchPrenotification.NotificationsOfChange.Builder changeCode(AchPrenotification.NotificationsOfChange.ChangeCode changeCode)
The required type of change that is being signaled by the receiving financial institution.
-
changeCode
final AchPrenotification.NotificationsOfChange.Builder changeCode(JsonField<AchPrenotification.NotificationsOfChange.ChangeCode> changeCode)
The required type of change that is being signaled by the receiving financial institution.
-
correctedData
final AchPrenotification.NotificationsOfChange.Builder correctedData(String correctedData)
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
correctedData
final AchPrenotification.NotificationsOfChange.Builder correctedData(JsonField<String> correctedData)
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
createdAt
final AchPrenotification.NotificationsOfChange.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the notification occurred.
-
createdAt
final AchPrenotification.NotificationsOfChange.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the notification occurred.
-
additionalProperties
final AchPrenotification.NotificationsOfChange.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchPrenotification.NotificationsOfChange.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchPrenotification.NotificationsOfChange.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchPrenotification.NotificationsOfChange.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchPrenotification.NotificationsOfChange.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchPrenotification.NotificationsOfChange build()
-
-
-
-