Class AchPrenotificationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchPrenotificationCreateParams implements Params
Create an ACH Prenotification
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotificationCreateParams.Bodypublic final classAchPrenotificationCreateParams.BuilderA builder for AchPrenotificationCreateParams.
public final classAchPrenotificationCreateParams.CreditDebitIndicatorWhether the Prenotification is for a future debit or credit.
public final classAchPrenotificationCreateParams.StandardEntryClassCodeThe Standard Entry Class (SEC) code to use for the ACH Prenotification.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Increase identifier for the account that will send the transfer. final StringaccountNumber()The account number for the destination account. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<String>addendum()Additional information that will be sent to the recipient. final Optional<String>companyDescriptiveDate()The description of the date of the transfer. final Optional<String>companyDiscretionaryData()The data you choose to associate with the transfer. final Optional<String>companyEntryDescription()The description of the transfer you wish to be shown to the recipient. final Optional<String>companyName()The name by which the recipient knows you. final Optional<AchPrenotificationCreateParams.CreditDebitIndicator>creditDebitIndicator()Whether the Prenotification is for a future debit or credit. final Optional<LocalDate>effectiveDate()The transfer effective date in ISO 8601 format. final Optional<String>individualId()Your identifier for the transfer recipient. final Optional<String>individualName()The name of the transfer recipient. final Optional<AchPrenotificationCreateParams.StandardEntryClassCode>standardEntryClassCode()The Standard Entry Class (SEC) code to use for the ACH Prenotification. final JsonField<String>_accountId()The Increase identifier for the account that will send the transfer. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<String>_addendum()Additional information that will be sent to the recipient. final JsonField<String>_companyDescriptiveDate()The description of the date of the transfer. final JsonField<String>_companyDiscretionaryData()The data you choose to associate with the transfer. final JsonField<String>_companyEntryDescription()The description of the transfer you wish to be shown to the recipient. final JsonField<String>_companyName()The name by which the recipient knows you. final JsonField<AchPrenotificationCreateParams.CreditDebitIndicator>_creditDebitIndicator()Whether the Prenotification is for a future debit or credit. final JsonField<LocalDate>_effectiveDate()The transfer effective date in ISO 8601 format. final JsonField<String>_individualId()Your identifier for the transfer recipient. final JsonField<String>_individualName()The name of the transfer recipient. final JsonField<AchPrenotificationCreateParams.StandardEntryClassCode>_standardEntryClassCode()The Standard Entry Class (SEC) code to use for the ACH Prenotification. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final AchPrenotificationCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchPrenotificationCreateParams.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The Increase identifier for the account that will send the transfer.
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
addendum
final Optional<String> addendum()
Additional information that will be sent to the recipient.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
The data you choose to associate with the transfer.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the transfer you wish to be shown to the recipient.
-
companyName
final Optional<String> companyName()
The name by which the recipient knows you.
-
creditDebitIndicator
final Optional<AchPrenotificationCreateParams.CreditDebitIndicator> creditDebitIndicator()
Whether the Prenotification is for a future debit or credit.
-
effectiveDate
final Optional<LocalDate> effectiveDate()
The transfer effective date in ISO 8601 format.
-
individualId
final Optional<String> individualId()
Your identifier for the transfer recipient.
-
individualName
final Optional<String> individualName()
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
standardEntryClassCode
final Optional<AchPrenotificationCreateParams.StandardEntryClassCode> standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the ACH Prenotification.
-
_accountId
final JsonField<String> _accountId()
The Increase identifier for the account that will send the transfer.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_addendum
final JsonField<String> _addendum()
Additional information that will be sent to the recipient.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
The description of the date of the transfer.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
The data you choose to associate with the transfer.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
The description of the transfer you wish to be shown to the recipient.
-
_companyName
final JsonField<String> _companyName()
The name by which the recipient knows you.
-
_creditDebitIndicator
final JsonField<AchPrenotificationCreateParams.CreditDebitIndicator> _creditDebitIndicator()
Whether the Prenotification is for a future debit or credit.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
The transfer effective date in ISO 8601 format.
-
_individualId
final JsonField<String> _individualId()
Your identifier for the transfer recipient.
-
_individualName
final JsonField<String> _individualName()
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
_standardEntryClassCode
final JsonField<AchPrenotificationCreateParams.StandardEntryClassCode> _standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the ACH Prenotification.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final AchPrenotificationCreateParams.Builder toBuilder()
-
builder
final static AchPrenotificationCreateParams.Builder builder()
-
-
-
-