Class AchPrenotificationCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AchPrenotificationCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final AchPrenotificationCreateParams.Body.Builder accountId(String accountId)
The Increase identifier for the account that will send the transfer.
-
accountId
final AchPrenotificationCreateParams.Body.Builder accountId(JsonField<String> accountId)
The Increase identifier for the account that will send the transfer.
-
accountNumber
final AchPrenotificationCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final AchPrenotificationCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
The account number for the destination account.
-
routingNumber
final AchPrenotificationCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final AchPrenotificationCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
addendum
final AchPrenotificationCreateParams.Body.Builder addendum(String addendum)
Additional information that will be sent to the recipient.
-
addendum
final AchPrenotificationCreateParams.Body.Builder addendum(JsonField<String> addendum)
Additional information that will be sent to the recipient.
-
companyDescriptiveDate
final AchPrenotificationCreateParams.Body.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the transfer.
-
companyDescriptiveDate
final AchPrenotificationCreateParams.Body.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
The description of the date of the transfer.
-
companyDiscretionaryData
final AchPrenotificationCreateParams.Body.Builder companyDiscretionaryData(String companyDiscretionaryData)
The data you choose to associate with the transfer.
-
companyDiscretionaryData
final AchPrenotificationCreateParams.Body.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
The data you choose to associate with the transfer.
-
companyEntryDescription
final AchPrenotificationCreateParams.Body.Builder companyEntryDescription(String companyEntryDescription)
The description of the transfer you wish to be shown to the recipient.
-
companyEntryDescription
final AchPrenotificationCreateParams.Body.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
The description of the transfer you wish to be shown to the recipient.
-
companyName
final AchPrenotificationCreateParams.Body.Builder companyName(String companyName)
The name by which the recipient knows you.
-
companyName
final AchPrenotificationCreateParams.Body.Builder companyName(JsonField<String> companyName)
The name by which the recipient knows you.
-
creditDebitIndicator
final AchPrenotificationCreateParams.Body.Builder creditDebitIndicator(AchPrenotificationCreateParams.CreditDebitIndicator creditDebitIndicator)
Whether the Prenotification is for a future debit or credit.
-
creditDebitIndicator
final AchPrenotificationCreateParams.Body.Builder creditDebitIndicator(JsonField<AchPrenotificationCreateParams.CreditDebitIndicator> creditDebitIndicator)
Whether the Prenotification is for a future debit or credit.
-
effectiveDate
final AchPrenotificationCreateParams.Body.Builder effectiveDate(LocalDate effectiveDate)
The transfer effective date in ISO 8601 format.
-
effectiveDate
final AchPrenotificationCreateParams.Body.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
The transfer effective date in ISO 8601 format.
-
individualId
final AchPrenotificationCreateParams.Body.Builder individualId(String individualId)
Your identifier for the transfer recipient.
-
individualId
final AchPrenotificationCreateParams.Body.Builder individualId(JsonField<String> individualId)
Your identifier for the transfer recipient.
-
individualName
final AchPrenotificationCreateParams.Body.Builder individualName(String individualName)
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
individualName
final AchPrenotificationCreateParams.Body.Builder individualName(JsonField<String> individualName)
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
standardEntryClassCode
final AchPrenotificationCreateParams.Body.Builder standardEntryClassCode(AchPrenotificationCreateParams.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the ACH Prenotification.
-
standardEntryClassCode
final AchPrenotificationCreateParams.Body.Builder standardEntryClassCode(JsonField<AchPrenotificationCreateParams.StandardEntryClassCode> standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the ACH Prenotification.
-
additionalProperties
final AchPrenotificationCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchPrenotificationCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchPrenotificationCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchPrenotificationCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchPrenotificationCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchPrenotificationCreateParams.Body build()
-
-
-
-