Class AchTransfer
-
- All Implemented Interfaces:
public final class AchTransferACH transfers move funds between your Increase account and any other account accessible by the Automated Clearing House (ACH).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.BuilderA builder for AchTransfer.
public final classAchTransfer.AcknowledgementAfter the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
public final classAchTransfer.AddendaAdditional information that will be sent to the recipient.
public final classAchTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classAchTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classAchTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classAchTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.public final classAchTransfer.DestinationAccountHolderThe type of entity that owns the account to which the ACH Transfer is being sent.
public final classAchTransfer.FundingThe type of the account to which the transfer will be sent.
public final classAchTransfer.InboundFundsHoldIncrease will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
public final classAchTransfer.NetworkThe transfer's network.
public final classAchTransfer.NotificationsOfChangepublic final classAchTransfer.PreferredEffectiveDateConfiguration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.public final classAchTransfer.ReturnIf your transfer is returned, this will contain details of the return.
public final classAchTransfer.SettlementA subhash containing information about when and how the transfer settled at the Federal Reserve.
public final classAchTransfer.StandardEntryClassCodeThe Standard Entry Class (SEC) code to use for the transfer.
public final classAchTransfer.StatusThe lifecycle status of the transfer.
public final classAchTransfer.SubmissionAfter the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
public final classAchTransfer.TypeA constant representing the object's type. For this resource it will always be
ach_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The ACH transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumber()The destination account number. final Optional<AchTransfer.Acknowledgement>acknowledgement()After the transfer is acknowledged by FedACH, this will contain supplemental details. final Optional<AchTransfer.Addenda>addenda()Additional information that will be sent to the recipient. final Longamount()The transfer amount in USD cents. final Optional<AchTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<AchTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final Optional<String>companyDescriptiveDate()The description of the date of the transfer. final Optional<String>companyDiscretionaryData()The data you chose to associate with the transfer. final Optional<String>companyEntryDescription()The description of the transfer you set to be shown to the recipient. final Optional<String>companyName()The name by which the recipient knows you. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<AchTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final AchTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final AchTransfer.DestinationAccountHolderdestinationAccountHolder()The type of entity that owns the account to which the ACH Transfer is being sent. final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final AchTransfer.Fundingfunding()The type of the account to which the transfer will be sent. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<AchTransfer.InboundFundsHold>inboundFundsHold()Increase will sometimes hold the funds for ACH debit transfers. final Optional<String>individualId()Your identifier for the transfer recipient. final Optional<String>individualName()The name of the transfer recipient. final AchTransfer.Networknetwork()The transfer's network. final List<AchTransfer.NotificationsOfChange>notificationsOfChange()If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final AchTransfer.PreferredEffectiveDatepreferredEffectiveDate()Configuration for how the effective date of the transfer will be set. final Optional<AchTransfer.Return>return_()If your transfer is returned, this will contain details of the return. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<AchTransfer.Settlement>settlement()A subhash containing information about when and how the transfer settled at the Federal Reserve. final AchTransfer.StandardEntryClassCodestandardEntryClassCode()The Standard Entry Class (SEC) code to use for the transfer. final StringstatementDescriptor()The descriptor that will show on the recipient's bank statement. final AchTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<AchTransfer.Submission>submission()After the transfer is submitted to FedACH, this will contain supplemental details. final Optional<String>transactionId()The ID for the transaction funding the transfer. final AchTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The ACH transfer's identifier. final JsonField<String>_accountId()The Account to which the transfer belongs. final JsonField<String>_accountNumber()The destination account number. final JsonField<AchTransfer.Acknowledgement>_acknowledgement()After the transfer is acknowledged by FedACH, this will contain supplemental details. final JsonField<AchTransfer.Addenda>_addenda()Additional information that will be sent to the recipient. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<AchTransfer.Approval>_approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final JsonField<AchTransfer.Cancellation>_cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final JsonField<String>_companyDescriptiveDate()The description of the date of the transfer. final JsonField<String>_companyDiscretionaryData()The data you chose to associate with the transfer. final JsonField<String>_companyEntryDescription()The description of the transfer you set to be shown to the recipient. final JsonField<String>_companyName()The name by which the recipient knows you. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<AchTransfer.CreatedBy>_createdBy()What object created the transfer, either via the API or the dashboard. final JsonField<AchTransfer.Currency>_currency()The ISO 4217 code for the transfer's currency. final JsonField<AchTransfer.DestinationAccountHolder>_destinationAccountHolder()The type of entity that owns the account to which the ACH Transfer is being sent. final JsonField<String>_externalAccountId()The identifier of the External Account the transfer was made to, if any. final JsonField<AchTransfer.Funding>_funding()The type of the account to which the transfer will be sent. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<AchTransfer.InboundFundsHold>_inboundFundsHold()Increase will sometimes hold the funds for ACH debit transfers. final JsonField<String>_individualId()Your identifier for the transfer recipient. final JsonField<String>_individualName()The name of the transfer recipient. final JsonField<AchTransfer.Network>_network()The transfer's network. final JsonField<List<AchTransfer.NotificationsOfChange>>_notificationsOfChange()If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final JsonField<String>_pendingTransactionId()The ID for the pending transaction representing the transfer. final JsonField<AchTransfer.PreferredEffectiveDate>_preferredEffectiveDate()Configuration for how the effective date of the transfer will be set. final JsonField<AchTransfer.Return>_return_()If your transfer is returned, this will contain details of the return. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<AchTransfer.Settlement>_settlement()A subhash containing information about when and how the transfer settled at the Federal Reserve. final JsonField<AchTransfer.StandardEntryClassCode>_standardEntryClassCode()The Standard Entry Class (SEC) code to use for the transfer. final JsonField<String>_statementDescriptor()The descriptor that will show on the recipient's bank statement. final JsonField<AchTransfer.Status>_status()The lifecycle status of the transfer. final JsonField<AchTransfer.Submission>_submission()After the transfer is submitted to FedACH, this will contain supplemental details. final JsonField<String>_transactionId()The ID for the transaction funding the transfer. final JsonField<AchTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final AchTransfervalidate()final AchTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
acknowledgement
final Optional<AchTransfer.Acknowledgement> acknowledgement()
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
addenda
final Optional<AchTransfer.Addenda> addenda()
Additional information that will be sent to the recipient.
-
amount
final Long amount()
The transfer amount in USD cents. A positive amount indicates a credit transfer pushing funds to the receiving account. A negative amount indicates a debit transfer pulling funds from the receiving account.
-
approval
final Optional<AchTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final Optional<AchTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
The data you chose to associate with the transfer.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the transfer you set to be shown to the recipient.
-
companyName
final Optional<String> companyName()
The name by which the recipient knows you.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<AchTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final AchTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.
-
destinationAccountHolder
final AchTransfer.DestinationAccountHolder destinationAccountHolder()
The type of entity that owns the account to which the ACH Transfer is being sent.
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
funding
final AchTransfer.Funding funding()
The type of the account to which the transfer will be sent.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundFundsHold
final Optional<AchTransfer.InboundFundsHold> inboundFundsHold()
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
individualId
final Optional<String> individualId()
Your identifier for the transfer recipient.
-
individualName
final Optional<String> individualName()
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
network
final AchTransfer.Network network()
The transfer's network.
-
notificationsOfChange
final List<AchTransfer.NotificationsOfChange> notificationsOfChange()
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
preferredEffectiveDate
final AchTransfer.PreferredEffectiveDate preferredEffectiveDate()
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
return_
final Optional<AchTransfer.Return> return_()
If your transfer is returned, this will contain details of the return.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
settlement
final Optional<AchTransfer.Settlement> settlement()
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
standardEntryClassCode
final AchTransfer.StandardEntryClassCode standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the transfer.
-
statementDescriptor
final String statementDescriptor()
The descriptor that will show on the recipient's bank statement.
-
status
final AchTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<AchTransfer.Submission> submission()
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
transactionId
final Optional<String> transactionId()
The ID for the transaction funding the transfer.
-
type
final AchTransfer.Type type()
A constant representing the object's type. For this resource it will always be
ach_transfer.
-
_accountId
final JsonField<String> _accountId()
The Account to which the transfer belongs.
-
_accountNumber
final JsonField<String> _accountNumber()
The destination account number.
-
_acknowledgement
final JsonField<AchTransfer.Acknowledgement> _acknowledgement()
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
_addenda
final JsonField<AchTransfer.Addenda> _addenda()
Additional information that will be sent to the recipient.
-
_amount
final JsonField<Long> _amount()
The transfer amount in USD cents. A positive amount indicates a credit transfer pushing funds to the receiving account. A negative amount indicates a debit transfer pulling funds from the receiving account.
-
_approval
final JsonField<AchTransfer.Approval> _approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
_cancellation
final JsonField<AchTransfer.Cancellation> _cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
The description of the date of the transfer.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
The data you chose to associate with the transfer.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
The description of the transfer you set to be shown to the recipient.
-
_companyName
final JsonField<String> _companyName()
The name by which the recipient knows you.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_createdBy
final JsonField<AchTransfer.CreatedBy> _createdBy()
What object created the transfer, either via the API or the dashboard.
-
_currency
final JsonField<AchTransfer.Currency> _currency()
The ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.
-
_destinationAccountHolder
final JsonField<AchTransfer.DestinationAccountHolder> _destinationAccountHolder()
The type of entity that owns the account to which the ACH Transfer is being sent.
-
_externalAccountId
final JsonField<String> _externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
_funding
final JsonField<AchTransfer.Funding> _funding()
The type of the account to which the transfer will be sent.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_inboundFundsHold
final JsonField<AchTransfer.InboundFundsHold> _inboundFundsHold()
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
_individualId
final JsonField<String> _individualId()
Your identifier for the transfer recipient.
-
_individualName
final JsonField<String> _individualName()
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
_network
final JsonField<AchTransfer.Network> _network()
The transfer's network.
-
_notificationsOfChange
final JsonField<List<AchTransfer.NotificationsOfChange>> _notificationsOfChange()
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
_preferredEffectiveDate
final JsonField<AchTransfer.PreferredEffectiveDate> _preferredEffectiveDate()
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
_return_
final JsonField<AchTransfer.Return> _return_()
If your transfer is returned, this will contain details of the return.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_settlement
final JsonField<AchTransfer.Settlement> _settlement()
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
_standardEntryClassCode
final JsonField<AchTransfer.StandardEntryClassCode> _standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the transfer.
-
_statementDescriptor
final JsonField<String> _statementDescriptor()
The descriptor that will show on the recipient's bank statement.
-
_status
final JsonField<AchTransfer.Status> _status()
The lifecycle status of the transfer.
-
_submission
final JsonField<AchTransfer.Submission> _submission()
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
_transactionId
final JsonField<String> _transactionId()
The ID for the transaction funding the transfer.
-
_type
final JsonField<AchTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
ach_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer validate()
-
toBuilder
final AchTransfer.Builder toBuilder()
-
builder
final static AchTransfer.Builder builder()
-
-
-
-