Class AchTransfer.Addenda
-
- All Implemented Interfaces:
public final class AchTransfer.AddendaAdditional information that will be sent to the recipient.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Addenda.BuilderA builder for Addenda.
public final classAchTransfer.Addenda.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classAchTransfer.Addenda.FreeformUnstructured
payment_related_informationpassed through with the transfer.public final classAchTransfer.Addenda.PaymentOrderRemittanceAdviceStructured ASC X12 820 remittance advice records. Please reach out to [email protected] for more information.
-
Method Summary
-
-
Method Detail
-
category
final AchTransfer.Addenda.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
freeform
final Optional<AchTransfer.Addenda.Freeform> freeform()
Unstructured
payment_related_informationpassed through with the transfer.
-
paymentOrderRemittanceAdvice
final Optional<AchTransfer.Addenda.PaymentOrderRemittanceAdvice> paymentOrderRemittanceAdvice()
Structured ASC X12 820 remittance advice records. Please reach out to [email protected] for more information.
-
_category
final JsonField<AchTransfer.Addenda.Category> _category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
_freeform
final JsonField<AchTransfer.Addenda.Freeform> _freeform()
Unstructured
payment_related_informationpassed through with the transfer.
-
_paymentOrderRemittanceAdvice
final JsonField<AchTransfer.Addenda.PaymentOrderRemittanceAdvice> _paymentOrderRemittanceAdvice()
Structured ASC X12 820 remittance advice records. Please reach out to [email protected] for more information.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.Addenda validate()
-
toBuilder
final AchTransfer.Addenda.Builder toBuilder()
-
builder
final static AchTransfer.Addenda.Builder builder()
-
-
-
-