Class AchTransfer.Builder
-
- All Implemented Interfaces:
public final class AchTransfer.BuilderA builder for AchTransfer.
-
-
Method Summary
Modifier and Type Method Description final AchTransfer.Builderid(String id)The ACH transfer's identifier. final AchTransfer.Builderid(JsonField<String> id)The ACH transfer's identifier. final AchTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final AchTransfer.BuilderaccountId(JsonField<String> accountId)The Account to which the transfer belongs. final AchTransfer.BuilderaccountNumber(String accountNumber)The destination account number. final AchTransfer.BuilderaccountNumber(JsonField<String> accountNumber)The destination account number. final AchTransfer.Builderacknowledgement(AchTransfer.Acknowledgement acknowledgement)After the transfer is acknowledged by FedACH, this will contain supplemental details. final AchTransfer.Builderacknowledgement(Optional<AchTransfer.Acknowledgement> acknowledgement)After the transfer is acknowledged by FedACH, this will contain supplemental details. final AchTransfer.Builderacknowledgement(JsonField<AchTransfer.Acknowledgement> acknowledgement)After the transfer is acknowledged by FedACH, this will contain supplemental details. final AchTransfer.Builderaddenda(AchTransfer.Addenda addenda)Additional information that will be sent to the recipient. final AchTransfer.Builderaddenda(Optional<AchTransfer.Addenda> addenda)Additional information that will be sent to the recipient. final AchTransfer.Builderaddenda(JsonField<AchTransfer.Addenda> addenda)Additional information that will be sent to the recipient. final AchTransfer.Builderamount(Long amount)The transfer amount in USD cents. final AchTransfer.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final AchTransfer.Builderapproval(AchTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AchTransfer.Builderapproval(Optional<AchTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AchTransfer.Builderapproval(JsonField<AchTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AchTransfer.Buildercancellation(AchTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AchTransfer.Buildercancellation(Optional<AchTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AchTransfer.Buildercancellation(JsonField<AchTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AchTransfer.BuildercompanyDescriptiveDate(String companyDescriptiveDate)The description of the date of the transfer. final AchTransfer.BuildercompanyDescriptiveDate(Optional<String> companyDescriptiveDate)The description of the date of the transfer. final AchTransfer.BuildercompanyDescriptiveDate(JsonField<String> companyDescriptiveDate)The description of the date of the transfer. final AchTransfer.BuildercompanyDiscretionaryData(String companyDiscretionaryData)The data you chose to associate with the transfer. final AchTransfer.BuildercompanyDiscretionaryData(Optional<String> companyDiscretionaryData)The data you chose to associate with the transfer. final AchTransfer.BuildercompanyDiscretionaryData(JsonField<String> companyDiscretionaryData)The data you chose to associate with the transfer. final AchTransfer.BuildercompanyEntryDescription(String companyEntryDescription)The description of the transfer you set to be shown to the recipient. final AchTransfer.BuildercompanyEntryDescription(Optional<String> companyEntryDescription)The description of the transfer you set to be shown to the recipient. final AchTransfer.BuildercompanyEntryDescription(JsonField<String> companyEntryDescription)The description of the transfer you set to be shown to the recipient. final AchTransfer.BuildercompanyName(String companyName)The name by which the recipient knows you. final AchTransfer.BuildercompanyName(Optional<String> companyName)The name by which the recipient knows you. final AchTransfer.BuildercompanyName(JsonField<String> companyName)The name by which the recipient knows you. final AchTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final AchTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the transfer was created. final AchTransfer.BuildercreatedBy(AchTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final AchTransfer.BuildercreatedBy(Optional<AchTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final AchTransfer.BuildercreatedBy(JsonField<AchTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final AchTransfer.Buildercurrency(AchTransfer.Currency currency)The ISO 4217 code for the transfer's currency. final AchTransfer.Buildercurrency(JsonField<AchTransfer.Currency> currency)The ISO 4217 code for the transfer's currency. final AchTransfer.BuilderdestinationAccountHolder(AchTransfer.DestinationAccountHolder destinationAccountHolder)The type of entity that owns the account to which the ACH Transfer is being sent. final AchTransfer.BuilderdestinationAccountHolder(JsonField<AchTransfer.DestinationAccountHolder> destinationAccountHolder)The type of entity that owns the account to which the ACH Transfer is being sent. final AchTransfer.BuilderexternalAccountId(String externalAccountId)The identifier of the External Account the transfer was made to, if any. final AchTransfer.BuilderexternalAccountId(Optional<String> externalAccountId)The identifier of the External Account the transfer was made to, if any. final AchTransfer.BuilderexternalAccountId(JsonField<String> externalAccountId)The identifier of the External Account the transfer was made to, if any. final AchTransfer.Builderfunding(AchTransfer.Funding funding)The type of the account to which the transfer will be sent. final AchTransfer.Builderfunding(JsonField<AchTransfer.Funding> funding)The type of the account to which the transfer will be sent. final AchTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AchTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final AchTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final AchTransfer.BuilderinboundFundsHold(AchTransfer.InboundFundsHold inboundFundsHold)Increase will sometimes hold the funds for ACH debit transfers. final AchTransfer.BuilderinboundFundsHold(Optional<AchTransfer.InboundFundsHold> inboundFundsHold)Increase will sometimes hold the funds for ACH debit transfers. final AchTransfer.BuilderinboundFundsHold(JsonField<AchTransfer.InboundFundsHold> inboundFundsHold)Increase will sometimes hold the funds for ACH debit transfers. final AchTransfer.BuilderindividualId(String individualId)Your identifier for the transfer recipient. final AchTransfer.BuilderindividualId(Optional<String> individualId)Your identifier for the transfer recipient. final AchTransfer.BuilderindividualId(JsonField<String> individualId)Your identifier for the transfer recipient. final AchTransfer.BuilderindividualName(String individualName)The name of the transfer recipient. final AchTransfer.BuilderindividualName(Optional<String> individualName)The name of the transfer recipient. final AchTransfer.BuilderindividualName(JsonField<String> individualName)The name of the transfer recipient. final AchTransfer.Buildernetwork(AchTransfer.Network network)The transfer's network. final AchTransfer.Buildernetwork(JsonField<AchTransfer.Network> network)The transfer's network. final AchTransfer.BuildernotificationsOfChange(List<AchTransfer.NotificationsOfChange> notificationsOfChange)If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final AchTransfer.BuildernotificationsOfChange(JsonField<List<AchTransfer.NotificationsOfChange>> notificationsOfChange)If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final AchTransfer.BuilderaddNotificationsOfChange(AchTransfer.NotificationsOfChange notificationsOfChange)If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final AchTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final AchTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final AchTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final AchTransfer.BuilderpreferredEffectiveDate(AchTransfer.PreferredEffectiveDate preferredEffectiveDate)Configuration for how the effective date of the transfer will be set. final AchTransfer.BuilderpreferredEffectiveDate(JsonField<AchTransfer.PreferredEffectiveDate> preferredEffectiveDate)Configuration for how the effective date of the transfer will be set. final AchTransfer.Builderreturn_(AchTransfer.Return return_)If your transfer is returned, this will contain details of the return. final AchTransfer.Builderreturn_(Optional<AchTransfer.Return> return_)If your transfer is returned, this will contain details of the return. final AchTransfer.Builderreturn_(JsonField<AchTransfer.Return> return_)If your transfer is returned, this will contain details of the return. final AchTransfer.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AchTransfer.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AchTransfer.Buildersettlement(AchTransfer.Settlement settlement)A subhash containing information about when and how the transfer settled at the Federal Reserve. final AchTransfer.Buildersettlement(Optional<AchTransfer.Settlement> settlement)A subhash containing information about when and how the transfer settled at the Federal Reserve. final AchTransfer.Buildersettlement(JsonField<AchTransfer.Settlement> settlement)A subhash containing information about when and how the transfer settled at the Federal Reserve. final AchTransfer.BuilderstandardEntryClassCode(AchTransfer.StandardEntryClassCode standardEntryClassCode)The Standard Entry Class (SEC) code to use for the transfer. final AchTransfer.BuilderstandardEntryClassCode(JsonField<AchTransfer.StandardEntryClassCode> standardEntryClassCode)The Standard Entry Class (SEC) code to use for the transfer. final AchTransfer.BuilderstatementDescriptor(String statementDescriptor)The descriptor that will show on the recipient's bank statement. final AchTransfer.BuilderstatementDescriptor(JsonField<String> statementDescriptor)The descriptor that will show on the recipient's bank statement. final AchTransfer.Builderstatus(AchTransfer.Status status)The lifecycle status of the transfer. final AchTransfer.Builderstatus(JsonField<AchTransfer.Status> status)The lifecycle status of the transfer. final AchTransfer.Buildersubmission(AchTransfer.Submission submission)After the transfer is submitted to FedACH, this will contain supplemental details. final AchTransfer.Buildersubmission(Optional<AchTransfer.Submission> submission)After the transfer is submitted to FedACH, this will contain supplemental details. final AchTransfer.Buildersubmission(JsonField<AchTransfer.Submission> submission)After the transfer is submitted to FedACH, this will contain supplemental details. final AchTransfer.BuildertransactionId(String transactionId)The ID for the transaction funding the transfer. final AchTransfer.BuildertransactionId(Optional<String> transactionId)The ID for the transaction funding the transfer. final AchTransfer.BuildertransactionId(JsonField<String> transactionId)The ID for the transaction funding the transfer. final AchTransfer.Buildertype(AchTransfer.Type type)A constant representing the object's type. final AchTransfer.Buildertype(JsonField<AchTransfer.Type> type)A constant representing the object's type. final AchTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final AchTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.BuilderremoveAdditionalProperty(String key)final AchTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchTransferbuild()-
-
Method Detail
-
id
final AchTransfer.Builder id(String id)
The ACH transfer's identifier.
-
id
final AchTransfer.Builder id(JsonField<String> id)
The ACH transfer's identifier.
-
accountId
final AchTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final AchTransfer.Builder accountId(JsonField<String> accountId)
The Account to which the transfer belongs.
-
accountNumber
final AchTransfer.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final AchTransfer.Builder accountNumber(JsonField<String> accountNumber)
The destination account number.
-
acknowledgement
final AchTransfer.Builder acknowledgement(AchTransfer.Acknowledgement acknowledgement)
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
acknowledgement
final AchTransfer.Builder acknowledgement(Optional<AchTransfer.Acknowledgement> acknowledgement)
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
acknowledgement
final AchTransfer.Builder acknowledgement(JsonField<AchTransfer.Acknowledgement> acknowledgement)
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
addenda
final AchTransfer.Builder addenda(AchTransfer.Addenda addenda)
Additional information that will be sent to the recipient.
-
addenda
final AchTransfer.Builder addenda(Optional<AchTransfer.Addenda> addenda)
Additional information that will be sent to the recipient.
-
addenda
final AchTransfer.Builder addenda(JsonField<AchTransfer.Addenda> addenda)
Additional information that will be sent to the recipient.
-
amount
final AchTransfer.Builder amount(Long amount)
The transfer amount in USD cents. A positive amount indicates a credit transfer pushing funds to the receiving account. A negative amount indicates a debit transfer pulling funds from the receiving account.
-
amount
final AchTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents. A positive amount indicates a credit transfer pushing funds to the receiving account. A negative amount indicates a debit transfer pulling funds from the receiving account.
-
approval
final AchTransfer.Builder approval(AchTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final AchTransfer.Builder approval(Optional<AchTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final AchTransfer.Builder approval(JsonField<AchTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final AchTransfer.Builder cancellation(AchTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final AchTransfer.Builder cancellation(Optional<AchTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final AchTransfer.Builder cancellation(JsonField<AchTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
companyDescriptiveDate
final AchTransfer.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the transfer.
-
companyDescriptiveDate
final AchTransfer.Builder companyDescriptiveDate(Optional<String> companyDescriptiveDate)
The description of the date of the transfer.
-
companyDescriptiveDate
final AchTransfer.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
The description of the date of the transfer.
-
companyDiscretionaryData
final AchTransfer.Builder companyDiscretionaryData(String companyDiscretionaryData)
The data you chose to associate with the transfer.
-
companyDiscretionaryData
final AchTransfer.Builder companyDiscretionaryData(Optional<String> companyDiscretionaryData)
The data you chose to associate with the transfer.
-
companyDiscretionaryData
final AchTransfer.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
The data you chose to associate with the transfer.
-
companyEntryDescription
final AchTransfer.Builder companyEntryDescription(String companyEntryDescription)
The description of the transfer you set to be shown to the recipient.
-
companyEntryDescription
final AchTransfer.Builder companyEntryDescription(Optional<String> companyEntryDescription)
The description of the transfer you set to be shown to the recipient.
-
companyEntryDescription
final AchTransfer.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
The description of the transfer you set to be shown to the recipient.
-
companyName
final AchTransfer.Builder companyName(String companyName)
The name by which the recipient knows you.
-
companyName
final AchTransfer.Builder companyName(Optional<String> companyName)
The name by which the recipient knows you.
-
companyName
final AchTransfer.Builder companyName(JsonField<String> companyName)
The name by which the recipient knows you.
-
createdAt
final AchTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final AchTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final AchTransfer.Builder createdBy(AchTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final AchTransfer.Builder createdBy(Optional<AchTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final AchTransfer.Builder createdBy(JsonField<AchTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
currency
final AchTransfer.Builder currency(AchTransfer.Currency currency)
The ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.
-
currency
final AchTransfer.Builder currency(JsonField<AchTransfer.Currency> currency)
The ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.
-
destinationAccountHolder
final AchTransfer.Builder destinationAccountHolder(AchTransfer.DestinationAccountHolder destinationAccountHolder)
The type of entity that owns the account to which the ACH Transfer is being sent.
-
destinationAccountHolder
final AchTransfer.Builder destinationAccountHolder(JsonField<AchTransfer.DestinationAccountHolder> destinationAccountHolder)
The type of entity that owns the account to which the ACH Transfer is being sent.
-
externalAccountId
final AchTransfer.Builder externalAccountId(String externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final AchTransfer.Builder externalAccountId(Optional<String> externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final AchTransfer.Builder externalAccountId(JsonField<String> externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
funding
final AchTransfer.Builder funding(AchTransfer.Funding funding)
The type of the account to which the transfer will be sent.
-
funding
final AchTransfer.Builder funding(JsonField<AchTransfer.Funding> funding)
The type of the account to which the transfer will be sent.
-
idempotencyKey
final AchTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AchTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AchTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundFundsHold
final AchTransfer.Builder inboundFundsHold(AchTransfer.InboundFundsHold inboundFundsHold)
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
inboundFundsHold
final AchTransfer.Builder inboundFundsHold(Optional<AchTransfer.InboundFundsHold> inboundFundsHold)
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
inboundFundsHold
final AchTransfer.Builder inboundFundsHold(JsonField<AchTransfer.InboundFundsHold> inboundFundsHold)
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
individualId
final AchTransfer.Builder individualId(String individualId)
Your identifier for the transfer recipient.
-
individualId
final AchTransfer.Builder individualId(Optional<String> individualId)
Your identifier for the transfer recipient.
-
individualId
final AchTransfer.Builder individualId(JsonField<String> individualId)
Your identifier for the transfer recipient.
-
individualName
final AchTransfer.Builder individualName(String individualName)
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
individualName
final AchTransfer.Builder individualName(Optional<String> individualName)
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
individualName
final AchTransfer.Builder individualName(JsonField<String> individualName)
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
network
final AchTransfer.Builder network(AchTransfer.Network network)
The transfer's network.
-
network
final AchTransfer.Builder network(JsonField<AchTransfer.Network> network)
The transfer's network.
-
notificationsOfChange
final AchTransfer.Builder notificationsOfChange(List<AchTransfer.NotificationsOfChange> notificationsOfChange)
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
notificationsOfChange
final AchTransfer.Builder notificationsOfChange(JsonField<List<AchTransfer.NotificationsOfChange>> notificationsOfChange)
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
addNotificationsOfChange
final AchTransfer.Builder addNotificationsOfChange(AchTransfer.NotificationsOfChange notificationsOfChange)
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
pendingTransactionId
final AchTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final AchTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final AchTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
preferredEffectiveDate
final AchTransfer.Builder preferredEffectiveDate(AchTransfer.PreferredEffectiveDate preferredEffectiveDate)
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
preferredEffectiveDate
final AchTransfer.Builder preferredEffectiveDate(JsonField<AchTransfer.PreferredEffectiveDate> preferredEffectiveDate)
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
return_
final AchTransfer.Builder return_(AchTransfer.Return return_)
If your transfer is returned, this will contain details of the return.
-
return_
final AchTransfer.Builder return_(Optional<AchTransfer.Return> return_)
If your transfer is returned, this will contain details of the return.
-
return_
final AchTransfer.Builder return_(JsonField<AchTransfer.Return> return_)
If your transfer is returned, this will contain details of the return.
-
routingNumber
final AchTransfer.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final AchTransfer.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
settlement
final AchTransfer.Builder settlement(AchTransfer.Settlement settlement)
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
settlement
final AchTransfer.Builder settlement(Optional<AchTransfer.Settlement> settlement)
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
settlement
final AchTransfer.Builder settlement(JsonField<AchTransfer.Settlement> settlement)
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
standardEntryClassCode
final AchTransfer.Builder standardEntryClassCode(AchTransfer.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the transfer.
-
standardEntryClassCode
final AchTransfer.Builder standardEntryClassCode(JsonField<AchTransfer.StandardEntryClassCode> standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the transfer.
-
statementDescriptor
final AchTransfer.Builder statementDescriptor(String statementDescriptor)
The descriptor that will show on the recipient's bank statement.
-
statementDescriptor
final AchTransfer.Builder statementDescriptor(JsonField<String> statementDescriptor)
The descriptor that will show on the recipient's bank statement.
-
status
final AchTransfer.Builder status(AchTransfer.Status status)
The lifecycle status of the transfer.
-
status
final AchTransfer.Builder status(JsonField<AchTransfer.Status> status)
The lifecycle status of the transfer.
-
submission
final AchTransfer.Builder submission(AchTransfer.Submission submission)
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
submission
final AchTransfer.Builder submission(Optional<AchTransfer.Submission> submission)
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
submission
final AchTransfer.Builder submission(JsonField<AchTransfer.Submission> submission)
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
transactionId
final AchTransfer.Builder transactionId(String transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final AchTransfer.Builder transactionId(Optional<String> transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final AchTransfer.Builder transactionId(JsonField<String> transactionId)
The ID for the transaction funding the transfer.
-
type
final AchTransfer.Builder type(AchTransfer.Type type)
A constant representing the object's type. For this resource it will always be
ach_transfer.
-
type
final AchTransfer.Builder type(JsonField<AchTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
ach_transfer.
-
additionalProperties
final AchTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransfer build()
-
-
-
-