Package com.increase.api.models
Class AchTransfer.Cancellation
-
- All Implemented Interfaces:
public final class AchTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Cancellation.BuilderA builder for Cancellation.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecanceledAt()The ISO 8601 date and time at which the Transfer was canceled. final Optional<String>canceledBy()If the Transfer was canceled by a user in the dashboard, the email address of that user. final JsonField<OffsetDateTime>_canceledAt()The ISO 8601 date and time at which the Transfer was canceled. final JsonField<String>_canceledBy()If the Transfer was canceled by a user in the dashboard, the email address of that user. final Map<String, JsonValue>_additionalProperties()final AchTransfer.Cancellationvalidate()final AchTransfer.Cancellation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Cancellation.Builderbuilder()-
-
Method Detail
-
canceledAt
final OffsetDateTime canceledAt()
The ISO 8601 date and time at which the Transfer was canceled.
-
canceledBy
final Optional<String> canceledBy()
If the Transfer was canceled by a user in the dashboard, the email address of that user.
-
_canceledAt
final JsonField<OffsetDateTime> _canceledAt()
The ISO 8601 date and time at which the Transfer was canceled.
-
_canceledBy
final JsonField<String> _canceledBy()
If the Transfer was canceled by a user in the dashboard, the email address of that user.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.Cancellation validate()
-
toBuilder
final AchTransfer.Cancellation.Builder toBuilder()
-
builder
final static AchTransfer.Cancellation.Builder builder()
-
-
-
-