Class AchTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class AchTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classAchTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classAchTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classAchTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classAchTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final Optional<AchTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final AchTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<AchTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<AchTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<AchTransfer.CreatedBy.ApiKey>_apiKey()If present, details about the API key that created the transfer. final JsonField<AchTransfer.CreatedBy.Category>_category()The type of object that created this transfer. final JsonField<AchTransfer.CreatedBy.OAuthApplication>_oauthApplication()If present, details about the OAuth Application that created the transfer. final JsonField<AchTransfer.CreatedBy.User>_user()If present, details about the User that created the transfer. final Map<String, JsonValue>_additionalProperties()final AchTransfer.CreatedByvalidate()final AchTransfer.CreatedBy.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.CreatedBy.Builderbuilder()-
-
Method Detail
-
apiKey
final Optional<AchTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
category
final AchTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
oauthApplication
final Optional<AchTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<AchTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_apiKey
final JsonField<AchTransfer.CreatedBy.ApiKey> _apiKey()
If present, details about the API key that created the transfer.
-
_category
final JsonField<AchTransfer.CreatedBy.Category> _category()
The type of object that created this transfer.
-
_oauthApplication
final JsonField<AchTransfer.CreatedBy.OAuthApplication> _oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
_user
final JsonField<AchTransfer.CreatedBy.User> _user()
If present, details about the User that created the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.CreatedBy validate()
-
toBuilder
final AchTransfer.CreatedBy.Builder toBuilder()
-
builder
final static AchTransfer.CreatedBy.Builder builder()
-
-
-
-