Class AchTransfer.InboundFundsHold
-
- All Implemented Interfaces:
public final class AchTransfer.InboundFundsHoldIncrease will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.InboundFundsHold.BuilderA builder for InboundFundsHold.
public final classAchTransfer.InboundFundsHold.CurrencyThe ISO 4217 code for the hold's currency.
public final classAchTransfer.InboundFundsHold.StatusThe status of the hold.
public final classAchTransfer.InboundFundsHold.TypeA constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
Method Summary
Modifier and Type Method Description final Stringid()The Inbound Funds Hold identifier. final Longamount()The held amount in the minor unit of the account's currency. final OffsetDateTimeautomaticallyReleasesAt()When the hold will be released automatically. final OffsetDateTimecreatedAt()The ISO 8601 time at which the hold was created. final AchTransfer.InboundFundsHold.Currencycurrency()The ISO 4217 code for the hold's currency. final Optional<String>heldTransactionId()The ID of the Transaction for which funds were held. final Optional<String>pendingTransactionId()The ID of the Pending Transaction representing the held funds. final Optional<OffsetDateTime>releasedAt()When the hold was released (if it has been released). final AchTransfer.InboundFundsHold.Statusstatus()The status of the hold. final AchTransfer.InboundFundsHold.Typetype()A constant representing the object's type. final JsonField<String>_id()The Inbound Funds Hold identifier. final JsonField<Long>_amount()The held amount in the minor unit of the account's currency. final JsonField<OffsetDateTime>_automaticallyReleasesAt()When the hold will be released automatically. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the hold was created. final JsonField<AchTransfer.InboundFundsHold.Currency>_currency()The ISO 4217 code for the hold's currency. final JsonField<String>_heldTransactionId()The ID of the Transaction for which funds were held. final JsonField<String>_pendingTransactionId()The ID of the Pending Transaction representing the held funds. final JsonField<OffsetDateTime>_releasedAt()When the hold was released (if it has been released). final JsonField<AchTransfer.InboundFundsHold.Status>_status()The status of the hold. final JsonField<AchTransfer.InboundFundsHold.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final AchTransfer.InboundFundsHoldvalidate()final AchTransfer.InboundFundsHold.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.InboundFundsHold.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final OffsetDateTime automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the hold was created.
-
currency
final AchTransfer.InboundFundsHold.Currency currency()
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final Optional<String> heldTransactionId()
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final Optional<OffsetDateTime> releasedAt()
When the hold was released (if it has been released).
-
status
final AchTransfer.InboundFundsHold.Status status()
The status of the hold.
-
type
final AchTransfer.InboundFundsHold.Type type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_amount
final JsonField<Long> _amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
_automaticallyReleasesAt
final JsonField<OffsetDateTime> _automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the hold was created.
-
_currency
final JsonField<AchTransfer.InboundFundsHold.Currency> _currency()
The ISO 4217 code for the hold's currency.
-
_heldTransactionId
final JsonField<String> _heldTransactionId()
The ID of the Transaction for which funds were held.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
_releasedAt
final JsonField<OffsetDateTime> _releasedAt()
When the hold was released (if it has been released).
-
_status
final JsonField<AchTransfer.InboundFundsHold.Status> _status()
The status of the hold.
-
_type
final JsonField<AchTransfer.InboundFundsHold.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.InboundFundsHold validate()
-
toBuilder
final AchTransfer.InboundFundsHold.Builder toBuilder()
-
builder
final static AchTransfer.InboundFundsHold.Builder builder()
-
-
-
-