Class AchTransfer.NotificationsOfChange.Builder
-
- All Implemented Interfaces:
public final class AchTransfer.NotificationsOfChange.BuilderA builder for NotificationsOfChange.
-
-
Method Summary
-
-
Method Detail
-
changeCode
final AchTransfer.NotificationsOfChange.Builder changeCode(AchTransfer.NotificationsOfChange.ChangeCode changeCode)
The required type of change that is being signaled by the receiving financial institution.
-
changeCode
final AchTransfer.NotificationsOfChange.Builder changeCode(JsonField<AchTransfer.NotificationsOfChange.ChangeCode> changeCode)
The required type of change that is being signaled by the receiving financial institution.
-
correctedData
final AchTransfer.NotificationsOfChange.Builder correctedData(String correctedData)
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
correctedData
final AchTransfer.NotificationsOfChange.Builder correctedData(JsonField<String> correctedData)
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
createdAt
final AchTransfer.NotificationsOfChange.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the notification occurred.
-
createdAt
final AchTransfer.NotificationsOfChange.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the notification occurred.
-
additionalProperties
final AchTransfer.NotificationsOfChange.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransfer.NotificationsOfChange.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransfer.NotificationsOfChange.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransfer.NotificationsOfChange.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransfer.NotificationsOfChange.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransfer.NotificationsOfChange build()
-
-
-
-