Class AchTransfer.Return
-
- All Implemented Interfaces:
public final class AchTransfer.ReturnIf your transfer is returned, this will contain details of the return.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Return.BuilderA builder for Return.
public final classAchTransfer.Return.ReturnReasonCodeWhy the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final StringrawReturnReasonCode()The three character ACH return code, in the range R01 to R85. final AchTransfer.Return.ReturnReasonCodereturnReasonCode()Why the ACH Transfer was returned. final StringtraceNumber()A 15 digit number that was generated by the bank that initiated the return. final StringtransactionId()The identifier of the Transaction associated with this return. final StringtransferId()The identifier of the ACH Transfer associated with this return. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<String>_rawReturnReasonCode()The three character ACH return code, in the range R01 to R85. final JsonField<AchTransfer.Return.ReturnReasonCode>_returnReasonCode()Why the ACH Transfer was returned. final JsonField<String>_traceNumber()A 15 digit number that was generated by the bank that initiated the return. final JsonField<String>_transactionId()The identifier of the Transaction associated with this return. final JsonField<String>_transferId()The identifier of the ACH Transfer associated with this return. final Map<String, JsonValue>_additionalProperties()final AchTransfer.Returnvalidate()final AchTransfer.Return.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Return.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
rawReturnReasonCode
final String rawReturnReasonCode()
The three character ACH return code, in the range R01 to R85.
-
returnReasonCode
final AchTransfer.Return.ReturnReasonCode returnReasonCode()
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
traceNumber
final String traceNumber()
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
transactionId
final String transactionId()
The identifier of the Transaction associated with this return.
-
transferId
final String transferId()
The identifier of the ACH Transfer associated with this return.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_rawReturnReasonCode
final JsonField<String> _rawReturnReasonCode()
The three character ACH return code, in the range R01 to R85.
-
_returnReasonCode
final JsonField<AchTransfer.Return.ReturnReasonCode> _returnReasonCode()
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
_traceNumber
final JsonField<String> _traceNumber()
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction associated with this return.
-
_transferId
final JsonField<String> _transferId()
The identifier of the ACH Transfer associated with this return.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.Return validate()
-
toBuilder
final AchTransfer.Return.Builder toBuilder()
-
builder
final static AchTransfer.Return.Builder builder()
-
-
-
-