Class AchTransfer.Return.Builder
-
- All Implemented Interfaces:
public final class AchTransfer.Return.BuilderA builder for Return.
-
-
Method Summary
Modifier and Type Method Description final AchTransfer.Return.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final AchTransfer.Return.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the transfer was created. final AchTransfer.Return.BuilderrawReturnReasonCode(String rawReturnReasonCode)The three character ACH return code, in the range R01 to R85. final AchTransfer.Return.BuilderrawReturnReasonCode(JsonField<String> rawReturnReasonCode)The three character ACH return code, in the range R01 to R85. final AchTransfer.Return.BuilderreturnReasonCode(AchTransfer.Return.ReturnReasonCode returnReasonCode)Why the ACH Transfer was returned. final AchTransfer.Return.BuilderreturnReasonCode(JsonField<AchTransfer.Return.ReturnReasonCode> returnReasonCode)Why the ACH Transfer was returned. final AchTransfer.Return.BuildertraceNumber(String traceNumber)A 15 digit number that was generated by the bank that initiated the return. final AchTransfer.Return.BuildertraceNumber(JsonField<String> traceNumber)A 15 digit number that was generated by the bank that initiated the return. final AchTransfer.Return.BuildertransactionId(String transactionId)The identifier of the Transaction associated with this return. final AchTransfer.Return.BuildertransactionId(JsonField<String> transactionId)The identifier of the Transaction associated with this return. final AchTransfer.Return.BuildertransferId(String transferId)The identifier of the ACH Transfer associated with this return. final AchTransfer.Return.BuildertransferId(JsonField<String> transferId)The identifier of the ACH Transfer associated with this return. final AchTransfer.Return.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.Return.BuilderputAdditionalProperty(String key, JsonValue value)final AchTransfer.Return.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.Return.BuilderremoveAdditionalProperty(String key)final AchTransfer.Return.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchTransfer.Returnbuild()-
-
Method Detail
-
createdAt
final AchTransfer.Return.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final AchTransfer.Return.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
rawReturnReasonCode
final AchTransfer.Return.Builder rawReturnReasonCode(String rawReturnReasonCode)
The three character ACH return code, in the range R01 to R85.
-
rawReturnReasonCode
final AchTransfer.Return.Builder rawReturnReasonCode(JsonField<String> rawReturnReasonCode)
The three character ACH return code, in the range R01 to R85.
-
returnReasonCode
final AchTransfer.Return.Builder returnReasonCode(AchTransfer.Return.ReturnReasonCode returnReasonCode)
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
returnReasonCode
final AchTransfer.Return.Builder returnReasonCode(JsonField<AchTransfer.Return.ReturnReasonCode> returnReasonCode)
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
traceNumber
final AchTransfer.Return.Builder traceNumber(String traceNumber)
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
traceNumber
final AchTransfer.Return.Builder traceNumber(JsonField<String> traceNumber)
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
transactionId
final AchTransfer.Return.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this return.
-
transactionId
final AchTransfer.Return.Builder transactionId(JsonField<String> transactionId)
The identifier of the Transaction associated with this return.
-
transferId
final AchTransfer.Return.Builder transferId(String transferId)
The identifier of the ACH Transfer associated with this return.
-
transferId
final AchTransfer.Return.Builder transferId(JsonField<String> transferId)
The identifier of the ACH Transfer associated with this return.
-
additionalProperties
final AchTransfer.Return.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransfer.Return.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransfer.Return.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransfer.Return.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransfer.Return.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransfer.Return build()
-
-
-
-