Enum AchTransfer.Return.ReturnReasonCode.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AchTransfer.Return.ReturnReasonCode.Known extends Enum<AchTransfer.Return.ReturnReasonCode.Known>
An enum containing ReturnReasonCode's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AchTransfer.Return.ReturnReasonCode.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description INSUFFICIENT_FUNDCode R01. Insufficient funds in the receiving account. Sometimes abbreviated to NSF.
NO_ACCOUNTCode R03. The account does not exist or the receiving bank was unable to locate it.
ACCOUNT_CLOSEDCode R02. The account is closed at the receiving bank.
INVALID_ACCOUNT_NUMBER_STRUCTURECode R04. The account number is invalid at the receiving bank.
ACCOUNT_FROZEN_ENTRY_RETURNED_PER_OFAC_INSTRUCTIONCode R16. The account at the receiving bank was frozen per the Office of Foreign Assets Control.
CREDIT_ENTRY_REFUSED_BY_RECEIVERCode R23. The receiving bank account refused a credit transfer.
UNAUTHORIZED_DEBIT_TO_CONSUMER_ACCOUNT_USING_CORPORATE_SEC_CODECode R05. The receiving bank rejected because of an incorrect Standard Entry Class code.
CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZEDCode R29. The corporate customer at the receiving bank reversed the transfer.
PAYMENT_STOPPEDCode R08. The receiving bank stopped payment on this transfer.
NON_TRANSACTION_ACCOUNTCode R20. The receiving bank account does not perform transfers.
UNCOLLECTED_FUNDSCode R09. The receiving bank account does not have enough available balance for the transfer.
ROUTING_NUMBER_CHECK_DIGIT_ERRORCode R28. The routing number is incorrect.
CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETECode R10. The customer at the receiving bank reversed the transfer.
AMOUNT_FIELD_ERRORCode R19. The amount field is incorrect or too large.
AUTHORIZATION_REVOKED_BY_CUSTOMERCode R07. The customer at the receiving institution informed their bank that they have revoked authorization for a previously authorized transfer.
INVALID_ACH_ROUTING_NUMBERCode R13. The routing number is invalid.
FILE_RECORD_EDIT_CRITERIACode R17. The receiving bank is unable to process a field in the transfer.
ENR_INVALID_INDIVIDUAL_NAMECode R45. The individual name field was invalid.
RETURNED_PER_ODFI_REQUESTCode R06. The originating financial institution asked for this transfer to be returned. The receiving bank is complying with the request.
LIMITED_PARTICIPATION_DFICode R34. The receiving bank's regulatory supervisor has limited their participation in the ACH network.
INCORRECTLY_CODED_OUTBOUND_INTERNATIONAL_PAYMENTCode R85. The outbound international ACH transfer was incorrect.
ACCOUNT_SOLD_TO_ANOTHER_DFICode R12. A rare return reason. The account was sold to another bank.
ADDENDA_ERRORCode R25. The addenda record is incorrect or missing.
BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASEDCode R15. A rare return reason. The account holder is deceased.
CUSTOMER_ADVISED_NOT_WITHIN_AUTHORIZATION_TERMSCode R11. A rare return reason. The customer authorized some payment to the sender, but this payment was not in error.
CORRECTED_RETURNCode R74. A rare return reason. Sent in response to a return that was returned with code
field_error. The latest return should include the corrected field(s).DUPLICATE_ENTRYCode R24. A rare return reason. The receiving bank received an exact duplicate entry with the same trace number and amount.
DUPLICATE_RETURNCode R67. A rare return reason. The return this message refers to was a duplicate.
ENR_DUPLICATE_ENROLLMENTCode R47. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENR_INVALID_DFI_ACCOUNT_NUMBERCode R43. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENR_INVALID_INDIVIDUAL_ID_NUMBERCode R44. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENR_INVALID_REPRESENTATIVE_PAYEE_INDICATORCode R46. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENR_INVALID_TRANSACTION_CODECode R41. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENR_RETURN_OF_ENR_ENTRYCode R40. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENR_ROUTING_NUMBER_CHECK_DIGIT_ERRORCode R42. A rare return reason. Only used for US Government agency non-monetary automatic enrollment messages.
ENTRY_NOT_PROCESSED_BY_GATEWAYCode R84. A rare return reason. The International ACH Transfer cannot be processed by the gateway.
FIELD_ERRORCode R69. A rare return reason. One or more of the fields in the ACH were malformed.
FOREIGN_RECEIVING_DFI_UNABLE_TO_SETTLECode R83. A rare return reason. The Foreign receiving bank was unable to settle this ACH transfer.
IAT_ENTRY_CODING_ERRORCode R80. A rare return reason. The International ACH Transfer is malformed.
IMPROPER_EFFECTIVE_ENTRY_DATECode R18. A rare return reason. The ACH has an improper effective entry date field.
IMPROPER_SOURCE_DOCUMENT_SOURCE_DOCUMENT_PRESENTEDCode R39. A rare return reason. The source document related to this ACH, usually an ACH check conversion, was presented to the bank.
INVALID_COMPANY_IDCode R21. A rare return reason. The Company ID field of the ACH was invalid.
INVALID_FOREIGN_RECEIVING_DFI_IDENTIFICATIONCode R82. A rare return reason. The foreign receiving bank identifier for an International ACH Transfer was invalid.
INVALID_INDIVIDUAL_ID_NUMBERCode R22. A rare return reason. The Individual ID number field of the ACH was invalid.
ITEM_AND_RCK_ENTRY_PRESENTED_FOR_PAYMENTCode R53. A rare return reason. Both the Represented Check ("RCK") entry and the original check were presented to the bank.
ITEM_RELATED_TO_RCK_ENTRY_IS_INELIGIBLECode R51. A rare return reason. The Represented Check ("RCK") entry is ineligible.
MANDATORY_FIELD_ERRORCode R26. A rare return reason. The ACH is missing a required field.
MISROUTED_DISHONORED_RETURNCode R71. A rare return reason. The receiving bank does not recognize the routing number in a dishonored return entry.
MISROUTED_RETURNCode R61. A rare return reason. The receiving bank does not recognize the routing number in a return entry.
NO_ERRORS_FOUNDCode R76. A rare return reason. Sent in response to a return, the bank does not find the errors alleged by the returning bank.
NON_ACCEPTANCE_OF_R62_DISHONORED_RETURNCode R77. A rare return reason. The receiving bank does not accept the return of the erroneous debit. The funds are not available at the receiving bank.
NON_PARTICIPANT_IN_IAT_PROGRAMCode R81. A rare return reason. The receiving bank does not accept International ACH Transfers.
PERMISSIBLE_RETURN_ENTRYCode R31. A rare return reason. A return that has been agreed to be accepted by the receiving bank, despite falling outside of the usual return timeframe.
PERMISSIBLE_RETURN_ENTRY_NOT_ACCEPTEDCode R70. A rare return reason. The receiving bank had not approved this return.
RDFI_NON_SETTLEMENTCode R32. A rare return reason. The receiving bank could not settle this transaction.
RDFI_PARTICIPANT_IN_CHECK_TRUNCATION_PROGRAMCode R30. A rare return reason. The receiving bank does not accept Check Truncation ACH transfers.
REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITYCode R14. A rare return reason. The payee is deceased.
RETURN_NOT_A_DUPLICATECode R75. A rare return reason. The originating bank disputes that an earlier
duplicate_entryreturn was actually a duplicate.RETURN_OF_ERRONEOUS_OR_REVERSING_DEBITCode R62. A rare return reason. The originating financial institution made a mistake and this return corrects it.
RETURN_OF_IMPROPER_CREDIT_ENTRYCode R36. A rare return reason. Return of a malformed credit entry.
RETURN_OF_IMPROPER_DEBIT_ENTRYCode R35. A rare return reason. Return of a malformed debit entry.
RETURN_OF_XCK_ENTRYCode R33. A rare return reason. Return of a Destroyed Check ("XKC") entry.
SOURCE_DOCUMENT_PRESENTED_FOR_PAYMENTCode R37. A rare return reason. The source document related to this ACH, usually an ACH check conversion, was presented to the bank.
STATE_LAW_AFFECTING_RCK_ACCEPTANCECode R50. A rare return reason. State law prevents the bank from accepting the Represented Check ("RCK") entry.
STOP_PAYMENT_ON_ITEM_RELATED_TO_RCK_ENTRYCode R52. A rare return reason. A stop payment was issued on a Represented Check ("RCK") entry.
STOP_PAYMENT_ON_SOURCE_DOCUMENTCode R38. A rare return reason. The source attached to the ACH, usually an ACH check conversion, includes a stop payment.
TIMELY_ORIGINAL_RETURNCode R73. A rare return reason. The bank receiving an
untimely_returnbelieves it was on time.TRACE_NUMBER_ERRORCode R27. A rare return reason. An ACH return's trace number does not match an originated ACH.
UNTIMELY_DISHONORED_RETURNCode R72. A rare return reason. The dishonored return was sent too late.
UNTIMELY_RETURNCode R68. A rare return reason. The return was sent too late.
-
Method Summary
Modifier and Type Method Description final AchTransfer.Return.ReturnReasonCode.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AchTransfer.Return.ReturnReasonCode.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AchTransfer.Return.ReturnReasonCode.Known>getEntries()An enum containing ReturnReasonCode's known values. -
-
Method Detail
-
valueOf
final AchTransfer.Return.ReturnReasonCode.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AchTransfer.Return.ReturnReasonCode.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AchTransfer.Return.ReturnReasonCode.Known> getEntries()
An enum containing ReturnReasonCode's known values.
-
-
-
-