Package com.increase.api.models
Class AchTransfer.Settlement
-
- All Implemented Interfaces:
public final class AchTransfer.SettlementA subhash containing information about when and how the transfer settled at the Federal Reserve.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Settlement.BuilderA builder for Settlement.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimesettledAt()When the funds for this transfer have settled at the destination bank at the Federal Reserve. final JsonField<OffsetDateTime>_settledAt()When the funds for this transfer have settled at the destination bank at the Federal Reserve. final Map<String, JsonValue>_additionalProperties()final AchTransfer.Settlementvalidate()final AchTransfer.Settlement.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Settlement.Builderbuilder()-
-
Method Detail
-
settledAt
final OffsetDateTime settledAt()
When the funds for this transfer have settled at the destination bank at the Federal Reserve.
-
_settledAt
final JsonField<OffsetDateTime> _settledAt()
When the funds for this transfer have settled at the destination bank at the Federal Reserve.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.Settlement validate()
-
toBuilder
final AchTransfer.Settlement.Builder toBuilder()
-
builder
final static AchTransfer.Settlement.Builder builder()
-
-
-
-