Class AchTransfer.Submission
-
- All Implemented Interfaces:
public final class AchTransfer.SubmissionAfter the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Submission.BuilderA builder for Submission.
public final classAchTransfer.Submission.ExpectedSettlementScheduleThe settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
Method Summary
Modifier and Type Method Description final LocalDateeffectiveDate()The ACH transfer's effective date as sent to the Federal Reserve. final OffsetDateTimeexpectedFundsSettlementAt()When the transfer is expected to settle in the recipient's account. final AchTransfer.Submission.ExpectedSettlementScheduleexpectedSettlementSchedule()The settlement schedule the transfer is expected to follow. final OffsetDateTimesubmittedAt()When the ACH transfer was sent to FedACH. final StringtraceNumber()A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. final JsonField<LocalDate>_effectiveDate()The ACH transfer's effective date as sent to the Federal Reserve. final JsonField<OffsetDateTime>_expectedFundsSettlementAt()When the transfer is expected to settle in the recipient's account. final JsonField<AchTransfer.Submission.ExpectedSettlementSchedule>_expectedSettlementSchedule()The settlement schedule the transfer is expected to follow. final JsonField<OffsetDateTime>_submittedAt()When the ACH transfer was sent to FedACH. final JsonField<String>_traceNumber()A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. final Map<String, JsonValue>_additionalProperties()final AchTransfer.Submissionvalidate()final AchTransfer.Submission.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Submission.Builderbuilder()-
-
Method Detail
-
effectiveDate
final LocalDate effectiveDate()
The ACH transfer's effective date as sent to the Federal Reserve. If a specific date was configured using
preferred_effective_date, this will match that value. Otherwise, it will be the date selected (following the specified settlement schedule) at the time the transfer was submitted.
-
expectedFundsSettlementAt
final OffsetDateTime expectedFundsSettlementAt()
When the transfer is expected to settle in the recipient's account. Credits may be available sooner, at the receiving banks discretion. The FedACH schedule is published here.
-
expectedSettlementSchedule
final AchTransfer.Submission.ExpectedSettlementSchedule expectedSettlementSchedule()
The settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
submittedAt
final OffsetDateTime submittedAt()
When the ACH transfer was sent to FedACH.
-
traceNumber
final String traceNumber()
A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at the receiving bank. ACH trace numbers are not unique, but are used to correlate returns.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
The ACH transfer's effective date as sent to the Federal Reserve. If a specific date was configured using
preferred_effective_date, this will match that value. Otherwise, it will be the date selected (following the specified settlement schedule) at the time the transfer was submitted.
-
_expectedFundsSettlementAt
final JsonField<OffsetDateTime> _expectedFundsSettlementAt()
When the transfer is expected to settle in the recipient's account. Credits may be available sooner, at the receiving banks discretion. The FedACH schedule is published here.
-
_expectedSettlementSchedule
final JsonField<AchTransfer.Submission.ExpectedSettlementSchedule> _expectedSettlementSchedule()
The settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
When the ACH transfer was sent to FedACH.
-
_traceNumber
final JsonField<String> _traceNumber()
A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at the receiving bank. ACH trace numbers are not unique, but are used to correlate returns.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AchTransfer.Submission validate()
-
toBuilder
final AchTransfer.Submission.Builder toBuilder()
-
builder
final static AchTransfer.Submission.Builder builder()
-
-
-
-