Class AchTransfer.Submission.Builder
-
- All Implemented Interfaces:
public final class AchTransfer.Submission.BuilderA builder for Submission.
-
-
Method Summary
Modifier and Type Method Description final AchTransfer.Submission.BuildereffectiveDate(LocalDate effectiveDate)The ACH transfer's effective date as sent to the Federal Reserve. final AchTransfer.Submission.BuildereffectiveDate(JsonField<LocalDate> effectiveDate)The ACH transfer's effective date as sent to the Federal Reserve. final AchTransfer.Submission.BuilderexpectedFundsSettlementAt(OffsetDateTime expectedFundsSettlementAt)When the transfer is expected to settle in the recipient's account. final AchTransfer.Submission.BuilderexpectedFundsSettlementAt(JsonField<OffsetDateTime> expectedFundsSettlementAt)When the transfer is expected to settle in the recipient's account. final AchTransfer.Submission.BuilderexpectedSettlementSchedule(AchTransfer.Submission.ExpectedSettlementSchedule expectedSettlementSchedule)The settlement schedule the transfer is expected to follow. final AchTransfer.Submission.BuilderexpectedSettlementSchedule(JsonField<AchTransfer.Submission.ExpectedSettlementSchedule> expectedSettlementSchedule)The settlement schedule the transfer is expected to follow. final AchTransfer.Submission.BuildersubmittedAt(OffsetDateTime submittedAt)When the ACH transfer was sent to FedACH. final AchTransfer.Submission.BuildersubmittedAt(JsonField<OffsetDateTime> submittedAt)When the ACH transfer was sent to FedACH. final AchTransfer.Submission.BuildertraceNumber(String traceNumber)A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. final AchTransfer.Submission.BuildertraceNumber(JsonField<String> traceNumber)A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. final AchTransfer.Submission.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.Submission.BuilderputAdditionalProperty(String key, JsonValue value)final AchTransfer.Submission.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.Submission.BuilderremoveAdditionalProperty(String key)final AchTransfer.Submission.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchTransfer.Submissionbuild()-
-
Method Detail
-
effectiveDate
final AchTransfer.Submission.Builder effectiveDate(LocalDate effectiveDate)
The ACH transfer's effective date as sent to the Federal Reserve. If a specific date was configured using
preferred_effective_date, this will match that value. Otherwise, it will be the date selected (following the specified settlement schedule) at the time the transfer was submitted.
-
effectiveDate
final AchTransfer.Submission.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
The ACH transfer's effective date as sent to the Federal Reserve. If a specific date was configured using
preferred_effective_date, this will match that value. Otherwise, it will be the date selected (following the specified settlement schedule) at the time the transfer was submitted.
-
expectedFundsSettlementAt
final AchTransfer.Submission.Builder expectedFundsSettlementAt(OffsetDateTime expectedFundsSettlementAt)
When the transfer is expected to settle in the recipient's account. Credits may be available sooner, at the receiving banks discretion. The FedACH schedule is published here.
-
expectedFundsSettlementAt
final AchTransfer.Submission.Builder expectedFundsSettlementAt(JsonField<OffsetDateTime> expectedFundsSettlementAt)
When the transfer is expected to settle in the recipient's account. Credits may be available sooner, at the receiving banks discretion. The FedACH schedule is published here.
-
expectedSettlementSchedule
final AchTransfer.Submission.Builder expectedSettlementSchedule(AchTransfer.Submission.ExpectedSettlementSchedule expectedSettlementSchedule)
The settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
expectedSettlementSchedule
final AchTransfer.Submission.Builder expectedSettlementSchedule(JsonField<AchTransfer.Submission.ExpectedSettlementSchedule> expectedSettlementSchedule)
The settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
submittedAt
final AchTransfer.Submission.Builder submittedAt(OffsetDateTime submittedAt)
When the ACH transfer was sent to FedACH.
-
submittedAt
final AchTransfer.Submission.Builder submittedAt(JsonField<OffsetDateTime> submittedAt)
When the ACH transfer was sent to FedACH.
-
traceNumber
final AchTransfer.Submission.Builder traceNumber(String traceNumber)
A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at the receiving bank. ACH trace numbers are not unique, but are used to correlate returns.
-
traceNumber
final AchTransfer.Submission.Builder traceNumber(JsonField<String> traceNumber)
A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at the receiving bank. ACH trace numbers are not unique, but are used to correlate returns.
-
additionalProperties
final AchTransfer.Submission.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransfer.Submission.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransfer.Submission.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransfer.Submission.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransfer.Submission.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransfer.Submission build()
-
-
-
-