Class AchTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchTransferCreateParams implements Params
Create an ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateParams.Bodypublic final classAchTransferCreateParams.BuilderA builder for AchTransferCreateParams.
public final classAchTransferCreateParams.AddendaAdditional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
public final classAchTransferCreateParams.DestinationAccountHolderThe type of entity that owns the account to which the ACH Transfer is being sent.
public final classAchTransferCreateParams.FundingThe type of the account to which the transfer will be sent.
public final classAchTransferCreateParams.PreferredEffectiveDateConfiguration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.public final classAchTransferCreateParams.StandardEntryClassCodeThe Standard Entry Class (SEC) code to use for the transfer.
public final classAchTransferCreateParams.TransactionTimingThe timing of the transaction.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Increase identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final StringstatementDescriptor()A description you choose to give the transfer. final Optional<String>accountNumber()The account number for the destination account. final Optional<AchTransferCreateParams.Addenda>addenda()Additional information that will be sent to the recipient. final Optional<String>companyDescriptiveDate()The description of the date of the transfer, usually in the format YYMMDD.final Optional<String>companyDiscretionaryData()The data you choose to associate with the transfer. final Optional<String>companyEntryDescription()A description of the transfer. final Optional<String>companyName()The name by which the recipient knows you. final Optional<AchTransferCreateParams.DestinationAccountHolder>destinationAccountHolder()The type of entity that owns the account to which the ACH Transfer is being sent. final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<AchTransferCreateParams.Funding>funding()The type of the account to which the transfer will be sent. final Optional<String>individualId()Your identifier for the transfer recipient. final Optional<String>individualName()The name of the transfer recipient. final Optional<AchTransferCreateParams.PreferredEffectiveDate>preferredEffectiveDate()Configuration for how the effective date of the transfer will be set. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<AchTransferCreateParams.StandardEntryClassCode>standardEntryClassCode()The Standard Entry Class (SEC) code to use for the transfer. final Optional<AchTransferCreateParams.TransactionTiming>transactionTiming()The timing of the transaction. final JsonField<String>_accountId()The Increase identifier for the account that will send the transfer. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<String>_statementDescriptor()A description you choose to give the transfer. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<AchTransferCreateParams.Addenda>_addenda()Additional information that will be sent to the recipient. final JsonField<String>_companyDescriptiveDate()The description of the date of the transfer, usually in the format YYMMDD.final JsonField<String>_companyDiscretionaryData()The data you choose to associate with the transfer. final JsonField<String>_companyEntryDescription()A description of the transfer. final JsonField<String>_companyName()The name by which the recipient knows you. final JsonField<AchTransferCreateParams.DestinationAccountHolder>_destinationAccountHolder()The type of entity that owns the account to which the ACH Transfer is being sent. final JsonField<String>_externalAccountId()The ID of an External Account to initiate a transfer to. final JsonField<AchTransferCreateParams.Funding>_funding()The type of the account to which the transfer will be sent. final JsonField<String>_individualId()Your identifier for the transfer recipient. final JsonField<String>_individualName()The name of the transfer recipient. final JsonField<AchTransferCreateParams.PreferredEffectiveDate>_preferredEffectiveDate()Configuration for how the effective date of the transfer will be set. final JsonField<Boolean>_requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<AchTransferCreateParams.StandardEntryClassCode>_standardEntryClassCode()The Standard Entry Class (SEC) code to use for the transfer. final JsonField<AchTransferCreateParams.TransactionTiming>_transactionTiming()The timing of the transaction. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final AchTransferCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferCreateParams.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The Increase identifier for the account that will send the transfer.
-
amount
final Long amount()
The transfer amount in USD cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
statementDescriptor
final String statementDescriptor()
A description you choose to give the transfer. This will be saved with the transfer details, displayed in the dashboard, and returned by the API. If
individual_nameandcompany_nameare not explicitly set by this API, thestatement_descriptorwill be sent in those fields to the receiving bank to help the customer recognize the transfer. You are highly encouraged to passindividual_nameandcompany_nameinstead of relying on this fallback.
-
accountNumber
final Optional<String> accountNumber()
The account number for the destination account.
-
addenda
final Optional<AchTransferCreateParams.Addenda> addenda()
Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer, usually in the format
YYMMDD. This is included in the transfer data sent to the receiving bank.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
The data you choose to associate with the transfer. This is included in the transfer data sent to the receiving bank.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
A description of the transfer. This is included in the transfer data sent to the receiving bank.
-
companyName
final Optional<String> companyName()
The name by which the recipient knows you. This is included in the transfer data sent to the receiving bank.
-
destinationAccountHolder
final Optional<AchTransferCreateParams.DestinationAccountHolder> destinationAccountHolder()
The type of entity that owns the account to which the ACH Transfer is being sent.
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_number,routing_number, andfundingmust be absent.
-
funding
final Optional<AchTransferCreateParams.Funding> funding()
The type of the account to which the transfer will be sent.
-
individualId
final Optional<String> individualId()
Your identifier for the transfer recipient.
-
individualName
final Optional<String> individualName()
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
preferredEffectiveDate
final Optional<AchTransferCreateParams.PreferredEffectiveDate> preferredEffectiveDate()
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
standardEntryClassCode
final Optional<AchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the transfer.
-
transactionTiming
final Optional<AchTransferCreateParams.TransactionTiming> transactionTiming()
The timing of the transaction.
-
_accountId
final JsonField<String> _accountId()
The Increase identifier for the account that will send the transfer.
-
_amount
final JsonField<Long> _amount()
The transfer amount in USD cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
_statementDescriptor
final JsonField<String> _statementDescriptor()
A description you choose to give the transfer. This will be saved with the transfer details, displayed in the dashboard, and returned by the API. If
individual_nameandcompany_nameare not explicitly set by this API, thestatement_descriptorwill be sent in those fields to the receiving bank to help the customer recognize the transfer. You are highly encouraged to passindividual_nameandcompany_nameinstead of relying on this fallback.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_addenda
final JsonField<AchTransferCreateParams.Addenda> _addenda()
Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
The description of the date of the transfer, usually in the format
YYMMDD. This is included in the transfer data sent to the receiving bank.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
The data you choose to associate with the transfer. This is included in the transfer data sent to the receiving bank.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
A description of the transfer. This is included in the transfer data sent to the receiving bank.
-
_companyName
final JsonField<String> _companyName()
The name by which the recipient knows you. This is included in the transfer data sent to the receiving bank.
-
_destinationAccountHolder
final JsonField<AchTransferCreateParams.DestinationAccountHolder> _destinationAccountHolder()
The type of entity that owns the account to which the ACH Transfer is being sent.
-
_externalAccountId
final JsonField<String> _externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_number,routing_number, andfundingmust be absent.
-
_funding
final JsonField<AchTransferCreateParams.Funding> _funding()
The type of the account to which the transfer will be sent.
-
_individualId
final JsonField<String> _individualId()
Your identifier for the transfer recipient.
-
_individualName
final JsonField<String> _individualName()
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
_preferredEffectiveDate
final JsonField<AchTransferCreateParams.PreferredEffectiveDate> _preferredEffectiveDate()
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_standardEntryClassCode
final JsonField<AchTransferCreateParams.StandardEntryClassCode> _standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the transfer.
-
_transactionTiming
final JsonField<AchTransferCreateParams.TransactionTiming> _transactionTiming()
The timing of the transaction.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final AchTransferCreateParams.Builder toBuilder()
-
builder
final static AchTransferCreateParams.Builder builder()
-
-
-
-