Package com.increase.api.models
Enum AchTransferCreateParams.Addenda.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AchTransferCreateParams.Addenda.Category.Known extends Enum<AchTransferCreateParams.Addenda.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AchTransferCreateParams.Addenda.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FREEFORMUnstructured
payment_related_informationpassed through with the transfer.PAYMENT_ORDER_REMITTANCE_ADVICEStructured ASC X12 820 remittance advice records. Please reach out to [email protected] for more information.
-
Method Summary
Modifier and Type Method Description final AchTransferCreateParams.Addenda.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AchTransferCreateParams.Addenda.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AchTransferCreateParams.Addenda.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final AchTransferCreateParams.Addenda.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AchTransferCreateParams.Addenda.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AchTransferCreateParams.Addenda.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-