Class AchTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AchTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final AchTransferCreateParams.Body.BuilderaccountId(String accountId)The Increase identifier for the account that will send the transfer. final AchTransferCreateParams.Body.BuilderaccountId(JsonField<String> accountId)The Increase identifier for the account that will send the transfer. final AchTransferCreateParams.Body.Builderamount(Long amount)The transfer amount in USD cents. final AchTransferCreateParams.Body.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final AchTransferCreateParams.Body.BuilderstatementDescriptor(String statementDescriptor)A description you choose to give the transfer. final AchTransferCreateParams.Body.BuilderstatementDescriptor(JsonField<String> statementDescriptor)A description you choose to give the transfer. final AchTransferCreateParams.Body.BuilderaccountNumber(String accountNumber)The account number for the destination account. final AchTransferCreateParams.Body.BuilderaccountNumber(JsonField<String> accountNumber)The account number for the destination account. final AchTransferCreateParams.Body.Builderaddenda(AchTransferCreateParams.Addenda addenda)Additional information that will be sent to the recipient. final AchTransferCreateParams.Body.Builderaddenda(JsonField<AchTransferCreateParams.Addenda> addenda)Additional information that will be sent to the recipient. final AchTransferCreateParams.Body.BuildercompanyDescriptiveDate(String companyDescriptiveDate)The description of the date of the transfer, usually in the format YYMMDD.final AchTransferCreateParams.Body.BuildercompanyDescriptiveDate(JsonField<String> companyDescriptiveDate)The description of the date of the transfer, usually in the format YYMMDD.final AchTransferCreateParams.Body.BuildercompanyDiscretionaryData(String companyDiscretionaryData)The data you choose to associate with the transfer. final AchTransferCreateParams.Body.BuildercompanyDiscretionaryData(JsonField<String> companyDiscretionaryData)The data you choose to associate with the transfer. final AchTransferCreateParams.Body.BuildercompanyEntryDescription(String companyEntryDescription)A description of the transfer. final AchTransferCreateParams.Body.BuildercompanyEntryDescription(JsonField<String> companyEntryDescription)A description of the transfer. final AchTransferCreateParams.Body.BuildercompanyName(String companyName)The name by which the recipient knows you. final AchTransferCreateParams.Body.BuildercompanyName(JsonField<String> companyName)The name by which the recipient knows you. final AchTransferCreateParams.Body.BuilderdestinationAccountHolder(AchTransferCreateParams.DestinationAccountHolder destinationAccountHolder)The type of entity that owns the account to which the ACH Transfer is being sent. final AchTransferCreateParams.Body.BuilderdestinationAccountHolder(JsonField<AchTransferCreateParams.DestinationAccountHolder> destinationAccountHolder)The type of entity that owns the account to which the ACH Transfer is being sent. final AchTransferCreateParams.Body.BuilderexternalAccountId(String externalAccountId)The ID of an External Account to initiate a transfer to. final AchTransferCreateParams.Body.BuilderexternalAccountId(JsonField<String> externalAccountId)The ID of an External Account to initiate a transfer to. final AchTransferCreateParams.Body.Builderfunding(AchTransferCreateParams.Funding funding)The type of the account to which the transfer will be sent. final AchTransferCreateParams.Body.Builderfunding(JsonField<AchTransferCreateParams.Funding> funding)The type of the account to which the transfer will be sent. final AchTransferCreateParams.Body.BuilderindividualId(String individualId)Your identifier for the transfer recipient. final AchTransferCreateParams.Body.BuilderindividualId(JsonField<String> individualId)Your identifier for the transfer recipient. final AchTransferCreateParams.Body.BuilderindividualName(String individualName)The name of the transfer recipient. final AchTransferCreateParams.Body.BuilderindividualName(JsonField<String> individualName)The name of the transfer recipient. final AchTransferCreateParams.Body.BuilderpreferredEffectiveDate(AchTransferCreateParams.PreferredEffectiveDate preferredEffectiveDate)Configuration for how the effective date of the transfer will be set. final AchTransferCreateParams.Body.BuilderpreferredEffectiveDate(JsonField<AchTransferCreateParams.PreferredEffectiveDate> preferredEffectiveDate)Configuration for how the effective date of the transfer will be set. final AchTransferCreateParams.Body.BuilderrequireApproval(Boolean requireApproval)Whether the transfer requires explicit approval via the dashboard or API. final AchTransferCreateParams.Body.BuilderrequireApproval(JsonField<Boolean> requireApproval)Whether the transfer requires explicit approval via the dashboard or API. final AchTransferCreateParams.Body.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final AchTransferCreateParams.Body.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final AchTransferCreateParams.Body.BuilderstandardEntryClassCode(AchTransferCreateParams.StandardEntryClassCode standardEntryClassCode)The Standard Entry Class (SEC) code to use for the transfer. final AchTransferCreateParams.Body.BuilderstandardEntryClassCode(JsonField<AchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode)The Standard Entry Class (SEC) code to use for the transfer. final AchTransferCreateParams.Body.BuildertransactionTiming(AchTransferCreateParams.TransactionTiming transactionTiming)The timing of the transaction. final AchTransferCreateParams.Body.BuildertransactionTiming(JsonField<AchTransferCreateParams.TransactionTiming> transactionTiming)The timing of the transaction. final AchTransferCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransferCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final AchTransferCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransferCreateParams.Body.BuilderremoveAdditionalProperty(String key)final AchTransferCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchTransferCreateParams.Bodybuild()-
-
Method Detail
-
accountId
final AchTransferCreateParams.Body.Builder accountId(String accountId)
The Increase identifier for the account that will send the transfer.
-
accountId
final AchTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
The Increase identifier for the account that will send the transfer.
-
amount
final AchTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
amount
final AchTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
statementDescriptor
final AchTransferCreateParams.Body.Builder statementDescriptor(String statementDescriptor)
A description you choose to give the transfer. This will be saved with the transfer details, displayed in the dashboard, and returned by the API. If
individual_nameandcompany_nameare not explicitly set by this API, thestatement_descriptorwill be sent in those fields to the receiving bank to help the customer recognize the transfer. You are highly encouraged to passindividual_nameandcompany_nameinstead of relying on this fallback.
-
statementDescriptor
final AchTransferCreateParams.Body.Builder statementDescriptor(JsonField<String> statementDescriptor)
A description you choose to give the transfer. This will be saved with the transfer details, displayed in the dashboard, and returned by the API. If
individual_nameandcompany_nameare not explicitly set by this API, thestatement_descriptorwill be sent in those fields to the receiving bank to help the customer recognize the transfer. You are highly encouraged to passindividual_nameandcompany_nameinstead of relying on this fallback.
-
accountNumber
final AchTransferCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final AchTransferCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
The account number for the destination account.
-
addenda
final AchTransferCreateParams.Body.Builder addenda(AchTransferCreateParams.Addenda addenda)
Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
addenda
final AchTransferCreateParams.Body.Builder addenda(JsonField<AchTransferCreateParams.Addenda> addenda)
Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
companyDescriptiveDate
final AchTransferCreateParams.Body.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD. This is included in the transfer data sent to the receiving bank.
-
companyDescriptiveDate
final AchTransferCreateParams.Body.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD. This is included in the transfer data sent to the receiving bank.
-
companyDiscretionaryData
final AchTransferCreateParams.Body.Builder companyDiscretionaryData(String companyDiscretionaryData)
The data you choose to associate with the transfer. This is included in the transfer data sent to the receiving bank.
-
companyDiscretionaryData
final AchTransferCreateParams.Body.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
The data you choose to associate with the transfer. This is included in the transfer data sent to the receiving bank.
-
companyEntryDescription
final AchTransferCreateParams.Body.Builder companyEntryDescription(String companyEntryDescription)
A description of the transfer. This is included in the transfer data sent to the receiving bank.
-
companyEntryDescription
final AchTransferCreateParams.Body.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
A description of the transfer. This is included in the transfer data sent to the receiving bank.
-
companyName
final AchTransferCreateParams.Body.Builder companyName(String companyName)
The name by which the recipient knows you. This is included in the transfer data sent to the receiving bank.
-
companyName
final AchTransferCreateParams.Body.Builder companyName(JsonField<String> companyName)
The name by which the recipient knows you. This is included in the transfer data sent to the receiving bank.
-
destinationAccountHolder
final AchTransferCreateParams.Body.Builder destinationAccountHolder(AchTransferCreateParams.DestinationAccountHolder destinationAccountHolder)
The type of entity that owns the account to which the ACH Transfer is being sent.
-
destinationAccountHolder
final AchTransferCreateParams.Body.Builder destinationAccountHolder(JsonField<AchTransferCreateParams.DestinationAccountHolder> destinationAccountHolder)
The type of entity that owns the account to which the ACH Transfer is being sent.
-
externalAccountId
final AchTransferCreateParams.Body.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_number,routing_number, andfundingmust be absent.
-
externalAccountId
final AchTransferCreateParams.Body.Builder externalAccountId(JsonField<String> externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_number,routing_number, andfundingmust be absent.
-
funding
final AchTransferCreateParams.Body.Builder funding(AchTransferCreateParams.Funding funding)
The type of the account to which the transfer will be sent.
-
funding
final AchTransferCreateParams.Body.Builder funding(JsonField<AchTransferCreateParams.Funding> funding)
The type of the account to which the transfer will be sent.
-
individualId
final AchTransferCreateParams.Body.Builder individualId(String individualId)
Your identifier for the transfer recipient.
-
individualId
final AchTransferCreateParams.Body.Builder individualId(JsonField<String> individualId)
Your identifier for the transfer recipient.
-
individualName
final AchTransferCreateParams.Body.Builder individualName(String individualName)
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
individualName
final AchTransferCreateParams.Body.Builder individualName(JsonField<String> individualName)
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
preferredEffectiveDate
final AchTransferCreateParams.Body.Builder preferredEffectiveDate(AchTransferCreateParams.PreferredEffectiveDate preferredEffectiveDate)
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
preferredEffectiveDate
final AchTransferCreateParams.Body.Builder preferredEffectiveDate(JsonField<AchTransferCreateParams.PreferredEffectiveDate> preferredEffectiveDate)
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
requireApproval
final AchTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final AchTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final AchTransferCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final AchTransferCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
standardEntryClassCode
final AchTransferCreateParams.Body.Builder standardEntryClassCode(AchTransferCreateParams.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the transfer.
-
standardEntryClassCode
final AchTransferCreateParams.Body.Builder standardEntryClassCode(JsonField<AchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the transfer.
-
transactionTiming
final AchTransferCreateParams.Body.Builder transactionTiming(AchTransferCreateParams.TransactionTiming transactionTiming)
The timing of the transaction.
-
transactionTiming
final AchTransferCreateParams.Body.Builder transactionTiming(JsonField<AchTransferCreateParams.TransactionTiming> transactionTiming)
The timing of the transaction.
-
additionalProperties
final AchTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransferCreateParams.Body build()
-
-
-
-