Class BalanceLookup
-
- All Implemented Interfaces:
public final class BalanceLookupRepresents a request to lookup the balance of an Account at a given point in time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceLookup.BuilderA builder for BalanceLookup.
public final classBalanceLookup.TypeA constant representing the object's type. For this resource it will always be
balance_lookup.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account for which the balance was queried. final LongavailableBalance()The Account's available balance, representing the current balance less any open Pending Transactions on the Account. final LongcurrentBalance()The Account's current balance, representing the sum of all posted Transactions on the Account. final BalanceLookup.Typetype()A constant representing the object's type. final JsonField<String>_accountId()The identifier for the account for which the balance was queried. final JsonField<Long>_availableBalance()The Account's available balance, representing the current balance less any open Pending Transactions on the Account. final JsonField<Long>_currentBalance()The Account's current balance, representing the sum of all posted Transactions on the Account. final JsonField<BalanceLookup.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final BalanceLookupvalidate()final BalanceLookup.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceLookup.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier for the account for which the balance was queried.
-
availableBalance
final Long availableBalance()
The Account's available balance, representing the current balance less any open Pending Transactions on the Account.
-
currentBalance
final Long currentBalance()
The Account's current balance, representing the sum of all posted Transactions on the Account.
-
type
final BalanceLookup.Type type()
A constant representing the object's type. For this resource it will always be
balance_lookup.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account for which the balance was queried.
-
_availableBalance
final JsonField<Long> _availableBalance()
The Account's available balance, representing the current balance less any open Pending Transactions on the Account.
-
_currentBalance
final JsonField<Long> _currentBalance()
The Account's current balance, representing the sum of all posted Transactions on the Account.
-
_type
final JsonField<BalanceLookup.Type> _type()
A constant representing the object's type. For this resource it will always be
balance_lookup.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BalanceLookup validate()
-
toBuilder
final BalanceLookup.Builder toBuilder()
-
builder
final static BalanceLookup.Builder builder()
-
-
-
-