Class BalanceLookup.Builder
-
- All Implemented Interfaces:
public final class BalanceLookup.BuilderA builder for BalanceLookup.
-
-
Method Summary
Modifier and Type Method Description final BalanceLookup.BuilderaccountId(String accountId)The identifier for the account for which the balance was queried. final BalanceLookup.BuilderaccountId(JsonField<String> accountId)The identifier for the account for which the balance was queried. final BalanceLookup.BuilderavailableBalance(Long availableBalance)The Account's available balance, representing the current balance less any open Pending Transactions on the Account. final BalanceLookup.BuilderavailableBalance(JsonField<Long> availableBalance)The Account's available balance, representing the current balance less any open Pending Transactions on the Account. final BalanceLookup.BuildercurrentBalance(Long currentBalance)The Account's current balance, representing the sum of all posted Transactions on the Account. final BalanceLookup.BuildercurrentBalance(JsonField<Long> currentBalance)The Account's current balance, representing the sum of all posted Transactions on the Account. final BalanceLookup.Buildertype(BalanceLookup.Type type)A constant representing the object's type. final BalanceLookup.Buildertype(JsonField<BalanceLookup.Type> type)A constant representing the object's type. final BalanceLookup.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BalanceLookup.BuilderputAdditionalProperty(String key, JsonValue value)final BalanceLookup.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BalanceLookup.BuilderremoveAdditionalProperty(String key)final BalanceLookup.BuilderremoveAllAdditionalProperties(Set<String> keys)final BalanceLookupbuild()-
-
Method Detail
-
accountId
final BalanceLookup.Builder accountId(String accountId)
The identifier for the account for which the balance was queried.
-
accountId
final BalanceLookup.Builder accountId(JsonField<String> accountId)
The identifier for the account for which the balance was queried.
-
availableBalance
final BalanceLookup.Builder availableBalance(Long availableBalance)
The Account's available balance, representing the current balance less any open Pending Transactions on the Account.
-
availableBalance
final BalanceLookup.Builder availableBalance(JsonField<Long> availableBalance)
The Account's available balance, representing the current balance less any open Pending Transactions on the Account.
-
currentBalance
final BalanceLookup.Builder currentBalance(Long currentBalance)
The Account's current balance, representing the sum of all posted Transactions on the Account.
-
currentBalance
final BalanceLookup.Builder currentBalance(JsonField<Long> currentBalance)
The Account's current balance, representing the sum of all posted Transactions on the Account.
-
type
final BalanceLookup.Builder type(BalanceLookup.Type type)
A constant representing the object's type. For this resource it will always be
balance_lookup.
-
type
final BalanceLookup.Builder type(JsonField<BalanceLookup.Type> type)
A constant representing the object's type. For this resource it will always be
balance_lookup.
-
additionalProperties
final BalanceLookup.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BalanceLookup.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BalanceLookup.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BalanceLookup.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BalanceLookup.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BalanceLookup build()
-
-
-
-