Class BookkeepingAccount
-
- All Implemented Interfaces:
public final class BookkeepingAccountAccounts are T-accounts. They can store accounting entries. Your compliance setup might require annotating money movements using this API. Learn more in our guide to Bookkeeping.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccount.BuilderA builder for BookkeepingAccount.
public final classBookkeepingAccount.ComplianceCategoryThe compliance category of the account.
public final classBookkeepingAccount.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
Method Summary
Modifier and Type Method Description final Stringid()The account identifier. final Optional<String>accountId()The API Account associated with this bookkeeping account. final Optional<BookkeepingAccount.ComplianceCategory>complianceCategory()The compliance category of the account. final Optional<String>entityId()The Entity associated with this bookkeeping account. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Stringname()The name you choose for the account. final BookkeepingAccount.Typetype()A constant representing the object's type. final JsonField<String>_id()The account identifier. final JsonField<String>_accountId()The API Account associated with this bookkeeping account. final JsonField<BookkeepingAccount.ComplianceCategory>_complianceCategory()The compliance category of the account. final JsonField<String>_entityId()The Entity associated with this bookkeeping account. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_name()The name you choose for the account. final JsonField<BookkeepingAccount.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final BookkeepingAccountvalidate()final BookkeepingAccount.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccount.Builderbuilder()-
-
Method Detail
-
accountId
final Optional<String> accountId()
The API Account associated with this bookkeeping account.
-
complianceCategory
final Optional<BookkeepingAccount.ComplianceCategory> complianceCategory()
The compliance category of the account.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final BookkeepingAccount.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
_accountId
final JsonField<String> _accountId()
The API Account associated with this bookkeeping account.
-
_complianceCategory
final JsonField<BookkeepingAccount.ComplianceCategory> _complianceCategory()
The compliance category of the account.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_type
final JsonField<BookkeepingAccount.Type> _type()
A constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookkeepingAccount validate()
-
toBuilder
final BookkeepingAccount.Builder toBuilder()
-
builder
final static BookkeepingAccount.Builder builder()
-
-
-
-