Class BookkeepingAccount.Builder
-
- All Implemented Interfaces:
public final class BookkeepingAccount.BuilderA builder for BookkeepingAccount.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingAccount.Builderid(String id)The account identifier. final BookkeepingAccount.Builderid(JsonField<String> id)The account identifier. final BookkeepingAccount.BuilderaccountId(String accountId)The API Account associated with this bookkeeping account. final BookkeepingAccount.BuilderaccountId(Optional<String> accountId)The API Account associated with this bookkeeping account. final BookkeepingAccount.BuilderaccountId(JsonField<String> accountId)The API Account associated with this bookkeeping account. final BookkeepingAccount.BuildercomplianceCategory(BookkeepingAccount.ComplianceCategory complianceCategory)The compliance category of the account. final BookkeepingAccount.BuildercomplianceCategory(Optional<BookkeepingAccount.ComplianceCategory> complianceCategory)The compliance category of the account. final BookkeepingAccount.BuildercomplianceCategory(JsonField<BookkeepingAccount.ComplianceCategory> complianceCategory)The compliance category of the account. final BookkeepingAccount.BuilderentityId(String entityId)The Entity associated with this bookkeeping account. final BookkeepingAccount.BuilderentityId(Optional<String> entityId)The Entity associated with this bookkeeping account. final BookkeepingAccount.BuilderentityId(JsonField<String> entityId)The Entity associated with this bookkeeping account. final BookkeepingAccount.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final BookkeepingAccount.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final BookkeepingAccount.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final BookkeepingAccount.Buildername(String name)The name you choose for the account. final BookkeepingAccount.Buildername(JsonField<String> name)The name you choose for the account. final BookkeepingAccount.Buildertype(BookkeepingAccount.Type type)A constant representing the object's type. final BookkeepingAccount.Buildertype(JsonField<BookkeepingAccount.Type> type)A constant representing the object's type. final BookkeepingAccount.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BookkeepingAccount.BuilderputAdditionalProperty(String key, JsonValue value)final BookkeepingAccount.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BookkeepingAccount.BuilderremoveAdditionalProperty(String key)final BookkeepingAccount.BuilderremoveAllAdditionalProperties(Set<String> keys)final BookkeepingAccountbuild()-
-
Method Detail
-
id
final BookkeepingAccount.Builder id(String id)
The account identifier.
-
id
final BookkeepingAccount.Builder id(JsonField<String> id)
The account identifier.
-
accountId
final BookkeepingAccount.Builder accountId(String accountId)
The API Account associated with this bookkeeping account.
-
accountId
final BookkeepingAccount.Builder accountId(Optional<String> accountId)
The API Account associated with this bookkeeping account.
-
accountId
final BookkeepingAccount.Builder accountId(JsonField<String> accountId)
The API Account associated with this bookkeeping account.
-
complianceCategory
final BookkeepingAccount.Builder complianceCategory(BookkeepingAccount.ComplianceCategory complianceCategory)
The compliance category of the account.
-
complianceCategory
final BookkeepingAccount.Builder complianceCategory(Optional<BookkeepingAccount.ComplianceCategory> complianceCategory)
The compliance category of the account.
-
complianceCategory
final BookkeepingAccount.Builder complianceCategory(JsonField<BookkeepingAccount.ComplianceCategory> complianceCategory)
The compliance category of the account.
-
entityId
final BookkeepingAccount.Builder entityId(String entityId)
The Entity associated with this bookkeeping account.
-
entityId
final BookkeepingAccount.Builder entityId(Optional<String> entityId)
The Entity associated with this bookkeeping account.
-
entityId
final BookkeepingAccount.Builder entityId(JsonField<String> entityId)
The Entity associated with this bookkeeping account.
-
idempotencyKey
final BookkeepingAccount.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final BookkeepingAccount.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final BookkeepingAccount.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
name
final BookkeepingAccount.Builder name(String name)
The name you choose for the account.
-
name
final BookkeepingAccount.Builder name(JsonField<String> name)
The name you choose for the account.
-
type
final BookkeepingAccount.Builder type(BookkeepingAccount.Type type)
A constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
type
final BookkeepingAccount.Builder type(JsonField<BookkeepingAccount.Type> type)
A constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
additionalProperties
final BookkeepingAccount.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingAccount.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingAccount.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingAccount.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingAccount.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingAccount build()
-
-
-
-