Package com.increase.api.models
Enum BookkeepingAccountCreateParams.ComplianceCategory.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum BookkeepingAccountCreateParams.ComplianceCategory.Known extends Enum<BookkeepingAccountCreateParams.ComplianceCategory.Known>
An enum containing ComplianceCategory's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<BookkeepingAccountCreateParams.ComplianceCategory.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description COMMINGLED_CASHA cash in an commingled Increase Account.
CUSTOMER_BALANCEA customer balance.
-
Method Summary
Modifier and Type Method Description final BookkeepingAccountCreateParams.ComplianceCategory.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<BookkeepingAccountCreateParams.ComplianceCategory.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<BookkeepingAccountCreateParams.ComplianceCategory.Known>getEntries()An enum containing ComplianceCategory's known values. -
-
Method Detail
-
valueOf
final BookkeepingAccountCreateParams.ComplianceCategory.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<BookkeepingAccountCreateParams.ComplianceCategory.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<BookkeepingAccountCreateParams.ComplianceCategory.Known> getEntries()
An enum containing ComplianceCategory's known values.
-
-
-
-