Package com.increase.api.models
Class BookkeepingAccountUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingAccountUpdateParams implements Params
Update a Bookkeeping Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountUpdateParams.Bodypublic final classBookkeepingAccountUpdateParams.BuilderA builder for BookkeepingAccountUpdateParams.
-
Method Summary
Modifier and Type Method Description final StringbookkeepingAccountId()The bookkeeping account you would like to update. final Stringname()The name you choose for the account. final JsonField<String>_name()The name you choose for the account. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final BookkeepingAccountUpdateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccountUpdateParams.Builderbuilder()-
-
Method Detail
-
bookkeepingAccountId
final String bookkeepingAccountId()
The bookkeeping account you would like to update.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final BookkeepingAccountUpdateParams.Builder toBuilder()
-
builder
final static BookkeepingAccountUpdateParams.Builder builder()
-
-
-
-