Class BookkeepingBalanceLookup
-
- All Implemented Interfaces:
public final class BookkeepingBalanceLookupRepresents a request to lookup the balance of an Bookkeeping Account at a given point in time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingBalanceLookup.BuilderA builder for BookkeepingBalanceLookup.
public final classBookkeepingBalanceLookup.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
Method Summary
Modifier and Type Method Description final Longbalance()The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account. final StringbookkeepingAccountId()The identifier for the account for which the balance was queried. final BookkeepingBalanceLookup.Typetype()A constant representing the object's type. final JsonField<Long>_balance()The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account. final JsonField<String>_bookkeepingAccountId()The identifier for the account for which the balance was queried. final JsonField<BookkeepingBalanceLookup.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final BookkeepingBalanceLookupvalidate()final BookkeepingBalanceLookup.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingBalanceLookup.Builderbuilder()-
-
Method Detail
-
balance
final Long balance()
The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account.
-
bookkeepingAccountId
final String bookkeepingAccountId()
The identifier for the account for which the balance was queried.
-
type
final BookkeepingBalanceLookup.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
_balance
final JsonField<Long> _balance()
The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account.
-
_bookkeepingAccountId
final JsonField<String> _bookkeepingAccountId()
The identifier for the account for which the balance was queried.
-
_type
final JsonField<BookkeepingBalanceLookup.Type> _type()
A constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookkeepingBalanceLookup validate()
-
toBuilder
final BookkeepingBalanceLookup.Builder toBuilder()
-
builder
final static BookkeepingBalanceLookup.Builder builder()
-
-
-
-