Package com.increase.api.models
Class BookkeepingBalanceLookup.Builder
-
- All Implemented Interfaces:
public final class BookkeepingBalanceLookup.BuilderA builder for BookkeepingBalanceLookup.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingBalanceLookup.Builderbalance(Long balance)The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account. final BookkeepingBalanceLookup.Builderbalance(JsonField<Long> balance)The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account. final BookkeepingBalanceLookup.BuilderbookkeepingAccountId(String bookkeepingAccountId)The identifier for the account for which the balance was queried. final BookkeepingBalanceLookup.BuilderbookkeepingAccountId(JsonField<String> bookkeepingAccountId)The identifier for the account for which the balance was queried. final BookkeepingBalanceLookup.Buildertype(BookkeepingBalanceLookup.Type type)A constant representing the object's type. final BookkeepingBalanceLookup.Buildertype(JsonField<BookkeepingBalanceLookup.Type> type)A constant representing the object's type. final BookkeepingBalanceLookup.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BookkeepingBalanceLookup.BuilderputAdditionalProperty(String key, JsonValue value)final BookkeepingBalanceLookup.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BookkeepingBalanceLookup.BuilderremoveAdditionalProperty(String key)final BookkeepingBalanceLookup.BuilderremoveAllAdditionalProperties(Set<String> keys)final BookkeepingBalanceLookupbuild()-
-
Method Detail
-
balance
final BookkeepingBalanceLookup.Builder balance(Long balance)
The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account.
-
balance
final BookkeepingBalanceLookup.Builder balance(JsonField<Long> balance)
The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account.
-
bookkeepingAccountId
final BookkeepingBalanceLookup.Builder bookkeepingAccountId(String bookkeepingAccountId)
The identifier for the account for which the balance was queried.
-
bookkeepingAccountId
final BookkeepingBalanceLookup.Builder bookkeepingAccountId(JsonField<String> bookkeepingAccountId)
The identifier for the account for which the balance was queried.
-
type
final BookkeepingBalanceLookup.Builder type(BookkeepingBalanceLookup.Type type)
A constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
type
final BookkeepingBalanceLookup.Builder type(JsonField<BookkeepingBalanceLookup.Type> type)
A constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
additionalProperties
final BookkeepingBalanceLookup.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingBalanceLookup.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingBalanceLookup.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingBalanceLookup.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingBalanceLookup.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingBalanceLookup build()
-
-
-
-