Class BookkeepingEntry
-
- All Implemented Interfaces:
public final class BookkeepingEntryEntries are T-account entries recording debits and credits. Your compliance setup might require annotating money movements using this API. Learn more in our guide to Bookkeeping.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntry.BuilderA builder for BookkeepingEntry.
public final classBookkeepingEntry.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
Method Summary
Modifier and Type Method Description final Stringid()The entry identifier. final StringaccountId()The identifier for the Account the Entry belongs to. final Longamount()The Entry amount in the minor unit of its currency. final OffsetDateTimecreatedAt()When the entry set was created. final StringentrySetId()The identifier for the Account the Entry belongs to. final BookkeepingEntry.Typetype()A constant representing the object's type. final JsonField<String>_id()The entry identifier. final JsonField<String>_accountId()The identifier for the Account the Entry belongs to. final JsonField<Long>_amount()The Entry amount in the minor unit of its currency. final JsonField<OffsetDateTime>_createdAt()When the entry set was created. final JsonField<String>_entrySetId()The identifier for the Account the Entry belongs to. final JsonField<BookkeepingEntry.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntryvalidate()final BookkeepingEntry.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntry.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The Entry amount in the minor unit of its currency. For dollars, for example, this is cents.
-
createdAt
final OffsetDateTime createdAt()
When the entry set was created.
-
entrySetId
final String entrySetId()
The identifier for the Account the Entry belongs to.
-
type
final BookkeepingEntry.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Account the Entry belongs to.
-
_amount
final JsonField<Long> _amount()
The Entry amount in the minor unit of its currency. For dollars, for example, this is cents.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
When the entry set was created.
-
_entrySetId
final JsonField<String> _entrySetId()
The identifier for the Account the Entry belongs to.
-
_type
final JsonField<BookkeepingEntry.Type> _type()
A constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookkeepingEntry validate()
-
toBuilder
final BookkeepingEntry.Builder toBuilder()
-
builder
final static BookkeepingEntry.Builder builder()
-
-
-
-