Package com.increase.api.models
Class BookkeepingEntry.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntry.BuilderA builder for BookkeepingEntry.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingEntry.Builderid(String id)The entry identifier. final BookkeepingEntry.Builderid(JsonField<String> id)The entry identifier. final BookkeepingEntry.BuilderaccountId(String accountId)The identifier for the Account the Entry belongs to. final BookkeepingEntry.BuilderaccountId(JsonField<String> accountId)The identifier for the Account the Entry belongs to. final BookkeepingEntry.Builderamount(Long amount)The Entry amount in the minor unit of its currency. final BookkeepingEntry.Builderamount(JsonField<Long> amount)The Entry amount in the minor unit of its currency. final BookkeepingEntry.BuildercreatedAt(OffsetDateTime createdAt)When the entry set was created. final BookkeepingEntry.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)When the entry set was created. final BookkeepingEntry.BuilderentrySetId(String entrySetId)The identifier for the Account the Entry belongs to. final BookkeepingEntry.BuilderentrySetId(JsonField<String> entrySetId)The identifier for the Account the Entry belongs to. final BookkeepingEntry.Buildertype(BookkeepingEntry.Type type)A constant representing the object's type. final BookkeepingEntry.Buildertype(JsonField<BookkeepingEntry.Type> type)A constant representing the object's type. final BookkeepingEntry.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BookkeepingEntry.BuilderputAdditionalProperty(String key, JsonValue value)final BookkeepingEntry.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BookkeepingEntry.BuilderremoveAdditionalProperty(String key)final BookkeepingEntry.BuilderremoveAllAdditionalProperties(Set<String> keys)final BookkeepingEntrybuild()-
-
Method Detail
-
id
final BookkeepingEntry.Builder id(String id)
The entry identifier.
-
id
final BookkeepingEntry.Builder id(JsonField<String> id)
The entry identifier.
-
accountId
final BookkeepingEntry.Builder accountId(String accountId)
The identifier for the Account the Entry belongs to.
-
accountId
final BookkeepingEntry.Builder accountId(JsonField<String> accountId)
The identifier for the Account the Entry belongs to.
-
amount
final BookkeepingEntry.Builder amount(Long amount)
The Entry amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final BookkeepingEntry.Builder amount(JsonField<Long> amount)
The Entry amount in the minor unit of its currency. For dollars, for example, this is cents.
-
createdAt
final BookkeepingEntry.Builder createdAt(OffsetDateTime createdAt)
When the entry set was created.
-
createdAt
final BookkeepingEntry.Builder createdAt(JsonField<OffsetDateTime> createdAt)
When the entry set was created.
-
entrySetId
final BookkeepingEntry.Builder entrySetId(String entrySetId)
The identifier for the Account the Entry belongs to.
-
entrySetId
final BookkeepingEntry.Builder entrySetId(JsonField<String> entrySetId)
The identifier for the Account the Entry belongs to.
-
type
final BookkeepingEntry.Builder type(BookkeepingEntry.Type type)
A constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
type
final BookkeepingEntry.Builder type(JsonField<BookkeepingEntry.Type> type)
A constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
additionalProperties
final BookkeepingEntry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingEntry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingEntry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingEntry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingEntry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingEntry build()
-
-
-
-