Class BookkeepingEntrySet
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetEntry Sets are accounting entries that are transactionally applied. Your compliance setup might require annotating money movements using this API. Learn more in our guide to Bookkeeping.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySet.BuilderA builder for BookkeepingEntrySet.
public final classBookkeepingEntrySet.Entrypublic final classBookkeepingEntrySet.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_entry_set.
-
Method Summary
Modifier and Type Method Description final Stringid()The entry set identifier. final OffsetDateTimecreatedAt()When the entry set was created. final OffsetDateTimedate()The timestamp of the entry set. final List<BookkeepingEntrySet.Entry>entries()The entries. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>transactionId()The transaction identifier, if any. final BookkeepingEntrySet.Typetype()A constant representing the object's type. final JsonField<String>_id()The entry set identifier. final JsonField<OffsetDateTime>_createdAt()When the entry set was created. final JsonField<OffsetDateTime>_date()The timestamp of the entry set. final JsonField<List<BookkeepingEntrySet.Entry>>_entries()The entries. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_transactionId()The transaction identifier, if any. final JsonField<BookkeepingEntrySet.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySetvalidate()final BookkeepingEntrySet.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySet.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
When the entry set was created.
-
date
final OffsetDateTime date()
The timestamp of the entry set.
-
entries
final List<BookkeepingEntrySet.Entry> entries()
The entries.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
transactionId
final Optional<String> transactionId()
The transaction identifier, if any.
-
type
final BookkeepingEntrySet.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_entry_set.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
When the entry set was created.
-
_date
final JsonField<OffsetDateTime> _date()
The timestamp of the entry set.
-
_entries
final JsonField<List<BookkeepingEntrySet.Entry>> _entries()
The entries.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_transactionId
final JsonField<String> _transactionId()
The transaction identifier, if any.
-
_type
final JsonField<BookkeepingEntrySet.Type> _type()
A constant representing the object's type. For this resource it will always be
bookkeeping_entry_set.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookkeepingEntrySet validate()
-
toBuilder
final BookkeepingEntrySet.Builder toBuilder()
-
builder
final static BookkeepingEntrySet.Builder builder()
-
-
-
-