Package com.increase.api.models
Class BookkeepingEntrySetCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingEntrySetCreateParams implements Params
Create a Bookkeeping Entry Set
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetCreateParams.Bodypublic final classBookkeepingEntrySetCreateParams.BuilderA builder for BookkeepingEntrySetCreateParams.
public final classBookkeepingEntrySetCreateParams.Entry
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntrySetCreateParams.Entry>entries()The bookkeeping entries. final Optional<OffsetDateTime>date()The date of the transaction. final Optional<String>transactionId()The identifier of the Transaction related to this entry set, if any. final JsonField<List<BookkeepingEntrySetCreateParams.Entry>>_entries()The bookkeeping entries. final JsonField<OffsetDateTime>_date()The date of the transaction. final JsonField<String>_transactionId()The identifier of the Transaction related to this entry set, if any. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final BookkeepingEntrySetCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetCreateParams.Builderbuilder()-
-
Method Detail
-
entries
final List<BookkeepingEntrySetCreateParams.Entry> entries()
The bookkeeping entries.
-
date
final Optional<OffsetDateTime> date()
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
transactionId
final Optional<String> transactionId()
The identifier of the Transaction related to this entry set, if any.
-
_entries
final JsonField<List<BookkeepingEntrySetCreateParams.Entry>> _entries()
The bookkeeping entries.
-
_date
final JsonField<OffsetDateTime> _date()
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction related to this entry set, if any.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final BookkeepingEntrySetCreateParams.Builder toBuilder()
-
builder
final static BookkeepingEntrySetCreateParams.Builder builder()
-
-
-
-