Package com.increase.api.models
Class BookkeepingEntrySetCreateParams.Body
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntrySetCreateParams.Entry>entries()The bookkeeping entries. final Optional<OffsetDateTime>date()The date of the transaction. final Optional<String>transactionId()The identifier of the Transaction related to this entry set, if any. final JsonField<List<BookkeepingEntrySetCreateParams.Entry>>_entries()The bookkeeping entries. final JsonField<OffsetDateTime>_date()The date of the transaction. final JsonField<String>_transactionId()The identifier of the Transaction related to this entry set, if any. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySetCreateParams.Bodyvalidate()final BookkeepingEntrySetCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetCreateParams.Body.Builderbuilder()-
-
Method Detail
-
entries
final List<BookkeepingEntrySetCreateParams.Entry> entries()
The bookkeeping entries.
-
date
final Optional<OffsetDateTime> date()
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
transactionId
final Optional<String> transactionId()
The identifier of the Transaction related to this entry set, if any.
-
_entries
final JsonField<List<BookkeepingEntrySetCreateParams.Entry>> _entries()
The bookkeeping entries.
-
_date
final JsonField<OffsetDateTime> _date()
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction related to this entry set, if any.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookkeepingEntrySetCreateParams.Body validate()
-
toBuilder
final BookkeepingEntrySetCreateParams.Body.Builder toBuilder()
-
builder
final static BookkeepingEntrySetCreateParams.Body.Builder builder()
-
-
-
-