Package com.increase.api.models
Class BookkeepingEntrySetCreateParams.Entry
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetCreateParams.Entry
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetCreateParams.Entry.BuilderA builder for Entry.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the Bookkeeping Account impacted by this entry. final Longamount()The entry amount in the minor unit of the account currency. final JsonField<String>_accountId()The identifier for the Bookkeeping Account impacted by this entry. final JsonField<Long>_amount()The entry amount in the minor unit of the account currency. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySetCreateParams.Entryvalidate()final BookkeepingEntrySetCreateParams.Entry.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetCreateParams.Entry.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier for the Bookkeeping Account impacted by this entry.
-
amount
final Long amount()
The entry amount in the minor unit of the account currency. For dollars, for example, this is cents. Debit entries have positive amounts; credit entries have negative amounts.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Bookkeeping Account impacted by this entry.
-
_amount
final JsonField<Long> _amount()
The entry amount in the minor unit of the account currency. For dollars, for example, this is cents. Debit entries have positive amounts; credit entries have negative amounts.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final BookkeepingEntrySetCreateParams.Entry validate()
-
toBuilder
final BookkeepingEntrySetCreateParams.Entry.Builder toBuilder()
-
builder
final static BookkeepingEntrySetCreateParams.Entry.Builder builder()
-
-
-
-