Class Card
-
- All Implemented Interfaces:
public final class CardCards are commercial credit cards. They'll immediately work for online purchases after you create them. All cards maintain a credit limit of 100% of the Account’s available balance at the time of transaction. Funds are deducted from the Account upon transaction settlement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.BuilderA builder for Card.
public final classCard.BillingAddressThe Card's billing address.
public final classCard.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
public final classCard.StatusThis indicates if payments can be made with the card.
public final classCard.TypeA constant representing the object's type. For this resource it will always be
card.
-
Method Summary
Modifier and Type Method Description final Stringid()The card identifier. final StringaccountId()The identifier for the account this card belongs to. final Card.BillingAddressbillingAddress()The Card's billing address. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Card was created. final Optional<String>description()The card's description for display purposes. final Optional<Card.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The identifier for the entity associated with this card. final LongexpirationMonth()The month the card expires in M format (e.g., August is 8). final LongexpirationYear()The year the card expires in YYYY format (e.g., 2025). final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Stringlast4()The last 4 digits of the Card's Primary Account Number. final Card.Statusstatus()This indicates if payments can be made with the card. final Card.Typetype()A constant representing the object's type. final JsonField<String>_id()The card identifier. final JsonField<String>_accountId()The identifier for the account this card belongs to. final JsonField<Card.BillingAddress>_billingAddress()The Card's billing address. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the Card was created. final JsonField<String>_description()The card's description for display purposes. final JsonField<Card.DigitalWallet>_digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final JsonField<String>_entityId()The identifier for the entity associated with this card. final JsonField<Long>_expirationMonth()The month the card expires in M format (e.g., August is 8). final JsonField<Long>_expirationYear()The year the card expires in YYYY format (e.g., 2025). final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_last4()The last 4 digits of the Card's Primary Account Number. final JsonField<Card.Status>_status()This indicates if payments can be made with the card. final JsonField<Card.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Cardvalidate()final Card.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.Builderbuilder()-
-
Method Detail
-
billingAddress
final Card.BillingAddress billingAddress()
The Card's billing address.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Card was created.
-
description
final Optional<String> description()
The card's description for display purposes.
-
digitalWallet
final Optional<Card.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
expirationMonth
final Long expirationMonth()
The month the card expires in M format (e.g., August is 8).
-
expirationYear
final Long expirationYear()
The year the card expires in YYYY format (e.g., 2025).
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final Card.Status status()
This indicates if payments can be made with the card.
-
type
final Card.Type type()
A constant representing the object's type. For this resource it will always be
card.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account this card belongs to.
-
_billingAddress
final JsonField<Card.BillingAddress> _billingAddress()
The Card's billing address.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the Card was created.
-
_description
final JsonField<String> _description()
The card's description for display purposes.
-
_digitalWallet
final JsonField<Card.DigitalWallet> _digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
_entityId
final JsonField<String> _entityId()
The identifier for the entity associated with this card.
-
_expirationMonth
final JsonField<Long> _expirationMonth()
The month the card expires in M format (e.g., August is 8).
-
_expirationYear
final JsonField<Long> _expirationYear()
The year the card expires in YYYY format (e.g., 2025).
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_status
final JsonField<Card.Status> _status()
This indicates if payments can be made with the card.
-
_type
final JsonField<Card.Type> _type()
A constant representing the object's type. For this resource it will always be
card.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.Builder toBuilder()
-
builder
final static Card.Builder builder()
-
-
-
-