Class Card.Builder
-
- All Implemented Interfaces:
public final class Card.BuilderA builder for Card.
-
-
Method Summary
Modifier and Type Method Description final Card.Builderid(String id)The card identifier. final Card.Builderid(JsonField<String> id)The card identifier. final Card.BuilderaccountId(String accountId)The identifier for the account this card belongs to. final Card.BuilderaccountId(JsonField<String> accountId)The identifier for the account this card belongs to. final Card.BuilderbillingAddress(Card.BillingAddress billingAddress)The Card's billing address. final Card.BuilderbillingAddress(JsonField<Card.BillingAddress> billingAddress)The Card's billing address. final Card.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the Card was created. final Card.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the Card was created. final Card.Builderdescription(String description)The card's description for display purposes. final Card.Builderdescription(Optional<String> description)The card's description for display purposes. final Card.Builderdescription(JsonField<String> description)The card's description for display purposes. final Card.BuilderdigitalWallet(Card.DigitalWallet digitalWallet)The contact information used in the two-factor steps for digital wallet card creation. final Card.BuilderdigitalWallet(Optional<Card.DigitalWallet> digitalWallet)The contact information used in the two-factor steps for digital wallet card creation. final Card.BuilderdigitalWallet(JsonField<Card.DigitalWallet> digitalWallet)The contact information used in the two-factor steps for digital wallet card creation. final Card.BuilderentityId(String entityId)The identifier for the entity associated with this card. final Card.BuilderentityId(Optional<String> entityId)The identifier for the entity associated with this card. final Card.BuilderentityId(JsonField<String> entityId)The identifier for the entity associated with this card. final Card.BuilderexpirationMonth(Long expirationMonth)The month the card expires in M format (e.g., August is 8). final Card.BuilderexpirationMonth(JsonField<Long> expirationMonth)The month the card expires in M format (e.g., August is 8). final Card.BuilderexpirationYear(Long expirationYear)The year the card expires in YYYY format (e.g., 2025). final Card.BuilderexpirationYear(JsonField<Long> expirationYear)The year the card expires in YYYY format (e.g., 2025). final Card.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Card.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final Card.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final Card.Builderlast4(String last4)The last 4 digits of the Card's Primary Account Number. final Card.Builderlast4(JsonField<String> last4)The last 4 digits of the Card's Primary Account Number. final Card.Builderstatus(Card.Status status)This indicates if payments can be made with the card. final Card.Builderstatus(JsonField<Card.Status> status)This indicates if payments can be made with the card. final Card.Buildertype(Card.Type type)A constant representing the object's type. final Card.Buildertype(JsonField<Card.Type> type)A constant representing the object's type. final Card.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderputAdditionalProperty(String key, JsonValue value)final Card.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderremoveAdditionalProperty(String key)final Card.BuilderremoveAllAdditionalProperties(Set<String> keys)final Cardbuild()-
-
Method Detail
-
id
final Card.Builder id(String id)
The card identifier.
-
id
final Card.Builder id(JsonField<String> id)
The card identifier.
-
accountId
final Card.Builder accountId(String accountId)
The identifier for the account this card belongs to.
-
accountId
final Card.Builder accountId(JsonField<String> accountId)
The identifier for the account this card belongs to.
-
billingAddress
final Card.Builder billingAddress(Card.BillingAddress billingAddress)
The Card's billing address.
-
billingAddress
final Card.Builder billingAddress(JsonField<Card.BillingAddress> billingAddress)
The Card's billing address.
-
createdAt
final Card.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Card was created.
-
createdAt
final Card.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the Card was created.
-
description
final Card.Builder description(String description)
The card's description for display purposes.
-
description
final Card.Builder description(Optional<String> description)
The card's description for display purposes.
-
description
final Card.Builder description(JsonField<String> description)
The card's description for display purposes.
-
digitalWallet
final Card.Builder digitalWallet(Card.DigitalWallet digitalWallet)
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
digitalWallet
final Card.Builder digitalWallet(Optional<Card.DigitalWallet> digitalWallet)
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
digitalWallet
final Card.Builder digitalWallet(JsonField<Card.DigitalWallet> digitalWallet)
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
entityId
final Card.Builder entityId(String entityId)
The identifier for the entity associated with this card.
-
entityId
final Card.Builder entityId(Optional<String> entityId)
The identifier for the entity associated with this card.
-
entityId
final Card.Builder entityId(JsonField<String> entityId)
The identifier for the entity associated with this card.
-
expirationMonth
final Card.Builder expirationMonth(Long expirationMonth)
The month the card expires in M format (e.g., August is 8).
-
expirationMonth
final Card.Builder expirationMonth(JsonField<Long> expirationMonth)
The month the card expires in M format (e.g., August is 8).
-
expirationYear
final Card.Builder expirationYear(Long expirationYear)
The year the card expires in YYYY format (e.g., 2025).
-
expirationYear
final Card.Builder expirationYear(JsonField<Long> expirationYear)
The year the card expires in YYYY format (e.g., 2025).
-
idempotencyKey
final Card.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Card.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Card.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
last4
final Card.Builder last4(String last4)
The last 4 digits of the Card's Primary Account Number.
-
last4
final Card.Builder last4(JsonField<String> last4)
The last 4 digits of the Card's Primary Account Number.
-
status
final Card.Builder status(Card.Status status)
This indicates if payments can be made with the card.
-
status
final Card.Builder status(JsonField<Card.Status> status)
This indicates if payments can be made with the card.
-
type
final Card.Builder type(Card.Type type)
A constant representing the object's type. For this resource it will always be
card.
-
type
final Card.Builder type(JsonField<Card.Type> type)
A constant representing the object's type. For this resource it will always be
card.
-
additionalProperties
final Card.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Card.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Card.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Card.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Card.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-