Class CardCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardCreateParams implements Params
Create a Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.Bodypublic final classCardCreateParams.BuilderA builder for CardCreateParams.
public final classCardCreateParams.BillingAddressThe card's billing address.
public final classCardCreateParams.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the card should belong to. final Optional<CardCreateParams.BillingAddress>billingAddress()The card's billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardCreateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final JsonField<String>_accountId()The Account the card should belong to. final JsonField<CardCreateParams.BillingAddress>_billingAddress()The card's billing address. final JsonField<String>_description()The description you choose to give the card. final JsonField<CardCreateParams.DigitalWallet>_digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final JsonField<String>_entityId()The Entity the card belongs to. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final CardCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.Builderbuilder()-
-
Method Detail
-
billingAddress
final Optional<CardCreateParams.BillingAddress> billingAddress()
The card's billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardCreateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_accountId
final JsonField<String> _accountId()
The Account the card should belong to.
-
_billingAddress
final JsonField<CardCreateParams.BillingAddress> _billingAddress()
The card's billing address.
-
_description
final JsonField<String> _description()
The description you choose to give the card.
-
_digitalWallet
final JsonField<CardCreateParams.DigitalWallet> _digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
_entityId
final JsonField<String> _entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final CardCreateParams.Builder toBuilder()
-
builder
final static CardCreateParams.Builder builder()
-
-
-
-