Class CardCreateParams.Body
-
- All Implemented Interfaces:
public final class CardCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the card should belong to. final Optional<CardCreateParams.BillingAddress>billingAddress()The card's billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardCreateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final JsonField<String>_accountId()The Account the card should belong to. final JsonField<CardCreateParams.BillingAddress>_billingAddress()The card's billing address. final JsonField<String>_description()The description you choose to give the card. final JsonField<CardCreateParams.DigitalWallet>_digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final JsonField<String>_entityId()The Entity the card belongs to. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.Bodyvalidate()final CardCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.Body.Builderbuilder()-
-
Method Detail
-
billingAddress
final Optional<CardCreateParams.BillingAddress> billingAddress()
The card's billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardCreateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_accountId
final JsonField<String> _accountId()
The Account the card should belong to.
-
_billingAddress
final JsonField<CardCreateParams.BillingAddress> _billingAddress()
The card's billing address.
-
_description
final JsonField<String> _description()
The description you choose to give the card.
-
_digitalWallet
final JsonField<CardCreateParams.DigitalWallet> _digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
_entityId
final JsonField<String> _entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardCreateParams.Body validate()
-
toBuilder
final CardCreateParams.Body.Builder toBuilder()
-
builder
final static CardCreateParams.Body.Builder builder()
-
-
-
-