Class CardDetails
-
- All Implemented Interfaces:
public final class CardDetailsAn object containing the sensitive details (card number, cvc, etc) for a Card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDetails.BuilderA builder for CardDetails.
public final classCardDetails.TypeA constant representing the object's type. For this resource it will always be
card_details.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier for the Card for which sensitive details have been returned. final LongexpirationMonth()The month the card expires in M format (e.g., August is 8). final LongexpirationYear()The year the card expires in YYYY format (e.g., 2025). final StringprimaryAccountNumber()The card number. final CardDetails.Typetype()A constant representing the object's type. final StringverificationCode()The three-digit verification code for the card. final JsonField<String>_cardId()The identifier for the Card for which sensitive details have been returned. final JsonField<Long>_expirationMonth()The month the card expires in M format (e.g., August is 8). final JsonField<Long>_expirationYear()The year the card expires in YYYY format (e.g., 2025). final JsonField<String>_primaryAccountNumber()The card number. final JsonField<CardDetails.Type>_type()A constant representing the object's type. final JsonField<String>_verificationCode()The three-digit verification code for the card. final Map<String, JsonValue>_additionalProperties()final CardDetailsvalidate()final CardDetails.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDetails.Builderbuilder()-
-
Method Detail
-
cardId
final String cardId()
The identifier for the Card for which sensitive details have been returned.
-
expirationMonth
final Long expirationMonth()
The month the card expires in M format (e.g., August is 8).
-
expirationYear
final Long expirationYear()
The year the card expires in YYYY format (e.g., 2025).
-
primaryAccountNumber
final String primaryAccountNumber()
The card number.
-
type
final CardDetails.Type type()
A constant representing the object's type. For this resource it will always be
card_details.
-
verificationCode
final String verificationCode()
The three-digit verification code for the card. It's also known as the Card Verification Code (CVC), the Card Verification Value (CVV), or the Card Identification (CID).
-
_cardId
final JsonField<String> _cardId()
The identifier for the Card for which sensitive details have been returned.
-
_expirationMonth
final JsonField<Long> _expirationMonth()
The month the card expires in M format (e.g., August is 8).
-
_expirationYear
final JsonField<Long> _expirationYear()
The year the card expires in YYYY format (e.g., 2025).
-
_primaryAccountNumber
final JsonField<String> _primaryAccountNumber()
The card number.
-
_type
final JsonField<CardDetails.Type> _type()
A constant representing the object's type. For this resource it will always be
card_details.
-
_verificationCode
final JsonField<String> _verificationCode()
The three-digit verification code for the card. It's also known as the Card Verification Code (CVC), the Card Verification Value (CVV), or the Card Identification (CID).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDetails validate()
-
toBuilder
final CardDetails.Builder toBuilder()
-
builder
final static CardDetails.Builder builder()
-
-
-
-