Class CardDispute
-
- All Implemented Interfaces:
public final class CardDisputeIf unauthorized activity occurs on a card, you can create a Card Dispute and we'll return the funds if appropriate.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDispute.BuilderA builder for CardDispute.
public final classCardDispute.AcceptanceIf the Card Dispute's status is
accepted, this will contain details of the successful dispute.public final classCardDispute.LossIf the Card Dispute's status is
lost, this will contain details of the lost dispute.public final classCardDispute.RejectionIf the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.public final classCardDispute.StatusThe results of the Dispute investigation.
public final classCardDispute.TypeA constant representing the object's type. For this resource it will always be
card_dispute.public final classCardDispute.WinIf the Card Dispute's status is
won, this will contain details of the won dispute.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Dispute identifier. final Optional<CardDispute.Acceptance>acceptance()If the Card Dispute's status is accepted, this will contain details of the successful dispute.final Optional<Long>amount()The amount of the dispute, if provided, or the transaction amount otherwise. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Card Dispute was created. final StringdisputedTransactionId()The identifier of the Transaction that was disputed. final Stringexplanation()Why you disputed the Transaction in question. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<CardDispute.Loss>loss()If the Card Dispute's status is lost, this will contain details of the lost dispute.final Optional<CardDispute.Rejection>rejection()If the Card Dispute's status is rejected, this will contain details of the unsuccessful dispute.final CardDispute.Statusstatus()The results of the Dispute investigation. final CardDispute.Typetype()A constant representing the object's type. final Optional<CardDispute.Win>win()If the Card Dispute's status is won, this will contain details of the won dispute.final JsonField<String>_id()The Card Dispute identifier. final JsonField<CardDispute.Acceptance>_acceptance()If the Card Dispute's status is accepted, this will contain details of the successful dispute.final JsonField<Long>_amount()The amount of the dispute, if provided, or the transaction amount otherwise. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the Card Dispute was created. final JsonField<String>_disputedTransactionId()The identifier of the Transaction that was disputed. final JsonField<String>_explanation()Why you disputed the Transaction in question. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<CardDispute.Loss>_loss()If the Card Dispute's status is lost, this will contain details of the lost dispute.final JsonField<CardDispute.Rejection>_rejection()If the Card Dispute's status is rejected, this will contain details of the unsuccessful dispute.final JsonField<CardDispute.Status>_status()The results of the Dispute investigation. final JsonField<CardDispute.Type>_type()A constant representing the object's type. final JsonField<CardDispute.Win>_win()If the Card Dispute's status is won, this will contain details of the won dispute.final Map<String, JsonValue>_additionalProperties()final CardDisputevalidate()final CardDispute.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDispute.Builderbuilder()-
-
Method Detail
-
acceptance
final Optional<CardDispute.Acceptance> acceptance()
If the Card Dispute's status is
accepted, this will contain details of the successful dispute.
-
amount
final Optional<Long> amount()
The amount of the dispute, if provided, or the transaction amount otherwise.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Card Dispute was created.
-
disputedTransactionId
final String disputedTransactionId()
The identifier of the Transaction that was disputed.
-
explanation
final String explanation()
Why you disputed the Transaction in question.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
loss
final Optional<CardDispute.Loss> loss()
If the Card Dispute's status is
lost, this will contain details of the lost dispute.
-
rejection
final Optional<CardDispute.Rejection> rejection()
If the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.
-
status
final CardDispute.Status status()
The results of the Dispute investigation.
-
type
final CardDispute.Type type()
A constant representing the object's type. For this resource it will always be
card_dispute.
-
win
final Optional<CardDispute.Win> win()
If the Card Dispute's status is
won, this will contain details of the won dispute.
-
_acceptance
final JsonField<CardDispute.Acceptance> _acceptance()
If the Card Dispute's status is
accepted, this will contain details of the successful dispute.
-
_amount
final JsonField<Long> _amount()
The amount of the dispute, if provided, or the transaction amount otherwise.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the Card Dispute was created.
-
_disputedTransactionId
final JsonField<String> _disputedTransactionId()
The identifier of the Transaction that was disputed.
-
_explanation
final JsonField<String> _explanation()
Why you disputed the Transaction in question.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_loss
final JsonField<CardDispute.Loss> _loss()
If the Card Dispute's status is
lost, this will contain details of the lost dispute.
-
_rejection
final JsonField<CardDispute.Rejection> _rejection()
If the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.
-
_status
final JsonField<CardDispute.Status> _status()
The results of the Dispute investigation.
-
_type
final JsonField<CardDispute.Type> _type()
A constant representing the object's type. For this resource it will always be
card_dispute.
-
_win
final JsonField<CardDispute.Win> _win()
If the Card Dispute's status is
won, this will contain details of the won dispute.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDispute validate()
-
toBuilder
final CardDispute.Builder toBuilder()
-
builder
final static CardDispute.Builder builder()
-
-
-
-