Package com.increase.api.models
Class CardDispute.Acceptance
-
- All Implemented Interfaces:
public final class CardDispute.AcceptanceIf the Card Dispute's status is
accepted, this will contain details of the successful dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDispute.Acceptance.BuilderA builder for Acceptance.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The ISO 8601 date and time at which the Card Dispute was accepted. final StringcardDisputeId()The identifier of the Card Dispute that was accepted. final StringtransactionId()The identifier of the Transaction that was created to return the disputed funds to your account. final JsonField<OffsetDateTime>_acceptedAt()The ISO 8601 date and time at which the Card Dispute was accepted. final JsonField<String>_cardDisputeId()The identifier of the Card Dispute that was accepted. final JsonField<String>_transactionId()The identifier of the Transaction that was created to return the disputed funds to your account. final Map<String, JsonValue>_additionalProperties()final CardDispute.Acceptancevalidate()final CardDispute.Acceptance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDispute.Acceptance.Builderbuilder()-
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the Card Dispute was accepted.
-
cardDisputeId
final String cardDisputeId()
The identifier of the Card Dispute that was accepted.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to return the disputed funds to your account.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
The ISO 8601 date and time at which the Card Dispute was accepted.
-
_cardDisputeId
final JsonField<String> _cardDisputeId()
The identifier of the Card Dispute that was accepted.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction that was created to return the disputed funds to your account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDispute.Acceptance validate()
-
toBuilder
final CardDispute.Acceptance.Builder toBuilder()
-
builder
final static CardDispute.Acceptance.Builder builder()
-
-
-
-