Class CardDispute.Builder
-
- All Implemented Interfaces:
public final class CardDispute.BuilderA builder for CardDispute.
-
-
Method Summary
Modifier and Type Method Description final CardDispute.Builderid(String id)The Card Dispute identifier. final CardDispute.Builderid(JsonField<String> id)The Card Dispute identifier. final CardDispute.Builderacceptance(CardDispute.Acceptance acceptance)If the Card Dispute's status is accepted, this will contain details of the successful dispute.final CardDispute.Builderacceptance(Optional<CardDispute.Acceptance> acceptance)If the Card Dispute's status is accepted, this will contain details of the successful dispute.final CardDispute.Builderacceptance(JsonField<CardDispute.Acceptance> acceptance)If the Card Dispute's status is accepted, this will contain details of the successful dispute.final CardDispute.Builderamount(Long amount)The amount of the dispute, if provided, or the transaction amount otherwise. final CardDispute.Builderamount(Long amount)The amount of the dispute, if provided, or the transaction amount otherwise. final CardDispute.Builderamount(Optional<Long> amount)The amount of the dispute, if provided, or the transaction amount otherwise. final CardDispute.Builderamount(JsonField<Long> amount)The amount of the dispute, if provided, or the transaction amount otherwise. final CardDispute.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the Card Dispute was created. final CardDispute.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the Card Dispute was created. final CardDispute.BuilderdisputedTransactionId(String disputedTransactionId)The identifier of the Transaction that was disputed. final CardDispute.BuilderdisputedTransactionId(JsonField<String> disputedTransactionId)The identifier of the Transaction that was disputed. final CardDispute.Builderexplanation(String explanation)Why you disputed the Transaction in question. final CardDispute.Builderexplanation(JsonField<String> explanation)Why you disputed the Transaction in question. final CardDispute.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final CardDispute.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final CardDispute.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final CardDispute.Builderloss(CardDispute.Loss loss)If the Card Dispute's status is lost, this will contain details of the lost dispute.final CardDispute.Builderloss(Optional<CardDispute.Loss> loss)If the Card Dispute's status is lost, this will contain details of the lost dispute.final CardDispute.Builderloss(JsonField<CardDispute.Loss> loss)If the Card Dispute's status is lost, this will contain details of the lost dispute.final CardDispute.Builderrejection(CardDispute.Rejection rejection)If the Card Dispute's status is rejected, this will contain details of the unsuccessful dispute.final CardDispute.Builderrejection(Optional<CardDispute.Rejection> rejection)If the Card Dispute's status is rejected, this will contain details of the unsuccessful dispute.final CardDispute.Builderrejection(JsonField<CardDispute.Rejection> rejection)If the Card Dispute's status is rejected, this will contain details of the unsuccessful dispute.final CardDispute.Builderstatus(CardDispute.Status status)The results of the Dispute investigation. final CardDispute.Builderstatus(JsonField<CardDispute.Status> status)The results of the Dispute investigation. final CardDispute.Buildertype(CardDispute.Type type)A constant representing the object's type. final CardDispute.Buildertype(JsonField<CardDispute.Type> type)A constant representing the object's type. final CardDispute.Builderwin(CardDispute.Win win)If the Card Dispute's status is won, this will contain details of the won dispute.final CardDispute.Builderwin(Optional<CardDispute.Win> win)If the Card Dispute's status is won, this will contain details of the won dispute.final CardDispute.Builderwin(JsonField<CardDispute.Win> win)If the Card Dispute's status is won, this will contain details of the won dispute.final CardDispute.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardDispute.BuilderputAdditionalProperty(String key, JsonValue value)final CardDispute.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardDispute.BuilderremoveAdditionalProperty(String key)final CardDispute.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardDisputebuild()-
-
Method Detail
-
id
final CardDispute.Builder id(String id)
The Card Dispute identifier.
-
id
final CardDispute.Builder id(JsonField<String> id)
The Card Dispute identifier.
-
acceptance
final CardDispute.Builder acceptance(CardDispute.Acceptance acceptance)
If the Card Dispute's status is
accepted, this will contain details of the successful dispute.
-
acceptance
final CardDispute.Builder acceptance(Optional<CardDispute.Acceptance> acceptance)
If the Card Dispute's status is
accepted, this will contain details of the successful dispute.
-
acceptance
final CardDispute.Builder acceptance(JsonField<CardDispute.Acceptance> acceptance)
If the Card Dispute's status is
accepted, this will contain details of the successful dispute.
-
amount
final CardDispute.Builder amount(Long amount)
The amount of the dispute, if provided, or the transaction amount otherwise.
-
amount
final CardDispute.Builder amount(Long amount)
The amount of the dispute, if provided, or the transaction amount otherwise.
-
amount
final CardDispute.Builder amount(Optional<Long> amount)
The amount of the dispute, if provided, or the transaction amount otherwise.
-
amount
final CardDispute.Builder amount(JsonField<Long> amount)
The amount of the dispute, if provided, or the transaction amount otherwise.
-
createdAt
final CardDispute.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Card Dispute was created.
-
createdAt
final CardDispute.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the Card Dispute was created.
-
disputedTransactionId
final CardDispute.Builder disputedTransactionId(String disputedTransactionId)
The identifier of the Transaction that was disputed.
-
disputedTransactionId
final CardDispute.Builder disputedTransactionId(JsonField<String> disputedTransactionId)
The identifier of the Transaction that was disputed.
-
explanation
final CardDispute.Builder explanation(String explanation)
Why you disputed the Transaction in question.
-
explanation
final CardDispute.Builder explanation(JsonField<String> explanation)
Why you disputed the Transaction in question.
-
idempotencyKey
final CardDispute.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CardDispute.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CardDispute.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
loss
final CardDispute.Builder loss(CardDispute.Loss loss)
If the Card Dispute's status is
lost, this will contain details of the lost dispute.
-
loss
final CardDispute.Builder loss(Optional<CardDispute.Loss> loss)
If the Card Dispute's status is
lost, this will contain details of the lost dispute.
-
loss
final CardDispute.Builder loss(JsonField<CardDispute.Loss> loss)
If the Card Dispute's status is
lost, this will contain details of the lost dispute.
-
rejection
final CardDispute.Builder rejection(CardDispute.Rejection rejection)
If the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.
-
rejection
final CardDispute.Builder rejection(Optional<CardDispute.Rejection> rejection)
If the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.
-
rejection
final CardDispute.Builder rejection(JsonField<CardDispute.Rejection> rejection)
If the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.
-
status
final CardDispute.Builder status(CardDispute.Status status)
The results of the Dispute investigation.
-
status
final CardDispute.Builder status(JsonField<CardDispute.Status> status)
The results of the Dispute investigation.
-
type
final CardDispute.Builder type(CardDispute.Type type)
A constant representing the object's type. For this resource it will always be
card_dispute.
-
type
final CardDispute.Builder type(JsonField<CardDispute.Type> type)
A constant representing the object's type. For this resource it will always be
card_dispute.
-
win
final CardDispute.Builder win(CardDispute.Win win)
If the Card Dispute's status is
won, this will contain details of the won dispute.
-
win
final CardDispute.Builder win(Optional<CardDispute.Win> win)
If the Card Dispute's status is
won, this will contain details of the won dispute.
-
win
final CardDispute.Builder win(JsonField<CardDispute.Win> win)
If the Card Dispute's status is
won, this will contain details of the won dispute.
-
additionalProperties
final CardDispute.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardDispute.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardDispute.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardDispute.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardDispute.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardDispute build()
-
-
-
-