Package com.increase.api.models
Class CardDispute.Loss
-
- All Implemented Interfaces:
public final class CardDispute.LossIf the Card Dispute's status is
lost, this will contain details of the lost dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDispute.Loss.BuilderA builder for Loss.
-
Method Summary
Modifier and Type Method Description final StringcardDisputeId()The identifier of the Card Dispute that was lost. final Stringexplanation()Why the Card Dispute was lost. final OffsetDateTimelostAt()The ISO 8601 date and time at which the Card Dispute was lost. final StringtransactionId()The identifier of the Transaction that was created to debit the disputed funds from your account. final JsonField<String>_cardDisputeId()The identifier of the Card Dispute that was lost. final JsonField<String>_explanation()Why the Card Dispute was lost. final JsonField<OffsetDateTime>_lostAt()The ISO 8601 date and time at which the Card Dispute was lost. final JsonField<String>_transactionId()The identifier of the Transaction that was created to debit the disputed funds from your account. final Map<String, JsonValue>_additionalProperties()final CardDispute.Lossvalidate()final CardDispute.Loss.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDispute.Loss.Builderbuilder()-
-
Method Detail
-
cardDisputeId
final String cardDisputeId()
The identifier of the Card Dispute that was lost.
-
explanation
final String explanation()
Why the Card Dispute was lost.
-
lostAt
final OffsetDateTime lostAt()
The ISO 8601 date and time at which the Card Dispute was lost.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to debit the disputed funds from your account.
-
_cardDisputeId
final JsonField<String> _cardDisputeId()
The identifier of the Card Dispute that was lost.
-
_explanation
final JsonField<String> _explanation()
Why the Card Dispute was lost.
-
_lostAt
final JsonField<OffsetDateTime> _lostAt()
The ISO 8601 date and time at which the Card Dispute was lost.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction that was created to debit the disputed funds from your account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDispute.Loss validate()
-
toBuilder
final CardDispute.Loss.Builder toBuilder()
-
builder
final static CardDispute.Loss.Builder builder()
-
-
-
-