Package com.increase.api.models
Class CardDispute.Rejection
-
- All Implemented Interfaces:
public final class CardDispute.RejectionIf the Card Dispute's status is
rejected, this will contain details of the unsuccessful dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDispute.Rejection.BuilderA builder for Rejection.
-
Method Summary
Modifier and Type Method Description final StringcardDisputeId()The identifier of the Card Dispute that was rejected. final Stringexplanation()Why the Card Dispute was rejected. final OffsetDateTimerejectedAt()The ISO 8601 date and time at which the Card Dispute was rejected. final JsonField<String>_cardDisputeId()The identifier of the Card Dispute that was rejected. final JsonField<String>_explanation()Why the Card Dispute was rejected. final JsonField<OffsetDateTime>_rejectedAt()The ISO 8601 date and time at which the Card Dispute was rejected. final Map<String, JsonValue>_additionalProperties()final CardDispute.Rejectionvalidate()final CardDispute.Rejection.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDispute.Rejection.Builderbuilder()-
-
Method Detail
-
cardDisputeId
final String cardDisputeId()
The identifier of the Card Dispute that was rejected.
-
explanation
final String explanation()
Why the Card Dispute was rejected.
-
rejectedAt
final OffsetDateTime rejectedAt()
The ISO 8601 date and time at which the Card Dispute was rejected.
-
_cardDisputeId
final JsonField<String> _cardDisputeId()
The identifier of the Card Dispute that was rejected.
-
_explanation
final JsonField<String> _explanation()
Why the Card Dispute was rejected.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
The ISO 8601 date and time at which the Card Dispute was rejected.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDispute.Rejection validate()
-
toBuilder
final CardDispute.Rejection.Builder toBuilder()
-
builder
final static CardDispute.Rejection.Builder builder()
-
-
-
-