Enum CardDispute.Status.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum CardDispute.Status.Value
    extends Enum<CardDispute.Status.Value>
                        

    An enum containing Status's known values, as well as an _UNKNOWN member.

    An instance of Status can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      PENDING_REVIEWING

      The Card Dispute is pending review.

      PENDING_USER_INFORMATION

      Increase has requested more information related to the Card Dispute from you.

      ACCEPTED

      The Card Dispute has been accepted and your funds have been returned. The card dispute will eventually transition into won or lost depending on the outcome.

      REJECTED

      The Card Dispute has been rejected.

      LOST

      The Card Dispute has been lost and funds previously credited from the acceptance have been debited.

      WON

      The Card Dispute has been won and no further action can be taken.

      _UNKNOWN

      An enum member indicating that Status was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final CardDispute.Status.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • values

         final Array<CardDispute.Status.Value> values()

        Returns an array containing the constants of this enum type, in the order they're declared.

        This method may be used to iterate over the constants.

      • getEntries

         final EnumEntries<CardDispute.Status.Value> getEntries()

        An enum containing Status's known values, as well as an _UNKNOWN member.

        An instance of Status can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.