Package com.increase.api.models
Class CardDispute.Win
-
- All Implemented Interfaces:
public final class CardDispute.WinIf the Card Dispute's status is
won, this will contain details of the won dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDispute.Win.BuilderA builder for Win.
-
Method Summary
Modifier and Type Method Description final StringcardDisputeId()The identifier of the Card Dispute that was won. final OffsetDateTimewonAt()The ISO 8601 date and time at which the Card Dispute was won. final JsonField<String>_cardDisputeId()The identifier of the Card Dispute that was won. final JsonField<OffsetDateTime>_wonAt()The ISO 8601 date and time at which the Card Dispute was won. final Map<String, JsonValue>_additionalProperties()final CardDispute.Winvalidate()final CardDispute.Win.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDispute.Win.Builderbuilder()-
-
Method Detail
-
cardDisputeId
final String cardDisputeId()
The identifier of the Card Dispute that was won.
-
wonAt
final OffsetDateTime wonAt()
The ISO 8601 date and time at which the Card Dispute was won.
-
_cardDisputeId
final JsonField<String> _cardDisputeId()
The identifier of the Card Dispute that was won.
-
_wonAt
final JsonField<OffsetDateTime> _wonAt()
The ISO 8601 date and time at which the Card Dispute was won.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDispute.Win validate()
-
toBuilder
final CardDispute.Win.Builder toBuilder()
-
builder
final static CardDispute.Win.Builder builder()
-
-
-
-