Class CardDisputeCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardDisputeCreateParams implements Params
Create a Card Dispute
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeCreateParams.Bodypublic final classCardDisputeCreateParams.BuilderA builder for CardDisputeCreateParams.
-
Method Summary
Modifier and Type Method Description final StringdisputedTransactionId()The Transaction you wish to dispute. final Stringexplanation()Why you are disputing this Transaction. final Optional<Long>amount()The monetary amount of the part of the transaction that is being disputed. final JsonField<String>_disputedTransactionId()The Transaction you wish to dispute. final JsonField<String>_explanation()Why you are disputing this Transaction. final JsonField<Long>_amount()The monetary amount of the part of the transaction that is being disputed. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final CardDisputeCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDisputeCreateParams.Builderbuilder()-
-
Method Detail
-
disputedTransactionId
final String disputedTransactionId()
The Transaction you wish to dispute. This Transaction must have a
source_typeofcard_settlement.
-
explanation
final String explanation()
Why you are disputing this Transaction.
-
amount
final Optional<Long> amount()
The monetary amount of the part of the transaction that is being disputed. This is optional and will default to the full amount of the transaction if not provided. If provided, the amount must be less than or equal to the amount of the transaction.
-
_disputedTransactionId
final JsonField<String> _disputedTransactionId()
The Transaction you wish to dispute. This Transaction must have a
source_typeofcard_settlement.
-
_explanation
final JsonField<String> _explanation()
Why you are disputing this Transaction.
-
_amount
final JsonField<Long> _amount()
The monetary amount of the part of the transaction that is being disputed. This is optional and will default to the full amount of the transaction if not provided. If provided, the amount must be less than or equal to the amount of the transaction.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final CardDisputeCreateParams.Builder toBuilder()
-
builder
final static CardDisputeCreateParams.Builder builder()
-
-
-
-