Class CardDisputeCreateParams.Body
-
- All Implemented Interfaces:
public final class CardDisputeCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringdisputedTransactionId()The Transaction you wish to dispute. final Stringexplanation()Why you are disputing this Transaction. final Optional<Long>amount()The monetary amount of the part of the transaction that is being disputed. final JsonField<String>_disputedTransactionId()The Transaction you wish to dispute. final JsonField<String>_explanation()Why you are disputing this Transaction. final JsonField<Long>_amount()The monetary amount of the part of the transaction that is being disputed. final Map<String, JsonValue>_additionalProperties()final CardDisputeCreateParams.Bodyvalidate()final CardDisputeCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDisputeCreateParams.Body.Builderbuilder()-
-
Method Detail
-
disputedTransactionId
final String disputedTransactionId()
The Transaction you wish to dispute. This Transaction must have a
source_typeofcard_settlement.
-
explanation
final String explanation()
Why you are disputing this Transaction.
-
amount
final Optional<Long> amount()
The monetary amount of the part of the transaction that is being disputed. This is optional and will default to the full amount of the transaction if not provided. If provided, the amount must be less than or equal to the amount of the transaction.
-
_disputedTransactionId
final JsonField<String> _disputedTransactionId()
The Transaction you wish to dispute. This Transaction must have a
source_typeofcard_settlement.
-
_explanation
final JsonField<String> _explanation()
Why you are disputing this Transaction.
-
_amount
final JsonField<Long> _amount()
The monetary amount of the part of the transaction that is being disputed. This is optional and will default to the full amount of the transaction if not provided. If provided, the amount must be less than or equal to the amount of the transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDisputeCreateParams.Body validate()
-
toBuilder
final CardDisputeCreateParams.Body.Builder toBuilder()
-
builder
final static CardDisputeCreateParams.Body.Builder builder()
-
-
-
-