Class CardPayment
-
- All Implemented Interfaces:
public final class CardPaymentCard Payments group together interactions related to a single card payment, such as an authorization and its corresponding settlement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.BuilderA builder for CardPayment.
public final classCardPayment.Elementpublic final classCardPayment.StateThe summarized state of this card payment.
public final classCardPayment.TypeA constant representing the object's type. For this resource it will always be
card_payment.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Payment identifier. final StringaccountId()The identifier for the Account the Transaction belongs to. final StringcardId()The Card identifier for this payment. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Card Payment was created. final Optional<String>digitalWalletTokenId()The Digital Wallet Token identifier for this payment. final List<CardPayment.Element>elements()The interactions related to this card payment. final Optional<String>physicalCardId()The Physical Card identifier for this payment. final CardPayment.Statestate()The summarized state of this card payment. final CardPayment.Typetype()A constant representing the object's type. final JsonField<String>_id()The Card Payment identifier. final JsonField<String>_accountId()The identifier for the Account the Transaction belongs to. final JsonField<String>_cardId()The Card identifier for this payment. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Card Payment was created. final JsonField<String>_digitalWalletTokenId()The Digital Wallet Token identifier for this payment. final JsonField<List<CardPayment.Element>>_elements()The interactions related to this card payment. final JsonField<String>_physicalCardId()The Physical Card identifier for this payment. final JsonField<CardPayment.State>_state()The summarized state of this card payment. final JsonField<CardPayment.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final CardPaymentvalidate()final CardPayment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Payment was created.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
The Digital Wallet Token identifier for this payment.
-
elements
final List<CardPayment.Element> elements()
The interactions related to this card payment.
-
physicalCardId
final Optional<String> physicalCardId()
The Physical Card identifier for this payment.
-
state
final CardPayment.State state()
The summarized state of this card payment.
-
type
final CardPayment.Type type()
A constant representing the object's type. For this resource it will always be
card_payment.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Account the Transaction belongs to.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Card Payment was created.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
The Digital Wallet Token identifier for this payment.
-
_elements
final JsonField<List<CardPayment.Element>> _elements()
The interactions related to this card payment.
-
_physicalCardId
final JsonField<String> _physicalCardId()
The Physical Card identifier for this payment.
-
_state
final JsonField<CardPayment.State> _state()
The summarized state of this card payment.
-
_type
final JsonField<CardPayment.Type> _type()
A constant representing the object's type. For this resource it will always be
card_payment.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment validate()
-
toBuilder
final CardPayment.Builder toBuilder()
-
builder
final static CardPayment.Builder builder()
-
-
-
-