Class CardPayment.Builder
-
- All Implemented Interfaces:
public final class CardPayment.BuilderA builder for CardPayment.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.Builderid(String id)The Card Payment identifier. final CardPayment.Builderid(JsonField<String> id)The Card Payment identifier. final CardPayment.BuilderaccountId(String accountId)The identifier for the Account the Transaction belongs to. final CardPayment.BuilderaccountId(JsonField<String> accountId)The identifier for the Account the Transaction belongs to. final CardPayment.BuildercardId(String cardId)The Card identifier for this payment. final CardPayment.BuildercardId(JsonField<String> cardId)The Card identifier for this payment. final CardPayment.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Card Payment was created. final CardPayment.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 time at which the Card Payment was created. final CardPayment.BuilderdigitalWalletTokenId(String digitalWalletTokenId)The Digital Wallet Token identifier for this payment. final CardPayment.BuilderdigitalWalletTokenId(Optional<String> digitalWalletTokenId)The Digital Wallet Token identifier for this payment. final CardPayment.BuilderdigitalWalletTokenId(JsonField<String> digitalWalletTokenId)The Digital Wallet Token identifier for this payment. final CardPayment.Builderelements(List<CardPayment.Element> elements)The interactions related to this card payment. final CardPayment.Builderelements(JsonField<List<CardPayment.Element>> elements)The interactions related to this card payment. final CardPayment.BuilderaddElement(CardPayment.Element element)The interactions related to this card payment. final CardPayment.BuilderphysicalCardId(String physicalCardId)The Physical Card identifier for this payment. final CardPayment.BuilderphysicalCardId(Optional<String> physicalCardId)The Physical Card identifier for this payment. final CardPayment.BuilderphysicalCardId(JsonField<String> physicalCardId)The Physical Card identifier for this payment. final CardPayment.Builderstate(CardPayment.State state)The summarized state of this card payment. final CardPayment.Builderstate(JsonField<CardPayment.State> state)The summarized state of this card payment. final CardPayment.Buildertype(CardPayment.Type type)A constant representing the object's type. final CardPayment.Buildertype(JsonField<CardPayment.Type> type)A constant representing the object's type. final CardPayment.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.BuilderremoveAdditionalProperty(String key)final CardPayment.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPaymentbuild()-
-
Method Detail
-
id
final CardPayment.Builder id(String id)
The Card Payment identifier.
-
id
final CardPayment.Builder id(JsonField<String> id)
The Card Payment identifier.
-
accountId
final CardPayment.Builder accountId(String accountId)
The identifier for the Account the Transaction belongs to.
-
accountId
final CardPayment.Builder accountId(JsonField<String> accountId)
The identifier for the Account the Transaction belongs to.
-
cardId
final CardPayment.Builder cardId(String cardId)
The Card identifier for this payment.
-
cardId
final CardPayment.Builder cardId(JsonField<String> cardId)
The Card identifier for this payment.
-
createdAt
final CardPayment.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Card Payment was created.
-
createdAt
final CardPayment.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Card Payment was created.
-
digitalWalletTokenId
final CardPayment.Builder digitalWalletTokenId(String digitalWalletTokenId)
The Digital Wallet Token identifier for this payment.
-
digitalWalletTokenId
final CardPayment.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
The Digital Wallet Token identifier for this payment.
-
digitalWalletTokenId
final CardPayment.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
The Digital Wallet Token identifier for this payment.
-
elements
final CardPayment.Builder elements(List<CardPayment.Element> elements)
The interactions related to this card payment.
-
elements
final CardPayment.Builder elements(JsonField<List<CardPayment.Element>> elements)
The interactions related to this card payment.
-
addElement
final CardPayment.Builder addElement(CardPayment.Element element)
The interactions related to this card payment.
-
physicalCardId
final CardPayment.Builder physicalCardId(String physicalCardId)
The Physical Card identifier for this payment.
-
physicalCardId
final CardPayment.Builder physicalCardId(Optional<String> physicalCardId)
The Physical Card identifier for this payment.
-
physicalCardId
final CardPayment.Builder physicalCardId(JsonField<String> physicalCardId)
The Physical Card identifier for this payment.
-
state
final CardPayment.Builder state(CardPayment.State state)
The summarized state of this card payment.
-
state
final CardPayment.Builder state(JsonField<CardPayment.State> state)
The summarized state of this card payment.
-
type
final CardPayment.Builder type(CardPayment.Type type)
A constant representing the object's type. For this resource it will always be
card_payment.
-
type
final CardPayment.Builder type(JsonField<CardPayment.Type> type)
A constant representing the object's type. For this resource it will always be
card_payment.
-
additionalProperties
final CardPayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment build()
-
-
-
-