Class CardPayment.Element
-
- All Implemented Interfaces:
public final class CardPayment.Element
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.BuilderA builder for Element.
public final classCardPayment.Element.CardAuthenticationA Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.public final classCardPayment.Element.CardAuthorizationA Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customers funds with the intent to later clear a transaction.public final classCardPayment.Element.CardAuthorizationExpirationA Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.public final classCardPayment.Element.CardDeclineA Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.public final classCardPayment.Element.CardFuelConfirmationA Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.public final classCardPayment.Element.CardIncrementA Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.public final classCardPayment.Element.CardRefundA Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.public final classCardPayment.Element.CardReversalA Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.public final classCardPayment.Element.CardSettlementA Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.public final classCardPayment.Element.CardValidationA Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.public final classCardPayment.Element.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
Method Summary
-
-
Method Detail
-
cardAuthentication
final Optional<CardPayment.Element.CardAuthentication> cardAuthentication()
A Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
cardAuthorization
final Optional<CardPayment.Element.CardAuthorization> cardAuthorization()
A Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customers funds with the intent to later clear a transaction.
-
cardAuthorizationExpiration
final Optional<CardPayment.Element.CardAuthorizationExpiration> cardAuthorizationExpiration()
A Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.
-
cardDecline
final Optional<CardPayment.Element.CardDecline> cardDecline()
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
cardFuelConfirmation
final Optional<CardPayment.Element.CardFuelConfirmation> cardFuelConfirmation()
A Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.
-
cardIncrement
final Optional<CardPayment.Element.CardIncrement> cardIncrement()
A Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.
-
cardRefund
final Optional<CardPayment.Element.CardRefund> cardRefund()
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
cardReversal
final Optional<CardPayment.Element.CardReversal> cardReversal()
A Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.
-
cardSettlement
final Optional<CardPayment.Element.CardSettlement> cardSettlement()
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cardValidation
final Optional<CardPayment.Element.CardValidation> cardValidation()
A Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.
-
category
final CardPayment.Element.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the card payment element was created.
-
_other
final JsonValue _other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
_cardAuthentication
final JsonField<CardPayment.Element.CardAuthentication> _cardAuthentication()
A Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
_cardAuthorization
final JsonField<CardPayment.Element.CardAuthorization> _cardAuthorization()
A Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customers funds with the intent to later clear a transaction.
-
_cardAuthorizationExpiration
final JsonField<CardPayment.Element.CardAuthorizationExpiration> _cardAuthorizationExpiration()
A Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.
-
_cardDecline
final JsonField<CardPayment.Element.CardDecline> _cardDecline()
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
_cardFuelConfirmation
final JsonField<CardPayment.Element.CardFuelConfirmation> _cardFuelConfirmation()
A Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.
-
_cardIncrement
final JsonField<CardPayment.Element.CardIncrement> _cardIncrement()
A Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.
-
_cardRefund
final JsonField<CardPayment.Element.CardRefund> _cardRefund()
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
_cardReversal
final JsonField<CardPayment.Element.CardReversal> _cardReversal()
A Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.
-
_cardSettlement
final JsonField<CardPayment.Element.CardSettlement> _cardSettlement()
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
_cardValidation
final JsonField<CardPayment.Element.CardValidation> _cardValidation()
A Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.
-
_category
final JsonField<CardPayment.Element.Category> _category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the card payment element was created.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element validate()
-
toBuilder
final CardPayment.Element.Builder toBuilder()
-
builder
final static CardPayment.Element.Builder builder()
-
-
-
-