Class CardPayment.Element.CardAuthentication
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthenticationA Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.BuilderA builder for CardAuthentication.
public final classCardPayment.Element.CardAuthentication.CategoryThe category of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.ChallengeDetails about the challenge, if one was requested.
public final classCardPayment.Element.CardAuthentication.DenyReasonThe reason why this authentication attempt was denied, if it was.
public final classCardPayment.Element.CardAuthentication.DeviceChannelThe device channel of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.StatusThe status of the card authentication.
public final classCardPayment.Element.CardAuthentication.TypeA constant representing the object's type. For this resource it will always be
card_authentication.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Authentication identifier. final StringcardId()The identifier of the Card. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final Optional<CardPayment.Element.CardAuthentication.Category>category()The category of the card authentication attempt. final Optional<CardPayment.Element.CardAuthentication.Challenge>challenge()Details about the challenge, if one was requested. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Card Authentication was attempted. final Optional<CardPayment.Element.CardAuthentication.DenyReason>denyReason()The reason why this authentication attempt was denied, if it was. final Optional<CardPayment.Element.CardAuthentication.DeviceChannel>deviceChannel()The device channel of the card authentication attempt. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final StringmerchantCountry()The country the merchant resides in. final StringmerchantName()The name of the merchant. final Optional<Long>purchaseAmount()The purchase amount in minor units. final Optional<String>purchaseCurrency()The ISO 4217 code for the authentication attempt's purchase currency. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this authentication attempt. final CardPayment.Element.CardAuthentication.Statusstatus()The status of the card authentication. final CardPayment.Element.CardAuthentication.Typetype()A constant representing the object's type. final JsonField<String>_id()The Card Authentication identifier. final JsonField<String>_cardId()The identifier of the Card. final JsonField<String>_cardPaymentId()The ID of the Card Payment this transaction belongs to. final JsonField<CardPayment.Element.CardAuthentication.Category>_category()The category of the card authentication attempt. final JsonField<CardPayment.Element.CardAuthentication.Challenge>_challenge()Details about the challenge, if one was requested. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Card Authentication was attempted. final JsonField<CardPayment.Element.CardAuthentication.DenyReason>_denyReason()The reason why this authentication attempt was denied, if it was. final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel>_deviceChannel()The device channel of the card authentication attempt. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantName()The name of the merchant. final JsonField<Long>_purchaseAmount()The purchase amount in minor units. final JsonField<String>_purchaseCurrency()The ISO 4217 code for the authentication attempt's purchase currency. final JsonField<String>_realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this authentication attempt. final JsonField<CardPayment.Element.CardAuthentication.Status>_status()The status of the card authentication. final JsonField<CardPayment.Element.CardAuthentication.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthenticationvalidate()final CardPayment.Element.CardAuthentication.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.Builderbuilder()-
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
category
final Optional<CardPayment.Element.CardAuthentication.Category> category()
The category of the card authentication attempt.
-
challenge
final Optional<CardPayment.Element.CardAuthentication.Challenge> challenge()
Details about the challenge, if one was requested.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Authentication was attempted.
-
denyReason
final Optional<CardPayment.Element.CardAuthentication.DenyReason> denyReason()
The reason why this authentication attempt was denied, if it was.
-
deviceChannel
final Optional<CardPayment.Element.CardAuthentication.DeviceChannel> deviceChannel()
The device channel of the card authentication attempt.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantName
final String merchantName()
The name of the merchant.
-
purchaseAmount
final Optional<Long> purchaseAmount()
The purchase amount in minor units.
-
purchaseCurrency
final Optional<String> purchaseCurrency()
The ISO 4217 code for the authentication attempt's purchase currency.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
status
final CardPayment.Element.CardAuthentication.Status status()
The status of the card authentication.
-
type
final CardPayment.Element.CardAuthentication.Type type()
A constant representing the object's type. For this resource it will always be
card_authentication.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
_category
final JsonField<CardPayment.Element.CardAuthentication.Category> _category()
The category of the card authentication attempt.
-
_challenge
final JsonField<CardPayment.Element.CardAuthentication.Challenge> _challenge()
Details about the challenge, if one was requested.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Card Authentication was attempted.
-
_denyReason
final JsonField<CardPayment.Element.CardAuthentication.DenyReason> _denyReason()
The reason why this authentication attempt was denied, if it was.
-
_deviceChannel
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel> _deviceChannel()
The device channel of the card authentication attempt.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantName
final JsonField<String> _merchantName()
The name of the merchant.
-
_purchaseAmount
final JsonField<Long> _purchaseAmount()
The purchase amount in minor units.
-
_purchaseCurrency
final JsonField<String> _purchaseCurrency()
The ISO 4217 code for the authentication attempt's purchase currency.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
_status
final JsonField<CardPayment.Element.CardAuthentication.Status> _status()
The status of the card authentication.
-
_type
final JsonField<CardPayment.Element.CardAuthentication.Type> _type()
A constant representing the object's type. For this resource it will always be
card_authentication.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardAuthentication validate()
-
toBuilder
final CardPayment.Element.CardAuthentication.Builder toBuilder()
-
builder
final static CardPayment.Element.CardAuthentication.Builder builder()
-
-
-
-