Class CardPayment.Element.CardAuthentication.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.BuilderA builder for CardAuthentication.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardAuthentication.Builder id(String id)
The Card Authentication identifier.
-
id
final CardPayment.Element.CardAuthentication.Builder id(JsonField<String> id)
The Card Authentication identifier.
-
cardId
final CardPayment.Element.CardAuthentication.Builder cardId(String cardId)
The identifier of the Card.
-
cardId
final CardPayment.Element.CardAuthentication.Builder cardId(JsonField<String> cardId)
The identifier of the Card.
-
cardPaymentId
final CardPayment.Element.CardAuthentication.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPayment.Element.CardAuthentication.Builder cardPaymentId(JsonField<String> cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
category
final CardPayment.Element.CardAuthentication.Builder category(CardPayment.Element.CardAuthentication.Category category)
The category of the card authentication attempt.
-
category
final CardPayment.Element.CardAuthentication.Builder category(Optional<CardPayment.Element.CardAuthentication.Category> category)
The category of the card authentication attempt.
-
category
final CardPayment.Element.CardAuthentication.Builder category(JsonField<CardPayment.Element.CardAuthentication.Category> category)
The category of the card authentication attempt.
-
challenge
final CardPayment.Element.CardAuthentication.Builder challenge(CardPayment.Element.CardAuthentication.Challenge challenge)
Details about the challenge, if one was requested.
-
challenge
final CardPayment.Element.CardAuthentication.Builder challenge(Optional<CardPayment.Element.CardAuthentication.Challenge> challenge)
Details about the challenge, if one was requested.
-
challenge
final CardPayment.Element.CardAuthentication.Builder challenge(JsonField<CardPayment.Element.CardAuthentication.Challenge> challenge)
Details about the challenge, if one was requested.
-
createdAt
final CardPayment.Element.CardAuthentication.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Card Authentication was attempted.
-
createdAt
final CardPayment.Element.CardAuthentication.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Card Authentication was attempted.
-
denyReason
final CardPayment.Element.CardAuthentication.Builder denyReason(CardPayment.Element.CardAuthentication.DenyReason denyReason)
The reason why this authentication attempt was denied, if it was.
-
denyReason
final CardPayment.Element.CardAuthentication.Builder denyReason(Optional<CardPayment.Element.CardAuthentication.DenyReason> denyReason)
The reason why this authentication attempt was denied, if it was.
-
denyReason
final CardPayment.Element.CardAuthentication.Builder denyReason(JsonField<CardPayment.Element.CardAuthentication.DenyReason> denyReason)
The reason why this authentication attempt was denied, if it was.
-
deviceChannel
final CardPayment.Element.CardAuthentication.Builder deviceChannel(CardPayment.Element.CardAuthentication.DeviceChannel deviceChannel)
The device channel of the card authentication attempt.
-
deviceChannel
final CardPayment.Element.CardAuthentication.Builder deviceChannel(Optional<CardPayment.Element.CardAuthentication.DeviceChannel> deviceChannel)
The device channel of the card authentication attempt.
-
deviceChannel
final CardPayment.Element.CardAuthentication.Builder deviceChannel(JsonField<CardPayment.Element.CardAuthentication.DeviceChannel> deviceChannel)
The device channel of the card authentication attempt.
-
merchantAcceptorId
final CardPayment.Element.CardAuthentication.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardAuthentication.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardAuthentication.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardAuthentication.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCountry
final CardPayment.Element.CardAuthentication.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardAuthentication.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantName
final CardPayment.Element.CardAuthentication.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final CardPayment.Element.CardAuthentication.Builder merchantName(JsonField<String> merchantName)
The name of the merchant.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(Long purchaseAmount)
The purchase amount in minor units.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(Long purchaseAmount)
The purchase amount in minor units.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(Optional<Long> purchaseAmount)
The purchase amount in minor units.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(JsonField<Long> purchaseAmount)
The purchase amount in minor units.
-
purchaseCurrency
final CardPayment.Element.CardAuthentication.Builder purchaseCurrency(String purchaseCurrency)
The ISO 4217 code for the authentication attempt's purchase currency.
-
purchaseCurrency
final CardPayment.Element.CardAuthentication.Builder purchaseCurrency(Optional<String> purchaseCurrency)
The ISO 4217 code for the authentication attempt's purchase currency.
-
purchaseCurrency
final CardPayment.Element.CardAuthentication.Builder purchaseCurrency(JsonField<String> purchaseCurrency)
The ISO 4217 code for the authentication attempt's purchase currency.
-
realTimeDecisionId
final CardPayment.Element.CardAuthentication.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
realTimeDecisionId
final CardPayment.Element.CardAuthentication.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
realTimeDecisionId
final CardPayment.Element.CardAuthentication.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
status
final CardPayment.Element.CardAuthentication.Builder status(CardPayment.Element.CardAuthentication.Status status)
The status of the card authentication.
-
status
final CardPayment.Element.CardAuthentication.Builder status(JsonField<CardPayment.Element.CardAuthentication.Status> status)
The status of the card authentication.
-
type
final CardPayment.Element.CardAuthentication.Builder type(CardPayment.Element.CardAuthentication.Type type)
A constant representing the object's type. For this resource it will always be
card_authentication.
-
type
final CardPayment.Element.CardAuthentication.Builder type(JsonField<CardPayment.Element.CardAuthentication.Type> type)
A constant representing the object's type. For this resource it will always be
card_authentication.
-
additionalProperties
final CardPayment.Element.CardAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication build()
-
-
-
-