Class CardPayment.Element.CardAuthentication.Challenge
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.ChallengeDetails about the challenge, if one was requested.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.Challenge.BuilderA builder for Challenge.
public final classCardPayment.Element.CardAuthentication.Challenge.Attemptpublic final classCardPayment.Element.CardAuthentication.Challenge.VerificationMethodThe method used to verify the Card Authentication Challenge.
-
Method Summary
Modifier and Type Method Description final List<CardPayment.Element.CardAuthentication.Challenge.Attempt>attempts()Details about the challenge verification attempts, if any happened. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Card Authentication Challenge was started. final StringoneTimeCode()The one-time code used for the Card Authentication Challenge. final CardPayment.Element.CardAuthentication.Challenge.VerificationMethodverificationMethod()The method used to verify the Card Authentication Challenge. final Optional<String>verificationValue()E.g., the email address or phone number used for the Card Authentication Challenge. final JsonField<List<CardPayment.Element.CardAuthentication.Challenge.Attempt>>_attempts()Details about the challenge verification attempts, if any happened. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Card Authentication Challenge was started. final JsonField<String>_oneTimeCode()The one-time code used for the Card Authentication Challenge. final JsonField<CardPayment.Element.CardAuthentication.Challenge.VerificationMethod>_verificationMethod()The method used to verify the Card Authentication Challenge. final JsonField<String>_verificationValue()E.g., the email address or phone number used for the Card Authentication Challenge. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthentication.Challengevalidate()final CardPayment.Element.CardAuthentication.Challenge.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.Challenge.Builderbuilder()-
-
Method Detail
-
attempts
final List<CardPayment.Element.CardAuthentication.Challenge.Attempt> attempts()
Details about the challenge verification attempts, if any happened.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Authentication Challenge was started.
-
oneTimeCode
final String oneTimeCode()
The one-time code used for the Card Authentication Challenge.
-
verificationMethod
final CardPayment.Element.CardAuthentication.Challenge.VerificationMethod verificationMethod()
The method used to verify the Card Authentication Challenge.
-
verificationValue
final Optional<String> verificationValue()
E.g., the email address or phone number used for the Card Authentication Challenge.
-
_attempts
final JsonField<List<CardPayment.Element.CardAuthentication.Challenge.Attempt>> _attempts()
Details about the challenge verification attempts, if any happened.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Card Authentication Challenge was started.
-
_oneTimeCode
final JsonField<String> _oneTimeCode()
The one-time code used for the Card Authentication Challenge.
-
_verificationMethod
final JsonField<CardPayment.Element.CardAuthentication.Challenge.VerificationMethod> _verificationMethod()
The method used to verify the Card Authentication Challenge.
-
_verificationValue
final JsonField<String> _verificationValue()
E.g., the email address or phone number used for the Card Authentication Challenge.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardAuthentication.Challenge validate()
-
toBuilder
final CardPayment.Element.CardAuthentication.Challenge.Builder toBuilder()
-
builder
final static CardPayment.Element.CardAuthentication.Challenge.Builder builder()
-
-
-
-