Class CardPayment.Element.CardAuthentication.Challenge.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.Challenge.BuilderA builder for Challenge.
-
-
Method Summary
-
-
Method Detail
-
attempts
final CardPayment.Element.CardAuthentication.Challenge.Builder attempts(List<CardPayment.Element.CardAuthentication.Challenge.Attempt> attempts)
Details about the challenge verification attempts, if any happened.
-
attempts
final CardPayment.Element.CardAuthentication.Challenge.Builder attempts(JsonField<List<CardPayment.Element.CardAuthentication.Challenge.Attempt>> attempts)
Details about the challenge verification attempts, if any happened.
-
addAttempt
final CardPayment.Element.CardAuthentication.Challenge.Builder addAttempt(CardPayment.Element.CardAuthentication.Challenge.Attempt attempt)
Details about the challenge verification attempts, if any happened.
-
createdAt
final CardPayment.Element.CardAuthentication.Challenge.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Card Authentication Challenge was started.
-
createdAt
final CardPayment.Element.CardAuthentication.Challenge.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Card Authentication Challenge was started.
-
oneTimeCode
final CardPayment.Element.CardAuthentication.Challenge.Builder oneTimeCode(String oneTimeCode)
The one-time code used for the Card Authentication Challenge.
-
oneTimeCode
final CardPayment.Element.CardAuthentication.Challenge.Builder oneTimeCode(JsonField<String> oneTimeCode)
The one-time code used for the Card Authentication Challenge.
-
verificationMethod
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationMethod(CardPayment.Element.CardAuthentication.Challenge.VerificationMethod verificationMethod)
The method used to verify the Card Authentication Challenge.
-
verificationMethod
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationMethod(JsonField<CardPayment.Element.CardAuthentication.Challenge.VerificationMethod> verificationMethod)
The method used to verify the Card Authentication Challenge.
-
verificationValue
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationValue(String verificationValue)
E.g., the email address or phone number used for the Card Authentication Challenge.
-
verificationValue
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationValue(Optional<String> verificationValue)
E.g., the email address or phone number used for the Card Authentication Challenge.
-
verificationValue
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationValue(JsonField<String> verificationValue)
E.g., the email address or phone number used for the Card Authentication Challenge.
-
additionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.Challenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.Challenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication.Challenge build()
-
-
-
-