Package com.increase.api.models
Enum CardPayment.Element.CardAuthentication.DenyReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPayment.Element.CardAuthentication.DenyReason.Known extends Enum<CardPayment.Element.CardAuthentication.DenyReason.Known>
An enum containing DenyReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPayment.Element.CardAuthentication.DenyReason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description GROUP_LOCKEDThe group was locked.
CARD_NOT_ACTIVEThe card was not active.
ENTITY_NOT_ACTIVEThe entity was not active.
TRANSACTION_NOT_ALLOWEDThe transaction was not allowed.
WEBHOOK_DENIEDThe webhook was denied.
WEBHOOK_TIMED_OUTThe webhook timed out.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardAuthentication.DenyReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPayment.Element.CardAuthentication.DenyReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPayment.Element.CardAuthentication.DenyReason.Known>getEntries()An enum containing DenyReason's known values. -
-
Method Detail
-
valueOf
final CardPayment.Element.CardAuthentication.DenyReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPayment.Element.CardAuthentication.DenyReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPayment.Element.CardAuthentication.DenyReason.Known> getEntries()
An enum containing DenyReason's known values.
-
-
-
-