Class CardPayment.Element.CardAuthorization.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthorization.BuilderA builder for CardAuthorization.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardAuthorization.Builderid(String id)The Card Authorization identifier. final CardPayment.Element.CardAuthorization.Builderid(JsonField<String> id)The Card Authorization identifier. final CardPayment.Element.CardAuthorization.Builderactioner(CardPayment.Element.CardAuthorization.Actioner actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardAuthorization.Builderactioner(JsonField<CardPayment.Element.CardAuthorization.Actioner> actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardAuthorization.Builderamount(Long amount)The pending amount in the minor unit of the transaction's currency. final CardPayment.Element.CardAuthorization.Builderamount(JsonField<Long> amount)The pending amount in the minor unit of the transaction's currency. final CardPayment.Element.CardAuthorization.BuildercardPaymentId(String cardPaymentId)The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardAuthorization.BuildercardPaymentId(JsonField<String> cardPaymentId)The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardAuthorization.Buildercurrency(CardPayment.Element.CardAuthorization.Currency currency)The ISO 4217 code for the transaction's currency. final CardPayment.Element.CardAuthorization.Buildercurrency(JsonField<CardPayment.Element.CardAuthorization.Currency> currency)The ISO 4217 code for the transaction's currency. final CardPayment.Element.CardAuthorization.BuilderdigitalWalletTokenId(String digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardAuthorization.BuilderdigitalWalletTokenId(Optional<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardAuthorization.BuilderdigitalWalletTokenId(JsonField<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardAuthorization.Builderdirection(CardPayment.Element.CardAuthorization.Direction direction)The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final CardPayment.Element.CardAuthorization.Builderdirection(JsonField<CardPayment.Element.CardAuthorization.Direction> direction)The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final CardPayment.Element.CardAuthorization.BuilderexpiresAt(OffsetDateTime expiresAt)The ISO 8601 when this authorization will expire and the pending transaction will be released. final CardPayment.Element.CardAuthorization.BuilderexpiresAt(JsonField<OffsetDateTime> expiresAt)The ISO 8601 when this authorization will expire and the pending transaction will be released. final CardPayment.Element.CardAuthorization.BuildermerchantAcceptorId(String merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final CardPayment.Element.CardAuthorization.BuildermerchantAcceptorId(JsonField<String> merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final CardPayment.Element.CardAuthorization.BuildermerchantCategoryCode(String merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final CardPayment.Element.CardAuthorization.BuildermerchantCategoryCode(JsonField<String> merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final CardPayment.Element.CardAuthorization.BuildermerchantCity(String merchantCity)The city the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantCity(Optional<String> merchantCity)The city the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantCity(JsonField<String> merchantCity)The city the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantCountry(String merchantCountry)The country the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantCountry(JsonField<String> merchantCountry)The country the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantDescriptor(String merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final CardPayment.Element.CardAuthorization.BuildermerchantDescriptor(JsonField<String> merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final CardPayment.Element.CardAuthorization.BuildermerchantPostalCode(String merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardAuthorization.BuildermerchantPostalCode(Optional<String> merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardAuthorization.BuildermerchantPostalCode(JsonField<String> merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardAuthorization.BuildermerchantState(String merchantState)The state the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantState(Optional<String> merchantState)The state the merchant resides in. final CardPayment.Element.CardAuthorization.BuildermerchantState(JsonField<String> merchantState)The state the merchant resides in. final CardPayment.Element.CardAuthorization.BuildernetworkDetails(CardPayment.Element.CardAuthorization.NetworkDetails networkDetails)Fields specific to the network.final CardPayment.Element.CardAuthorization.BuildernetworkDetails(JsonField<CardPayment.Element.CardAuthorization.NetworkDetails> networkDetails)Fields specific to the network.final CardPayment.Element.CardAuthorization.BuildernetworkIdentifiers(CardPayment.Element.CardAuthorization.NetworkIdentifiers networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardAuthorization.BuildernetworkIdentifiers(JsonField<CardPayment.Element.CardAuthorization.NetworkIdentifiers> networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardAuthorization.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardAuthorization.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardAuthorization.BuildernetworkRiskScore(Optional<Long> networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardAuthorization.BuildernetworkRiskScore(JsonField<Long> networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardAuthorization.BuilderpendingTransactionId(String pendingTransactionId)The identifier of the Pending Transaction associated with this Transaction. final CardPayment.Element.CardAuthorization.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The identifier of the Pending Transaction associated with this Transaction. final CardPayment.Element.CardAuthorization.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The identifier of the Pending Transaction associated with this Transaction. final CardPayment.Element.CardAuthorization.BuilderphysicalCardId(String physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final CardPayment.Element.CardAuthorization.BuilderphysicalCardId(Optional<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final CardPayment.Element.CardAuthorization.BuilderphysicalCardId(JsonField<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final CardPayment.Element.CardAuthorization.BuilderpresentmentAmount(Long presentmentAmount)The pending amount in the minor unit of the transaction's presentment currency. final CardPayment.Element.CardAuthorization.BuilderpresentmentAmount(JsonField<Long> presentmentAmount)The pending amount in the minor unit of the transaction's presentment currency. final CardPayment.Element.CardAuthorization.BuilderpresentmentCurrency(String presentmentCurrency)The ISO 4217 code for the transaction's presentment currency. final CardPayment.Element.CardAuthorization.BuilderpresentmentCurrency(JsonField<String> presentmentCurrency)The ISO 4217 code for the transaction's presentment currency. final CardPayment.Element.CardAuthorization.BuilderprocessingCategory(CardPayment.Element.CardAuthorization.ProcessingCategory processingCategory)The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final CardPayment.Element.CardAuthorization.BuilderprocessingCategory(JsonField<CardPayment.Element.CardAuthorization.ProcessingCategory> processingCategory)The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final CardPayment.Element.CardAuthorization.BuilderrealTimeDecisionId(String realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final CardPayment.Element.CardAuthorization.BuilderrealTimeDecisionId(Optional<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final CardPayment.Element.CardAuthorization.BuilderrealTimeDecisionId(JsonField<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final CardPayment.Element.CardAuthorization.BuilderterminalId(String terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardAuthorization.BuilderterminalId(Optional<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardAuthorization.BuilderterminalId(JsonField<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardAuthorization.Buildertype(CardPayment.Element.CardAuthorization.Type type)A constant representing the object's type. final CardPayment.Element.CardAuthorization.Buildertype(JsonField<CardPayment.Element.CardAuthorization.Type> type)A constant representing the object's type. final CardPayment.Element.CardAuthorization.Builderverification(CardPayment.Element.CardAuthorization.Verification verification)Fields related to verification of cardholder-provided values. final CardPayment.Element.CardAuthorization.Builderverification(JsonField<CardPayment.Element.CardAuthorization.Verification> verification)Fields related to verification of cardholder-provided values. final CardPayment.Element.CardAuthorization.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardAuthorization.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.Element.CardAuthorization.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardAuthorization.BuilderremoveAdditionalProperty(String key)final CardPayment.Element.CardAuthorization.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPayment.Element.CardAuthorizationbuild()-
-
Method Detail
-
id
final CardPayment.Element.CardAuthorization.Builder id(String id)
The Card Authorization identifier.
-
id
final CardPayment.Element.CardAuthorization.Builder id(JsonField<String> id)
The Card Authorization identifier.
-
actioner
final CardPayment.Element.CardAuthorization.Builder actioner(CardPayment.Element.CardAuthorization.Actioner actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final CardPayment.Element.CardAuthorization.Builder actioner(JsonField<CardPayment.Element.CardAuthorization.Actioner> actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
amount
final CardPayment.Element.CardAuthorization.Builder amount(Long amount)
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final CardPayment.Element.CardAuthorization.Builder amount(JsonField<Long> amount)
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
cardPaymentId
final CardPayment.Element.CardAuthorization.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPayment.Element.CardAuthorization.Builder cardPaymentId(JsonField<String> cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
currency
final CardPayment.Element.CardAuthorization.Builder currency(CardPayment.Element.CardAuthorization.Currency currency)
The ISO 4217 code for the transaction's currency.
-
currency
final CardPayment.Element.CardAuthorization.Builder currency(JsonField<CardPayment.Element.CardAuthorization.Currency> currency)
The ISO 4217 code for the transaction's currency.
-
digitalWalletTokenId
final CardPayment.Element.CardAuthorization.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final CardPayment.Element.CardAuthorization.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final CardPayment.Element.CardAuthorization.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final CardPayment.Element.CardAuthorization.Builder direction(CardPayment.Element.CardAuthorization.Direction direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
direction
final CardPayment.Element.CardAuthorization.Builder direction(JsonField<CardPayment.Element.CardAuthorization.Direction> direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
expiresAt
final CardPayment.Element.CardAuthorization.Builder expiresAt(OffsetDateTime expiresAt)
The ISO 8601 when this authorization will expire and the pending transaction will be released.
-
expiresAt
final CardPayment.Element.CardAuthorization.Builder expiresAt(JsonField<OffsetDateTime> expiresAt)
The ISO 8601 when this authorization will expire and the pending transaction will be released.
-
merchantAcceptorId
final CardPayment.Element.CardAuthorization.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardAuthorization.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardAuthorization.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardAuthorization.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final CardPayment.Element.CardAuthorization.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardAuthorization.Builder merchantCity(Optional<String> merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardAuthorization.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardAuthorization.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardAuthorization.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantDescriptor
final CardPayment.Element.CardAuthorization.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final CardPayment.Element.CardAuthorization.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final CardPayment.Element.CardAuthorization.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardAuthorization.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardAuthorization.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final CardPayment.Element.CardAuthorization.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardAuthorization.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardAuthorization.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkDetails
final CardPayment.Element.CardAuthorization.Builder networkDetails(CardPayment.Element.CardAuthorization.NetworkDetails networkDetails)
Fields specific to the
network.
-
networkDetails
final CardPayment.Element.CardAuthorization.Builder networkDetails(JsonField<CardPayment.Element.CardAuthorization.NetworkDetails> networkDetails)
Fields specific to the
network.
-
networkIdentifiers
final CardPayment.Element.CardAuthorization.Builder networkIdentifiers(CardPayment.Element.CardAuthorization.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardAuthorization.Builder networkIdentifiers(JsonField<CardPayment.Element.CardAuthorization.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final CardPayment.Element.CardAuthorization.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardAuthorization.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardAuthorization.Builder networkRiskScore(Optional<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardAuthorization.Builder networkRiskScore(JsonField<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
pendingTransactionId
final CardPayment.Element.CardAuthorization.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
pendingTransactionId
final CardPayment.Element.CardAuthorization.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
pendingTransactionId
final CardPayment.Element.CardAuthorization.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
physicalCardId
final CardPayment.Element.CardAuthorization.Builder physicalCardId(String physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final CardPayment.Element.CardAuthorization.Builder physicalCardId(Optional<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final CardPayment.Element.CardAuthorization.Builder physicalCardId(JsonField<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final CardPayment.Element.CardAuthorization.Builder presentmentAmount(Long presentmentAmount)
The pending amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final CardPayment.Element.CardAuthorization.Builder presentmentAmount(JsonField<Long> presentmentAmount)
The pending amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final CardPayment.Element.CardAuthorization.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final CardPayment.Element.CardAuthorization.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
processingCategory
final CardPayment.Element.CardAuthorization.Builder processingCategory(CardPayment.Element.CardAuthorization.ProcessingCategory processingCategory)
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
processingCategory
final CardPayment.Element.CardAuthorization.Builder processingCategory(JsonField<CardPayment.Element.CardAuthorization.ProcessingCategory> processingCategory)
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
realTimeDecisionId
final CardPayment.Element.CardAuthorization.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final CardPayment.Element.CardAuthorization.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final CardPayment.Element.CardAuthorization.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
terminalId
final CardPayment.Element.CardAuthorization.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardAuthorization.Builder terminalId(Optional<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardAuthorization.Builder terminalId(JsonField<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardAuthorization.Builder type(CardPayment.Element.CardAuthorization.Type type)
A constant representing the object's type. For this resource it will always be
card_authorization.
-
type
final CardPayment.Element.CardAuthorization.Builder type(JsonField<CardPayment.Element.CardAuthorization.Type> type)
A constant representing the object's type. For this resource it will always be
card_authorization.
-
verification
final CardPayment.Element.CardAuthorization.Builder verification(CardPayment.Element.CardAuthorization.Verification verification)
Fields related to verification of cardholder-provided values.
-
verification
final CardPayment.Element.CardAuthorization.Builder verification(JsonField<CardPayment.Element.CardAuthorization.Verification> verification)
Fields related to verification of cardholder-provided values.
-
additionalProperties
final CardPayment.Element.CardAuthorization.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthorization.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthorization.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthorization.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthorization.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthorization build()
-
-
-
-