Class CardPayment.Element.CardDecline
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardDeclineA Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardDecline.BuilderA builder for CardDecline.
public final classCardPayment.Element.CardDecline.ActionerWhether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classCardPayment.Element.CardDecline.CurrencyThe ISO 4217 code for the destination account currency.
public final classCardPayment.Element.CardDecline.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classCardPayment.Element.CardDecline.NetworkDetailsFields specific to the
network.public final classCardPayment.Element.CardDecline.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardDecline.ProcessingCategoryThe processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
public final classCardPayment.Element.CardDecline.RealTimeDecisionReasonThis is present if a specific decline reason was given in the real-time decision.
public final classCardPayment.Element.CardDecline.ReasonWhy the transaction was declined.
public final classCardPayment.Element.CardDecline.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Decline identifier. final CardPayment.Element.CardDecline.Actioneractioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final Longamount()The declined amount in the minor unit of the destination account currency. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardDecline.Currencycurrency()The ISO 4217 code for the destination account currency. final StringdeclinedTransactionId()The identifier of the declined transaction created for this Card Decline. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardDecline.Directiondirection()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final CardPayment.Element.CardDecline.NetworkDetailsnetworkDetails()Fields specific to the network.final CardPayment.Element.CardDecline.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final LongpresentmentAmount()The declined amount in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final CardPayment.Element.CardDecline.ProcessingCategoryprocessingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final Optional<CardPayment.Element.CardDecline.RealTimeDecisionReason>realTimeDecisionReason()This is present if a specific decline reason was given in the real-time decision. final CardPayment.Element.CardDecline.Reasonreason()Why the transaction was declined. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardDecline.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_id()The Card Decline identifier. final JsonField<CardPayment.Element.CardDecline.Actioner>_actioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final JsonField<Long>_amount()The declined amount in the minor unit of the destination account currency. final JsonField<String>_cardPaymentId()The ID of the Card Payment this transaction belongs to. final JsonField<CardPayment.Element.CardDecline.Currency>_currency()The ISO 4217 code for the destination account currency. final JsonField<String>_declinedTransactionId()The identifier of the declined transaction created for this Card Decline. final JsonField<String>_digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final JsonField<CardPayment.Element.CardDecline.Direction>_direction()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final JsonField<String>_merchantPostalCode()The merchant's postal code. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<CardPayment.Element.CardDecline.NetworkDetails>_networkDetails()Fields specific to the network.final JsonField<CardPayment.Element.CardDecline.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for a specific request or transaction. final JsonField<Long>_networkRiskScore()The risk score generated by the card network. final JsonField<String>_physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final JsonField<Long>_presentmentAmount()The declined amount in the minor unit of the transaction's presentment currency. final JsonField<String>_presentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final JsonField<CardPayment.Element.CardDecline.ProcessingCategory>_processingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final JsonField<String>_realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final JsonField<CardPayment.Element.CardDecline.RealTimeDecisionReason>_realTimeDecisionReason()This is present if a specific decline reason was given in the real-time decision. final JsonField<CardPayment.Element.CardDecline.Reason>_reason()Why the transaction was declined. final JsonField<String>_terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<CardPayment.Element.CardDecline.Verification>_verification()Fields related to verification of cardholder-provided values. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardDeclinevalidate()final CardPayment.Element.CardDecline.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardDecline.Builderbuilder()-
-
Method Detail
-
actioner
final CardPayment.Element.CardDecline.Actioner actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
amount
final Long amount()
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
currency
final CardPayment.Element.CardDecline.Currency currency()
The ISO 4217 code for the destination account currency.
-
declinedTransactionId
final String declinedTransactionId()
The identifier of the declined transaction created for this Card Decline.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final CardPayment.Element.CardDecline.Direction direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final CardPayment.Element.CardDecline.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final CardPayment.Element.CardDecline.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final Long presentmentAmount()
The declined amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
processingCategory
final CardPayment.Element.CardDecline.ProcessingCategory processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionReason
final Optional<CardPayment.Element.CardDecline.RealTimeDecisionReason> realTimeDecisionReason()
This is present if a specific decline reason was given in the real-time decision.
-
reason
final CardPayment.Element.CardDecline.Reason reason()
Why the transaction was declined.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
verification
final CardPayment.Element.CardDecline.Verification verification()
Fields related to verification of cardholder-provided values.
-
_actioner
final JsonField<CardPayment.Element.CardDecline.Actioner> _actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
_amount
final JsonField<Long> _amount()
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
_currency
final JsonField<CardPayment.Element.CardDecline.Currency> _currency()
The ISO 4217 code for the destination account currency.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
The identifier of the declined transaction created for this Card Decline.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
_direction
final JsonField<CardPayment.Element.CardDecline.Direction> _direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_networkDetails
final JsonField<CardPayment.Element.CardDecline.NetworkDetails> _networkDetails()
Fields specific to the
network.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardDecline.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
_physicalCardId
final JsonField<String> _physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
The declined amount in the minor unit of the transaction's presentment currency.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
_processingCategory
final JsonField<CardPayment.Element.CardDecline.ProcessingCategory> _processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
_realTimeDecisionReason
final JsonField<CardPayment.Element.CardDecline.RealTimeDecisionReason> _realTimeDecisionReason()
This is present if a specific decline reason was given in the real-time decision.
-
_reason
final JsonField<CardPayment.Element.CardDecline.Reason> _reason()
Why the transaction was declined.
-
_terminalId
final JsonField<String> _terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_verification
final JsonField<CardPayment.Element.CardDecline.Verification> _verification()
Fields related to verification of cardholder-provided values.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardDecline validate()
-
toBuilder
final CardPayment.Element.CardDecline.Builder toBuilder()
-
builder
final static CardPayment.Element.CardDecline.Builder builder()
-
-
-
-