Class CardPayment.Element.CardFuelConfirmation
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardFuelConfirmationA Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardFuelConfirmation.BuilderA builder for CardFuelConfirmation.
public final classCardPayment.Element.CardFuelConfirmation.CurrencyThe ISO 4217 code for the increment's currency.
public final classCardPayment.Element.CardFuelConfirmation.NetworkThe card network used to process this card authorization.
public final classCardPayment.Element.CardFuelConfirmation.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardFuelConfirmation.TypeA constant representing the object's type. For this resource it will always be
card_fuel_confirmation.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Fuel Confirmation identifier. final StringcardAuthorizationId()The identifier for the Card Authorization this updates. final CardPayment.Element.CardFuelConfirmation.Currencycurrency()The ISO 4217 code for the increment's currency. final CardPayment.Element.CardFuelConfirmation.Networknetwork()The card network used to process this card authorization. final CardPayment.Element.CardFuelConfirmation.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Card Fuel Confirmation. final CardPayment.Element.CardFuelConfirmation.Typetype()A constant representing the object's type. final LongupdatedAuthorizationAmount()The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. final JsonField<String>_id()The Card Fuel Confirmation identifier. final JsonField<String>_cardAuthorizationId()The identifier for the Card Authorization this updates. final JsonField<CardPayment.Element.CardFuelConfirmation.Currency>_currency()The ISO 4217 code for the increment's currency. final JsonField<CardPayment.Element.CardFuelConfirmation.Network>_network()The card network used to process this card authorization. final JsonField<CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for a specific request or transaction. final JsonField<String>_pendingTransactionId()The identifier of the Pending Transaction associated with this Card Fuel Confirmation. final JsonField<CardPayment.Element.CardFuelConfirmation.Type>_type()A constant representing the object's type. final JsonField<Long>_updatedAuthorizationAmount()The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardFuelConfirmationvalidate()final CardPayment.Element.CardFuelConfirmation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardFuelConfirmation.Builderbuilder()-
-
Method Detail
-
cardAuthorizationId
final String cardAuthorizationId()
The identifier for the Card Authorization this updates.
-
currency
final CardPayment.Element.CardFuelConfirmation.Currency currency()
The ISO 4217 code for the increment's currency.
-
network
final CardPayment.Element.CardFuelConfirmation.Network network()
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Fuel Confirmation.
-
type
final CardPayment.Element.CardFuelConfirmation.Type type()
A constant representing the object's type. For this resource it will always be
card_fuel_confirmation.
-
updatedAuthorizationAmount
final Long updatedAuthorizationAmount()
The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_cardAuthorizationId
final JsonField<String> _cardAuthorizationId()
The identifier for the Card Authorization this updates.
-
_currency
final JsonField<CardPayment.Element.CardFuelConfirmation.Currency> _currency()
The ISO 4217 code for the increment's currency.
-
_network
final JsonField<CardPayment.Element.CardFuelConfirmation.Network> _network()
The card network used to process this card authorization.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Fuel Confirmation.
-
_type
final JsonField<CardPayment.Element.CardFuelConfirmation.Type> _type()
A constant representing the object's type. For this resource it will always be
card_fuel_confirmation.
-
_updatedAuthorizationAmount
final JsonField<Long> _updatedAuthorizationAmount()
The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardFuelConfirmation validate()
-
toBuilder
final CardPayment.Element.CardFuelConfirmation.Builder toBuilder()
-
builder
final static CardPayment.Element.CardFuelConfirmation.Builder builder()
-
-
-
-