Class CardPayment.Element.CardIncrement.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardIncrement.BuilderA builder for CardIncrement.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardIncrement.Builderid(String id)The Card Increment identifier. final CardPayment.Element.CardIncrement.Builderid(JsonField<String> id)The Card Increment identifier. final CardPayment.Element.CardIncrement.Builderactioner(CardPayment.Element.CardIncrement.Actioner actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardIncrement.Builderactioner(JsonField<CardPayment.Element.CardIncrement.Actioner> actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardIncrement.Builderamount(Long amount)The amount of this increment in the minor unit of the transaction's currency. final CardPayment.Element.CardIncrement.Builderamount(JsonField<Long> amount)The amount of this increment in the minor unit of the transaction's currency. final CardPayment.Element.CardIncrement.BuildercardAuthorizationId(String cardAuthorizationId)The identifier for the Card Authorization this increments. final CardPayment.Element.CardIncrement.BuildercardAuthorizationId(JsonField<String> cardAuthorizationId)The identifier for the Card Authorization this increments. final CardPayment.Element.CardIncrement.Buildercurrency(CardPayment.Element.CardIncrement.Currency currency)The ISO 4217 code for the increment's currency. final CardPayment.Element.CardIncrement.Buildercurrency(JsonField<CardPayment.Element.CardIncrement.Currency> currency)The ISO 4217 code for the increment's currency. final CardPayment.Element.CardIncrement.Buildernetwork(CardPayment.Element.CardIncrement.Network network)The card network used to process this card authorization. final CardPayment.Element.CardIncrement.Buildernetwork(JsonField<CardPayment.Element.CardIncrement.Network> network)The card network used to process this card authorization. final CardPayment.Element.CardIncrement.BuildernetworkIdentifiers(CardPayment.Element.CardIncrement.NetworkIdentifiers networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardIncrement.BuildernetworkIdentifiers(JsonField<CardPayment.Element.CardIncrement.NetworkIdentifiers> networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardIncrement.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardIncrement.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardIncrement.BuildernetworkRiskScore(Optional<Long> networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardIncrement.BuildernetworkRiskScore(JsonField<Long> networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardIncrement.BuilderpendingTransactionId(String pendingTransactionId)The identifier of the Pending Transaction associated with this Card Increment. final CardPayment.Element.CardIncrement.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The identifier of the Pending Transaction associated with this Card Increment. final CardPayment.Element.CardIncrement.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The identifier of the Pending Transaction associated with this Card Increment. final CardPayment.Element.CardIncrement.BuilderrealTimeDecisionId(String realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this incremental authorization. final CardPayment.Element.CardIncrement.BuilderrealTimeDecisionId(Optional<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this incremental authorization. final CardPayment.Element.CardIncrement.BuilderrealTimeDecisionId(JsonField<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this incremental authorization. final CardPayment.Element.CardIncrement.Buildertype(CardPayment.Element.CardIncrement.Type type)A constant representing the object's type. final CardPayment.Element.CardIncrement.Buildertype(JsonField<CardPayment.Element.CardIncrement.Type> type)A constant representing the object's type. final CardPayment.Element.CardIncrement.BuilderupdatedAuthorizationAmount(Long updatedAuthorizationAmount)The updated authorization amount after this increment, in the minor unit of the transaction's currency. final CardPayment.Element.CardIncrement.BuilderupdatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)The updated authorization amount after this increment, in the minor unit of the transaction's currency. final CardPayment.Element.CardIncrement.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardIncrement.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.Element.CardIncrement.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardIncrement.BuilderremoveAdditionalProperty(String key)final CardPayment.Element.CardIncrement.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPayment.Element.CardIncrementbuild()-
-
Method Detail
-
id
final CardPayment.Element.CardIncrement.Builder id(String id)
The Card Increment identifier.
-
id
final CardPayment.Element.CardIncrement.Builder id(JsonField<String> id)
The Card Increment identifier.
-
actioner
final CardPayment.Element.CardIncrement.Builder actioner(CardPayment.Element.CardIncrement.Actioner actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final CardPayment.Element.CardIncrement.Builder actioner(JsonField<CardPayment.Element.CardIncrement.Actioner> actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
amount
final CardPayment.Element.CardIncrement.Builder amount(Long amount)
The amount of this increment in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final CardPayment.Element.CardIncrement.Builder amount(JsonField<Long> amount)
The amount of this increment in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
cardAuthorizationId
final CardPayment.Element.CardIncrement.Builder cardAuthorizationId(String cardAuthorizationId)
The identifier for the Card Authorization this increments.
-
cardAuthorizationId
final CardPayment.Element.CardIncrement.Builder cardAuthorizationId(JsonField<String> cardAuthorizationId)
The identifier for the Card Authorization this increments.
-
currency
final CardPayment.Element.CardIncrement.Builder currency(CardPayment.Element.CardIncrement.Currency currency)
The ISO 4217 code for the increment's currency.
-
currency
final CardPayment.Element.CardIncrement.Builder currency(JsonField<CardPayment.Element.CardIncrement.Currency> currency)
The ISO 4217 code for the increment's currency.
-
network
final CardPayment.Element.CardIncrement.Builder network(CardPayment.Element.CardIncrement.Network network)
The card network used to process this card authorization.
-
network
final CardPayment.Element.CardIncrement.Builder network(JsonField<CardPayment.Element.CardIncrement.Network> network)
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardIncrement.Builder networkIdentifiers(CardPayment.Element.CardIncrement.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardIncrement.Builder networkIdentifiers(JsonField<CardPayment.Element.CardIncrement.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(Optional<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(JsonField<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
pendingTransactionId
final CardPayment.Element.CardIncrement.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Increment.
-
pendingTransactionId
final CardPayment.Element.CardIncrement.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Increment.
-
pendingTransactionId
final CardPayment.Element.CardIncrement.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Increment.
-
realTimeDecisionId
final CardPayment.Element.CardIncrement.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
-
realTimeDecisionId
final CardPayment.Element.CardIncrement.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
-
realTimeDecisionId
final CardPayment.Element.CardIncrement.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
-
type
final CardPayment.Element.CardIncrement.Builder type(CardPayment.Element.CardIncrement.Type type)
A constant representing the object's type. For this resource it will always be
card_increment.
-
type
final CardPayment.Element.CardIncrement.Builder type(JsonField<CardPayment.Element.CardIncrement.Type> type)
A constant representing the object's type. For this resource it will always be
card_increment.
-
updatedAuthorizationAmount
final CardPayment.Element.CardIncrement.Builder updatedAuthorizationAmount(Long updatedAuthorizationAmount)
The updated authorization amount after this increment, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
updatedAuthorizationAmount
final CardPayment.Element.CardIncrement.Builder updatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)
The updated authorization amount after this increment, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
additionalProperties
final CardPayment.Element.CardIncrement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardIncrement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardIncrement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardIncrement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardIncrement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardIncrement build()
-
-
-
-