Package com.increase.api.models
Class CardPayment.Element.CardRefund.Cashback
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardRefund.CashbackCashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardRefund.Cashback.BuilderA builder for Cashback.
public final classCardPayment.Element.CardRefund.Cashback.CurrencyThe ISO 4217 code for the cashback.
-
Method Summary
Modifier and Type Method Description final Stringamount()The cashback amount given as a string containing a decimal number. final CardPayment.Element.CardRefund.Cashback.Currencycurrency()The ISO 4217 code for the cashback. final JsonField<String>_amount()The cashback amount given as a string containing a decimal number. final JsonField<CardPayment.Element.CardRefund.Cashback.Currency>_currency()The ISO 4217 code for the cashback. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardRefund.Cashbackvalidate()final CardPayment.Element.CardRefund.Cashback.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardRefund.Cashback.Builderbuilder()-
-
Method Detail
-
amount
final String amount()
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
currency
final CardPayment.Element.CardRefund.Cashback.Currency currency()
The ISO 4217 code for the cashback.
-
_amount
final JsonField<String> _amount()
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
_currency
final JsonField<CardPayment.Element.CardRefund.Cashback.Currency> _currency()
The ISO 4217 code for the cashback.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardRefund.Cashback validate()
-
toBuilder
final CardPayment.Element.CardRefund.Cashback.Builder toBuilder()
-
builder
final static CardPayment.Element.CardRefund.Cashback.Builder builder()
-
-
-
-