Package com.increase.api.models
Class CardPayment.Element.CardRefund.Interchange
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardRefund.InterchangeInterchange assessed as a part of this transaciton.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardRefund.Interchange.BuilderA builder for Interchange.
public final classCardPayment.Element.CardRefund.Interchange.CurrencyThe ISO 4217 code for the interchange reimbursement.
-
Method Summary
Modifier and Type Method Description final Stringamount()The interchange amount given as a string containing a decimal number. final Optional<String>code()The card network specific interchange code. final CardPayment.Element.CardRefund.Interchange.Currencycurrency()The ISO 4217 code for the interchange reimbursement. final JsonField<String>_amount()The interchange amount given as a string containing a decimal number. final JsonField<String>_code()The card network specific interchange code. final JsonField<CardPayment.Element.CardRefund.Interchange.Currency>_currency()The ISO 4217 code for the interchange reimbursement. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardRefund.Interchangevalidate()final CardPayment.Element.CardRefund.Interchange.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardRefund.Interchange.Builderbuilder()-
-
Method Detail
-
amount
final String amount()
The interchange amount given as a string containing a decimal number. The amount is a positive number if it is credited to Increase (e.g., settlements) and a negative number if it is debited (e.g., refunds).
-
currency
final CardPayment.Element.CardRefund.Interchange.Currency currency()
The ISO 4217 code for the interchange reimbursement.
-
_amount
final JsonField<String> _amount()
The interchange amount given as a string containing a decimal number. The amount is a positive number if it is credited to Increase (e.g., settlements) and a negative number if it is debited (e.g., refunds).
-
_currency
final JsonField<CardPayment.Element.CardRefund.Interchange.Currency> _currency()
The ISO 4217 code for the interchange reimbursement.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardRefund.Interchange validate()
-
toBuilder
final CardPayment.Element.CardRefund.Interchange.Builder toBuilder()
-
builder
final static CardPayment.Element.CardRefund.Interchange.Builder builder()
-
-
-
-