Package com.increase.api.models
Class CardPayment.Element.CardRefund.Interchange.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardRefund.Interchange.BuilderA builder for Interchange.
-
-
Method Summary
-
-
Method Detail
-
amount
final CardPayment.Element.CardRefund.Interchange.Builder amount(String amount)
The interchange amount given as a string containing a decimal number. The amount is a positive number if it is credited to Increase (e.g., settlements) and a negative number if it is debited (e.g., refunds).
-
amount
final CardPayment.Element.CardRefund.Interchange.Builder amount(JsonField<String> amount)
The interchange amount given as a string containing a decimal number. The amount is a positive number if it is credited to Increase (e.g., settlements) and a negative number if it is debited (e.g., refunds).
-
code
final CardPayment.Element.CardRefund.Interchange.Builder code(String code)
The card network specific interchange code.
-
code
final CardPayment.Element.CardRefund.Interchange.Builder code(Optional<String> code)
The card network specific interchange code.
-
code
final CardPayment.Element.CardRefund.Interchange.Builder code(JsonField<String> code)
The card network specific interchange code.
-
currency
final CardPayment.Element.CardRefund.Interchange.Builder currency(CardPayment.Element.CardRefund.Interchange.Currency currency)
The ISO 4217 code for the interchange reimbursement.
-
currency
final CardPayment.Element.CardRefund.Interchange.Builder currency(JsonField<CardPayment.Element.CardRefund.Interchange.Currency> currency)
The ISO 4217 code for the interchange reimbursement.
-
additionalProperties
final CardPayment.Element.CardRefund.Interchange.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardRefund.Interchange.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardRefund.Interchange.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardRefund.Interchange.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardRefund.Interchange.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardRefund.Interchange build()
-
-
-
-