Class CardPayment.Element.CardReversal
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardReversalA Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardReversal.BuilderA builder for CardReversal.
public final classCardPayment.Element.CardReversal.CurrencyThe ISO 4217 code for the reversal's currency.
public final classCardPayment.Element.CardReversal.NetworkThe card network used to process this card authorization.
public final classCardPayment.Element.CardReversal.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardReversal.ReversalReasonWhy this reversal was initiated.
public final classCardPayment.Element.CardReversal.TypeA constant representing the object's type. For this resource it will always be
card_reversal.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Reversal identifier. final StringcardAuthorizationId()The identifier for the Card Authorization this reverses. final CardPayment.Element.CardReversal.Currencycurrency()The ISO 4217 code for the reversal's currency. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final Optional<String>merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final Optional<String>merchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final CardPayment.Element.CardReversal.Networknetwork()The card network used to process this card authorization. final CardPayment.Element.CardReversal.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Card Reversal. final LongreversalAmount()The amount of this reversal in the minor unit of the transaction's currency. final Optional<CardPayment.Element.CardReversal.ReversalReason>reversalReason()Why this reversal was initiated. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardReversal.Typetype()A constant representing the object's type. final LongupdatedAuthorizationAmount()The amount left pending on the Card Authorization in the minor unit of the transaction's currency. final JsonField<String>_id()The Card Reversal identifier. final JsonField<String>_cardAuthorizationId()The identifier for the Card Authorization this reverses. final JsonField<CardPayment.Element.CardReversal.Currency>_currency()The ISO 4217 code for the reversal's currency. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final JsonField<String>_merchantPostalCode()The merchant's postal code. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<CardPayment.Element.CardReversal.Network>_network()The card network used to process this card authorization. final JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for a specific request or transaction. final JsonField<String>_pendingTransactionId()The identifier of the Pending Transaction associated with this Card Reversal. final JsonField<Long>_reversalAmount()The amount of this reversal in the minor unit of the transaction's currency. final JsonField<CardPayment.Element.CardReversal.ReversalReason>_reversalReason()Why this reversal was initiated. final JsonField<String>_terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<CardPayment.Element.CardReversal.Type>_type()A constant representing the object's type. final JsonField<Long>_updatedAuthorizationAmount()The amount left pending on the Card Authorization in the minor unit of the transaction's currency. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardReversalvalidate()final CardPayment.Element.CardReversal.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardReversal.Builderbuilder()-
-
Method Detail
-
cardAuthorizationId
final String cardAuthorizationId()
The identifier for the Card Authorization this reverses.
-
currency
final CardPayment.Element.CardReversal.Currency currency()
The ISO 4217 code for the reversal's currency.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Optional<String> merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
network
final CardPayment.Element.CardReversal.Network network()
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardReversal.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Reversal.
-
reversalAmount
final Long reversalAmount()
The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversalReason
final Optional<CardPayment.Element.CardReversal.ReversalReason> reversalReason()
Why this reversal was initiated.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardReversal.Type type()
A constant representing the object's type. For this resource it will always be
card_reversal.
-
updatedAuthorizationAmount
final Long updatedAuthorizationAmount()
The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_cardAuthorizationId
final JsonField<String> _cardAuthorizationId()
The identifier for the Card Authorization this reverses.
-
_currency
final JsonField<CardPayment.Element.CardReversal.Currency> _currency()
The ISO 4217 code for the reversal's currency.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_network
final JsonField<CardPayment.Element.CardReversal.Network> _network()
The card network used to process this card authorization.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Reversal.
-
_reversalAmount
final JsonField<Long> _reversalAmount()
The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_reversalReason
final JsonField<CardPayment.Element.CardReversal.ReversalReason> _reversalReason()
Why this reversal was initiated.
-
_terminalId
final JsonField<String> _terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_type
final JsonField<CardPayment.Element.CardReversal.Type> _type()
A constant representing the object's type. For this resource it will always be
card_reversal.
-
_updatedAuthorizationAmount
final JsonField<Long> _updatedAuthorizationAmount()
The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardReversal validate()
-
toBuilder
final CardPayment.Element.CardReversal.Builder toBuilder()
-
builder
final static CardPayment.Element.CardReversal.Builder builder()
-
-
-
-