Class CardPayment.Element.CardReversal.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardReversal.BuilderA builder for CardReversal.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardReversal.Builderid(String id)The Card Reversal identifier. final CardPayment.Element.CardReversal.Builderid(JsonField<String> id)The Card Reversal identifier. final CardPayment.Element.CardReversal.BuildercardAuthorizationId(String cardAuthorizationId)The identifier for the Card Authorization this reverses. final CardPayment.Element.CardReversal.BuildercardAuthorizationId(JsonField<String> cardAuthorizationId)The identifier for the Card Authorization this reverses. final CardPayment.Element.CardReversal.Buildercurrency(CardPayment.Element.CardReversal.Currency currency)The ISO 4217 code for the reversal's currency. final CardPayment.Element.CardReversal.Buildercurrency(JsonField<CardPayment.Element.CardReversal.Currency> currency)The ISO 4217 code for the reversal's currency. final CardPayment.Element.CardReversal.BuildermerchantAcceptorId(String merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final CardPayment.Element.CardReversal.BuildermerchantAcceptorId(JsonField<String> merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final CardPayment.Element.CardReversal.BuildermerchantCategoryCode(String merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final CardPayment.Element.CardReversal.BuildermerchantCategoryCode(JsonField<String> merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final CardPayment.Element.CardReversal.BuildermerchantCity(String merchantCity)The city the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantCity(Optional<String> merchantCity)The city the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantCity(JsonField<String> merchantCity)The city the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantCountry(String merchantCountry)The country the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantCountry(Optional<String> merchantCountry)The country the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantCountry(JsonField<String> merchantCountry)The country the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantDescriptor(String merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final CardPayment.Element.CardReversal.BuildermerchantDescriptor(JsonField<String> merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final CardPayment.Element.CardReversal.BuildermerchantPostalCode(String merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardReversal.BuildermerchantPostalCode(Optional<String> merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardReversal.BuildermerchantPostalCode(JsonField<String> merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardReversal.BuildermerchantState(String merchantState)The state the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantState(Optional<String> merchantState)The state the merchant resides in. final CardPayment.Element.CardReversal.BuildermerchantState(JsonField<String> merchantState)The state the merchant resides in. final CardPayment.Element.CardReversal.Buildernetwork(CardPayment.Element.CardReversal.Network network)The card network used to process this card authorization. final CardPayment.Element.CardReversal.Buildernetwork(JsonField<CardPayment.Element.CardReversal.Network> network)The card network used to process this card authorization. final CardPayment.Element.CardReversal.BuildernetworkIdentifiers(CardPayment.Element.CardReversal.NetworkIdentifiers networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardReversal.BuildernetworkIdentifiers(JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers> networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardReversal.BuilderpendingTransactionId(String pendingTransactionId)The identifier of the Pending Transaction associated with this Card Reversal. final CardPayment.Element.CardReversal.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The identifier of the Pending Transaction associated with this Card Reversal. final CardPayment.Element.CardReversal.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The identifier of the Pending Transaction associated with this Card Reversal. final CardPayment.Element.CardReversal.BuilderreversalAmount(Long reversalAmount)The amount of this reversal in the minor unit of the transaction's currency. final CardPayment.Element.CardReversal.BuilderreversalAmount(JsonField<Long> reversalAmount)The amount of this reversal in the minor unit of the transaction's currency. final CardPayment.Element.CardReversal.BuilderreversalReason(CardPayment.Element.CardReversal.ReversalReason reversalReason)Why this reversal was initiated. final CardPayment.Element.CardReversal.BuilderreversalReason(Optional<CardPayment.Element.CardReversal.ReversalReason> reversalReason)Why this reversal was initiated. final CardPayment.Element.CardReversal.BuilderreversalReason(JsonField<CardPayment.Element.CardReversal.ReversalReason> reversalReason)Why this reversal was initiated. final CardPayment.Element.CardReversal.BuilderterminalId(String terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardReversal.BuilderterminalId(Optional<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardReversal.BuilderterminalId(JsonField<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardReversal.Buildertype(CardPayment.Element.CardReversal.Type type)A constant representing the object's type. final CardPayment.Element.CardReversal.Buildertype(JsonField<CardPayment.Element.CardReversal.Type> type)A constant representing the object's type. final CardPayment.Element.CardReversal.BuilderupdatedAuthorizationAmount(Long updatedAuthorizationAmount)The amount left pending on the Card Authorization in the minor unit of the transaction's currency. final CardPayment.Element.CardReversal.BuilderupdatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)The amount left pending on the Card Authorization in the minor unit of the transaction's currency. final CardPayment.Element.CardReversal.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardReversal.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.Element.CardReversal.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardReversal.BuilderremoveAdditionalProperty(String key)final CardPayment.Element.CardReversal.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPayment.Element.CardReversalbuild()-
-
Method Detail
-
id
final CardPayment.Element.CardReversal.Builder id(String id)
The Card Reversal identifier.
-
id
final CardPayment.Element.CardReversal.Builder id(JsonField<String> id)
The Card Reversal identifier.
-
cardAuthorizationId
final CardPayment.Element.CardReversal.Builder cardAuthorizationId(String cardAuthorizationId)
The identifier for the Card Authorization this reverses.
-
cardAuthorizationId
final CardPayment.Element.CardReversal.Builder cardAuthorizationId(JsonField<String> cardAuthorizationId)
The identifier for the Card Authorization this reverses.
-
currency
final CardPayment.Element.CardReversal.Builder currency(CardPayment.Element.CardReversal.Currency currency)
The ISO 4217 code for the reversal's currency.
-
currency
final CardPayment.Element.CardReversal.Builder currency(JsonField<CardPayment.Element.CardReversal.Currency> currency)
The ISO 4217 code for the reversal's currency.
-
merchantAcceptorId
final CardPayment.Element.CardReversal.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardReversal.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardReversal.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardReversal.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final CardPayment.Element.CardReversal.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardReversal.Builder merchantCity(Optional<String> merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardReversal.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardReversal.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardReversal.Builder merchantCountry(Optional<String> merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardReversal.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantDescriptor
final CardPayment.Element.CardReversal.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final CardPayment.Element.CardReversal.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final CardPayment.Element.CardReversal.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardReversal.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardReversal.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final CardPayment.Element.CardReversal.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardReversal.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardReversal.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
network
final CardPayment.Element.CardReversal.Builder network(CardPayment.Element.CardReversal.Network network)
The card network used to process this card authorization.
-
network
final CardPayment.Element.CardReversal.Builder network(JsonField<CardPayment.Element.CardReversal.Network> network)
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardReversal.Builder networkIdentifiers(CardPayment.Element.CardReversal.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardReversal.Builder networkIdentifiers(JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
pendingTransactionId
final CardPayment.Element.CardReversal.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Reversal.
-
pendingTransactionId
final CardPayment.Element.CardReversal.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Reversal.
-
pendingTransactionId
final CardPayment.Element.CardReversal.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Reversal.
-
reversalAmount
final CardPayment.Element.CardReversal.Builder reversalAmount(Long reversalAmount)
The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversalAmount
final CardPayment.Element.CardReversal.Builder reversalAmount(JsonField<Long> reversalAmount)
The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversalReason
final CardPayment.Element.CardReversal.Builder reversalReason(CardPayment.Element.CardReversal.ReversalReason reversalReason)
Why this reversal was initiated.
-
reversalReason
final CardPayment.Element.CardReversal.Builder reversalReason(Optional<CardPayment.Element.CardReversal.ReversalReason> reversalReason)
Why this reversal was initiated.
-
reversalReason
final CardPayment.Element.CardReversal.Builder reversalReason(JsonField<CardPayment.Element.CardReversal.ReversalReason> reversalReason)
Why this reversal was initiated.
-
terminalId
final CardPayment.Element.CardReversal.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardReversal.Builder terminalId(Optional<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardReversal.Builder terminalId(JsonField<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardReversal.Builder type(CardPayment.Element.CardReversal.Type type)
A constant representing the object's type. For this resource it will always be
card_reversal.
-
type
final CardPayment.Element.CardReversal.Builder type(JsonField<CardPayment.Element.CardReversal.Type> type)
A constant representing the object's type. For this resource it will always be
card_reversal.
-
updatedAuthorizationAmount
final CardPayment.Element.CardReversal.Builder updatedAuthorizationAmount(Long updatedAuthorizationAmount)
The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
updatedAuthorizationAmount
final CardPayment.Element.CardReversal.Builder updatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)
The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
additionalProperties
final CardPayment.Element.CardReversal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardReversal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardReversal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardReversal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardReversal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardReversal build()
-
-
-
-