Package com.increase.api.models
Enum CardPayment.Element.CardReversal.ReversalReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPayment.Element.CardReversal.ReversalReason.Known extends Enum<CardPayment.Element.CardReversal.ReversalReason.Known>
An enum containing ReversalReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPayment.Element.CardReversal.ReversalReason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description REVERSED_BY_CUSTOMERThe Card Reversal was initiated at the customer's request.
REVERSED_BY_NETWORK_OR_ACQUIRERThe Card Reversal was initiated by the network or acquirer.
REVERSED_BY_POINT_OF_SALEThe Card Reversal was initiated by the point of sale device.
PARTIAL_REVERSALThe Card Reversal was a partial reversal, for any reason.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardReversal.ReversalReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPayment.Element.CardReversal.ReversalReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPayment.Element.CardReversal.ReversalReason.Known>getEntries()An enum containing ReversalReason's known values. -
-
Method Detail
-
valueOf
final CardPayment.Element.CardReversal.ReversalReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPayment.Element.CardReversal.ReversalReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPayment.Element.CardReversal.ReversalReason.Known> getEntries()
An enum containing ReversalReason's known values.
-
-
-
-