Class CardPayment.Element.CardSettlement
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardSettlementA Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardSettlement.BuilderA builder for CardSettlement.
public final classCardPayment.Element.CardSettlement.CashbackCashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
public final classCardPayment.Element.CardSettlement.CurrencyThe ISO 4217 code for the transaction's settlement currency.
public final classCardPayment.Element.CardSettlement.InterchangeInterchange assessed as a part of this transaction.
public final classCardPayment.Element.CardSettlement.NetworkIdentifiersNetwork-specific identifiers for this refund.
public final classCardPayment.Element.CardSettlement.PurchaseDetailsAdditional details about the card purchase, such as tax and industry-specific fields.
public final classCardPayment.Element.CardSettlement.TypeA constant representing the object's type. For this resource it will always be
card_settlement.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Settlement identifier. final Longamount()The amount in the minor unit of the transaction's settlement currency. final Optional<String>cardAuthorization()The Card Authorization that was created prior to this Card Settlement, if one exists. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final Optional<CardPayment.Element.CardSettlement.Cashback>cashback()Cashback earned on this transaction, if eligible. final CardPayment.Element.CardSettlement.Currencycurrency()The ISO 4217 code for the transaction's settlement currency. final Optional<CardPayment.Element.CardSettlement.Interchange>interchange()Interchange assessed as a part of this transaction. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The 4-digit MCC describing the merchant's business. final StringmerchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantName()The name of the merchant. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final CardPayment.Element.CardSettlement.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for this refund. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Transaction. final LongpresentmentAmount()The amount in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final Optional<CardPayment.Element.CardSettlement.PurchaseDetails>purchaseDetails()Additional details about the card purchase, such as tax and industry-specific fields. final StringtransactionId()The identifier of the Transaction associated with this Transaction. final CardPayment.Element.CardSettlement.Typetype()A constant representing the object's type. final JsonField<String>_id()The Card Settlement identifier. final JsonField<Long>_amount()The amount in the minor unit of the transaction's settlement currency. final JsonField<String>_cardAuthorization()The Card Authorization that was created prior to this Card Settlement, if one exists. final JsonField<String>_cardPaymentId()The ID of the Card Payment this transaction belongs to. final JsonField<CardPayment.Element.CardSettlement.Cashback>_cashback()Cashback earned on this transaction, if eligible. final JsonField<CardPayment.Element.CardSettlement.Currency>_currency()The ISO 4217 code for the transaction's settlement currency. final JsonField<CardPayment.Element.CardSettlement.Interchange>_interchange()Interchange assessed as a part of this transaction. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The 4-digit MCC describing the merchant's business. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantName()The name of the merchant. final JsonField<String>_merchantPostalCode()The merchant's postal code. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<CardPayment.Element.CardSettlement.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for this refund. final JsonField<String>_pendingTransactionId()The identifier of the Pending Transaction associated with this Transaction. final JsonField<Long>_presentmentAmount()The amount in the minor unit of the transaction's presentment currency. final JsonField<String>_presentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final JsonField<CardPayment.Element.CardSettlement.PurchaseDetails>_purchaseDetails()Additional details about the card purchase, such as tax and industry-specific fields. final JsonField<String>_transactionId()The identifier of the Transaction associated with this Transaction. final JsonField<CardPayment.Element.CardSettlement.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardSettlementvalidate()final CardPayment.Element.CardSettlement.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardSettlement.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
cardAuthorization
final Optional<String> cardAuthorization()
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
cashback
final Optional<CardPayment.Element.CardSettlement.Cashback> cashback()
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
currency
final CardPayment.Element.CardSettlement.Currency currency()
The ISO 4217 code for the transaction's settlement currency.
-
interchange
final Optional<CardPayment.Element.CardSettlement.Interchange> interchange()
Interchange assessed as a part of this transaction.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The 4-digit MCC describing the merchant's business.
-
merchantCity
final String merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantName
final String merchantName()
The name of the merchant.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkIdentifiers
final CardPayment.Element.CardSettlement.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for this refund.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Transaction.
-
presentmentAmount
final Long presentmentAmount()
The amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
purchaseDetails
final Optional<CardPayment.Element.CardSettlement.PurchaseDetails> purchaseDetails()
Additional details about the card purchase, such as tax and industry-specific fields.
-
transactionId
final String transactionId()
The identifier of the Transaction associated with this Transaction.
-
type
final CardPayment.Element.CardSettlement.Type type()
A constant representing the object's type. For this resource it will always be
card_settlement.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
_cardAuthorization
final JsonField<String> _cardAuthorization()
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
_cashback
final JsonField<CardPayment.Element.CardSettlement.Cashback> _cashback()
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
_currency
final JsonField<CardPayment.Element.CardSettlement.Currency> _currency()
The ISO 4217 code for the transaction's settlement currency.
-
_interchange
final JsonField<CardPayment.Element.CardSettlement.Interchange> _interchange()
Interchange assessed as a part of this transaction.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The 4-digit MCC describing the merchant's business.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantName
final JsonField<String> _merchantName()
The name of the merchant.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardSettlement.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for this refund.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The identifier of the Pending Transaction associated with this Transaction.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
The amount in the minor unit of the transaction's presentment currency.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
_purchaseDetails
final JsonField<CardPayment.Element.CardSettlement.PurchaseDetails> _purchaseDetails()
Additional details about the card purchase, such as tax and industry-specific fields.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction associated with this Transaction.
-
_type
final JsonField<CardPayment.Element.CardSettlement.Type> _type()
A constant representing the object's type. For this resource it will always be
card_settlement.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardSettlement validate()
-
toBuilder
final CardPayment.Element.CardSettlement.Builder toBuilder()
-
builder
final static CardPayment.Element.CardSettlement.Builder builder()
-
-
-
-