Class CardPayment.Element.CardSettlement.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardSettlement.BuilderA builder for CardSettlement.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardSettlement.Builder id(String id)
The Card Settlement identifier.
-
id
final CardPayment.Element.CardSettlement.Builder id(JsonField<String> id)
The Card Settlement identifier.
-
amount
final CardPayment.Element.CardSettlement.Builder amount(Long amount)
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
amount
final CardPayment.Element.CardSettlement.Builder amount(JsonField<Long> amount)
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
cardAuthorization
final CardPayment.Element.CardSettlement.Builder cardAuthorization(String cardAuthorization)
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
cardAuthorization
final CardPayment.Element.CardSettlement.Builder cardAuthorization(Optional<String> cardAuthorization)
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
cardAuthorization
final CardPayment.Element.CardSettlement.Builder cardAuthorization(JsonField<String> cardAuthorization)
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
cardPaymentId
final CardPayment.Element.CardSettlement.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPayment.Element.CardSettlement.Builder cardPaymentId(JsonField<String> cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cashback
final CardPayment.Element.CardSettlement.Builder cashback(CardPayment.Element.CardSettlement.Cashback cashback)
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
cashback
final CardPayment.Element.CardSettlement.Builder cashback(Optional<CardPayment.Element.CardSettlement.Cashback> cashback)
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
cashback
final CardPayment.Element.CardSettlement.Builder cashback(JsonField<CardPayment.Element.CardSettlement.Cashback> cashback)
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
currency
final CardPayment.Element.CardSettlement.Builder currency(CardPayment.Element.CardSettlement.Currency currency)
The ISO 4217 code for the transaction's settlement currency.
-
currency
final CardPayment.Element.CardSettlement.Builder currency(JsonField<CardPayment.Element.CardSettlement.Currency> currency)
The ISO 4217 code for the transaction's settlement currency.
-
interchange
final CardPayment.Element.CardSettlement.Builder interchange(CardPayment.Element.CardSettlement.Interchange interchange)
Interchange assessed as a part of this transaction.
-
interchange
final CardPayment.Element.CardSettlement.Builder interchange(Optional<CardPayment.Element.CardSettlement.Interchange> interchange)
Interchange assessed as a part of this transaction.
-
interchange
final CardPayment.Element.CardSettlement.Builder interchange(JsonField<CardPayment.Element.CardSettlement.Interchange> interchange)
Interchange assessed as a part of this transaction.
-
merchantAcceptorId
final CardPayment.Element.CardSettlement.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardSettlement.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardSettlement.Builder merchantCategoryCode(String merchantCategoryCode)
The 4-digit MCC describing the merchant's business.
-
merchantCategoryCode
final CardPayment.Element.CardSettlement.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The 4-digit MCC describing the merchant's business.
-
merchantCity
final CardPayment.Element.CardSettlement.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardSettlement.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardSettlement.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardSettlement.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantName
final CardPayment.Element.CardSettlement.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final CardPayment.Element.CardSettlement.Builder merchantName(JsonField<String> merchantName)
The name of the merchant.
-
merchantPostalCode
final CardPayment.Element.CardSettlement.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantPostalCode
final CardPayment.Element.CardSettlement.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantPostalCode
final CardPayment.Element.CardSettlement.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantState
final CardPayment.Element.CardSettlement.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardSettlement.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardSettlement.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkIdentifiers
final CardPayment.Element.CardSettlement.Builder networkIdentifiers(CardPayment.Element.CardSettlement.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for this refund.
-
networkIdentifiers
final CardPayment.Element.CardSettlement.Builder networkIdentifiers(JsonField<CardPayment.Element.CardSettlement.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for this refund.
-
pendingTransactionId
final CardPayment.Element.CardSettlement.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
pendingTransactionId
final CardPayment.Element.CardSettlement.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
pendingTransactionId
final CardPayment.Element.CardSettlement.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
presentmentAmount
final CardPayment.Element.CardSettlement.Builder presentmentAmount(Long presentmentAmount)
The amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final CardPayment.Element.CardSettlement.Builder presentmentAmount(JsonField<Long> presentmentAmount)
The amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final CardPayment.Element.CardSettlement.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final CardPayment.Element.CardSettlement.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
purchaseDetails
final CardPayment.Element.CardSettlement.Builder purchaseDetails(CardPayment.Element.CardSettlement.PurchaseDetails purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
purchaseDetails
final CardPayment.Element.CardSettlement.Builder purchaseDetails(Optional<CardPayment.Element.CardSettlement.PurchaseDetails> purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
purchaseDetails
final CardPayment.Element.CardSettlement.Builder purchaseDetails(JsonField<CardPayment.Element.CardSettlement.PurchaseDetails> purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
transactionId
final CardPayment.Element.CardSettlement.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this Transaction.
-
transactionId
final CardPayment.Element.CardSettlement.Builder transactionId(JsonField<String> transactionId)
The identifier of the Transaction associated with this Transaction.
-
type
final CardPayment.Element.CardSettlement.Builder type(CardPayment.Element.CardSettlement.Type type)
A constant representing the object's type. For this resource it will always be
card_settlement.
-
type
final CardPayment.Element.CardSettlement.Builder type(JsonField<CardPayment.Element.CardSettlement.Type> type)
A constant representing the object's type. For this resource it will always be
card_settlement.
-
additionalProperties
final CardPayment.Element.CardSettlement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardSettlement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardSettlement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardSettlement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardSettlement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardSettlement build()
-
-
-
-