Package com.increase.api.models
Class CardPayment.Element.CardSettlement.Cashback.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardSettlement.Cashback.BuilderA builder for Cashback.
-
-
Method Summary
-
-
Method Detail
-
amount
final CardPayment.Element.CardSettlement.Cashback.Builder amount(String amount)
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
amount
final CardPayment.Element.CardSettlement.Cashback.Builder amount(JsonField<String> amount)
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
currency
final CardPayment.Element.CardSettlement.Cashback.Builder currency(CardPayment.Element.CardSettlement.Cashback.Currency currency)
The ISO 4217 code for the cashback.
-
currency
final CardPayment.Element.CardSettlement.Cashback.Builder currency(JsonField<CardPayment.Element.CardSettlement.Cashback.Currency> currency)
The ISO 4217 code for the cashback.
-
additionalProperties
final CardPayment.Element.CardSettlement.Cashback.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardSettlement.Cashback.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardSettlement.Cashback.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardSettlement.Cashback.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardSettlement.Cashback.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardSettlement.Cashback build()
-
-
-
-