Class CardPayment.Element.CardValidation
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardValidationA Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardValidation.BuilderA builder for CardValidation.
public final classCardPayment.Element.CardValidation.ActionerWhether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classCardPayment.Element.CardValidation.CurrencyThe ISO 4217 code for the transaction's currency.
public final classCardPayment.Element.CardValidation.NetworkDetailsFields specific to the
network.public final classCardPayment.Element.CardValidation.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardValidation.TypeA constant representing the object's type. For this resource it will always be
card_validation.public final classCardPayment.Element.CardValidation.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Validation identifier. final CardPayment.Element.CardValidation.Actioneractioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardValidation.Currencycurrency()The ISO 4217 code for the transaction's currency. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final CardPayment.Element.CardValidation.NetworkDetailsnetworkDetails()Fields specific to the network.final CardPayment.Element.CardValidation.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardValidation.Typetype()A constant representing the object's type. final CardPayment.Element.CardValidation.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_id()The Card Validation identifier. final JsonField<CardPayment.Element.CardValidation.Actioner>_actioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final JsonField<String>_cardPaymentId()The ID of the Card Payment this transaction belongs to. final JsonField<CardPayment.Element.CardValidation.Currency>_currency()The ISO 4217 code for the transaction's currency. final JsonField<String>_digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final JsonField<String>_merchantPostalCode()The merchant's postal code. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<CardPayment.Element.CardValidation.NetworkDetails>_networkDetails()Fields specific to the network.final JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for a specific request or transaction. final JsonField<Long>_networkRiskScore()The risk score generated by the card network. final JsonField<String>_physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final JsonField<String>_realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final JsonField<String>_terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<CardPayment.Element.CardValidation.Type>_type()A constant representing the object's type. final JsonField<CardPayment.Element.CardValidation.Verification>_verification()Fields related to verification of cardholder-provided values. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardValidationvalidate()final CardPayment.Element.CardValidation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardValidation.Builderbuilder()-
-
Method Detail
-
actioner
final CardPayment.Element.CardValidation.Actioner actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
currency
final CardPayment.Element.CardValidation.Currency currency()
The ISO 4217 code for the transaction's currency.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final CardPayment.Element.CardValidation.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final CardPayment.Element.CardValidation.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardValidation.Type type()
A constant representing the object's type. For this resource it will always be
card_validation.
-
verification
final CardPayment.Element.CardValidation.Verification verification()
Fields related to verification of cardholder-provided values.
-
_actioner
final JsonField<CardPayment.Element.CardValidation.Actioner> _actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
_currency
final JsonField<CardPayment.Element.CardValidation.Currency> _currency()
The ISO 4217 code for the transaction's currency.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_networkDetails
final JsonField<CardPayment.Element.CardValidation.NetworkDetails> _networkDetails()
Fields specific to the
network.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
_physicalCardId
final JsonField<String> _physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
_terminalId
final JsonField<String> _terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_type
final JsonField<CardPayment.Element.CardValidation.Type> _type()
A constant representing the object's type. For this resource it will always be
card_validation.
-
_verification
final JsonField<CardPayment.Element.CardValidation.Verification> _verification()
Fields related to verification of cardholder-provided values.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardValidation validate()
-
toBuilder
final CardPayment.Element.CardValidation.Builder toBuilder()
-
builder
final static CardPayment.Element.CardValidation.Builder builder()
-
-
-
-