Class CardPayment.Element.CardValidation.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardValidation.BuilderA builder for CardValidation.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardValidation.Builderid(String id)The Card Validation identifier. final CardPayment.Element.CardValidation.Builderid(JsonField<String> id)The Card Validation identifier. final CardPayment.Element.CardValidation.Builderactioner(CardPayment.Element.CardValidation.Actioner actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardValidation.Builderactioner(JsonField<CardPayment.Element.CardValidation.Actioner> actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardValidation.BuildercardPaymentId(String cardPaymentId)The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardValidation.BuildercardPaymentId(JsonField<String> cardPaymentId)The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardValidation.Buildercurrency(CardPayment.Element.CardValidation.Currency currency)The ISO 4217 code for the transaction's currency. final CardPayment.Element.CardValidation.Buildercurrency(JsonField<CardPayment.Element.CardValidation.Currency> currency)The ISO 4217 code for the transaction's currency. final CardPayment.Element.CardValidation.BuilderdigitalWalletTokenId(String digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardValidation.BuilderdigitalWalletTokenId(Optional<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardValidation.BuilderdigitalWalletTokenId(JsonField<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final CardPayment.Element.CardValidation.BuildermerchantAcceptorId(String merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final CardPayment.Element.CardValidation.BuildermerchantAcceptorId(JsonField<String> merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final CardPayment.Element.CardValidation.BuildermerchantCategoryCode(String merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final CardPayment.Element.CardValidation.BuildermerchantCategoryCode(JsonField<String> merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final CardPayment.Element.CardValidation.BuildermerchantCity(String merchantCity)The city the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantCity(Optional<String> merchantCity)The city the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantCity(JsonField<String> merchantCity)The city the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantCountry(String merchantCountry)The country the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantCountry(JsonField<String> merchantCountry)The country the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantDescriptor(String merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final CardPayment.Element.CardValidation.BuildermerchantDescriptor(JsonField<String> merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final CardPayment.Element.CardValidation.BuildermerchantPostalCode(String merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardValidation.BuildermerchantPostalCode(Optional<String> merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardValidation.BuildermerchantPostalCode(JsonField<String> merchantPostalCode)The merchant's postal code. final CardPayment.Element.CardValidation.BuildermerchantState(String merchantState)The state the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantState(Optional<String> merchantState)The state the merchant resides in. final CardPayment.Element.CardValidation.BuildermerchantState(JsonField<String> merchantState)The state the merchant resides in. final CardPayment.Element.CardValidation.BuildernetworkDetails(CardPayment.Element.CardValidation.NetworkDetails networkDetails)Fields specific to the network.final CardPayment.Element.CardValidation.BuildernetworkDetails(JsonField<CardPayment.Element.CardValidation.NetworkDetails> networkDetails)Fields specific to the network.final CardPayment.Element.CardValidation.BuildernetworkIdentifiers(CardPayment.Element.CardValidation.NetworkIdentifiers networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardValidation.BuildernetworkIdentifiers(JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers> networkIdentifiers)Network-specific identifiers for a specific request or transaction. final CardPayment.Element.CardValidation.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardValidation.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardValidation.BuildernetworkRiskScore(Optional<Long> networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardValidation.BuildernetworkRiskScore(JsonField<Long> networkRiskScore)The risk score generated by the card network. final CardPayment.Element.CardValidation.BuilderphysicalCardId(String physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final CardPayment.Element.CardValidation.BuilderphysicalCardId(Optional<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final CardPayment.Element.CardValidation.BuilderphysicalCardId(JsonField<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final CardPayment.Element.CardValidation.BuilderrealTimeDecisionId(String realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final CardPayment.Element.CardValidation.BuilderrealTimeDecisionId(Optional<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final CardPayment.Element.CardValidation.BuilderrealTimeDecisionId(JsonField<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final CardPayment.Element.CardValidation.BuilderterminalId(String terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardValidation.BuilderterminalId(Optional<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardValidation.BuilderterminalId(JsonField<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardValidation.Buildertype(CardPayment.Element.CardValidation.Type type)A constant representing the object's type. final CardPayment.Element.CardValidation.Buildertype(JsonField<CardPayment.Element.CardValidation.Type> type)A constant representing the object's type. final CardPayment.Element.CardValidation.Builderverification(CardPayment.Element.CardValidation.Verification verification)Fields related to verification of cardholder-provided values. final CardPayment.Element.CardValidation.Builderverification(JsonField<CardPayment.Element.CardValidation.Verification> verification)Fields related to verification of cardholder-provided values. final CardPayment.Element.CardValidation.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardValidation.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.Element.CardValidation.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.Element.CardValidation.BuilderremoveAdditionalProperty(String key)final CardPayment.Element.CardValidation.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPayment.Element.CardValidationbuild()-
-
Method Detail
-
id
final CardPayment.Element.CardValidation.Builder id(String id)
The Card Validation identifier.
-
id
final CardPayment.Element.CardValidation.Builder id(JsonField<String> id)
The Card Validation identifier.
-
actioner
final CardPayment.Element.CardValidation.Builder actioner(CardPayment.Element.CardValidation.Actioner actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final CardPayment.Element.CardValidation.Builder actioner(JsonField<CardPayment.Element.CardValidation.Actioner> actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
cardPaymentId
final CardPayment.Element.CardValidation.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPayment.Element.CardValidation.Builder cardPaymentId(JsonField<String> cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
currency
final CardPayment.Element.CardValidation.Builder currency(CardPayment.Element.CardValidation.Currency currency)
The ISO 4217 code for the transaction's currency.
-
currency
final CardPayment.Element.CardValidation.Builder currency(JsonField<CardPayment.Element.CardValidation.Currency> currency)
The ISO 4217 code for the transaction's currency.
-
digitalWalletTokenId
final CardPayment.Element.CardValidation.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final CardPayment.Element.CardValidation.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final CardPayment.Element.CardValidation.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
merchantAcceptorId
final CardPayment.Element.CardValidation.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardValidation.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardValidation.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardValidation.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final CardPayment.Element.CardValidation.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardValidation.Builder merchantCity(Optional<String> merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardValidation.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardValidation.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardValidation.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantDescriptor
final CardPayment.Element.CardValidation.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final CardPayment.Element.CardValidation.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final CardPayment.Element.CardValidation.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardValidation.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardValidation.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final CardPayment.Element.CardValidation.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardValidation.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardValidation.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkDetails
final CardPayment.Element.CardValidation.Builder networkDetails(CardPayment.Element.CardValidation.NetworkDetails networkDetails)
Fields specific to the
network.
-
networkDetails
final CardPayment.Element.CardValidation.Builder networkDetails(JsonField<CardPayment.Element.CardValidation.NetworkDetails> networkDetails)
Fields specific to the
network.
-
networkIdentifiers
final CardPayment.Element.CardValidation.Builder networkIdentifiers(CardPayment.Element.CardValidation.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardValidation.Builder networkIdentifiers(JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(Optional<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(JsonField<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final CardPayment.Element.CardValidation.Builder physicalCardId(String physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final CardPayment.Element.CardValidation.Builder physicalCardId(Optional<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final CardPayment.Element.CardValidation.Builder physicalCardId(JsonField<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
realTimeDecisionId
final CardPayment.Element.CardValidation.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final CardPayment.Element.CardValidation.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final CardPayment.Element.CardValidation.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
terminalId
final CardPayment.Element.CardValidation.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardValidation.Builder terminalId(Optional<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardValidation.Builder terminalId(JsonField<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardValidation.Builder type(CardPayment.Element.CardValidation.Type type)
A constant representing the object's type. For this resource it will always be
card_validation.
-
type
final CardPayment.Element.CardValidation.Builder type(JsonField<CardPayment.Element.CardValidation.Type> type)
A constant representing the object's type. For this resource it will always be
card_validation.
-
verification
final CardPayment.Element.CardValidation.Builder verification(CardPayment.Element.CardValidation.Verification verification)
Fields related to verification of cardholder-provided values.
-
verification
final CardPayment.Element.CardValidation.Builder verification(JsonField<CardPayment.Element.CardValidation.Verification> verification)
Fields related to verification of cardholder-provided values.
-
additionalProperties
final CardPayment.Element.CardValidation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardValidation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardValidation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardValidation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardValidation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardValidation build()
-
-
-
-