Enum CardPayment.Element.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPayment.Element.Category.Known extends Enum<CardPayment.Element.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPayment.Element.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARD_AUTHORIZATIONCard Authorization: details will be under the
card_authorizationobject.CARD_AUTHENTICATIONCard Authentication: details will be under the
card_authenticationobject.CARD_VALIDATIONCard Validation: details will be under the
card_validationobject.CARD_DECLINECard Decline: details will be under the
card_declineobject.CARD_REVERSALCard Reversal: details will be under the
card_reversalobject.CARD_AUTHORIZATION_EXPIRATIONCard Authorization Expiration: details will be under the
card_authorization_expirationobject.CARD_INCREMENTCard Increment: details will be under the
card_incrementobject.CARD_SETTLEMENTCard Settlement: details will be under the
card_settlementobject.CARD_REFUNDCard Refund: details will be under the
card_refundobject.CARD_FUEL_CONFIRMATIONCard Fuel Confirmation: details will be under the
card_fuel_confirmationobject.OTHERUnknown card payment element.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPayment.Element.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPayment.Element.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final CardPayment.Element.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPayment.Element.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPayment.Element.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-