Package com.increase.api.models
Enum CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known extends Enum<CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known>
An enum containing DiscountTreatmentCode's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NO_INVOICE_LEVEL_DISCOUNT_PROVIDEDNo invoice level discount provided
TAX_CALCULATED_ON_POST_DISCOUNT_INVOICE_TOTALTax calculated on post discount invoice total
TAX_CALCULATED_ON_PRE_DISCOUNT_INVOICE_TOTALTax calculated on pre discount invoice total
-
Method Summary
Modifier and Type Method Description final CardPurchaseSupplement.Invoice.DiscountTreatmentCode.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known>getEntries()An enum containing DiscountTreatmentCode's known values. -
-
Method Detail
-
valueOf
final CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPurchaseSupplement.Invoice.DiscountTreatmentCode.Known> getEntries()
An enum containing DiscountTreatmentCode's known values.
-
-
-
-