Package com.increase.api.models
Enum CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known extends Enum<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known>
An enum containing DiscountTreatmentCode's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NO_LINE_ITEM_LEVEL_DISCOUNT_PROVIDEDNo line item level discount provided
TAX_CALCULATED_ON_POST_DISCOUNT_LINE_ITEM_TOTALTax calculated on post discount line item total
TAX_CALCULATED_ON_PRE_DISCOUNT_LINE_ITEM_TOTALTax calculated on pre discount line item total
-
Method Summary
Modifier and Type Method Description final CardPurchaseSupplement.LineItem.DiscountTreatmentCode.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known>getEntries()An enum containing DiscountTreatmentCode's known values. -
-
Method Detail
-
valueOf
final CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Known> getEntries()
An enum containing DiscountTreatmentCode's known values.
-
-
-
-