Package com.increase.api.models
Class CardPurchaseSupplementListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardPurchaseSupplementListParams implements Params
List Card Purchase Supplements
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplementListParams.BuilderA builder for CardPurchaseSupplementListParams.
public final classCardPurchaseSupplementListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<String>cardPaymentId()Filter Card Purchase Supplements to ones belonging to the specified Card Payment. final Optional<CardPurchaseSupplementListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final CardPurchaseSupplementListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPurchaseSupplementListParamsnone()final static CardPurchaseSupplementListParams.Builderbuilder()-
-
Method Detail
-
cardPaymentId
final Optional<String> cardPaymentId()
Filter Card Purchase Supplements to ones belonging to the specified Card Payment.
-
createdAt
final Optional<CardPurchaseSupplementListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final CardPurchaseSupplementListParams.Builder toBuilder()
-
none
final static CardPurchaseSupplementListParams none()
-
builder
final static CardPurchaseSupplementListParams.Builder builder()
-
-
-
-