Class CardUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardUpdateParams implements Params
Update a Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.Bodypublic final classCardUpdateParams.BuilderA builder for CardUpdateParams.
public final classCardUpdateParams.BillingAddressThe card's updated billing address.
public final classCardUpdateParams.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
public final classCardUpdateParams.StatusThe status to update the Card with.
-
Method Summary
Modifier and Type Method Description final StringcardId()The card identifier. final Optional<CardUpdateParams.BillingAddress>billingAddress()The card's updated billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardUpdateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final Optional<CardUpdateParams.Status>status()The status to update the Card with. final JsonField<CardUpdateParams.BillingAddress>_billingAddress()The card's updated billing address. final JsonField<String>_description()The description you choose to give the card. final JsonField<CardUpdateParams.DigitalWallet>_digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final JsonField<String>_entityId()The Entity the card belongs to. final JsonField<CardUpdateParams.Status>_status()The status to update the Card with. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final CardUpdateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdateParams.Builderbuilder()-
-
Method Detail
-
billingAddress
final Optional<CardUpdateParams.BillingAddress> billingAddress()
The card's updated billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardUpdateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
status
final Optional<CardUpdateParams.Status> status()
The status to update the Card with.
-
_billingAddress
final JsonField<CardUpdateParams.BillingAddress> _billingAddress()
The card's updated billing address.
-
_description
final JsonField<String> _description()
The description you choose to give the card.
-
_digitalWallet
final JsonField<CardUpdateParams.DigitalWallet> _digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
_entityId
final JsonField<String> _entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_status
final JsonField<CardUpdateParams.Status> _status()
The status to update the Card with.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final CardUpdateParams.Builder toBuilder()
-
builder
final static CardUpdateParams.Builder builder()
-
-
-
-