Class CardUpdateParams.Body
-
- All Implemented Interfaces:
public final class CardUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<CardUpdateParams.BillingAddress>billingAddress()The card's updated billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardUpdateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final Optional<CardUpdateParams.Status>status()The status to update the Card with. final JsonField<CardUpdateParams.BillingAddress>_billingAddress()The card's updated billing address. final JsonField<String>_description()The description you choose to give the card. final JsonField<CardUpdateParams.DigitalWallet>_digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final JsonField<String>_entityId()The Entity the card belongs to. final JsonField<CardUpdateParams.Status>_status()The status to update the Card with. final Map<String, JsonValue>_additionalProperties()final CardUpdateParams.Bodyvalidate()final CardUpdateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdateParams.Body.Builderbuilder()-
-
Method Detail
-
billingAddress
final Optional<CardUpdateParams.BillingAddress> billingAddress()
The card's updated billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardUpdateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
status
final Optional<CardUpdateParams.Status> status()
The status to update the Card with.
-
_billingAddress
final JsonField<CardUpdateParams.BillingAddress> _billingAddress()
The card's updated billing address.
-
_description
final JsonField<String> _description()
The description you choose to give the card.
-
_digitalWallet
final JsonField<CardUpdateParams.DigitalWallet> _digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
_entityId
final JsonField<String> _entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_status
final JsonField<CardUpdateParams.Status> _status()
The status to update the Card with.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardUpdateParams.Body validate()
-
toBuilder
final CardUpdateParams.Body.Builder toBuilder()
-
builder
final static CardUpdateParams.Body.Builder builder()
-
-
-
-