Class CheckDeposit
-
- All Implemented Interfaces:
public final class CheckDepositCheck Deposits allow you to deposit images of paper checks into your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.BuilderA builder for CheckDeposit.
public final classCheckDeposit.DepositAcceptanceIf your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
public final classCheckDeposit.DepositRejectionIf your deposit is rejected by Increase, this will contain details as to why it was rejected.
public final classCheckDeposit.DepositReturnIf your deposit is returned, this will contain details as to why it was returned.
public final classCheckDeposit.DepositSubmissionAfter the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
public final classCheckDeposit.InboundFundsHoldIncrease will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
public final classCheckDeposit.StatusThe status of the Check Deposit.
public final classCheckDeposit.TypeA constant representing the object's type. For this resource it will always be
check_deposit.
-
Method Summary
Modifier and Type Method Description final Stringid()The deposit's identifier. final StringaccountId()The Account the check was deposited into. final Longamount()The deposited amount in USD cents. final Optional<String>backImageFileId()The ID for the File containing the image of the back of the check. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<CheckDeposit.DepositAcceptance>depositAcceptance()If your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check. final Optional<CheckDeposit.DepositRejection>depositRejection()If your deposit is rejected by Increase, this will contain details as to why it was rejected. final Optional<CheckDeposit.DepositReturn>depositReturn()If your deposit is returned, this will contain details as to why it was returned. final Optional<CheckDeposit.DepositSubmission>depositSubmission()After the check is parsed, it is submitted to the Check21 network for processing. final Optional<String>description()The description of the Check Deposit, for display purposes only. final StringfrontImageFileId()The ID for the File containing the image of the front of the check. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<CheckDeposit.InboundFundsHold>inboundFundsHold()Increase will sometimes hold the funds for Check Deposits. final Optional<String>inboundMailItemId()If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item. final Optional<String>lockboxId()If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Lockbox that received it. final CheckDeposit.Statusstatus()The status of the Check Deposit. final Optional<String>transactionId()The ID for the Transaction created by the deposit. final CheckDeposit.Typetype()A constant representing the object's type. final JsonField<String>_id()The deposit's identifier. final JsonField<String>_accountId()The Account the check was deposited into. final JsonField<Long>_amount()The deposited amount in USD cents. final JsonField<String>_backImageFileId()The ID for the File containing the image of the back of the check. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<CheckDeposit.DepositAcceptance>_depositAcceptance()If your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check. final JsonField<CheckDeposit.DepositRejection>_depositRejection()If your deposit is rejected by Increase, this will contain details as to why it was rejected. final JsonField<CheckDeposit.DepositReturn>_depositReturn()If your deposit is returned, this will contain details as to why it was returned. final JsonField<CheckDeposit.DepositSubmission>_depositSubmission()After the check is parsed, it is submitted to the Check21 network for processing. final JsonField<String>_description()The description of the Check Deposit, for display purposes only. final JsonField<String>_frontImageFileId()The ID for the File containing the image of the front of the check. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<CheckDeposit.InboundFundsHold>_inboundFundsHold()Increase will sometimes hold the funds for Check Deposits. final JsonField<String>_inboundMailItemId()If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item. final JsonField<String>_lockboxId()If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Lockbox that received it. final JsonField<CheckDeposit.Status>_status()The status of the Check Deposit. final JsonField<String>_transactionId()The ID for the Transaction created by the deposit. final JsonField<CheckDeposit.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final CheckDepositvalidate()final CheckDeposit.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.Builderbuilder()-
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The ID for the File containing the image of the back of the check.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
depositAcceptance
final Optional<CheckDeposit.DepositAcceptance> depositAcceptance()
If your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
depositRejection
final Optional<CheckDeposit.DepositRejection> depositRejection()
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
depositReturn
final Optional<CheckDeposit.DepositReturn> depositReturn()
If your deposit is returned, this will contain details as to why it was returned.
-
depositSubmission
final Optional<CheckDeposit.DepositSubmission> depositSubmission()
After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
-
description
final Optional<String> description()
The description of the Check Deposit, for display purposes only.
-
frontImageFileId
final String frontImageFileId()
The ID for the File containing the image of the front of the check.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundFundsHold
final Optional<CheckDeposit.InboundFundsHold> inboundFundsHold()
Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
-
inboundMailItemId
final Optional<String> inboundMailItemId()
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.
-
lockboxId
final Optional<String> lockboxId()
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Lockbox that received it.
-
status
final CheckDeposit.Status status()
The status of the Check Deposit.
-
transactionId
final Optional<String> transactionId()
The ID for the Transaction created by the deposit.
-
type
final CheckDeposit.Type type()
A constant representing the object's type. For this resource it will always be
check_deposit.
-
_accountId
final JsonField<String> _accountId()
The Account the check was deposited into.
-
_backImageFileId
final JsonField<String> _backImageFileId()
The ID for the File containing the image of the back of the check.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_depositAcceptance
final JsonField<CheckDeposit.DepositAcceptance> _depositAcceptance()
If your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
_depositRejection
final JsonField<CheckDeposit.DepositRejection> _depositRejection()
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
_depositReturn
final JsonField<CheckDeposit.DepositReturn> _depositReturn()
If your deposit is returned, this will contain details as to why it was returned.
-
_depositSubmission
final JsonField<CheckDeposit.DepositSubmission> _depositSubmission()
After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
-
_description
final JsonField<String> _description()
The description of the Check Deposit, for display purposes only.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The ID for the File containing the image of the front of the check.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_inboundFundsHold
final JsonField<CheckDeposit.InboundFundsHold> _inboundFundsHold()
Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
-
_inboundMailItemId
final JsonField<String> _inboundMailItemId()
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.
-
_lockboxId
final JsonField<String> _lockboxId()
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Lockbox that received it.
-
_status
final JsonField<CheckDeposit.Status> _status()
The status of the Check Deposit.
-
_transactionId
final JsonField<String> _transactionId()
The ID for the Transaction created by the deposit.
-
_type
final JsonField<CheckDeposit.Type> _type()
A constant representing the object's type. For this resource it will always be
check_deposit.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckDeposit validate()
-
toBuilder
final CheckDeposit.Builder toBuilder()
-
builder
final static CheckDeposit.Builder builder()
-
-
-
-