Class CheckDeposit.DepositAcceptance
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositAcceptanceIf your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositAcceptance.BuilderA builder for DepositAcceptance.
public final classCheckDeposit.DepositAcceptance.CurrencyThe ISO 4217 code for the transaction's currency.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number printed on the check. final Longamount()The amount to be deposited in the minor unit of the transaction's currency. final Optional<String>auxiliaryOnUs()An additional line of metadata printed on the check. final StringcheckDepositId()The ID of the Check Deposit that was accepted. final CheckDeposit.DepositAcceptance.Currencycurrency()The ISO 4217 code for the transaction's currency. final StringroutingNumber()The routing number printed on the check. final Optional<String>serialNumber()The check serial number, if present, for consumer checks. final JsonField<String>_accountNumber()The account number printed on the check. final JsonField<Long>_amount()The amount to be deposited in the minor unit of the transaction's currency. final JsonField<String>_auxiliaryOnUs()An additional line of metadata printed on the check. final JsonField<String>_checkDepositId()The ID of the Check Deposit that was accepted. final JsonField<CheckDeposit.DepositAcceptance.Currency>_currency()The ISO 4217 code for the transaction's currency. final JsonField<String>_routingNumber()The routing number printed on the check. final JsonField<String>_serialNumber()The check serial number, if present, for consumer checks. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositAcceptancevalidate()final CheckDeposit.DepositAcceptance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositAcceptance.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number printed on the check.
-
amount
final Long amount()
The amount to be deposited in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
An additional line of metadata printed on the check. This typically includes the check number for business checks.
-
checkDepositId
final String checkDepositId()
The ID of the Check Deposit that was accepted.
-
currency
final CheckDeposit.DepositAcceptance.Currency currency()
The ISO 4217 code for the transaction's currency.
-
routingNumber
final String routingNumber()
The routing number printed on the check.
-
serialNumber
final Optional<String> serialNumber()
The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the
auxiliary_on_usfield.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number printed on the check.
-
_amount
final JsonField<Long> _amount()
The amount to be deposited in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
An additional line of metadata printed on the check. This typically includes the check number for business checks.
-
_checkDepositId
final JsonField<String> _checkDepositId()
The ID of the Check Deposit that was accepted.
-
_currency
final JsonField<CheckDeposit.DepositAcceptance.Currency> _currency()
The ISO 4217 code for the transaction's currency.
-
_routingNumber
final JsonField<String> _routingNumber()
The routing number printed on the check.
-
_serialNumber
final JsonField<String> _serialNumber()
The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the
auxiliary_on_usfield.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckDeposit.DepositAcceptance validate()
-
toBuilder
final CheckDeposit.DepositAcceptance.Builder toBuilder()
-
builder
final static CheckDeposit.DepositAcceptance.Builder builder()
-
-
-
-