Class CheckDeposit.DepositRejection
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositRejectionIf your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositRejection.BuilderA builder for DepositRejection.
public final classCheckDeposit.DepositRejection.CurrencyThe ISO 4217 code for the check's currency.
public final classCheckDeposit.DepositRejection.ReasonWhy the check deposit was rejected.
-
Method Summary
Modifier and Type Method Description final Longamount()The rejected amount in the minor unit of check's currency. final StringcheckDepositId()The identifier of the Check Deposit that was rejected. final CheckDeposit.DepositRejection.Currencycurrency()The ISO 4217 code for the check's currency. final StringdeclinedTransactionId()The identifier of the associated declined transaction. final CheckDeposit.DepositRejection.Reasonreason()Why the check deposit was rejected. final OffsetDateTimerejectedAt()The ISO 8601 date and time at which the check deposit was rejected. final JsonField<Long>_amount()The rejected amount in the minor unit of check's currency. final JsonField<String>_checkDepositId()The identifier of the Check Deposit that was rejected. final JsonField<CheckDeposit.DepositRejection.Currency>_currency()The ISO 4217 code for the check's currency. final JsonField<String>_declinedTransactionId()The identifier of the associated declined transaction. final JsonField<CheckDeposit.DepositRejection.Reason>_reason()Why the check deposit was rejected. final JsonField<OffsetDateTime>_rejectedAt()The ISO 8601 date and time at which the check deposit was rejected. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositRejectionvalidate()final CheckDeposit.DepositRejection.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositRejection.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
checkDepositId
final String checkDepositId()
The identifier of the Check Deposit that was rejected.
-
currency
final CheckDeposit.DepositRejection.Currency currency()
The ISO 4217 code for the check's currency.
-
declinedTransactionId
final String declinedTransactionId()
The identifier of the associated declined transaction.
-
reason
final CheckDeposit.DepositRejection.Reason reason()
Why the check deposit was rejected.
-
rejectedAt
final OffsetDateTime rejectedAt()
The ISO 8601 date and time at which the check deposit was rejected.
-
_amount
final JsonField<Long> _amount()
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
_checkDepositId
final JsonField<String> _checkDepositId()
The identifier of the Check Deposit that was rejected.
-
_currency
final JsonField<CheckDeposit.DepositRejection.Currency> _currency()
The ISO 4217 code for the check's currency.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
The identifier of the associated declined transaction.
-
_reason
final JsonField<CheckDeposit.DepositRejection.Reason> _reason()
Why the check deposit was rejected.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
The ISO 8601 date and time at which the check deposit was rejected.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckDeposit.DepositRejection validate()
-
toBuilder
final CheckDeposit.DepositRejection.Builder toBuilder()
-
builder
final static CheckDeposit.DepositRejection.Builder builder()
-
-
-
-