Class CheckDeposit.DepositReturn
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositReturnIf your deposit is returned, this will contain details as to why it was returned.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositReturn.BuilderA builder for DepositReturn.
public final classCheckDeposit.DepositReturn.CurrencyThe ISO 4217 code for the transaction's currency.
public final classCheckDeposit.DepositReturn.ReturnReasonWhy this check was returned by the bank holding the account it was drawn against.
-
Method Summary
Modifier and Type Method Description final Longamount()The returned amount in USD cents. final StringcheckDepositId()The identifier of the Check Deposit that was returned. final CheckDeposit.DepositReturn.Currencycurrency()The ISO 4217 code for the transaction's currency. final CheckDeposit.DepositReturn.ReturnReasonreturnReason()Why this check was returned by the bank holding the account it was drawn against. final OffsetDateTimereturnedAt()The ISO 8601 date and time at which the check deposit was returned. final StringtransactionId()The identifier of the transaction that reversed the original check deposit transaction. final JsonField<Long>_amount()The returned amount in USD cents. final JsonField<String>_checkDepositId()The identifier of the Check Deposit that was returned. final JsonField<CheckDeposit.DepositReturn.Currency>_currency()The ISO 4217 code for the transaction's currency. final JsonField<CheckDeposit.DepositReturn.ReturnReason>_returnReason()Why this check was returned by the bank holding the account it was drawn against. final JsonField<OffsetDateTime>_returnedAt()The ISO 8601 date and time at which the check deposit was returned. final JsonField<String>_transactionId()The identifier of the transaction that reversed the original check deposit transaction. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositReturnvalidate()final CheckDeposit.DepositReturn.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositReturn.Builderbuilder()-
-
Method Detail
-
checkDepositId
final String checkDepositId()
The identifier of the Check Deposit that was returned.
-
currency
final CheckDeposit.DepositReturn.Currency currency()
The ISO 4217 code for the transaction's currency.
-
returnReason
final CheckDeposit.DepositReturn.ReturnReason returnReason()
Why this check was returned by the bank holding the account it was drawn against.
-
returnedAt
final OffsetDateTime returnedAt()
The ISO 8601 date and time at which the check deposit was returned.
-
transactionId
final String transactionId()
The identifier of the transaction that reversed the original check deposit transaction.
-
_checkDepositId
final JsonField<String> _checkDepositId()
The identifier of the Check Deposit that was returned.
-
_currency
final JsonField<CheckDeposit.DepositReturn.Currency> _currency()
The ISO 4217 code for the transaction's currency.
-
_returnReason
final JsonField<CheckDeposit.DepositReturn.ReturnReason> _returnReason()
Why this check was returned by the bank holding the account it was drawn against.
-
_returnedAt
final JsonField<OffsetDateTime> _returnedAt()
The ISO 8601 date and time at which the check deposit was returned.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the transaction that reversed the original check deposit transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckDeposit.DepositReturn validate()
-
toBuilder
final CheckDeposit.DepositReturn.Builder toBuilder()
-
builder
final static CheckDeposit.DepositReturn.Builder builder()
-
-
-
-