Class CheckDeposit.DepositSubmission
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositSubmissionAfter the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositSubmission.BuilderA builder for DepositSubmission.
-
Method Summary
Modifier and Type Method Description final StringbackFileId()The ID for the File containing the check back image that was submitted to the Check21 network. final StringfrontFileId()The ID for the File containing the check front image that was submitted to the Check21 network. final OffsetDateTimesubmittedAt()When the check deposit was submitted to the Check21 network for processing. final JsonField<String>_backFileId()The ID for the File containing the check back image that was submitted to the Check21 network. final JsonField<String>_frontFileId()The ID for the File containing the check front image that was submitted to the Check21 network. final JsonField<OffsetDateTime>_submittedAt()When the check deposit was submitted to the Check21 network for processing. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositSubmissionvalidate()final CheckDeposit.DepositSubmission.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositSubmission.Builderbuilder()-
-
Method Detail
-
backFileId
final String backFileId()
The ID for the File containing the check back image that was submitted to the Check21 network.
-
frontFileId
final String frontFileId()
The ID for the File containing the check front image that was submitted to the Check21 network.
-
submittedAt
final OffsetDateTime submittedAt()
When the check deposit was submitted to the Check21 network for processing. During business days, this happens within a few hours of the check being accepted by Increase.
-
_backFileId
final JsonField<String> _backFileId()
The ID for the File containing the check back image that was submitted to the Check21 network.
-
_frontFileId
final JsonField<String> _frontFileId()
The ID for the File containing the check front image that was submitted to the Check21 network.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
When the check deposit was submitted to the Check21 network for processing. During business days, this happens within a few hours of the check being accepted by Increase.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckDeposit.DepositSubmission validate()
-
toBuilder
final CheckDeposit.DepositSubmission.Builder toBuilder()
-
builder
final static CheckDeposit.DepositSubmission.Builder builder()
-
-
-
-