Package com.increase.api.models
Class CheckDepositCreateParams.Body
-
- All Implemented Interfaces:
public final class CheckDepositCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the Account to deposit the check in. final Longamount()The deposit amount in USD cents. final StringbackImageFileId()The File containing the check's back image. final StringfrontImageFileId()The File containing the check's front image. final Optional<String>description()The description you choose to give the Check Deposit, for display purposes only. final JsonField<String>_accountId()The identifier for the Account to deposit the check in. final JsonField<Long>_amount()The deposit amount in USD cents. final JsonField<String>_backImageFileId()The File containing the check's back image. final JsonField<String>_frontImageFileId()The File containing the check's front image. final JsonField<String>_description()The description you choose to give the Check Deposit, for display purposes only. final Map<String, JsonValue>_additionalProperties()final CheckDepositCreateParams.Bodyvalidate()final CheckDepositCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositCreateParams.Body.Builderbuilder()-
-
Method Detail
-
backImageFileId
final String backImageFileId()
The File containing the check's back image.
-
frontImageFileId
final String frontImageFileId()
The File containing the check's front image.
-
description
final Optional<String> description()
The description you choose to give the Check Deposit, for display purposes only.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Account to deposit the check in.
-
_backImageFileId
final JsonField<String> _backImageFileId()
The File containing the check's back image.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The File containing the check's front image.
-
_description
final JsonField<String> _description()
The description you choose to give the Check Deposit, for display purposes only.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckDepositCreateParams.Body validate()
-
toBuilder
final CheckDepositCreateParams.Body.Builder toBuilder()
-
builder
final static CheckDepositCreateParams.Body.Builder builder()
-
-
-
-