Class CheckTransfer
-
- All Implemented Interfaces:
public final class CheckTransferCheck Transfers move funds from your Increase account by mailing a physical check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.BuilderA builder for CheckTransfer.
public final classCheckTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classCheckTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classCheckTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classCheckTransfer.CurrencyThe ISO 4217 code for the check's currency.
public final classCheckTransfer.FulfillmentMethodWhether Increase will print and mail the check or if you will do it yourself.
public final classCheckTransfer.MailingIf the check has been mailed by Increase, this will contain details of the shipment.
public final classCheckTransfer.PhysicalCheckDetails relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.public final classCheckTransfer.StatusThe lifecycle status of the transfer.
public final classCheckTransfer.StopPaymentRequestAfter a stop-payment is requested on the check, this will contain supplemental details.
public final classCheckTransfer.SubmissionAfter the transfer is submitted, this will contain supplemental details.
public final classCheckTransfer.ThirdPartyDetails relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.public final classCheckTransfer.TypeA constant representing the object's type. For this resource it will always be
check_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Check transfer's identifier. final StringaccountId()The identifier of the Account from which funds will be transferred. final StringaccountNumber()The account number printed on the check. final Longamount()The transfer amount in USD cents. final Optional<CheckTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<String>approvedInboundCheckDepositId()If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final Optional<CheckTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final StringcheckNumber()The check number printed on the check. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<CheckTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final CheckTransfer.Currencycurrency()The ISO 4217 code for the check's currency. final CheckTransfer.FulfillmentMethodfulfillmentMethod()Whether Increase will print and mail the check or if you will do it yourself. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<CheckTransfer.Mailing>mailing()If the check has been mailed by Increase, this will contain details of the shipment. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<CheckTransfer.PhysicalCheck>physicalCheck()Details relating to the physical check that Increase will print and mail. final StringroutingNumber()The routing number printed on the check. final Optional<String>sourceAccountNumberId()The identifier of the Account Number from which to send the transfer and print on the check. final CheckTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<CheckTransfer.StopPaymentRequest>stopPaymentRequest()After a stop-payment is requested on the check, this will contain supplemental details. final Optional<CheckTransfer.Submission>submission()After the transfer is submitted, this will contain supplemental details. final Optional<CheckTransfer.ThirdParty>thirdParty()Details relating to the custom fulfillment you will perform. final CheckTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The Check transfer's identifier. final JsonField<String>_accountId()The identifier of the Account from which funds will be transferred. final JsonField<String>_accountNumber()The account number printed on the check. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<CheckTransfer.Approval>_approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final JsonField<String>_approvedInboundCheckDepositId()If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final JsonField<CheckTransfer.Cancellation>_cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final JsonField<String>_checkNumber()The check number printed on the check. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<CheckTransfer.CreatedBy>_createdBy()What object created the transfer, either via the API or the dashboard. final JsonField<CheckTransfer.Currency>_currency()The ISO 4217 code for the check's currency. final JsonField<CheckTransfer.FulfillmentMethod>_fulfillmentMethod()Whether Increase will print and mail the check or if you will do it yourself. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<CheckTransfer.Mailing>_mailing()If the check has been mailed by Increase, this will contain details of the shipment. final JsonField<String>_pendingTransactionId()The ID for the pending transaction representing the transfer. final JsonField<CheckTransfer.PhysicalCheck>_physicalCheck()Details relating to the physical check that Increase will print and mail. final JsonField<String>_routingNumber()The routing number printed on the check. final JsonField<String>_sourceAccountNumberId()The identifier of the Account Number from which to send the transfer and print on the check. final JsonField<CheckTransfer.Status>_status()The lifecycle status of the transfer. final JsonField<CheckTransfer.StopPaymentRequest>_stopPaymentRequest()After a stop-payment is requested on the check, this will contain supplemental details. final JsonField<CheckTransfer.Submission>_submission()After the transfer is submitted, this will contain supplemental details. final JsonField<CheckTransfer.ThirdParty>_thirdParty()Details relating to the custom fulfillment you will perform. final JsonField<CheckTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final CheckTransfervalidate()final CheckTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier of the Account from which funds will be transferred.
-
accountNumber
final String accountNumber()
The account number printed on the check.
-
approval
final Optional<CheckTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approvedInboundCheckDepositId
final Optional<String> approvedInboundCheckDepositId()
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
cancellation
final Optional<CheckTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
checkNumber
final String checkNumber()
The check number printed on the check.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<CheckTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final CheckTransfer.Currency currency()
The ISO 4217 code for the check's currency.
-
fulfillmentMethod
final CheckTransfer.FulfillmentMethod fulfillmentMethod()
Whether Increase will print and mail the check or if you will do it yourself.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
mailing
final Optional<CheckTransfer.Mailing> mailing()
If the check has been mailed by Increase, this will contain details of the shipment.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
physicalCheck
final Optional<CheckTransfer.PhysicalCheck> physicalCheck()
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
routingNumber
final String routingNumber()
The routing number printed on the check.
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer and print on the check.
-
status
final CheckTransfer.Status status()
The lifecycle status of the transfer.
-
stopPaymentRequest
final Optional<CheckTransfer.StopPaymentRequest> stopPaymentRequest()
After a stop-payment is requested on the check, this will contain supplemental details.
-
submission
final Optional<CheckTransfer.Submission> submission()
After the transfer is submitted, this will contain supplemental details.
-
thirdParty
final Optional<CheckTransfer.ThirdParty> thirdParty()
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
type
final CheckTransfer.Type type()
A constant representing the object's type. For this resource it will always be
check_transfer.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account from which funds will be transferred.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number printed on the check.
-
_approval
final JsonField<CheckTransfer.Approval> _approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
_approvedInboundCheckDepositId
final JsonField<String> _approvedInboundCheckDepositId()
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
_cancellation
final JsonField<CheckTransfer.Cancellation> _cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
_checkNumber
final JsonField<String> _checkNumber()
The check number printed on the check.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_createdBy
final JsonField<CheckTransfer.CreatedBy> _createdBy()
What object created the transfer, either via the API or the dashboard.
-
_currency
final JsonField<CheckTransfer.Currency> _currency()
The ISO 4217 code for the check's currency.
-
_fulfillmentMethod
final JsonField<CheckTransfer.FulfillmentMethod> _fulfillmentMethod()
Whether Increase will print and mail the check or if you will do it yourself.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_mailing
final JsonField<CheckTransfer.Mailing> _mailing()
If the check has been mailed by Increase, this will contain details of the shipment.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
_physicalCheck
final JsonField<CheckTransfer.PhysicalCheck> _physicalCheck()
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
_routingNumber
final JsonField<String> _routingNumber()
The routing number printed on the check.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer and print on the check.
-
_status
final JsonField<CheckTransfer.Status> _status()
The lifecycle status of the transfer.
-
_stopPaymentRequest
final JsonField<CheckTransfer.StopPaymentRequest> _stopPaymentRequest()
After a stop-payment is requested on the check, this will contain supplemental details.
-
_submission
final JsonField<CheckTransfer.Submission> _submission()
After the transfer is submitted, this will contain supplemental details.
-
_thirdParty
final JsonField<CheckTransfer.ThirdParty> _thirdParty()
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
_type
final JsonField<CheckTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
check_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransfer validate()
-
toBuilder
final CheckTransfer.Builder toBuilder()
-
builder
final static CheckTransfer.Builder builder()
-
-
-
-