Class CheckTransfer.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.BuilderA builder for CheckTransfer.
-
-
Method Summary
Modifier and Type Method Description final CheckTransfer.Builderid(String id)The Check transfer's identifier. final CheckTransfer.Builderid(JsonField<String> id)The Check transfer's identifier. final CheckTransfer.BuilderaccountId(String accountId)The identifier of the Account from which funds will be transferred. final CheckTransfer.BuilderaccountId(JsonField<String> accountId)The identifier of the Account from which funds will be transferred. final CheckTransfer.BuilderaccountNumber(String accountNumber)The account number printed on the check. final CheckTransfer.BuilderaccountNumber(JsonField<String> accountNumber)The account number printed on the check. final CheckTransfer.Builderamount(Long amount)The transfer amount in USD cents. final CheckTransfer.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final CheckTransfer.Builderapproval(CheckTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final CheckTransfer.Builderapproval(Optional<CheckTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final CheckTransfer.Builderapproval(JsonField<CheckTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final CheckTransfer.BuilderapprovedInboundCheckDepositId(String approvedInboundCheckDepositId)If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final CheckTransfer.BuilderapprovedInboundCheckDepositId(Optional<String> approvedInboundCheckDepositId)If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final CheckTransfer.BuilderapprovedInboundCheckDepositId(JsonField<String> approvedInboundCheckDepositId)If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final CheckTransfer.Buildercancellation(CheckTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final CheckTransfer.Buildercancellation(Optional<CheckTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final CheckTransfer.Buildercancellation(JsonField<CheckTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final CheckTransfer.BuildercheckNumber(String checkNumber)The check number printed on the check. final CheckTransfer.BuildercheckNumber(JsonField<String> checkNumber)The check number printed on the check. final CheckTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final CheckTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the transfer was created. final CheckTransfer.BuildercreatedBy(CheckTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final CheckTransfer.BuildercreatedBy(Optional<CheckTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final CheckTransfer.BuildercreatedBy(JsonField<CheckTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final CheckTransfer.Buildercurrency(CheckTransfer.Currency currency)The ISO 4217 code for the check's currency. final CheckTransfer.Buildercurrency(JsonField<CheckTransfer.Currency> currency)The ISO 4217 code for the check's currency. final CheckTransfer.BuilderfulfillmentMethod(CheckTransfer.FulfillmentMethod fulfillmentMethod)Whether Increase will print and mail the check or if you will do it yourself. final CheckTransfer.BuilderfulfillmentMethod(JsonField<CheckTransfer.FulfillmentMethod> fulfillmentMethod)Whether Increase will print and mail the check or if you will do it yourself. final CheckTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final CheckTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final CheckTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final CheckTransfer.Buildermailing(CheckTransfer.Mailing mailing)If the check has been mailed by Increase, this will contain details of the shipment. final CheckTransfer.Buildermailing(Optional<CheckTransfer.Mailing> mailing)If the check has been mailed by Increase, this will contain details of the shipment. final CheckTransfer.Buildermailing(JsonField<CheckTransfer.Mailing> mailing)If the check has been mailed by Increase, this will contain details of the shipment. final CheckTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final CheckTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final CheckTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final CheckTransfer.BuilderphysicalCheck(CheckTransfer.PhysicalCheck physicalCheck)Details relating to the physical check that Increase will print and mail. final CheckTransfer.BuilderphysicalCheck(Optional<CheckTransfer.PhysicalCheck> physicalCheck)Details relating to the physical check that Increase will print and mail. final CheckTransfer.BuilderphysicalCheck(JsonField<CheckTransfer.PhysicalCheck> physicalCheck)Details relating to the physical check that Increase will print and mail. final CheckTransfer.BuilderroutingNumber(String routingNumber)The routing number printed on the check. final CheckTransfer.BuilderroutingNumber(JsonField<String> routingNumber)The routing number printed on the check. final CheckTransfer.BuildersourceAccountNumberId(String sourceAccountNumberId)The identifier of the Account Number from which to send the transfer and print on the check. final CheckTransfer.BuildersourceAccountNumberId(Optional<String> sourceAccountNumberId)The identifier of the Account Number from which to send the transfer and print on the check. final CheckTransfer.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)The identifier of the Account Number from which to send the transfer and print on the check. final CheckTransfer.Builderstatus(CheckTransfer.Status status)The lifecycle status of the transfer. final CheckTransfer.Builderstatus(JsonField<CheckTransfer.Status> status)The lifecycle status of the transfer. final CheckTransfer.BuilderstopPaymentRequest(CheckTransfer.StopPaymentRequest stopPaymentRequest)After a stop-payment is requested on the check, this will contain supplemental details. final CheckTransfer.BuilderstopPaymentRequest(Optional<CheckTransfer.StopPaymentRequest> stopPaymentRequest)After a stop-payment is requested on the check, this will contain supplemental details. final CheckTransfer.BuilderstopPaymentRequest(JsonField<CheckTransfer.StopPaymentRequest> stopPaymentRequest)After a stop-payment is requested on the check, this will contain supplemental details. final CheckTransfer.Buildersubmission(CheckTransfer.Submission submission)After the transfer is submitted, this will contain supplemental details. final CheckTransfer.Buildersubmission(Optional<CheckTransfer.Submission> submission)After the transfer is submitted, this will contain supplemental details. final CheckTransfer.Buildersubmission(JsonField<CheckTransfer.Submission> submission)After the transfer is submitted, this will contain supplemental details. final CheckTransfer.BuilderthirdParty(CheckTransfer.ThirdParty thirdParty)Details relating to the custom fulfillment you will perform. final CheckTransfer.BuilderthirdParty(Optional<CheckTransfer.ThirdParty> thirdParty)Details relating to the custom fulfillment you will perform. final CheckTransfer.BuilderthirdParty(JsonField<CheckTransfer.ThirdParty> thirdParty)Details relating to the custom fulfillment you will perform. final CheckTransfer.Buildertype(CheckTransfer.Type type)A constant representing the object's type. final CheckTransfer.Buildertype(JsonField<CheckTransfer.Type> type)A constant representing the object's type. final CheckTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final CheckTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.BuilderremoveAdditionalProperty(String key)final CheckTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckTransferbuild()-
-
Method Detail
-
id
final CheckTransfer.Builder id(String id)
The Check transfer's identifier.
-
id
final CheckTransfer.Builder id(JsonField<String> id)
The Check transfer's identifier.
-
accountId
final CheckTransfer.Builder accountId(String accountId)
The identifier of the Account from which funds will be transferred.
-
accountId
final CheckTransfer.Builder accountId(JsonField<String> accountId)
The identifier of the Account from which funds will be transferred.
-
accountNumber
final CheckTransfer.Builder accountNumber(String accountNumber)
The account number printed on the check.
-
accountNumber
final CheckTransfer.Builder accountNumber(JsonField<String> accountNumber)
The account number printed on the check.
-
amount
final CheckTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final CheckTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
approval
final CheckTransfer.Builder approval(CheckTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final CheckTransfer.Builder approval(Optional<CheckTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final CheckTransfer.Builder approval(JsonField<CheckTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approvedInboundCheckDepositId
final CheckTransfer.Builder approvedInboundCheckDepositId(String approvedInboundCheckDepositId)
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
approvedInboundCheckDepositId
final CheckTransfer.Builder approvedInboundCheckDepositId(Optional<String> approvedInboundCheckDepositId)
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
approvedInboundCheckDepositId
final CheckTransfer.Builder approvedInboundCheckDepositId(JsonField<String> approvedInboundCheckDepositId)
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
cancellation
final CheckTransfer.Builder cancellation(CheckTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final CheckTransfer.Builder cancellation(Optional<CheckTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final CheckTransfer.Builder cancellation(JsonField<CheckTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
checkNumber
final CheckTransfer.Builder checkNumber(String checkNumber)
The check number printed on the check.
-
checkNumber
final CheckTransfer.Builder checkNumber(JsonField<String> checkNumber)
The check number printed on the check.
-
createdAt
final CheckTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final CheckTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final CheckTransfer.Builder createdBy(CheckTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final CheckTransfer.Builder createdBy(Optional<CheckTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final CheckTransfer.Builder createdBy(JsonField<CheckTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
currency
final CheckTransfer.Builder currency(CheckTransfer.Currency currency)
The ISO 4217 code for the check's currency.
-
currency
final CheckTransfer.Builder currency(JsonField<CheckTransfer.Currency> currency)
The ISO 4217 code for the check's currency.
-
fulfillmentMethod
final CheckTransfer.Builder fulfillmentMethod(CheckTransfer.FulfillmentMethod fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
fulfillmentMethod
final CheckTransfer.Builder fulfillmentMethod(JsonField<CheckTransfer.FulfillmentMethod> fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
idempotencyKey
final CheckTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CheckTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CheckTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
mailing
final CheckTransfer.Builder mailing(CheckTransfer.Mailing mailing)
If the check has been mailed by Increase, this will contain details of the shipment.
-
mailing
final CheckTransfer.Builder mailing(Optional<CheckTransfer.Mailing> mailing)
If the check has been mailed by Increase, this will contain details of the shipment.
-
mailing
final CheckTransfer.Builder mailing(JsonField<CheckTransfer.Mailing> mailing)
If the check has been mailed by Increase, this will contain details of the shipment.
-
pendingTransactionId
final CheckTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final CheckTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final CheckTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
physicalCheck
final CheckTransfer.Builder physicalCheck(CheckTransfer.PhysicalCheck physicalCheck)
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
physicalCheck
final CheckTransfer.Builder physicalCheck(Optional<CheckTransfer.PhysicalCheck> physicalCheck)
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
physicalCheck
final CheckTransfer.Builder physicalCheck(JsonField<CheckTransfer.PhysicalCheck> physicalCheck)
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
routingNumber
final CheckTransfer.Builder routingNumber(String routingNumber)
The routing number printed on the check.
-
routingNumber
final CheckTransfer.Builder routingNumber(JsonField<String> routingNumber)
The routing number printed on the check.
-
sourceAccountNumberId
final CheckTransfer.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
sourceAccountNumberId
final CheckTransfer.Builder sourceAccountNumberId(Optional<String> sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
sourceAccountNumberId
final CheckTransfer.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
status
final CheckTransfer.Builder status(CheckTransfer.Status status)
The lifecycle status of the transfer.
-
status
final CheckTransfer.Builder status(JsonField<CheckTransfer.Status> status)
The lifecycle status of the transfer.
-
stopPaymentRequest
final CheckTransfer.Builder stopPaymentRequest(CheckTransfer.StopPaymentRequest stopPaymentRequest)
After a stop-payment is requested on the check, this will contain supplemental details.
-
stopPaymentRequest
final CheckTransfer.Builder stopPaymentRequest(Optional<CheckTransfer.StopPaymentRequest> stopPaymentRequest)
After a stop-payment is requested on the check, this will contain supplemental details.
-
stopPaymentRequest
final CheckTransfer.Builder stopPaymentRequest(JsonField<CheckTransfer.StopPaymentRequest> stopPaymentRequest)
After a stop-payment is requested on the check, this will contain supplemental details.
-
submission
final CheckTransfer.Builder submission(CheckTransfer.Submission submission)
After the transfer is submitted, this will contain supplemental details.
-
submission
final CheckTransfer.Builder submission(Optional<CheckTransfer.Submission> submission)
After the transfer is submitted, this will contain supplemental details.
-
submission
final CheckTransfer.Builder submission(JsonField<CheckTransfer.Submission> submission)
After the transfer is submitted, this will contain supplemental details.
-
thirdParty
final CheckTransfer.Builder thirdParty(CheckTransfer.ThirdParty thirdParty)
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
thirdParty
final CheckTransfer.Builder thirdParty(Optional<CheckTransfer.ThirdParty> thirdParty)
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
thirdParty
final CheckTransfer.Builder thirdParty(JsonField<CheckTransfer.ThirdParty> thirdParty)
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
type
final CheckTransfer.Builder type(CheckTransfer.Type type)
A constant representing the object's type. For this resource it will always be
check_transfer.
-
type
final CheckTransfer.Builder type(JsonField<CheckTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
check_transfer.
-
additionalProperties
final CheckTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer build()
-
-
-
-