Class CheckTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class CheckTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classCheckTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classCheckTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classCheckTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classCheckTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final Optional<CheckTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final CheckTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<CheckTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<CheckTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<CheckTransfer.CreatedBy.ApiKey>_apiKey()If present, details about the API key that created the transfer. final JsonField<CheckTransfer.CreatedBy.Category>_category()The type of object that created this transfer. final JsonField<CheckTransfer.CreatedBy.OAuthApplication>_oauthApplication()If present, details about the OAuth Application that created the transfer. final JsonField<CheckTransfer.CreatedBy.User>_user()If present, details about the User that created the transfer. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.CreatedByvalidate()final CheckTransfer.CreatedBy.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.CreatedBy.Builderbuilder()-
-
Method Detail
-
apiKey
final Optional<CheckTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
category
final CheckTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
oauthApplication
final Optional<CheckTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<CheckTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_apiKey
final JsonField<CheckTransfer.CreatedBy.ApiKey> _apiKey()
If present, details about the API key that created the transfer.
-
_category
final JsonField<CheckTransfer.CreatedBy.Category> _category()
The type of object that created this transfer.
-
_oauthApplication
final JsonField<CheckTransfer.CreatedBy.OAuthApplication> _oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
_user
final JsonField<CheckTransfer.CreatedBy.User> _user()
If present, details about the User that created the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransfer.CreatedBy validate()
-
toBuilder
final CheckTransfer.CreatedBy.Builder toBuilder()
-
builder
final static CheckTransfer.CreatedBy.Builder builder()
-
-
-
-