Package com.increase.api.models
Class CheckTransfer.Mailing
-
- All Implemented Interfaces:
public final class CheckTransfer.MailingIf the check has been mailed by Increase, this will contain details of the shipment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Mailing.BuilderA builder for Mailing.
-
Method Summary
Modifier and Type Method Description final Optional<String>imageId()The ID of the file corresponding to an image of the check that was mailed, if available. final OffsetDateTimemailedAt()The ISO 8601 date and time at which the check was mailed. final Optional<String>trackingNumber()The tracking number of the shipment, if available for the shipping method. final JsonField<String>_imageId()The ID of the file corresponding to an image of the check that was mailed, if available. final JsonField<OffsetDateTime>_mailedAt()The ISO 8601 date and time at which the check was mailed. final JsonField<String>_trackingNumber()The tracking number of the shipment, if available for the shipping method. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Mailingvalidate()final CheckTransfer.Mailing.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Mailing.Builderbuilder()-
-
Method Detail
-
imageId
final Optional<String> imageId()
The ID of the file corresponding to an image of the check that was mailed, if available.
-
mailedAt
final OffsetDateTime mailedAt()
The ISO 8601 date and time at which the check was mailed.
-
trackingNumber
final Optional<String> trackingNumber()
The tracking number of the shipment, if available for the shipping method.
-
_imageId
final JsonField<String> _imageId()
The ID of the file corresponding to an image of the check that was mailed, if available.
-
_mailedAt
final JsonField<OffsetDateTime> _mailedAt()
The ISO 8601 date and time at which the check was mailed.
-
_trackingNumber
final JsonField<String> _trackingNumber()
The tracking number of the shipment, if available for the shipping method.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransfer.Mailing validate()
-
toBuilder
final CheckTransfer.Mailing.Builder toBuilder()
-
builder
final static CheckTransfer.Mailing.Builder builder()
-
-
-
-