Package com.increase.api.models
Class CheckTransfer.Mailing.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.Mailing.BuilderA builder for Mailing.
-
-
Method Summary
Modifier and Type Method Description final CheckTransfer.Mailing.BuilderimageId(String imageId)The ID of the file corresponding to an image of the check that was mailed, if available. final CheckTransfer.Mailing.BuilderimageId(Optional<String> imageId)The ID of the file corresponding to an image of the check that was mailed, if available. final CheckTransfer.Mailing.BuilderimageId(JsonField<String> imageId)The ID of the file corresponding to an image of the check that was mailed, if available. final CheckTransfer.Mailing.BuildermailedAt(OffsetDateTime mailedAt)The ISO 8601 date and time at which the check was mailed. final CheckTransfer.Mailing.BuildermailedAt(JsonField<OffsetDateTime> mailedAt)The ISO 8601 date and time at which the check was mailed. final CheckTransfer.Mailing.BuildertrackingNumber(String trackingNumber)The tracking number of the shipment, if available for the shipping method. final CheckTransfer.Mailing.BuildertrackingNumber(Optional<String> trackingNumber)The tracking number of the shipment, if available for the shipping method. final CheckTransfer.Mailing.BuildertrackingNumber(JsonField<String> trackingNumber)The tracking number of the shipment, if available for the shipping method. final CheckTransfer.Mailing.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.Mailing.BuilderputAdditionalProperty(String key, JsonValue value)final CheckTransfer.Mailing.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.Mailing.BuilderremoveAdditionalProperty(String key)final CheckTransfer.Mailing.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckTransfer.Mailingbuild()-
-
Method Detail
-
imageId
final CheckTransfer.Mailing.Builder imageId(String imageId)
The ID of the file corresponding to an image of the check that was mailed, if available.
-
imageId
final CheckTransfer.Mailing.Builder imageId(Optional<String> imageId)
The ID of the file corresponding to an image of the check that was mailed, if available.
-
imageId
final CheckTransfer.Mailing.Builder imageId(JsonField<String> imageId)
The ID of the file corresponding to an image of the check that was mailed, if available.
-
mailedAt
final CheckTransfer.Mailing.Builder mailedAt(OffsetDateTime mailedAt)
The ISO 8601 date and time at which the check was mailed.
-
mailedAt
final CheckTransfer.Mailing.Builder mailedAt(JsonField<OffsetDateTime> mailedAt)
The ISO 8601 date and time at which the check was mailed.
-
trackingNumber
final CheckTransfer.Mailing.Builder trackingNumber(String trackingNumber)
The tracking number of the shipment, if available for the shipping method.
-
trackingNumber
final CheckTransfer.Mailing.Builder trackingNumber(Optional<String> trackingNumber)
The tracking number of the shipment, if available for the shipping method.
-
trackingNumber
final CheckTransfer.Mailing.Builder trackingNumber(JsonField<String> trackingNumber)
The tracking number of the shipment, if available for the shipping method.
-
additionalProperties
final CheckTransfer.Mailing.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.Mailing.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.Mailing.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.Mailing.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.Mailing.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.Mailing build()
-
-
-
-