Class CheckTransfer.PhysicalCheck
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheckDetails relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.PhysicalCheck.BuilderA builder for PhysicalCheck.
public final classCheckTransfer.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
public final classCheckTransfer.PhysicalCheck.ReturnAddressThe return address to be printed on the check.
public final classCheckTransfer.PhysicalCheck.ShippingMethodThe shipping method for the check.
public final classCheckTransfer.PhysicalCheck.TrackingUpdate
-
Method Summary
Modifier and Type Method Description final CheckTransfer.PhysicalCheck.MailingAddressmailingAddress()Details for where Increase will mail the check. final Optional<String>memo()The descriptor that will be printed on the memo field on the check. final Optional<String>note()The descriptor that will be printed on the letter included with the check. final StringrecipientName()The name that will be printed on the check. final Optional<CheckTransfer.PhysicalCheck.ReturnAddress>returnAddress()The return address to be printed on the check. final Optional<CheckTransfer.PhysicalCheck.ShippingMethod>shippingMethod()The shipping method for the check. final Optional<String>signatureText()The text that will appear as the signature on the check in cursive font. final List<CheckTransfer.PhysicalCheck.TrackingUpdate>trackingUpdates()Tracking updates relating to the physical check's delivery. final JsonField<CheckTransfer.PhysicalCheck.MailingAddress>_mailingAddress()Details for where Increase will mail the check. final JsonField<String>_memo()The descriptor that will be printed on the memo field on the check. final JsonField<String>_note()The descriptor that will be printed on the letter included with the check. final JsonField<String>_recipientName()The name that will be printed on the check. final JsonField<CheckTransfer.PhysicalCheck.ReturnAddress>_returnAddress()The return address to be printed on the check. final JsonField<CheckTransfer.PhysicalCheck.ShippingMethod>_shippingMethod()The shipping method for the check. final JsonField<String>_signatureText()The text that will appear as the signature on the check in cursive font. final JsonField<List<CheckTransfer.PhysicalCheck.TrackingUpdate>>_trackingUpdates()Tracking updates relating to the physical check's delivery. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.PhysicalCheckvalidate()final CheckTransfer.PhysicalCheck.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.PhysicalCheck.Builderbuilder()-
-
Method Detail
-
mailingAddress
final CheckTransfer.PhysicalCheck.MailingAddress mailingAddress()
Details for where Increase will mail the check.
-
memo
final Optional<String> memo()
The descriptor that will be printed on the memo field on the check.
-
note
final Optional<String> note()
The descriptor that will be printed on the letter included with the check.
-
recipientName
final String recipientName()
The name that will be printed on the check.
-
returnAddress
final Optional<CheckTransfer.PhysicalCheck.ReturnAddress> returnAddress()
The return address to be printed on the check.
-
shippingMethod
final Optional<CheckTransfer.PhysicalCheck.ShippingMethod> shippingMethod()
The shipping method for the check.
-
signatureText
final Optional<String> signatureText()
The text that will appear as the signature on the check in cursive font. If blank, the check will be printed with 'No signature required'.
-
trackingUpdates
final List<CheckTransfer.PhysicalCheck.TrackingUpdate> trackingUpdates()
Tracking updates relating to the physical check's delivery.
-
_mailingAddress
final JsonField<CheckTransfer.PhysicalCheck.MailingAddress> _mailingAddress()
Details for where Increase will mail the check.
-
_memo
final JsonField<String> _memo()
The descriptor that will be printed on the memo field on the check.
-
_note
final JsonField<String> _note()
The descriptor that will be printed on the letter included with the check.
-
_recipientName
final JsonField<String> _recipientName()
The name that will be printed on the check.
-
_returnAddress
final JsonField<CheckTransfer.PhysicalCheck.ReturnAddress> _returnAddress()
The return address to be printed on the check.
-
_shippingMethod
final JsonField<CheckTransfer.PhysicalCheck.ShippingMethod> _shippingMethod()
The shipping method for the check.
-
_signatureText
final JsonField<String> _signatureText()
The text that will appear as the signature on the check in cursive font. If blank, the check will be printed with 'No signature required'.
-
_trackingUpdates
final JsonField<List<CheckTransfer.PhysicalCheck.TrackingUpdate>> _trackingUpdates()
Tracking updates relating to the physical check's delivery.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransfer.PhysicalCheck validate()
-
toBuilder
final CheckTransfer.PhysicalCheck.Builder toBuilder()
-
builder
final static CheckTransfer.PhysicalCheck.Builder builder()
-
-
-
-