Class CheckTransfer.PhysicalCheck.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.BuilderA builder for PhysicalCheck.
-
-
Method Summary
-
-
Method Detail
-
mailingAddress
final CheckTransfer.PhysicalCheck.Builder mailingAddress(CheckTransfer.PhysicalCheck.MailingAddress mailingAddress)
Details for where Increase will mail the check.
-
mailingAddress
final CheckTransfer.PhysicalCheck.Builder mailingAddress(JsonField<CheckTransfer.PhysicalCheck.MailingAddress> mailingAddress)
Details for where Increase will mail the check.
-
memo
final CheckTransfer.PhysicalCheck.Builder memo(String memo)
The descriptor that will be printed on the memo field on the check.
-
memo
final CheckTransfer.PhysicalCheck.Builder memo(Optional<String> memo)
The descriptor that will be printed on the memo field on the check.
-
memo
final CheckTransfer.PhysicalCheck.Builder memo(JsonField<String> memo)
The descriptor that will be printed on the memo field on the check.
-
note
final CheckTransfer.PhysicalCheck.Builder note(String note)
The descriptor that will be printed on the letter included with the check.
-
note
final CheckTransfer.PhysicalCheck.Builder note(Optional<String> note)
The descriptor that will be printed on the letter included with the check.
-
note
final CheckTransfer.PhysicalCheck.Builder note(JsonField<String> note)
The descriptor that will be printed on the letter included with the check.
-
recipientName
final CheckTransfer.PhysicalCheck.Builder recipientName(String recipientName)
The name that will be printed on the check.
-
recipientName
final CheckTransfer.PhysicalCheck.Builder recipientName(JsonField<String> recipientName)
The name that will be printed on the check.
-
returnAddress
final CheckTransfer.PhysicalCheck.Builder returnAddress(CheckTransfer.PhysicalCheck.ReturnAddress returnAddress)
The return address to be printed on the check.
-
returnAddress
final CheckTransfer.PhysicalCheck.Builder returnAddress(Optional<CheckTransfer.PhysicalCheck.ReturnAddress> returnAddress)
The return address to be printed on the check.
-
returnAddress
final CheckTransfer.PhysicalCheck.Builder returnAddress(JsonField<CheckTransfer.PhysicalCheck.ReturnAddress> returnAddress)
The return address to be printed on the check.
-
shippingMethod
final CheckTransfer.PhysicalCheck.Builder shippingMethod(CheckTransfer.PhysicalCheck.ShippingMethod shippingMethod)
The shipping method for the check.
-
shippingMethod
final CheckTransfer.PhysicalCheck.Builder shippingMethod(Optional<CheckTransfer.PhysicalCheck.ShippingMethod> shippingMethod)
The shipping method for the check.
-
shippingMethod
final CheckTransfer.PhysicalCheck.Builder shippingMethod(JsonField<CheckTransfer.PhysicalCheck.ShippingMethod> shippingMethod)
The shipping method for the check.
-
signatureText
final CheckTransfer.PhysicalCheck.Builder signatureText(String signatureText)
The text that will appear as the signature on the check in cursive font. If blank, the check will be printed with 'No signature required'.
-
signatureText
final CheckTransfer.PhysicalCheck.Builder signatureText(Optional<String> signatureText)
The text that will appear as the signature on the check in cursive font. If blank, the check will be printed with 'No signature required'.
-
signatureText
final CheckTransfer.PhysicalCheck.Builder signatureText(JsonField<String> signatureText)
The text that will appear as the signature on the check in cursive font. If blank, the check will be printed with 'No signature required'.
-
trackingUpdates
final CheckTransfer.PhysicalCheck.Builder trackingUpdates(List<CheckTransfer.PhysicalCheck.TrackingUpdate> trackingUpdates)
Tracking updates relating to the physical check's delivery.
-
trackingUpdates
final CheckTransfer.PhysicalCheck.Builder trackingUpdates(JsonField<List<CheckTransfer.PhysicalCheck.TrackingUpdate>> trackingUpdates)
Tracking updates relating to the physical check's delivery.
-
addTrackingUpdate
final CheckTransfer.PhysicalCheck.Builder addTrackingUpdate(CheckTransfer.PhysicalCheck.TrackingUpdate trackingUpdate)
Tracking updates relating to the physical check's delivery.
-
additionalProperties
final CheckTransfer.PhysicalCheck.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck build()
-
-
-
-