Class CheckTransfer.PhysicalCheck.MailingAddress.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final CheckTransfer.PhysicalCheck.MailingAddress.Builder city(String city)
The city of the check's destination.
-
city
final CheckTransfer.PhysicalCheck.MailingAddress.Builder city(Optional<String> city)
The city of the check's destination.
-
city
final CheckTransfer.PhysicalCheck.MailingAddress.Builder city(JsonField<String> city)
The city of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line1(String line1)
The street address of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line1(Optional<String> line1)
The street address of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line1(JsonField<String> line1)
The street address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line2(String line2)
The second line of the address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line2(Optional<String> line2)
The second line of the address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line2(JsonField<String> line2)
The second line of the address of the check's destination.
-
name
final CheckTransfer.PhysicalCheck.MailingAddress.Builder name(String name)
The name component of the check's mailing address.
-
name
final CheckTransfer.PhysicalCheck.MailingAddress.Builder name(Optional<String> name)
The name component of the check's mailing address.
-
name
final CheckTransfer.PhysicalCheck.MailingAddress.Builder name(JsonField<String> name)
The name component of the check's mailing address.
-
postalCode
final CheckTransfer.PhysicalCheck.MailingAddress.Builder postalCode(String postalCode)
The postal code of the check's destination.
-
postalCode
final CheckTransfer.PhysicalCheck.MailingAddress.Builder postalCode(Optional<String> postalCode)
The postal code of the check's destination.
-
postalCode
final CheckTransfer.PhysicalCheck.MailingAddress.Builder postalCode(JsonField<String> postalCode)
The postal code of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.MailingAddress.Builder state(String state)
The state of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.MailingAddress.Builder state(Optional<String> state)
The state of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.MailingAddress.Builder state(JsonField<String> state)
The state of the check's destination.
-
additionalProperties
final CheckTransfer.PhysicalCheck.MailingAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.MailingAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.MailingAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.MailingAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.MailingAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck.MailingAddress build()
-
-
-
-