Class CheckTransfer.PhysicalCheck.ReturnAddress.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.ReturnAddress.BuilderA builder for ReturnAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder city(String city)
The city of the check's destination.
-
city
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder city(Optional<String> city)
The city of the check's destination.
-
city
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder city(JsonField<String> city)
The city of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder line1(String line1)
The street address of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder line1(Optional<String> line1)
The street address of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder line1(JsonField<String> line1)
The street address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder line2(String line2)
The second line of the address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder line2(Optional<String> line2)
The second line of the address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder line2(JsonField<String> line2)
The second line of the address of the check's destination.
-
name
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder name(String name)
The name component of the check's return address.
-
name
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder name(Optional<String> name)
The name component of the check's return address.
-
name
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder name(JsonField<String> name)
The name component of the check's return address.
-
postalCode
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder postalCode(String postalCode)
The postal code of the check's destination.
-
postalCode
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder postalCode(Optional<String> postalCode)
The postal code of the check's destination.
-
postalCode
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder postalCode(JsonField<String> postalCode)
The postal code of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder state(String state)
The state of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder state(Optional<String> state)
The state of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder state(JsonField<String> state)
The state of the check's destination.
-
additionalProperties
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.ReturnAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck.ReturnAddress build()
-
-
-
-