Class CheckTransfer.StopPaymentRequest
-
- All Implemented Interfaces:
public final class CheckTransfer.StopPaymentRequestAfter a stop-payment is requested on the check, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.StopPaymentRequest.BuilderA builder for StopPaymentRequest.
public final classCheckTransfer.StopPaymentRequest.ReasonThe reason why this transfer was stopped.
public final classCheckTransfer.StopPaymentRequest.TypeA constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.StopPaymentRequest.Reasonreason()The reason why this transfer was stopped. final OffsetDateTimerequestedAt()The time the stop-payment was requested. final StringtransferId()The ID of the check transfer that was stopped. final CheckTransfer.StopPaymentRequest.Typetype()A constant representing the object's type. final JsonField<CheckTransfer.StopPaymentRequest.Reason>_reason()The reason why this transfer was stopped. final JsonField<OffsetDateTime>_requestedAt()The time the stop-payment was requested. final JsonField<String>_transferId()The ID of the check transfer that was stopped. final JsonField<CheckTransfer.StopPaymentRequest.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.StopPaymentRequestvalidate()final CheckTransfer.StopPaymentRequest.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.StopPaymentRequest.Builderbuilder()-
-
Method Detail
-
reason
final CheckTransfer.StopPaymentRequest.Reason reason()
The reason why this transfer was stopped.
-
requestedAt
final OffsetDateTime requestedAt()
The time the stop-payment was requested.
-
transferId
final String transferId()
The ID of the check transfer that was stopped.
-
type
final CheckTransfer.StopPaymentRequest.Type type()
A constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
-
_reason
final JsonField<CheckTransfer.StopPaymentRequest.Reason> _reason()
The reason why this transfer was stopped.
-
_requestedAt
final JsonField<OffsetDateTime> _requestedAt()
The time the stop-payment was requested.
-
_transferId
final JsonField<String> _transferId()
The ID of the check transfer that was stopped.
-
_type
final JsonField<CheckTransfer.StopPaymentRequest.Type> _type()
A constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransfer.StopPaymentRequest validate()
-
toBuilder
final CheckTransfer.StopPaymentRequest.Builder toBuilder()
-
builder
final static CheckTransfer.StopPaymentRequest.Builder builder()
-
-
-
-