Package com.increase.api.models
Class CheckTransfer.ThirdParty
-
- All Implemented Interfaces:
public final class CheckTransfer.ThirdPartyDetails relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.ThirdParty.BuilderA builder for ThirdParty.
-
Method Summary
Modifier and Type Method Description final Optional<String>checkNumber()The check number that will be printed on the check. final JsonField<String>_checkNumber()The check number that will be printed on the check. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.ThirdPartyvalidate()final CheckTransfer.ThirdParty.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.ThirdParty.Builderbuilder()-
-
Method Detail
-
checkNumber
final Optional<String> checkNumber()
The check number that will be printed on the check.
-
_checkNumber
final JsonField<String> _checkNumber()
The check number that will be printed on the check.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransfer.ThirdParty validate()
-
toBuilder
final CheckTransfer.ThirdParty.Builder toBuilder()
-
builder
final static CheckTransfer.ThirdParty.Builder builder()
-
-
-
-