Class CheckTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final CheckTransferCreateParams.FulfillmentMethodfulfillmentMethod()Whether Increase will print and mail the check or if you will do it yourself. final StringsourceAccountNumberId()The identifier of the Account Number from which to send the transfer and print on the check. final Optional<CheckTransferCreateParams.PhysicalCheck>physicalCheck()Details relating to the physical check that Increase will print and mail. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<CheckTransferCreateParams.ThirdParty>thirdParty()Details relating to the custom fulfillment you will perform. final JsonField<String>_accountId()The identifier for the account that will send the transfer. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<CheckTransferCreateParams.FulfillmentMethod>_fulfillmentMethod()Whether Increase will print and mail the check or if you will do it yourself. final JsonField<String>_sourceAccountNumberId()The identifier of the Account Number from which to send the transfer and print on the check. final JsonField<CheckTransferCreateParams.PhysicalCheck>_physicalCheck()Details relating to the physical check that Increase will print and mail. final JsonField<Boolean>_requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<CheckTransferCreateParams.ThirdParty>_thirdParty()Details relating to the custom fulfillment you will perform. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.Bodyvalidate()final CheckTransferCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.Body.Builderbuilder()-
-
Method Detail
-
fulfillmentMethod
final CheckTransferCreateParams.FulfillmentMethod fulfillmentMethod()
Whether Increase will print and mail the check or if you will do it yourself.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer and print on the check.
-
physicalCheck
final Optional<CheckTransferCreateParams.PhysicalCheck> physicalCheck()
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
thirdParty
final Optional<CheckTransferCreateParams.ThirdParty> thirdParty()
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account that will send the transfer.
-
_fulfillmentMethod
final JsonField<CheckTransferCreateParams.FulfillmentMethod> _fulfillmentMethod()
Whether Increase will print and mail the check or if you will do it yourself.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer and print on the check.
-
_physicalCheck
final JsonField<CheckTransferCreateParams.PhysicalCheck> _physicalCheck()
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_thirdParty
final JsonField<CheckTransferCreateParams.ThirdParty> _thirdParty()
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransferCreateParams.Body validate()
-
toBuilder
final CheckTransferCreateParams.Body.Builder toBuilder()
-
builder
final static CheckTransferCreateParams.Body.Builder builder()
-
-
-
-