Class CheckTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final CheckTransferCreateParams.Body.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final CheckTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
The identifier for the account that will send the transfer.
-
amount
final CheckTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final CheckTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
fulfillmentMethod
final CheckTransferCreateParams.Body.Builder fulfillmentMethod(CheckTransferCreateParams.FulfillmentMethod fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
fulfillmentMethod
final CheckTransferCreateParams.Body.Builder fulfillmentMethod(JsonField<CheckTransferCreateParams.FulfillmentMethod> fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
sourceAccountNumberId
final CheckTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
sourceAccountNumberId
final CheckTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
physicalCheck
final CheckTransferCreateParams.Body.Builder physicalCheck(CheckTransferCreateParams.PhysicalCheck physicalCheck)
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
physicalCheck
final CheckTransferCreateParams.Body.Builder physicalCheck(JsonField<CheckTransferCreateParams.PhysicalCheck> physicalCheck)
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
requireApproval
final CheckTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final CheckTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
thirdParty
final CheckTransferCreateParams.Body.Builder thirdParty(CheckTransferCreateParams.ThirdParty thirdParty)
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
thirdParty
final CheckTransferCreateParams.Body.Builder thirdParty(JsonField<CheckTransferCreateParams.ThirdParty> thirdParty)
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
additionalProperties
final CheckTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.Body build()
-
-
-
-