Class CheckTransferCreateParams.PhysicalCheck
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheckDetails relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.PhysicalCheck.BuilderA builder for PhysicalCheck.
public final classCheckTransferCreateParams.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
public final classCheckTransferCreateParams.PhysicalCheck.ReturnAddressThe return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
Method Summary
Modifier and Type Method Description final CheckTransferCreateParams.PhysicalCheck.MailingAddressmailingAddress()Details for where Increase will mail the check. final Stringmemo()The descriptor that will be printed on the memo field on the check. final StringrecipientName()The name that will be printed on the check in the 'To:' field. final Optional<String>note()The descriptor that will be printed on the letter included with the check. final Optional<CheckTransferCreateParams.PhysicalCheck.ReturnAddress>returnAddress()The return address to be printed on the check. final Optional<String>signatureText()The text that will appear as the signature on the check in cursive font. final JsonField<CheckTransferCreateParams.PhysicalCheck.MailingAddress>_mailingAddress()Details for where Increase will mail the check. final JsonField<String>_memo()The descriptor that will be printed on the memo field on the check. final JsonField<String>_recipientName()The name that will be printed on the check in the 'To:' field. final JsonField<String>_note()The descriptor that will be printed on the letter included with the check. final JsonField<CheckTransferCreateParams.PhysicalCheck.ReturnAddress>_returnAddress()The return address to be printed on the check. final JsonField<String>_signatureText()The text that will appear as the signature on the check in cursive font. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.PhysicalCheckvalidate()final CheckTransferCreateParams.PhysicalCheck.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.PhysicalCheck.Builderbuilder()-
-
Method Detail
-
mailingAddress
final CheckTransferCreateParams.PhysicalCheck.MailingAddress mailingAddress()
Details for where Increase will mail the check.
-
recipientName
final String recipientName()
The name that will be printed on the check in the 'To:' field.
-
note
final Optional<String> note()
The descriptor that will be printed on the letter included with the check.
-
returnAddress
final Optional<CheckTransferCreateParams.PhysicalCheck.ReturnAddress> returnAddress()
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
signatureText
final Optional<String> signatureText()
The text that will appear as the signature on the check in cursive font. If not provided, the check will be printed with 'No signature required'.
-
_mailingAddress
final JsonField<CheckTransferCreateParams.PhysicalCheck.MailingAddress> _mailingAddress()
Details for where Increase will mail the check.
-
_memo
final JsonField<String> _memo()
The descriptor that will be printed on the memo field on the check.
-
_recipientName
final JsonField<String> _recipientName()
The name that will be printed on the check in the 'To:' field.
-
_note
final JsonField<String> _note()
The descriptor that will be printed on the letter included with the check.
-
_returnAddress
final JsonField<CheckTransferCreateParams.PhysicalCheck.ReturnAddress> _returnAddress()
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
_signatureText
final JsonField<String> _signatureText()
The text that will appear as the signature on the check in cursive font. If not provided, the check will be printed with 'No signature required'.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransferCreateParams.PhysicalCheck validate()
-
toBuilder
final CheckTransferCreateParams.PhysicalCheck.Builder toBuilder()
-
builder
final static CheckTransferCreateParams.PhysicalCheck.Builder builder()
-
-
-
-