Class CheckTransferCreateParams.PhysicalCheck.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.BuilderA builder for PhysicalCheck.
-
-
Method Summary
-
-
Method Detail
-
mailingAddress
final CheckTransferCreateParams.PhysicalCheck.Builder mailingAddress(CheckTransferCreateParams.PhysicalCheck.MailingAddress mailingAddress)
Details for where Increase will mail the check.
-
mailingAddress
final CheckTransferCreateParams.PhysicalCheck.Builder mailingAddress(JsonField<CheckTransferCreateParams.PhysicalCheck.MailingAddress> mailingAddress)
Details for where Increase will mail the check.
-
memo
final CheckTransferCreateParams.PhysicalCheck.Builder memo(String memo)
The descriptor that will be printed on the memo field on the check.
-
memo
final CheckTransferCreateParams.PhysicalCheck.Builder memo(JsonField<String> memo)
The descriptor that will be printed on the memo field on the check.
-
recipientName
final CheckTransferCreateParams.PhysicalCheck.Builder recipientName(String recipientName)
The name that will be printed on the check in the 'To:' field.
-
recipientName
final CheckTransferCreateParams.PhysicalCheck.Builder recipientName(JsonField<String> recipientName)
The name that will be printed on the check in the 'To:' field.
-
note
final CheckTransferCreateParams.PhysicalCheck.Builder note(String note)
The descriptor that will be printed on the letter included with the check.
-
note
final CheckTransferCreateParams.PhysicalCheck.Builder note(JsonField<String> note)
The descriptor that will be printed on the letter included with the check.
-
returnAddress
final CheckTransferCreateParams.PhysicalCheck.Builder returnAddress(CheckTransferCreateParams.PhysicalCheck.ReturnAddress returnAddress)
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
returnAddress
final CheckTransferCreateParams.PhysicalCheck.Builder returnAddress(JsonField<CheckTransferCreateParams.PhysicalCheck.ReturnAddress> returnAddress)
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
signatureText
final CheckTransferCreateParams.PhysicalCheck.Builder signatureText(String signatureText)
The text that will appear as the signature on the check in cursive font. If not provided, the check will be printed with 'No signature required'.
-
signatureText
final CheckTransferCreateParams.PhysicalCheck.Builder signatureText(JsonField<String> signatureText)
The text that will appear as the signature on the check in cursive font. If not provided, the check will be printed with 'No signature required'.
-
additionalProperties
final CheckTransferCreateParams.PhysicalCheck.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.PhysicalCheck build()
-
-
-
-