Package com.increase.api.models
Class CheckTransferCreateParams.PhysicalCheck.MailingAddress
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city component of the check's destination address. final Stringline1()The first line of the address component of the check's destination address. final StringpostalCode()The postal code component of the check's destination address. final Stringstate()The US state component of the check's destination address. final Optional<String>line2()The second line of the address component of the check's destination address. final JsonField<String>_city()The city component of the check's destination address. final JsonField<String>_line1()The first line of the address component of the check's destination address. final JsonField<String>_postalCode()The postal code component of the check's destination address. final JsonField<String>_state()The US state component of the check's destination address. final JsonField<String>_line2()The second line of the address component of the check's destination address. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.PhysicalCheck.MailingAddressvalidate()final CheckTransferCreateParams.PhysicalCheck.MailingAddress.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builderbuilder()-
-
Method Detail
-
line1
final String line1()
The first line of the address component of the check's destination address.
-
postalCode
final String postalCode()
The postal code component of the check's destination address.
-
line2
final Optional<String> line2()
The second line of the address component of the check's destination address.
-
_line1
final JsonField<String> _line1()
The first line of the address component of the check's destination address.
-
_postalCode
final JsonField<String> _postalCode()
The postal code component of the check's destination address.
-
_line2
final JsonField<String> _line2()
The second line of the address component of the check's destination address.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransferCreateParams.PhysicalCheck.MailingAddress validate()
-
toBuilder
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder toBuilder()
-
builder
final static CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder builder()
-
-
-
-