Package com.increase.api.models
Class CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder city(String city)
The city component of the check's destination address.
-
city
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder city(JsonField<String> city)
The city component of the check's destination address.
-
line1
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line1(String line1)
The first line of the address component of the check's destination address.
-
line1
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line1(JsonField<String> line1)
The first line of the address component of the check's destination address.
-
postalCode
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder postalCode(String postalCode)
The postal code component of the check's destination address.
-
postalCode
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder postalCode(JsonField<String> postalCode)
The postal code component of the check's destination address.
-
state
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder state(String state)
The US state component of the check's destination address.
-
state
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder state(JsonField<String> state)
The US state component of the check's destination address.
-
line2
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line2(String line2)
The second line of the address component of the check's destination address.
-
line2
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line2(JsonField<String> line2)
The second line of the address component of the check's destination address.
-
additionalProperties
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.PhysicalCheck.MailingAddress build()
-
-
-
-