Package com.increase.api.models
Class CheckTransferStopPaymentParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CheckTransferStopPaymentParams implements Params
Request a stop payment on a Check Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferStopPaymentParams.Bodypublic final classCheckTransferStopPaymentParams.BuilderA builder for CheckTransferStopPaymentParams.
public final classCheckTransferStopPaymentParams.ReasonThe reason why this transfer should be stopped.
-
Method Summary
Modifier and Type Method Description final StringcheckTransferId()The identifier of the Check Transfer. final Optional<CheckTransferStopPaymentParams.Reason>reason()The reason why this transfer should be stopped. final JsonField<CheckTransferStopPaymentParams.Reason>_reason()The reason why this transfer should be stopped. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final CheckTransferStopPaymentParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferStopPaymentParams.Builderbuilder()-
-
Method Detail
-
checkTransferId
final String checkTransferId()
The identifier of the Check Transfer.
-
reason
final Optional<CheckTransferStopPaymentParams.Reason> reason()
The reason why this transfer should be stopped.
-
_reason
final JsonField<CheckTransferStopPaymentParams.Reason> _reason()
The reason why this transfer should be stopped.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final CheckTransferStopPaymentParams.Builder toBuilder()
-
builder
final static CheckTransferStopPaymentParams.Builder builder()
-
-
-
-