Class DeclinedTransaction
-
- All Implemented Interfaces:
public final class DeclinedTransactionDeclined Transactions are refused additions and removals of money from your bank account. For example, Declined Transactions are caused when your Account has an insufficient balance or your Limits are triggered.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.BuilderA builder for DeclinedTransaction.
public final classDeclinedTransaction.CurrencyThe ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
public final classDeclinedTransaction.RouteTypeThe type of the route this Declined Transaction came through.
public final classDeclinedTransaction.SourceThis is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
public final classDeclinedTransaction.TypeA constant representing the object's type. For this resource it will always be
declined_transaction.
-
Method Summary
Modifier and Type Method Description final Stringid()The Declined Transaction identifier. final StringaccountId()The identifier for the Account the Declined Transaction belongs to. final Longamount()The Declined Transaction amount in the minor unit of its currency. final OffsetDateTimecreatedAt()The ISO 8601 date on which the Transaction occurred. final DeclinedTransaction.Currencycurrency()The ISO 4217 code for the Declined Transaction's currency. final Stringdescription()This is the description the vendor provides. final Optional<String>routeId()The identifier for the route this Declined Transaction came through. final Optional<DeclinedTransaction.RouteType>routeType()The type of the route this Declined Transaction came through. final DeclinedTransaction.Sourcesource()This is an object giving more details on the network-level event that caused the Declined Transaction. final DeclinedTransaction.Typetype()A constant representing the object's type. final JsonField<String>_id()The Declined Transaction identifier. final JsonField<String>_accountId()The identifier for the Account the Declined Transaction belongs to. final JsonField<Long>_amount()The Declined Transaction amount in the minor unit of its currency. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date on which the Transaction occurred. final JsonField<DeclinedTransaction.Currency>_currency()The ISO 4217 code for the Declined Transaction's currency. final JsonField<String>_description()This is the description the vendor provides. final JsonField<String>_routeId()The identifier for the route this Declined Transaction came through. final JsonField<DeclinedTransaction.RouteType>_routeType()The type of the route this Declined Transaction came through. final JsonField<DeclinedTransaction.Source>_source()This is an object giving more details on the network-level event that caused the Declined Transaction. final JsonField<DeclinedTransaction.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final DeclinedTransactionvalidate()final DeclinedTransaction.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account the Declined Transaction belongs to.
-
amount
final Long amount()
The Declined Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date on which the Transaction occurred.
-
currency
final DeclinedTransaction.Currency currency()
The ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
-
description
final String description()
This is the description the vendor provides.
-
routeId
final Optional<String> routeId()
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
routeType
final Optional<DeclinedTransaction.RouteType> routeType()
The type of the route this Declined Transaction came through.
-
source
final DeclinedTransaction.Source source()
This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
type
final DeclinedTransaction.Type type()
A constant representing the object's type. For this resource it will always be
declined_transaction.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Account the Declined Transaction belongs to.
-
_amount
final JsonField<Long> _amount()
The Declined Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date on which the Transaction occurred.
-
_currency
final JsonField<DeclinedTransaction.Currency> _currency()
The ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
-
_description
final JsonField<String> _description()
This is the description the vendor provides.
-
_routeId
final JsonField<String> _routeId()
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
_routeType
final JsonField<DeclinedTransaction.RouteType> _routeType()
The type of the route this Declined Transaction came through.
-
_source
final JsonField<DeclinedTransaction.Source> _source()
This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
_type
final JsonField<DeclinedTransaction.Type> _type()
A constant representing the object's type. For this resource it will always be
declined_transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DeclinedTransaction validate()
-
toBuilder
final DeclinedTransaction.Builder toBuilder()
-
builder
final static DeclinedTransaction.Builder builder()
-
-
-
-