Class DeclinedTransaction.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.BuilderA builder for DeclinedTransaction.
-
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Builderid(String id)The Declined Transaction identifier. final DeclinedTransaction.Builderid(JsonField<String> id)The Declined Transaction identifier. final DeclinedTransaction.BuilderaccountId(String accountId)The identifier for the Account the Declined Transaction belongs to. final DeclinedTransaction.BuilderaccountId(JsonField<String> accountId)The identifier for the Account the Declined Transaction belongs to. final DeclinedTransaction.Builderamount(Long amount)The Declined Transaction amount in the minor unit of its currency. final DeclinedTransaction.Builderamount(JsonField<Long> amount)The Declined Transaction amount in the minor unit of its currency. final DeclinedTransaction.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date on which the Transaction occurred. final DeclinedTransaction.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date on which the Transaction occurred. final DeclinedTransaction.Buildercurrency(DeclinedTransaction.Currency currency)The ISO 4217 code for the Declined Transaction's currency. final DeclinedTransaction.Buildercurrency(JsonField<DeclinedTransaction.Currency> currency)The ISO 4217 code for the Declined Transaction's currency. final DeclinedTransaction.Builderdescription(String description)This is the description the vendor provides. final DeclinedTransaction.Builderdescription(JsonField<String> description)This is the description the vendor provides. final DeclinedTransaction.BuilderrouteId(String routeId)The identifier for the route this Declined Transaction came through. final DeclinedTransaction.BuilderrouteId(Optional<String> routeId)The identifier for the route this Declined Transaction came through. final DeclinedTransaction.BuilderrouteId(JsonField<String> routeId)The identifier for the route this Declined Transaction came through. final DeclinedTransaction.BuilderrouteType(DeclinedTransaction.RouteType routeType)The type of the route this Declined Transaction came through. final DeclinedTransaction.BuilderrouteType(Optional<DeclinedTransaction.RouteType> routeType)The type of the route this Declined Transaction came through. final DeclinedTransaction.BuilderrouteType(JsonField<DeclinedTransaction.RouteType> routeType)The type of the route this Declined Transaction came through. final DeclinedTransaction.Buildersource(DeclinedTransaction.Source source)This is an object giving more details on the network-level event that caused the Declined Transaction. final DeclinedTransaction.Buildersource(JsonField<DeclinedTransaction.Source> source)This is an object giving more details on the network-level event that caused the Declined Transaction. final DeclinedTransaction.Buildertype(DeclinedTransaction.Type type)A constant representing the object's type. final DeclinedTransaction.Buildertype(JsonField<DeclinedTransaction.Type> type)A constant representing the object's type. final DeclinedTransaction.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final DeclinedTransaction.BuilderputAdditionalProperty(String key, JsonValue value)final DeclinedTransaction.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final DeclinedTransaction.BuilderremoveAdditionalProperty(String key)final DeclinedTransaction.BuilderremoveAllAdditionalProperties(Set<String> keys)final DeclinedTransactionbuild()-
-
Method Detail
-
id
final DeclinedTransaction.Builder id(String id)
The Declined Transaction identifier.
-
id
final DeclinedTransaction.Builder id(JsonField<String> id)
The Declined Transaction identifier.
-
accountId
final DeclinedTransaction.Builder accountId(String accountId)
The identifier for the Account the Declined Transaction belongs to.
-
accountId
final DeclinedTransaction.Builder accountId(JsonField<String> accountId)
The identifier for the Account the Declined Transaction belongs to.
-
amount
final DeclinedTransaction.Builder amount(Long amount)
The Declined Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final DeclinedTransaction.Builder amount(JsonField<Long> amount)
The Declined Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
createdAt
final DeclinedTransaction.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date on which the Transaction occurred.
-
createdAt
final DeclinedTransaction.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date on which the Transaction occurred.
-
currency
final DeclinedTransaction.Builder currency(DeclinedTransaction.Currency currency)
The ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
-
currency
final DeclinedTransaction.Builder currency(JsonField<DeclinedTransaction.Currency> currency)
The ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
-
description
final DeclinedTransaction.Builder description(String description)
This is the description the vendor provides.
-
description
final DeclinedTransaction.Builder description(JsonField<String> description)
This is the description the vendor provides.
-
routeId
final DeclinedTransaction.Builder routeId(String routeId)
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
routeId
final DeclinedTransaction.Builder routeId(Optional<String> routeId)
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
routeId
final DeclinedTransaction.Builder routeId(JsonField<String> routeId)
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
routeType
final DeclinedTransaction.Builder routeType(DeclinedTransaction.RouteType routeType)
The type of the route this Declined Transaction came through.
-
routeType
final DeclinedTransaction.Builder routeType(Optional<DeclinedTransaction.RouteType> routeType)
The type of the route this Declined Transaction came through.
-
routeType
final DeclinedTransaction.Builder routeType(JsonField<DeclinedTransaction.RouteType> routeType)
The type of the route this Declined Transaction came through.
-
source
final DeclinedTransaction.Builder source(DeclinedTransaction.Source source)
This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
source
final DeclinedTransaction.Builder source(JsonField<DeclinedTransaction.Source> source)
This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
type
final DeclinedTransaction.Builder type(DeclinedTransaction.Type type)
A constant representing the object's type. For this resource it will always be
declined_transaction.
-
type
final DeclinedTransaction.Builder type(JsonField<DeclinedTransaction.Type> type)
A constant representing the object's type. For this resource it will always be
declined_transaction.
-
additionalProperties
final DeclinedTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction build()
-
-
-
-