Class DeclinedTransaction.Source
-
- All Implemented Interfaces:
public final class DeclinedTransaction.SourceThis is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.BuilderA builder for Source.
public final classDeclinedTransaction.Source.AchDeclineAn ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.public final classDeclinedTransaction.Source.CardDeclineA Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.public final classDeclinedTransaction.Source.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classDeclinedTransaction.Source.CheckDeclineA Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.public final classDeclinedTransaction.Source.CheckDepositRejectionA Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.public final classDeclinedTransaction.Source.InboundRealTimePaymentsTransferDeclineAn Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.public final classDeclinedTransaction.Source.WireDeclineA Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
Method Summary
-
-
Method Detail
-
achDecline
final Optional<DeclinedTransaction.Source.AchDecline> achDecline()
An ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.
-
cardDecline
final Optional<DeclinedTransaction.Source.CardDecline> cardDecline()
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
category
final DeclinedTransaction.Source.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
checkDecline
final Optional<DeclinedTransaction.Source.CheckDecline> checkDecline()
A Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.
-
checkDepositRejection
final Optional<DeclinedTransaction.Source.CheckDepositRejection> checkDepositRejection()
A Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.
-
inboundRealTimePaymentsTransferDecline
final Optional<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline()
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
_other
final JsonValue _other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
wireDecline
final Optional<DeclinedTransaction.Source.WireDecline> wireDecline()
A Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
_achDecline
final JsonField<DeclinedTransaction.Source.AchDecline> _achDecline()
An ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.
-
_cardDecline
final JsonField<DeclinedTransaction.Source.CardDecline> _cardDecline()
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
_category
final JsonField<DeclinedTransaction.Source.Category> _category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
_checkDecline
final JsonField<DeclinedTransaction.Source.CheckDecline> _checkDecline()
A Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.
-
_checkDepositRejection
final JsonField<DeclinedTransaction.Source.CheckDepositRejection> _checkDepositRejection()
A Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.
-
_inboundRealTimePaymentsTransferDecline
final JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline> _inboundRealTimePaymentsTransferDecline()
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
_wireDecline
final JsonField<DeclinedTransaction.Source.WireDecline> _wireDecline()
A Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DeclinedTransaction.Source validate()
-
toBuilder
final DeclinedTransaction.Source.Builder toBuilder()
-
builder
final static DeclinedTransaction.Source.Builder builder()
-
-
-
-