Class DeclinedTransaction.Source.AchDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.AchDeclineAn ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.AchDecline.BuilderA builder for AchDecline.
public final classDeclinedTransaction.Source.AchDecline.ReasonWhy the ACH transfer was declined.
public final classDeclinedTransaction.Source.AchDecline.TypeA constant representing the object's type. For this resource it will always be
ach_decline.
-
Method Summary
Modifier and Type Method Description final Stringid()The ACH Decline's identifier. final Longamount()The declined amount in USD cents. final StringinboundAchTransferId()The identifier of the Inbound ACH Transfer object associated with this decline. final Optional<String>originatorCompanyDescriptiveDate()The descriptive date of the transfer. final Optional<String>originatorCompanyDiscretionaryData()The additional information included with the transfer. final StringoriginatorCompanyId()The identifier of the company that initiated the transfer. final StringoriginatorCompanyName()The name of the company that initiated the transfer. final DeclinedTransaction.Source.AchDecline.Reasonreason()Why the ACH transfer was declined. final Optional<String>receiverIdNumber()The id of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final StringtraceNumber()The trace number of the transfer. final DeclinedTransaction.Source.AchDecline.Typetype()A constant representing the object's type. final JsonField<String>_id()The ACH Decline's identifier. final JsonField<Long>_amount()The declined amount in USD cents. final JsonField<String>_inboundAchTransferId()The identifier of the Inbound ACH Transfer object associated with this decline. final JsonField<String>_originatorCompanyDescriptiveDate()The descriptive date of the transfer. final JsonField<String>_originatorCompanyDiscretionaryData()The additional information included with the transfer. final JsonField<String>_originatorCompanyId()The identifier of the company that initiated the transfer. final JsonField<String>_originatorCompanyName()The name of the company that initiated the transfer. final JsonField<DeclinedTransaction.Source.AchDecline.Reason>_reason()Why the ACH transfer was declined. final JsonField<String>_receiverIdNumber()The id of the receiver of the transfer. final JsonField<String>_receiverName()The name of the receiver of the transfer. final JsonField<String>_traceNumber()The trace number of the transfer. final JsonField<DeclinedTransaction.Source.AchDecline.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.AchDeclinevalidate()final DeclinedTransaction.Source.AchDecline.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.AchDecline.Builderbuilder()-
-
Method Detail
-
inboundAchTransferId
final String inboundAchTransferId()
The identifier of the Inbound ACH Transfer object associated with this decline.
-
originatorCompanyDescriptiveDate
final Optional<String> originatorCompanyDescriptiveDate()
The descriptive date of the transfer.
-
originatorCompanyDiscretionaryData
final Optional<String> originatorCompanyDiscretionaryData()
The additional information included with the transfer.
-
originatorCompanyId
final String originatorCompanyId()
The identifier of the company that initiated the transfer.
-
originatorCompanyName
final String originatorCompanyName()
The name of the company that initiated the transfer.
-
reason
final DeclinedTransaction.Source.AchDecline.Reason reason()
Why the ACH transfer was declined.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The id of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
traceNumber
final String traceNumber()
The trace number of the transfer.
-
type
final DeclinedTransaction.Source.AchDecline.Type type()
A constant representing the object's type. For this resource it will always be
ach_decline.
-
_inboundAchTransferId
final JsonField<String> _inboundAchTransferId()
The identifier of the Inbound ACH Transfer object associated with this decline.
-
_originatorCompanyDescriptiveDate
final JsonField<String> _originatorCompanyDescriptiveDate()
The descriptive date of the transfer.
-
_originatorCompanyDiscretionaryData
final JsonField<String> _originatorCompanyDiscretionaryData()
The additional information included with the transfer.
-
_originatorCompanyId
final JsonField<String> _originatorCompanyId()
The identifier of the company that initiated the transfer.
-
_originatorCompanyName
final JsonField<String> _originatorCompanyName()
The name of the company that initiated the transfer.
-
_reason
final JsonField<DeclinedTransaction.Source.AchDecline.Reason> _reason()
Why the ACH transfer was declined.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
The id of the receiver of the transfer.
-
_receiverName
final JsonField<String> _receiverName()
The name of the receiver of the transfer.
-
_traceNumber
final JsonField<String> _traceNumber()
The trace number of the transfer.
-
_type
final JsonField<DeclinedTransaction.Source.AchDecline.Type> _type()
A constant representing the object's type. For this resource it will always be
ach_decline.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DeclinedTransaction.Source.AchDecline validate()
-
toBuilder
final DeclinedTransaction.Source.AchDecline.Builder toBuilder()
-
builder
final static DeclinedTransaction.Source.AchDecline.Builder builder()
-
-
-
-