Class DeclinedTransaction.Source.AchDecline.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.AchDecline.BuilderA builder for AchDecline.
-
-
Method Summary
-
-
Method Detail
-
id
final DeclinedTransaction.Source.AchDecline.Builder id(String id)
The ACH Decline's identifier.
-
id
final DeclinedTransaction.Source.AchDecline.Builder id(JsonField<String> id)
The ACH Decline's identifier.
-
amount
final DeclinedTransaction.Source.AchDecline.Builder amount(Long amount)
The declined amount in USD cents.
-
amount
final DeclinedTransaction.Source.AchDecline.Builder amount(JsonField<Long> amount)
The declined amount in USD cents.
-
inboundAchTransferId
final DeclinedTransaction.Source.AchDecline.Builder inboundAchTransferId(String inboundAchTransferId)
The identifier of the Inbound ACH Transfer object associated with this decline.
-
inboundAchTransferId
final DeclinedTransaction.Source.AchDecline.Builder inboundAchTransferId(JsonField<String> inboundAchTransferId)
The identifier of the Inbound ACH Transfer object associated with this decline.
-
originatorCompanyDescriptiveDate
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDescriptiveDate
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDescriptiveDate
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDiscretionaryData
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyDiscretionaryData
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyDiscretionaryData
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyId
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyId(String originatorCompanyId)
The identifier of the company that initiated the transfer.
-
originatorCompanyId
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyId(JsonField<String> originatorCompanyId)
The identifier of the company that initiated the transfer.
-
originatorCompanyName
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyName(String originatorCompanyName)
The name of the company that initiated the transfer.
-
originatorCompanyName
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyName(JsonField<String> originatorCompanyName)
The name of the company that initiated the transfer.
-
reason
final DeclinedTransaction.Source.AchDecline.Builder reason(DeclinedTransaction.Source.AchDecline.Reason reason)
Why the ACH transfer was declined.
-
reason
final DeclinedTransaction.Source.AchDecline.Builder reason(JsonField<DeclinedTransaction.Source.AchDecline.Reason> reason)
Why the ACH transfer was declined.
-
receiverIdNumber
final DeclinedTransaction.Source.AchDecline.Builder receiverIdNumber(String receiverIdNumber)
The id of the receiver of the transfer.
-
receiverIdNumber
final DeclinedTransaction.Source.AchDecline.Builder receiverIdNumber(Optional<String> receiverIdNumber)
The id of the receiver of the transfer.
-
receiverIdNumber
final DeclinedTransaction.Source.AchDecline.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
The id of the receiver of the transfer.
-
receiverName
final DeclinedTransaction.Source.AchDecline.Builder receiverName(String receiverName)
The name of the receiver of the transfer.
-
receiverName
final DeclinedTransaction.Source.AchDecline.Builder receiverName(Optional<String> receiverName)
The name of the receiver of the transfer.
-
receiverName
final DeclinedTransaction.Source.AchDecline.Builder receiverName(JsonField<String> receiverName)
The name of the receiver of the transfer.
-
traceNumber
final DeclinedTransaction.Source.AchDecline.Builder traceNumber(String traceNumber)
The trace number of the transfer.
-
traceNumber
final DeclinedTransaction.Source.AchDecline.Builder traceNumber(JsonField<String> traceNumber)
The trace number of the transfer.
-
type
final DeclinedTransaction.Source.AchDecline.Builder type(DeclinedTransaction.Source.AchDecline.Type type)
A constant representing the object's type. For this resource it will always be
ach_decline.
-
type
final DeclinedTransaction.Source.AchDecline.Builder type(JsonField<DeclinedTransaction.Source.AchDecline.Type> type)
A constant representing the object's type. For this resource it will always be
ach_decline.
-
additionalProperties
final DeclinedTransaction.Source.AchDecline.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.AchDecline.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.AchDecline.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.AchDecline.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.AchDecline.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source.AchDecline build()
-
-
-
-