Class DeclinedTransaction.Source.CardDecline.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CardDecline.BuilderA builder for CardDecline.
-
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.CardDecline.Builderid(String id)The Card Decline identifier. final DeclinedTransaction.Source.CardDecline.Builderid(JsonField<String> id)The Card Decline identifier. final DeclinedTransaction.Source.CardDecline.Builderactioner(DeclinedTransaction.Source.CardDecline.Actioner actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final DeclinedTransaction.Source.CardDecline.Builderactioner(JsonField<DeclinedTransaction.Source.CardDecline.Actioner> actioner)Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final DeclinedTransaction.Source.CardDecline.Builderamount(Long amount)The declined amount in the minor unit of the destination account currency. final DeclinedTransaction.Source.CardDecline.Builderamount(JsonField<Long> amount)The declined amount in the minor unit of the destination account currency. final DeclinedTransaction.Source.CardDecline.BuildercardPaymentId(String cardPaymentId)The ID of the Card Payment this transaction belongs to. final DeclinedTransaction.Source.CardDecline.BuildercardPaymentId(JsonField<String> cardPaymentId)The ID of the Card Payment this transaction belongs to. final DeclinedTransaction.Source.CardDecline.Buildercurrency(DeclinedTransaction.Source.CardDecline.Currency currency)The ISO 4217 code for the destination account currency. final DeclinedTransaction.Source.CardDecline.Buildercurrency(JsonField<DeclinedTransaction.Source.CardDecline.Currency> currency)The ISO 4217 code for the destination account currency. final DeclinedTransaction.Source.CardDecline.BuilderdeclinedTransactionId(String declinedTransactionId)The identifier of the declined transaction created for this Card Decline. final DeclinedTransaction.Source.CardDecline.BuilderdeclinedTransactionId(JsonField<String> declinedTransactionId)The identifier of the declined transaction created for this Card Decline. final DeclinedTransaction.Source.CardDecline.BuilderdigitalWalletTokenId(String digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final DeclinedTransaction.Source.CardDecline.BuilderdigitalWalletTokenId(Optional<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final DeclinedTransaction.Source.CardDecline.BuilderdigitalWalletTokenId(JsonField<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final DeclinedTransaction.Source.CardDecline.Builderdirection(DeclinedTransaction.Source.CardDecline.Direction direction)The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final DeclinedTransaction.Source.CardDecline.Builderdirection(JsonField<DeclinedTransaction.Source.CardDecline.Direction> direction)The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final DeclinedTransaction.Source.CardDecline.BuildermerchantAcceptorId(String merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuildermerchantAcceptorId(JsonField<String> merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuildermerchantCategoryCode(String merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuildermerchantCategoryCode(JsonField<String> merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuildermerchantCity(String merchantCity)The city the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantCity(Optional<String> merchantCity)The city the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantCity(JsonField<String> merchantCity)The city the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantCountry(String merchantCountry)The country the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantCountry(JsonField<String> merchantCountry)The country the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantDescriptor(String merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuildermerchantDescriptor(JsonField<String> merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuildermerchantPostalCode(String merchantPostalCode)The merchant's postal code. final DeclinedTransaction.Source.CardDecline.BuildermerchantPostalCode(Optional<String> merchantPostalCode)The merchant's postal code. final DeclinedTransaction.Source.CardDecline.BuildermerchantPostalCode(JsonField<String> merchantPostalCode)The merchant's postal code. final DeclinedTransaction.Source.CardDecline.BuildermerchantState(String merchantState)The state the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantState(Optional<String> merchantState)The state the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildermerchantState(JsonField<String> merchantState)The state the merchant resides in. final DeclinedTransaction.Source.CardDecline.BuildernetworkDetails(DeclinedTransaction.Source.CardDecline.NetworkDetails networkDetails)Fields specific to the network.final DeclinedTransaction.Source.CardDecline.BuildernetworkDetails(JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails> networkDetails)Fields specific to the network.final DeclinedTransaction.Source.CardDecline.BuildernetworkIdentifiers(DeclinedTransaction.Source.CardDecline.NetworkIdentifiers networkIdentifiers)Network-specific identifiers for a specific request or transaction. final DeclinedTransaction.Source.CardDecline.BuildernetworkIdentifiers(JsonField<DeclinedTransaction.Source.CardDecline.NetworkIdentifiers> networkIdentifiers)Network-specific identifiers for a specific request or transaction. final DeclinedTransaction.Source.CardDecline.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final DeclinedTransaction.Source.CardDecline.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final DeclinedTransaction.Source.CardDecline.BuildernetworkRiskScore(Optional<Long> networkRiskScore)The risk score generated by the card network. final DeclinedTransaction.Source.CardDecline.BuildernetworkRiskScore(JsonField<Long> networkRiskScore)The risk score generated by the card network. final DeclinedTransaction.Source.CardDecline.BuilderphysicalCardId(String physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final DeclinedTransaction.Source.CardDecline.BuilderphysicalCardId(Optional<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final DeclinedTransaction.Source.CardDecline.BuilderphysicalCardId(JsonField<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final DeclinedTransaction.Source.CardDecline.BuilderpresentmentAmount(Long presentmentAmount)The declined amount in the minor unit of the transaction's presentment currency. final DeclinedTransaction.Source.CardDecline.BuilderpresentmentAmount(JsonField<Long> presentmentAmount)The declined amount in the minor unit of the transaction's presentment currency. final DeclinedTransaction.Source.CardDecline.BuilderpresentmentCurrency(String presentmentCurrency)The ISO 4217 code for the transaction's presentment currency. final DeclinedTransaction.Source.CardDecline.BuilderpresentmentCurrency(JsonField<String> presentmentCurrency)The ISO 4217 code for the transaction's presentment currency. final DeclinedTransaction.Source.CardDecline.BuilderprocessingCategory(DeclinedTransaction.Source.CardDecline.ProcessingCategory processingCategory)The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final DeclinedTransaction.Source.CardDecline.BuilderprocessingCategory(JsonField<DeclinedTransaction.Source.CardDecline.ProcessingCategory> processingCategory)The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final DeclinedTransaction.Source.CardDecline.BuilderrealTimeDecisionId(String realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final DeclinedTransaction.Source.CardDecline.BuilderrealTimeDecisionId(Optional<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final DeclinedTransaction.Source.CardDecline.BuilderrealTimeDecisionId(JsonField<String> realTimeDecisionId)The identifier of the Real-Time Decision sent to approve or decline this transaction. final DeclinedTransaction.Source.CardDecline.BuilderrealTimeDecisionReason(DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason realTimeDecisionReason)This is present if a specific decline reason was given in the real-time decision. final DeclinedTransaction.Source.CardDecline.BuilderrealTimeDecisionReason(Optional<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason> realTimeDecisionReason)This is present if a specific decline reason was given in the real-time decision. final DeclinedTransaction.Source.CardDecline.BuilderrealTimeDecisionReason(JsonField<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason> realTimeDecisionReason)This is present if a specific decline reason was given in the real-time decision. final DeclinedTransaction.Source.CardDecline.Builderreason(DeclinedTransaction.Source.CardDecline.Reason reason)Why the transaction was declined. final DeclinedTransaction.Source.CardDecline.Builderreason(JsonField<DeclinedTransaction.Source.CardDecline.Reason> reason)Why the transaction was declined. final DeclinedTransaction.Source.CardDecline.BuilderterminalId(String terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuilderterminalId(Optional<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final DeclinedTransaction.Source.CardDecline.BuilderterminalId(JsonField<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final DeclinedTransaction.Source.CardDecline.Builderverification(DeclinedTransaction.Source.CardDecline.Verification verification)Fields related to verification of cardholder-provided values. final DeclinedTransaction.Source.CardDecline.Builderverification(JsonField<DeclinedTransaction.Source.CardDecline.Verification> verification)Fields related to verification of cardholder-provided values. final DeclinedTransaction.Source.CardDecline.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final DeclinedTransaction.Source.CardDecline.BuilderputAdditionalProperty(String key, JsonValue value)final DeclinedTransaction.Source.CardDecline.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final DeclinedTransaction.Source.CardDecline.BuilderremoveAdditionalProperty(String key)final DeclinedTransaction.Source.CardDecline.BuilderremoveAllAdditionalProperties(Set<String> keys)final DeclinedTransaction.Source.CardDeclinebuild()-
-
Method Detail
-
id
final DeclinedTransaction.Source.CardDecline.Builder id(String id)
The Card Decline identifier.
-
id
final DeclinedTransaction.Source.CardDecline.Builder id(JsonField<String> id)
The Card Decline identifier.
-
actioner
final DeclinedTransaction.Source.CardDecline.Builder actioner(DeclinedTransaction.Source.CardDecline.Actioner actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final DeclinedTransaction.Source.CardDecline.Builder actioner(JsonField<DeclinedTransaction.Source.CardDecline.Actioner> actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
amount
final DeclinedTransaction.Source.CardDecline.Builder amount(Long amount)
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
amount
final DeclinedTransaction.Source.CardDecline.Builder amount(JsonField<Long> amount)
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
cardPaymentId
final DeclinedTransaction.Source.CardDecline.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final DeclinedTransaction.Source.CardDecline.Builder cardPaymentId(JsonField<String> cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
currency
final DeclinedTransaction.Source.CardDecline.Builder currency(DeclinedTransaction.Source.CardDecline.Currency currency)
The ISO 4217 code for the destination account currency.
-
currency
final DeclinedTransaction.Source.CardDecline.Builder currency(JsonField<DeclinedTransaction.Source.CardDecline.Currency> currency)
The ISO 4217 code for the destination account currency.
-
declinedTransactionId
final DeclinedTransaction.Source.CardDecline.Builder declinedTransactionId(String declinedTransactionId)
The identifier of the declined transaction created for this Card Decline.
-
declinedTransactionId
final DeclinedTransaction.Source.CardDecline.Builder declinedTransactionId(JsonField<String> declinedTransactionId)
The identifier of the declined transaction created for this Card Decline.
-
digitalWalletTokenId
final DeclinedTransaction.Source.CardDecline.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final DeclinedTransaction.Source.CardDecline.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final DeclinedTransaction.Source.CardDecline.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final DeclinedTransaction.Source.CardDecline.Builder direction(DeclinedTransaction.Source.CardDecline.Direction direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
direction
final DeclinedTransaction.Source.CardDecline.Builder direction(JsonField<DeclinedTransaction.Source.CardDecline.Direction> direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
merchantAcceptorId
final DeclinedTransaction.Source.CardDecline.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final DeclinedTransaction.Source.CardDecline.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final DeclinedTransaction.Source.CardDecline.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final DeclinedTransaction.Source.CardDecline.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final DeclinedTransaction.Source.CardDecline.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final DeclinedTransaction.Source.CardDecline.Builder merchantCity(Optional<String> merchantCity)
The city the merchant resides in.
-
merchantCity
final DeclinedTransaction.Source.CardDecline.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final DeclinedTransaction.Source.CardDecline.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final DeclinedTransaction.Source.CardDecline.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantDescriptor
final DeclinedTransaction.Source.CardDecline.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final DeclinedTransaction.Source.CardDecline.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final DeclinedTransaction.Source.CardDecline.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final DeclinedTransaction.Source.CardDecline.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final DeclinedTransaction.Source.CardDecline.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final DeclinedTransaction.Source.CardDecline.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final DeclinedTransaction.Source.CardDecline.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final DeclinedTransaction.Source.CardDecline.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkDetails
final DeclinedTransaction.Source.CardDecline.Builder networkDetails(DeclinedTransaction.Source.CardDecline.NetworkDetails networkDetails)
Fields specific to the
network.
-
networkDetails
final DeclinedTransaction.Source.CardDecline.Builder networkDetails(JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails> networkDetails)
Fields specific to the
network.
-
networkIdentifiers
final DeclinedTransaction.Source.CardDecline.Builder networkIdentifiers(DeclinedTransaction.Source.CardDecline.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final DeclinedTransaction.Source.CardDecline.Builder networkIdentifiers(JsonField<DeclinedTransaction.Source.CardDecline.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final DeclinedTransaction.Source.CardDecline.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final DeclinedTransaction.Source.CardDecline.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final DeclinedTransaction.Source.CardDecline.Builder networkRiskScore(Optional<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final DeclinedTransaction.Source.CardDecline.Builder networkRiskScore(JsonField<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final DeclinedTransaction.Source.CardDecline.Builder physicalCardId(String physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final DeclinedTransaction.Source.CardDecline.Builder physicalCardId(Optional<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final DeclinedTransaction.Source.CardDecline.Builder physicalCardId(JsonField<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final DeclinedTransaction.Source.CardDecline.Builder presentmentAmount(Long presentmentAmount)
The declined amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final DeclinedTransaction.Source.CardDecline.Builder presentmentAmount(JsonField<Long> presentmentAmount)
The declined amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final DeclinedTransaction.Source.CardDecline.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final DeclinedTransaction.Source.CardDecline.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
processingCategory
final DeclinedTransaction.Source.CardDecline.Builder processingCategory(DeclinedTransaction.Source.CardDecline.ProcessingCategory processingCategory)
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
processingCategory
final DeclinedTransaction.Source.CardDecline.Builder processingCategory(JsonField<DeclinedTransaction.Source.CardDecline.ProcessingCategory> processingCategory)
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
realTimeDecisionId
final DeclinedTransaction.Source.CardDecline.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final DeclinedTransaction.Source.CardDecline.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final DeclinedTransaction.Source.CardDecline.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionReason
final DeclinedTransaction.Source.CardDecline.Builder realTimeDecisionReason(DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason realTimeDecisionReason)
This is present if a specific decline reason was given in the real-time decision.
-
realTimeDecisionReason
final DeclinedTransaction.Source.CardDecline.Builder realTimeDecisionReason(Optional<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason> realTimeDecisionReason)
This is present if a specific decline reason was given in the real-time decision.
-
realTimeDecisionReason
final DeclinedTransaction.Source.CardDecline.Builder realTimeDecisionReason(JsonField<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason> realTimeDecisionReason)
This is present if a specific decline reason was given in the real-time decision.
-
reason
final DeclinedTransaction.Source.CardDecline.Builder reason(DeclinedTransaction.Source.CardDecline.Reason reason)
Why the transaction was declined.
-
reason
final DeclinedTransaction.Source.CardDecline.Builder reason(JsonField<DeclinedTransaction.Source.CardDecline.Reason> reason)
Why the transaction was declined.
-
terminalId
final DeclinedTransaction.Source.CardDecline.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final DeclinedTransaction.Source.CardDecline.Builder terminalId(Optional<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final DeclinedTransaction.Source.CardDecline.Builder terminalId(JsonField<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
verification
final DeclinedTransaction.Source.CardDecline.Builder verification(DeclinedTransaction.Source.CardDecline.Verification verification)
Fields related to verification of cardholder-provided values.
-
verification
final DeclinedTransaction.Source.CardDecline.Builder verification(JsonField<DeclinedTransaction.Source.CardDecline.Verification> verification)
Fields related to verification of cardholder-provided values.
-
additionalProperties
final DeclinedTransaction.Source.CardDecline.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.CardDecline.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.CardDecline.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.CardDecline.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.CardDecline.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source.CardDecline build()
-
-
-
-