Class DeclinedTransaction.Source.CheckDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDeclineA Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.CheckDecline.BuilderA builder for CheckDecline.
public final classDeclinedTransaction.Source.CheckDecline.ReasonWhy the check was declined.
-
Method Summary
Modifier and Type Method Description final Longamount()The declined amount in USD cents. final Optional<String>auxiliaryOnUs()A computer-readable number printed on the MICR line of business checks, usually the check number. final Optional<String>backImageFileId()The identifier of the API File object containing an image of the back of the declined check. final Optional<String>checkTransferId()The identifier of the Check Transfer object associated with this decline. final Optional<String>frontImageFileId()The identifier of the API File object containing an image of the front of the declined check. final Optional<String>inboundCheckDepositId()The identifier of the Inbound Check Deposit object associated with this decline. final DeclinedTransaction.Source.CheckDecline.Reasonreason()Why the check was declined. final JsonField<Long>_amount()The declined amount in USD cents. final JsonField<String>_auxiliaryOnUs()A computer-readable number printed on the MICR line of business checks, usually the check number. final JsonField<String>_backImageFileId()The identifier of the API File object containing an image of the back of the declined check. final JsonField<String>_checkTransferId()The identifier of the Check Transfer object associated with this decline. final JsonField<String>_frontImageFileId()The identifier of the API File object containing an image of the front of the declined check. final JsonField<String>_inboundCheckDepositId()The identifier of the Inbound Check Deposit object associated with this decline. final JsonField<DeclinedTransaction.Source.CheckDecline.Reason>_reason()Why the check was declined. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.CheckDeclinevalidate()final DeclinedTransaction.Source.CheckDecline.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.CheckDecline.Builderbuilder()-
-
Method Detail
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the API File object containing an image of the back of the declined check.
-
checkTransferId
final Optional<String> checkTransferId()
The identifier of the Check Transfer object associated with this decline.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the API File object containing an image of the front of the declined check.
-
inboundCheckDepositId
final Optional<String> inboundCheckDepositId()
The identifier of the Inbound Check Deposit object associated with this decline.
-
reason
final DeclinedTransaction.Source.CheckDecline.Reason reason()
Why the check was declined.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
_backImageFileId
final JsonField<String> _backImageFileId()
The identifier of the API File object containing an image of the back of the declined check.
-
_checkTransferId
final JsonField<String> _checkTransferId()
The identifier of the Check Transfer object associated with this decline.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the API File object containing an image of the front of the declined check.
-
_inboundCheckDepositId
final JsonField<String> _inboundCheckDepositId()
The identifier of the Inbound Check Deposit object associated with this decline.
-
_reason
final JsonField<DeclinedTransaction.Source.CheckDecline.Reason> _reason()
Why the check was declined.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DeclinedTransaction.Source.CheckDecline validate()
-
toBuilder
final DeclinedTransaction.Source.CheckDecline.Builder toBuilder()
-
builder
final static DeclinedTransaction.Source.CheckDecline.Builder builder()
-
-
-
-