Class DeclinedTransaction.Source.CheckDecline.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDecline.BuilderA builder for CheckDecline.
-
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.CheckDecline.Builderamount(Long amount)The declined amount in USD cents. final DeclinedTransaction.Source.CheckDecline.Builderamount(JsonField<Long> amount)The declined amount in USD cents. final DeclinedTransaction.Source.CheckDecline.BuilderauxiliaryOnUs(String auxiliaryOnUs)A computer-readable number printed on the MICR line of business checks, usually the check number. final DeclinedTransaction.Source.CheckDecline.BuilderauxiliaryOnUs(Optional<String> auxiliaryOnUs)A computer-readable number printed on the MICR line of business checks, usually the check number. final DeclinedTransaction.Source.CheckDecline.BuilderauxiliaryOnUs(JsonField<String> auxiliaryOnUs)A computer-readable number printed on the MICR line of business checks, usually the check number. final DeclinedTransaction.Source.CheckDecline.BuilderbackImageFileId(String backImageFileId)The identifier of the API File object containing an image of the back of the declined check. final DeclinedTransaction.Source.CheckDecline.BuilderbackImageFileId(Optional<String> backImageFileId)The identifier of the API File object containing an image of the back of the declined check. final DeclinedTransaction.Source.CheckDecline.BuilderbackImageFileId(JsonField<String> backImageFileId)The identifier of the API File object containing an image of the back of the declined check. final DeclinedTransaction.Source.CheckDecline.BuildercheckTransferId(String checkTransferId)The identifier of the Check Transfer object associated with this decline. final DeclinedTransaction.Source.CheckDecline.BuildercheckTransferId(Optional<String> checkTransferId)The identifier of the Check Transfer object associated with this decline. final DeclinedTransaction.Source.CheckDecline.BuildercheckTransferId(JsonField<String> checkTransferId)The identifier of the Check Transfer object associated with this decline. final DeclinedTransaction.Source.CheckDecline.BuilderfrontImageFileId(String frontImageFileId)The identifier of the API File object containing an image of the front of the declined check. final DeclinedTransaction.Source.CheckDecline.BuilderfrontImageFileId(Optional<String> frontImageFileId)The identifier of the API File object containing an image of the front of the declined check. final DeclinedTransaction.Source.CheckDecline.BuilderfrontImageFileId(JsonField<String> frontImageFileId)The identifier of the API File object containing an image of the front of the declined check. final DeclinedTransaction.Source.CheckDecline.BuilderinboundCheckDepositId(String inboundCheckDepositId)The identifier of the Inbound Check Deposit object associated with this decline. final DeclinedTransaction.Source.CheckDecline.BuilderinboundCheckDepositId(Optional<String> inboundCheckDepositId)The identifier of the Inbound Check Deposit object associated with this decline. final DeclinedTransaction.Source.CheckDecline.BuilderinboundCheckDepositId(JsonField<String> inboundCheckDepositId)The identifier of the Inbound Check Deposit object associated with this decline. final DeclinedTransaction.Source.CheckDecline.Builderreason(DeclinedTransaction.Source.CheckDecline.Reason reason)Why the check was declined. final DeclinedTransaction.Source.CheckDecline.Builderreason(JsonField<DeclinedTransaction.Source.CheckDecline.Reason> reason)Why the check was declined. final DeclinedTransaction.Source.CheckDecline.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final DeclinedTransaction.Source.CheckDecline.BuilderputAdditionalProperty(String key, JsonValue value)final DeclinedTransaction.Source.CheckDecline.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final DeclinedTransaction.Source.CheckDecline.BuilderremoveAdditionalProperty(String key)final DeclinedTransaction.Source.CheckDecline.BuilderremoveAllAdditionalProperties(Set<String> keys)final DeclinedTransaction.Source.CheckDeclinebuild()-
-
Method Detail
-
amount
final DeclinedTransaction.Source.CheckDecline.Builder amount(Long amount)
The declined amount in USD cents.
-
amount
final DeclinedTransaction.Source.CheckDecline.Builder amount(JsonField<Long> amount)
The declined amount in USD cents.
-
auxiliaryOnUs
final DeclinedTransaction.Source.CheckDecline.Builder auxiliaryOnUs(String auxiliaryOnUs)
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
auxiliaryOnUs
final DeclinedTransaction.Source.CheckDecline.Builder auxiliaryOnUs(Optional<String> auxiliaryOnUs)
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
auxiliaryOnUs
final DeclinedTransaction.Source.CheckDecline.Builder auxiliaryOnUs(JsonField<String> auxiliaryOnUs)
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
backImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder backImageFileId(String backImageFileId)
The identifier of the API File object containing an image of the back of the declined check.
-
backImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder backImageFileId(Optional<String> backImageFileId)
The identifier of the API File object containing an image of the back of the declined check.
-
backImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder backImageFileId(JsonField<String> backImageFileId)
The identifier of the API File object containing an image of the back of the declined check.
-
checkTransferId
final DeclinedTransaction.Source.CheckDecline.Builder checkTransferId(String checkTransferId)
The identifier of the Check Transfer object associated with this decline.
-
checkTransferId
final DeclinedTransaction.Source.CheckDecline.Builder checkTransferId(Optional<String> checkTransferId)
The identifier of the Check Transfer object associated with this decline.
-
checkTransferId
final DeclinedTransaction.Source.CheckDecline.Builder checkTransferId(JsonField<String> checkTransferId)
The identifier of the Check Transfer object associated with this decline.
-
frontImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder frontImageFileId(String frontImageFileId)
The identifier of the API File object containing an image of the front of the declined check.
-
frontImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder frontImageFileId(Optional<String> frontImageFileId)
The identifier of the API File object containing an image of the front of the declined check.
-
frontImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder frontImageFileId(JsonField<String> frontImageFileId)
The identifier of the API File object containing an image of the front of the declined check.
-
inboundCheckDepositId
final DeclinedTransaction.Source.CheckDecline.Builder inboundCheckDepositId(String inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this decline.
-
inboundCheckDepositId
final DeclinedTransaction.Source.CheckDecline.Builder inboundCheckDepositId(Optional<String> inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this decline.
-
inboundCheckDepositId
final DeclinedTransaction.Source.CheckDecline.Builder inboundCheckDepositId(JsonField<String> inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this decline.
-
reason
final DeclinedTransaction.Source.CheckDecline.Builder reason(DeclinedTransaction.Source.CheckDecline.Reason reason)
Why the check was declined.
-
reason
final DeclinedTransaction.Source.CheckDecline.Builder reason(JsonField<DeclinedTransaction.Source.CheckDecline.Reason> reason)
Why the check was declined.
-
additionalProperties
final DeclinedTransaction.Source.CheckDecline.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.CheckDecline.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.CheckDecline.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.CheckDecline.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.CheckDecline.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source.CheckDecline build()
-
-
-
-