Class DeclinedTransaction.Source.CheckDepositRejection
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDepositRejectionA Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.CheckDepositRejection.BuilderA builder for CheckDepositRejection.
public final classDeclinedTransaction.Source.CheckDepositRejection.CurrencyThe ISO 4217 code for the check's currency.
public final classDeclinedTransaction.Source.CheckDepositRejection.ReasonWhy the check deposit was rejected.
-
Method Summary
Modifier and Type Method Description final Longamount()The rejected amount in the minor unit of check's currency. final StringcheckDepositId()The identifier of the Check Deposit that was rejected. final DeclinedTransaction.Source.CheckDepositRejection.Currencycurrency()The ISO 4217 code for the check's currency. final StringdeclinedTransactionId()The identifier of the associated declined transaction. final DeclinedTransaction.Source.CheckDepositRejection.Reasonreason()Why the check deposit was rejected. final OffsetDateTimerejectedAt()The ISO 8601 date and time at which the check deposit was rejected. final JsonField<Long>_amount()The rejected amount in the minor unit of check's currency. final JsonField<String>_checkDepositId()The identifier of the Check Deposit that was rejected. final JsonField<DeclinedTransaction.Source.CheckDepositRejection.Currency>_currency()The ISO 4217 code for the check's currency. final JsonField<String>_declinedTransactionId()The identifier of the associated declined transaction. final JsonField<DeclinedTransaction.Source.CheckDepositRejection.Reason>_reason()Why the check deposit was rejected. final JsonField<OffsetDateTime>_rejectedAt()The ISO 8601 date and time at which the check deposit was rejected. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.CheckDepositRejectionvalidate()final DeclinedTransaction.Source.CheckDepositRejection.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.CheckDepositRejection.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
checkDepositId
final String checkDepositId()
The identifier of the Check Deposit that was rejected.
-
currency
final DeclinedTransaction.Source.CheckDepositRejection.Currency currency()
The ISO 4217 code for the check's currency.
-
declinedTransactionId
final String declinedTransactionId()
The identifier of the associated declined transaction.
-
reason
final DeclinedTransaction.Source.CheckDepositRejection.Reason reason()
Why the check deposit was rejected.
-
rejectedAt
final OffsetDateTime rejectedAt()
The ISO 8601 date and time at which the check deposit was rejected.
-
_amount
final JsonField<Long> _amount()
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
_checkDepositId
final JsonField<String> _checkDepositId()
The identifier of the Check Deposit that was rejected.
-
_currency
final JsonField<DeclinedTransaction.Source.CheckDepositRejection.Currency> _currency()
The ISO 4217 code for the check's currency.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
The identifier of the associated declined transaction.
-
_reason
final JsonField<DeclinedTransaction.Source.CheckDepositRejection.Reason> _reason()
Why the check deposit was rejected.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
The ISO 8601 date and time at which the check deposit was rejected.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DeclinedTransaction.Source.CheckDepositRejection validate()
-
toBuilder
final DeclinedTransaction.Source.CheckDepositRejection.Builder toBuilder()
-
builder
final static DeclinedTransaction.Source.CheckDepositRejection.Builder builder()
-
-
-
-