Class DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.InboundRealTimePaymentsTransferDeclineAn Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.BuilderA builder for InboundRealTimePaymentsTransferDecline.
public final classDeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.CurrencyThe ISO 4217 code of the declined transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
public final classDeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.ReasonWhy the transfer was declined.
-
Method Summary
Modifier and Type Method Description final Longamount()The declined amount in the minor unit of the destination account currency. final StringcreditorName()The name the sender of the transfer specified as the recipient of the transfer. final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Currencycurrency()The ISO 4217 code of the declined transfer's currency. final StringdebtorAccountNumber()The account number of the account that sent the transfer. final StringdebtorName()The name provided by the sender of the transfer. final StringdebtorRoutingNumber()The routing number of the account that sent the transfer. final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Reasonreason()Why the transfer was declined. final Optional<String>remittanceInformation()Additional information included with the transfer. final StringtransactionIdentification()The Real-Time Payments network identification of the declined transfer. final StringtransferId()The identifier of the Real-Time Payments Transfer that led to this Transaction. final JsonField<Long>_amount()The declined amount in the minor unit of the destination account currency. final JsonField<String>_creditorName()The name the sender of the transfer specified as the recipient of the transfer. final JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Currency>_currency()The ISO 4217 code of the declined transfer's currency. final JsonField<String>_debtorAccountNumber()The account number of the account that sent the transfer. final JsonField<String>_debtorName()The name provided by the sender of the transfer. final JsonField<String>_debtorRoutingNumber()The routing number of the account that sent the transfer. final JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Reason>_reason()Why the transfer was declined. final JsonField<String>_remittanceInformation()Additional information included with the transfer. final JsonField<String>_transactionIdentification()The Real-Time Payments network identification of the declined transfer. final JsonField<String>_transferId()The identifier of the Real-Time Payments Transfer that led to this Transaction. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDeclinevalidate()final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
creditorName
final String creditorName()
The name the sender of the transfer specified as the recipient of the transfer.
-
currency
final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Currency currency()
The ISO 4217 code of the declined transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
debtorAccountNumber
final String debtorAccountNumber()
The account number of the account that sent the transfer.
-
debtorName
final String debtorName()
The name provided by the sender of the transfer.
-
debtorRoutingNumber
final String debtorRoutingNumber()
The routing number of the account that sent the transfer.
-
reason
final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Reason reason()
Why the transfer was declined.
-
remittanceInformation
final Optional<String> remittanceInformation()
Additional information included with the transfer.
-
transactionIdentification
final String transactionIdentification()
The Real-Time Payments network identification of the declined transfer.
-
transferId
final String transferId()
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
_amount
final JsonField<Long> _amount()
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
_creditorName
final JsonField<String> _creditorName()
The name the sender of the transfer specified as the recipient of the transfer.
-
_currency
final JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Currency> _currency()
The ISO 4217 code of the declined transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
The account number of the account that sent the transfer.
-
_debtorName
final JsonField<String> _debtorName()
The name provided by the sender of the transfer.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
The routing number of the account that sent the transfer.
-
_reason
final JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Reason> _reason()
Why the transfer was declined.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Additional information included with the transfer.
-
_transactionIdentification
final JsonField<String> _transactionIdentification()
The Real-Time Payments network identification of the declined transfer.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Builder toBuilder()
-
builder
final static DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline.Builder builder()
-
-
-
-