Class DigitalCardProfile
-
- All Implemented Interfaces:
public final class DigitalCardProfileThis contains artwork and metadata relating to a Card's appearance in digital wallet apps like Apple Pay and Google Pay. For more information, see our guide on digital card artwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfile.BuilderA builder for DigitalCardProfile.
public final classDigitalCardProfile.StatusThe status of the Card Profile.
public final classDigitalCardProfile.TextColorThe Card's text color, specified as an RGB triple.
public final classDigitalCardProfile.TypeA constant representing the object's type. For this resource it will always be
digital_card_profile.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Profile identifier. final StringappIconFileId()The identifier of the File containing the card's icon image. final StringbackgroundImageFileId()The identifier of the File containing the card's front image. final StringcardDescription()A user-facing description for the card itself. final Optional<String>contactEmail()An email address the user can contact to receive support for their card. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>contactWebsite()A website the user can visit to view and receive support for their card. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Card Dispute was created. final Stringdescription()A description you can use to identify the Card Profile. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringissuerName()A user-facing description for whoever is issuing the card. final DigitalCardProfile.Statusstatus()The status of the Card Profile. final DigitalCardProfile.TextColortextColor()The Card's text color, specified as an RGB triple. final DigitalCardProfile.Typetype()A constant representing the object's type. final JsonField<String>_id()The Card Profile identifier. final JsonField<String>_appIconFileId()The identifier of the File containing the card's icon image. final JsonField<String>_backgroundImageFileId()The identifier of the File containing the card's front image. final JsonField<String>_cardDescription()A user-facing description for the card itself. final JsonField<String>_contactEmail()An email address the user can contact to receive support for their card. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_contactWebsite()A website the user can visit to view and receive support for their card. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the Card Dispute was created. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_issuerName()A user-facing description for whoever is issuing the card. final JsonField<DigitalCardProfile.Status>_status()The status of the Card Profile. final JsonField<DigitalCardProfile.TextColor>_textColor()The Card's text color, specified as an RGB triple. final JsonField<DigitalCardProfile.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final DigitalCardProfilevalidate()final DigitalCardProfile.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfile.Builderbuilder()-
-
Method Detail
-
appIconFileId
final String appIconFileId()
The identifier of the File containing the card's icon image.
-
backgroundImageFileId
final String backgroundImageFileId()
The identifier of the File containing the card's front image.
-
cardDescription
final String cardDescription()
A user-facing description for the card itself.
-
contactEmail
final Optional<String> contactEmail()
An email address the user can contact to receive support for their card.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
contactWebsite
final Optional<String> contactWebsite()
A website the user can visit to view and receive support for their card.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Card Dispute was created.
-
description
final String description()
A description you can use to identify the Card Profile.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
issuerName
final String issuerName()
A user-facing description for whoever is issuing the card.
-
status
final DigitalCardProfile.Status status()
The status of the Card Profile.
-
textColor
final DigitalCardProfile.TextColor textColor()
The Card's text color, specified as an RGB triple.
-
type
final DigitalCardProfile.Type type()
A constant representing the object's type. For this resource it will always be
digital_card_profile.
-
_appIconFileId
final JsonField<String> _appIconFileId()
The identifier of the File containing the card's icon image.
-
_backgroundImageFileId
final JsonField<String> _backgroundImageFileId()
The identifier of the File containing the card's front image.
-
_cardDescription
final JsonField<String> _cardDescription()
A user-facing description for the card itself.
-
_contactEmail
final JsonField<String> _contactEmail()
An email address the user can contact to receive support for their card.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_contactWebsite
final JsonField<String> _contactWebsite()
A website the user can visit to view and receive support for their card.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the Card Dispute was created.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_issuerName
final JsonField<String> _issuerName()
A user-facing description for whoever is issuing the card.
-
_status
final JsonField<DigitalCardProfile.Status> _status()
The status of the Card Profile.
-
_textColor
final JsonField<DigitalCardProfile.TextColor> _textColor()
The Card's text color, specified as an RGB triple.
-
_type
final JsonField<DigitalCardProfile.Type> _type()
A constant representing the object's type. For this resource it will always be
digital_card_profile.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DigitalCardProfile validate()
-
toBuilder
final DigitalCardProfile.Builder toBuilder()
-
builder
final static DigitalCardProfile.Builder builder()
-
-
-
-