Class DigitalCardProfileCloneParams.Body
-
- All Implemented Interfaces:
public final class DigitalCardProfileCloneParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileCloneParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>appIconFileId()The identifier of the File containing the card's icon image. final Optional<String>backgroundImageFileId()The identifier of the File containing the card's front image. final Optional<String>cardDescription()A user-facing description for the card itself. final Optional<String>contactEmail()An email address the user can contact to receive support for their card. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>contactWebsite()A website the user can visit to view and receive support for their card. final Optional<String>description()A description you can use to identify the Card Profile. final Optional<String>issuerName()A user-facing description for whoever is issuing the card. final Optional<DigitalCardProfileCloneParams.TextColor>textColor()The Card's text color, specified as an RGB triple. final JsonField<String>_appIconFileId()The identifier of the File containing the card's icon image. final JsonField<String>_backgroundImageFileId()The identifier of the File containing the card's front image. final JsonField<String>_cardDescription()A user-facing description for the card itself. final JsonField<String>_contactEmail()An email address the user can contact to receive support for their card. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_contactWebsite()A website the user can visit to view and receive support for their card. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_issuerName()A user-facing description for whoever is issuing the card. final JsonField<DigitalCardProfileCloneParams.TextColor>_textColor()The Card's text color, specified as an RGB triple. final Map<String, JsonValue>_additionalProperties()final DigitalCardProfileCloneParams.Bodyvalidate()final DigitalCardProfileCloneParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileCloneParams.Body.Builderbuilder()-
-
Method Detail
-
appIconFileId
final Optional<String> appIconFileId()
The identifier of the File containing the card's icon image.
-
backgroundImageFileId
final Optional<String> backgroundImageFileId()
The identifier of the File containing the card's front image.
-
cardDescription
final Optional<String> cardDescription()
A user-facing description for the card itself.
-
contactEmail
final Optional<String> contactEmail()
An email address the user can contact to receive support for their card.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
contactWebsite
final Optional<String> contactWebsite()
A website the user can visit to view and receive support for their card.
-
description
final Optional<String> description()
A description you can use to identify the Card Profile.
-
issuerName
final Optional<String> issuerName()
A user-facing description for whoever is issuing the card.
-
textColor
final Optional<DigitalCardProfileCloneParams.TextColor> textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_appIconFileId
final JsonField<String> _appIconFileId()
The identifier of the File containing the card's icon image.
-
_backgroundImageFileId
final JsonField<String> _backgroundImageFileId()
The identifier of the File containing the card's front image.
-
_cardDescription
final JsonField<String> _cardDescription()
A user-facing description for the card itself.
-
_contactEmail
final JsonField<String> _contactEmail()
An email address the user can contact to receive support for their card.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_contactWebsite
final JsonField<String> _contactWebsite()
A website the user can visit to view and receive support for their card.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_issuerName
final JsonField<String> _issuerName()
A user-facing description for whoever is issuing the card.
-
_textColor
final JsonField<DigitalCardProfileCloneParams.TextColor> _textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DigitalCardProfileCloneParams.Body validate()
-
toBuilder
final DigitalCardProfileCloneParams.Body.Builder toBuilder()
-
builder
final static DigitalCardProfileCloneParams.Body.Builder builder()
-
-
-
-