Package com.increase.api.models
Class DigitalCardProfileCloneParams.TextColor
-
- All Implemented Interfaces:
public final class DigitalCardProfileCloneParams.TextColorThe Card's text color, specified as an RGB triple. The default is white.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileCloneParams.TextColor.BuilderA builder for TextColor.
-
Method Summary
Modifier and Type Method Description final Longblue()The value of the blue channel in the RGB color. final Longgreen()The value of the green channel in the RGB color. final Longred()The value of the red channel in the RGB color. final JsonField<Long>_blue()The value of the blue channel in the RGB color. final JsonField<Long>_green()The value of the green channel in the RGB color. final JsonField<Long>_red()The value of the red channel in the RGB color. final Map<String, JsonValue>_additionalProperties()final DigitalCardProfileCloneParams.TextColorvalidate()final DigitalCardProfileCloneParams.TextColor.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileCloneParams.TextColor.Builderbuilder()-
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DigitalCardProfileCloneParams.TextColor validate()
-
toBuilder
final DigitalCardProfileCloneParams.TextColor.Builder toBuilder()
-
builder
final static DigitalCardProfileCloneParams.TextColor.Builder builder()
-
-
-
-