Class DigitalCardProfileCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class DigitalCardProfileCreateParams implements Params
Create a Digital Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileCreateParams.Bodypublic final classDigitalCardProfileCreateParams.BuilderA builder for DigitalCardProfileCreateParams.
public final classDigitalCardProfileCreateParams.TextColorThe Card's text color, specified as an RGB triple. The default is white.
-
Method Summary
Modifier and Type Method Description final StringappIconFileId()The identifier of the File containing the card's icon image. final StringbackgroundImageFileId()The identifier of the File containing the card's front image. final StringcardDescription()A user-facing description for the card itself. final Stringdescription()A description you can use to identify the Card Profile. final StringissuerName()A user-facing description for whoever is issuing the card. final Optional<String>contactEmail()An email address the user can contact to receive support for their card. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>contactWebsite()A website the user can visit to view and receive support for their card. final Optional<DigitalCardProfileCreateParams.TextColor>textColor()The Card's text color, specified as an RGB triple. final JsonField<String>_appIconFileId()The identifier of the File containing the card's icon image. final JsonField<String>_backgroundImageFileId()The identifier of the File containing the card's front image. final JsonField<String>_cardDescription()A user-facing description for the card itself. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_issuerName()A user-facing description for whoever is issuing the card. final JsonField<String>_contactEmail()An email address the user can contact to receive support for their card. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_contactWebsite()A website the user can visit to view and receive support for their card. final JsonField<DigitalCardProfileCreateParams.TextColor>_textColor()The Card's text color, specified as an RGB triple. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final DigitalCardProfileCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileCreateParams.Builderbuilder()-
-
Method Detail
-
appIconFileId
final String appIconFileId()
The identifier of the File containing the card's icon image.
-
backgroundImageFileId
final String backgroundImageFileId()
The identifier of the File containing the card's front image.
-
cardDescription
final String cardDescription()
A user-facing description for the card itself.
-
description
final String description()
A description you can use to identify the Card Profile.
-
issuerName
final String issuerName()
A user-facing description for whoever is issuing the card.
-
contactEmail
final Optional<String> contactEmail()
An email address the user can contact to receive support for their card.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
contactWebsite
final Optional<String> contactWebsite()
A website the user can visit to view and receive support for their card.
-
textColor
final Optional<DigitalCardProfileCreateParams.TextColor> textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_appIconFileId
final JsonField<String> _appIconFileId()
The identifier of the File containing the card's icon image.
-
_backgroundImageFileId
final JsonField<String> _backgroundImageFileId()
The identifier of the File containing the card's front image.
-
_cardDescription
final JsonField<String> _cardDescription()
A user-facing description for the card itself.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_issuerName
final JsonField<String> _issuerName()
A user-facing description for whoever is issuing the card.
-
_contactEmail
final JsonField<String> _contactEmail()
An email address the user can contact to receive support for their card.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_contactWebsite
final JsonField<String> _contactWebsite()
A website the user can visit to view and receive support for their card.
-
_textColor
final JsonField<DigitalCardProfileCreateParams.TextColor> _textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final DigitalCardProfileCreateParams.Builder toBuilder()
-
builder
final static DigitalCardProfileCreateParams.Builder builder()
-
-
-
-