Class DigitalCardProfileCreateParams.Body
-
- All Implemented Interfaces:
public final class DigitalCardProfileCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringappIconFileId()The identifier of the File containing the card's icon image. final StringbackgroundImageFileId()The identifier of the File containing the card's front image. final StringcardDescription()A user-facing description for the card itself. final Stringdescription()A description you can use to identify the Card Profile. final StringissuerName()A user-facing description for whoever is issuing the card. final Optional<String>contactEmail()An email address the user can contact to receive support for their card. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>contactWebsite()A website the user can visit to view and receive support for their card. final Optional<DigitalCardProfileCreateParams.TextColor>textColor()The Card's text color, specified as an RGB triple. final JsonField<String>_appIconFileId()The identifier of the File containing the card's icon image. final JsonField<String>_backgroundImageFileId()The identifier of the File containing the card's front image. final JsonField<String>_cardDescription()A user-facing description for the card itself. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_issuerName()A user-facing description for whoever is issuing the card. final JsonField<String>_contactEmail()An email address the user can contact to receive support for their card. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_contactWebsite()A website the user can visit to view and receive support for their card. final JsonField<DigitalCardProfileCreateParams.TextColor>_textColor()The Card's text color, specified as an RGB triple. final Map<String, JsonValue>_additionalProperties()final DigitalCardProfileCreateParams.Bodyvalidate()final DigitalCardProfileCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileCreateParams.Body.Builderbuilder()-
-
Method Detail
-
appIconFileId
final String appIconFileId()
The identifier of the File containing the card's icon image.
-
backgroundImageFileId
final String backgroundImageFileId()
The identifier of the File containing the card's front image.
-
cardDescription
final String cardDescription()
A user-facing description for the card itself.
-
description
final String description()
A description you can use to identify the Card Profile.
-
issuerName
final String issuerName()
A user-facing description for whoever is issuing the card.
-
contactEmail
final Optional<String> contactEmail()
An email address the user can contact to receive support for their card.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
contactWebsite
final Optional<String> contactWebsite()
A website the user can visit to view and receive support for their card.
-
textColor
final Optional<DigitalCardProfileCreateParams.TextColor> textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_appIconFileId
final JsonField<String> _appIconFileId()
The identifier of the File containing the card's icon image.
-
_backgroundImageFileId
final JsonField<String> _backgroundImageFileId()
The identifier of the File containing the card's front image.
-
_cardDescription
final JsonField<String> _cardDescription()
A user-facing description for the card itself.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_issuerName
final JsonField<String> _issuerName()
A user-facing description for whoever is issuing the card.
-
_contactEmail
final JsonField<String> _contactEmail()
An email address the user can contact to receive support for their card.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_contactWebsite
final JsonField<String> _contactWebsite()
A website the user can visit to view and receive support for their card.
-
_textColor
final JsonField<DigitalCardProfileCreateParams.TextColor> _textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DigitalCardProfileCreateParams.Body validate()
-
toBuilder
final DigitalCardProfileCreateParams.Body.Builder toBuilder()
-
builder
final static DigitalCardProfileCreateParams.Body.Builder builder()
-
-
-
-