Package com.increase.api.models
Class DigitalCardProfileCreateParams.TextColor.Builder
-
- All Implemented Interfaces:
public final class DigitalCardProfileCreateParams.TextColor.BuilderA builder for TextColor.
-
-
Method Summary
-
-
Method Detail
-
blue
final DigitalCardProfileCreateParams.TextColor.Builder blue(Long blue)
The value of the blue channel in the RGB color.
-
blue
final DigitalCardProfileCreateParams.TextColor.Builder blue(JsonField<Long> blue)
The value of the blue channel in the RGB color.
-
green
final DigitalCardProfileCreateParams.TextColor.Builder green(Long green)
The value of the green channel in the RGB color.
-
green
final DigitalCardProfileCreateParams.TextColor.Builder green(JsonField<Long> green)
The value of the green channel in the RGB color.
-
red
final DigitalCardProfileCreateParams.TextColor.Builder red(Long red)
The value of the red channel in the RGB color.
-
red
final DigitalCardProfileCreateParams.TextColor.Builder red(JsonField<Long> red)
The value of the red channel in the RGB color.
-
additionalProperties
final DigitalCardProfileCreateParams.TextColor.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalCardProfileCreateParams.TextColor.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalCardProfileCreateParams.TextColor.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalCardProfileCreateParams.TextColor.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalCardProfileCreateParams.TextColor.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalCardProfileCreateParams.TextColor build()
-
-
-
-