Class DigitalWalletToken
-
- All Implemented Interfaces:
public final class DigitalWalletTokenA Digital Wallet Token is created when a user adds a Card to their Apple Pay or Google Pay app. The Digital Wallet Token can be used for purchases just like a Card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletToken.BuilderA builder for DigitalWalletToken.
public final classDigitalWalletToken.StatusThis indicates if payments can be made with the Digital Wallet Token.
public final classDigitalWalletToken.TokenRequestorThe digital wallet app being used.
public final classDigitalWalletToken.TypeA constant representing the object's type. For this resource it will always be
digital_wallet_token.public final classDigitalWalletToken.Update
-
Method Summary
Modifier and Type Method Description final Stringid()The Digital Wallet Token identifier. final StringcardId()The identifier for the Card this Digital Wallet Token belongs to. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Digital Wallet Token was created. final DigitalWalletToken.Statusstatus()This indicates if payments can be made with the Digital Wallet Token. final DigitalWalletToken.TokenRequestortokenRequestor()The digital wallet app being used. final DigitalWalletToken.Typetype()A constant representing the object's type. final List<DigitalWalletToken.Update>updates()Updates to the Digital Wallet Token. final JsonField<String>_id()The Digital Wallet Token identifier. final JsonField<String>_cardId()The identifier for the Card this Digital Wallet Token belongs to. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the Digital Wallet Token was created. final JsonField<DigitalWalletToken.Status>_status()This indicates if payments can be made with the Digital Wallet Token. final JsonField<DigitalWalletToken.TokenRequestor>_tokenRequestor()The digital wallet app being used. final JsonField<DigitalWalletToken.Type>_type()A constant representing the object's type. final JsonField<List<DigitalWalletToken.Update>>_updates()Updates to the Digital Wallet Token. final Map<String, JsonValue>_additionalProperties()final DigitalWalletTokenvalidate()final DigitalWalletToken.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletToken.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Digital Wallet Token was created.
-
status
final DigitalWalletToken.Status status()
This indicates if payments can be made with the Digital Wallet Token.
-
tokenRequestor
final DigitalWalletToken.TokenRequestor tokenRequestor()
The digital wallet app being used.
-
type
final DigitalWalletToken.Type type()
A constant representing the object's type. For this resource it will always be
digital_wallet_token.
-
updates
final List<DigitalWalletToken.Update> updates()
Updates to the Digital Wallet Token.
-
_cardId
final JsonField<String> _cardId()
The identifier for the Card this Digital Wallet Token belongs to.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the Digital Wallet Token was created.
-
_status
final JsonField<DigitalWalletToken.Status> _status()
This indicates if payments can be made with the Digital Wallet Token.
-
_tokenRequestor
final JsonField<DigitalWalletToken.TokenRequestor> _tokenRequestor()
The digital wallet app being used.
-
_type
final JsonField<DigitalWalletToken.Type> _type()
A constant representing the object's type. For this resource it will always be
digital_wallet_token.
-
_updates
final JsonField<List<DigitalWalletToken.Update>> _updates()
Updates to the Digital Wallet Token.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DigitalWalletToken validate()
-
toBuilder
final DigitalWalletToken.Builder toBuilder()
-
builder
final static DigitalWalletToken.Builder builder()
-
-
-
-