Package com.increase.api.models
Enum DigitalWalletToken.TokenRequestor.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DigitalWalletToken.TokenRequestor.Known extends Enum<DigitalWalletToken.TokenRequestor.Known>
An enum containing TokenRequestor's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DigitalWalletToken.TokenRequestor.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description APPLE_PAYApple Pay
GOOGLE_PAYGoogle Pay
SAMSUNG_PAYSamsung Pay
UNKNOWNUnknown
-
Method Summary
Modifier and Type Method Description final DigitalWalletToken.TokenRequestor.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DigitalWalletToken.TokenRequestor.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DigitalWalletToken.TokenRequestor.Known>getEntries()An enum containing TokenRequestor's known values. -
-
Method Detail
-
valueOf
final DigitalWalletToken.TokenRequestor.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DigitalWalletToken.TokenRequestor.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DigitalWalletToken.TokenRequestor.Known> getEntries()
An enum containing TokenRequestor's known values.
-
-
-
-