Package com.increase.api.models
Class DigitalWalletToken.Update
-
- All Implemented Interfaces:
public final class DigitalWalletToken.Update
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletToken.Update.BuilderA builder for Update.
public final classDigitalWalletToken.Update.StatusThe status the update changed this Digital Wallet Token to.
-
Method Summary
Modifier and Type Method Description final DigitalWalletToken.Update.Statusstatus()The status the update changed this Digital Wallet Token to. final OffsetDateTimetimestamp()The ISO 8601 date and time at which the update happened. final JsonField<DigitalWalletToken.Update.Status>_status()The status the update changed this Digital Wallet Token to. final JsonField<OffsetDateTime>_timestamp()The ISO 8601 date and time at which the update happened. final Map<String, JsonValue>_additionalProperties()final DigitalWalletToken.Updatevalidate()final DigitalWalletToken.Update.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletToken.Update.Builderbuilder()-
-
Method Detail
-
status
final DigitalWalletToken.Update.Status status()
The status the update changed this Digital Wallet Token to.
-
timestamp
final OffsetDateTime timestamp()
The ISO 8601 date and time at which the update happened.
-
_status
final JsonField<DigitalWalletToken.Update.Status> _status()
The status the update changed this Digital Wallet Token to.
-
_timestamp
final JsonField<OffsetDateTime> _timestamp()
The ISO 8601 date and time at which the update happened.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final DigitalWalletToken.Update validate()
-
toBuilder
final DigitalWalletToken.Update.Builder toBuilder()
-
builder
final static DigitalWalletToken.Update.Builder builder()
-
-
-
-