Package com.increase.api.models
Enum DigitalWalletToken.Update.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DigitalWalletToken.Update.Status.Known extends Enum<DigitalWalletToken.Update.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DigitalWalletToken.Update.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACTIVEThe digital wallet token is active.
INACTIVEThe digital wallet token has been created but not successfully activated via two-factor authentication yet.
SUSPENDEDThe digital wallet token has been temporarily paused.
DEACTIVATEDThe digital wallet token has been permanently canceled.
-
Method Summary
Modifier and Type Method Description final DigitalWalletToken.Update.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DigitalWalletToken.Update.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DigitalWalletToken.Update.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final DigitalWalletToken.Update.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DigitalWalletToken.Update.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DigitalWalletToken.Update.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-