Package com.increase.api.models
Class DigitalWalletTokenListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class DigitalWalletTokenListParams implements Params
List Digital Wallet Tokens
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenListParams.BuilderA builder for DigitalWalletTokenListParams.
public final classDigitalWalletTokenListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<String>cardId()Filter Digital Wallet Tokens to ones belonging to the specified Card. final Optional<DigitalWalletTokenListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final DigitalWalletTokenListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletTokenListParamsnone()final static DigitalWalletTokenListParams.Builderbuilder()-
-
Method Detail
-
cardId
final Optional<String> cardId()
Filter Digital Wallet Tokens to ones belonging to the specified Card.
-
createdAt
final Optional<DigitalWalletTokenListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final DigitalWalletTokenListParams.Builder toBuilder()
-
none
final static DigitalWalletTokenListParams none()
-
builder
final static DigitalWalletTokenListParams.Builder builder()
-
-
-
-