Package com.increase.api.models
Class Document
-
- All Implemented Interfaces:
public final class DocumentIncrease generates certain documents / forms automatically for your application; they can be listed here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocument.BuilderA builder for Document.
public final classDocument.CategoryThe type of document.
public final classDocument.TypeA constant representing the object's type. For this resource it will always be
document.
-
Method Summary
Modifier and Type Method Description final Stringid()The Document identifier. final Document.Categorycategory()The type of document. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Document was created. final Optional<String>entityId()The identifier of the Entity the document was generated for. final StringfileId()The identifier of the File containing the Document's contents. final Document.Typetype()A constant representing the object's type. final JsonField<String>_id()The Document identifier. final JsonField<Document.Category>_category()The type of document. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Document was created. final JsonField<String>_entityId()The identifier of the Entity the document was generated for. final JsonField<String>_fileId()The identifier of the File containing the Document's contents. final JsonField<Document.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Documentvalidate()final Document.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Document.Builderbuilder()-
-
Method Detail
-
category
final Document.Category category()
The type of document.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Document was created.
-
entityId
final Optional<String> entityId()
The identifier of the Entity the document was generated for.
-
type
final Document.Type type()
A constant representing the object's type. For this resource it will always be
document.
-
_category
final JsonField<Document.Category> _category()
The type of document.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Document was created.
-
_entityId
final JsonField<String> _entityId()
The identifier of the Entity the document was generated for.
-
_fileId
final JsonField<String> _fileId()
The identifier of the File containing the Document's contents.
-
_type
final JsonField<Document.Type> _type()
A constant representing the object's type. For this resource it will always be
document.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Document.Builder toBuilder()
-
builder
final static Document.Builder builder()
-
-
-
-