Class Entity
-
- All Implemented Interfaces:
public final class EntityEntities are the legal entities that own accounts. They can be people, corporations, partnerships, government authorities, or trusts.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.BuilderA builder for Entity.
public final classEntity.CorporationDetails of the corporation entity. Will be present if
structureis equal tocorporation.public final classEntity.GovernmentAuthorityDetails of the government authority entity. Will be present if
structureis equal togovernment_authority.public final classEntity.JointDetails of the joint entity. Will be present if
structureis equal tojoint.public final classEntity.NaturalPersonDetails of the natural person entity. Will be present if
structureis equal tonatural_person.public final classEntity.StatusThe status of the entity.
public final classEntity.StructureThe entity's legal structure.
public final classEntity.ThirdPartyVerificationA reference to data stored in a third-party verification service. Your integration may or may not use this field.
public final classEntity.TrustDetails of the trust entity. Will be present if
structureis equal totrust.public final classEntity.TypeA constant representing the object's type. For this resource it will always be
entity.
-
Method Summary
Modifier and Type Method Description final Stringid()The entity's identifier. final Optional<Entity.Corporation>corporation()Details of the corporation entity. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Entity was created. final Optional<String>description()The entity's description for display purposes. final Optional<OffsetDateTime>detailsConfirmedAt()The ISO 8601 time at which the Entity's details were most recently confirmed. final Optional<Entity.GovernmentAuthority>governmentAuthority()Details of the government authority entity. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<Entity.Joint>joint()Details of the joint entity. final Optional<Entity.NaturalPerson>naturalPerson()Details of the natural person entity. final Entity.Statusstatus()The status of the entity. final Entity.Structurestructure()The entity's legal structure. final List<EntitySupplementalDocument>supplementalDocuments()Additional documentation associated with the entity. final Optional<Entity.ThirdPartyVerification>thirdPartyVerification()A reference to data stored in a third-party verification service. final Optional<Entity.Trust>trust()Details of the trust entity. final Entity.Typetype()A constant representing the object's type. final JsonField<String>_id()The entity's identifier. final JsonField<Entity.Corporation>_corporation()Details of the corporation entity. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Entity was created. final JsonField<String>_description()The entity's description for display purposes. final JsonField<OffsetDateTime>_detailsConfirmedAt()The ISO 8601 time at which the Entity's details were most recently confirmed. final JsonField<Entity.GovernmentAuthority>_governmentAuthority()Details of the government authority entity. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<Entity.Joint>_joint()Details of the joint entity. final JsonField<Entity.NaturalPerson>_naturalPerson()Details of the natural person entity. final JsonField<Entity.Status>_status()The status of the entity. final JsonField<Entity.Structure>_structure()The entity's legal structure. final JsonField<List<EntitySupplementalDocument>>_supplementalDocuments()Additional documentation associated with the entity. final JsonField<Entity.ThirdPartyVerification>_thirdPartyVerification()A reference to data stored in a third-party verification service. final JsonField<Entity.Trust>_trust()Details of the trust entity. final JsonField<Entity.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Entityvalidate()final Entity.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Builderbuilder()-
-
Method Detail
-
corporation
final Optional<Entity.Corporation> corporation()
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Entity was created.
-
description
final Optional<String> description()
The entity's description for display purposes.
-
detailsConfirmedAt
final Optional<OffsetDateTime> detailsConfirmedAt()
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
governmentAuthority
final Optional<Entity.GovernmentAuthority> governmentAuthority()
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
joint
final Optional<Entity.Joint> joint()
Details of the joint entity. Will be present if
structureis equal tojoint.
-
naturalPerson
final Optional<Entity.NaturalPerson> naturalPerson()
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
status
final Entity.Status status()
The status of the entity.
-
structure
final Entity.Structure structure()
The entity's legal structure.
-
supplementalDocuments
final List<EntitySupplementalDocument> supplementalDocuments()
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
thirdPartyVerification
final Optional<Entity.ThirdPartyVerification> thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
trust
final Optional<Entity.Trust> trust()
Details of the trust entity. Will be present if
structureis equal totrust.
-
type
final Entity.Type type()
A constant representing the object's type. For this resource it will always be
entity.
-
_corporation
final JsonField<Entity.Corporation> _corporation()
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Entity was created.
-
_description
final JsonField<String> _description()
The entity's description for display purposes.
-
_detailsConfirmedAt
final JsonField<OffsetDateTime> _detailsConfirmedAt()
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
_governmentAuthority
final JsonField<Entity.GovernmentAuthority> _governmentAuthority()
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_joint
final JsonField<Entity.Joint> _joint()
Details of the joint entity. Will be present if
structureis equal tojoint.
-
_naturalPerson
final JsonField<Entity.NaturalPerson> _naturalPerson()
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
_status
final JsonField<Entity.Status> _status()
The status of the entity.
-
_structure
final JsonField<Entity.Structure> _structure()
The entity's legal structure.
-
_supplementalDocuments
final JsonField<List<EntitySupplementalDocument>> _supplementalDocuments()
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
_thirdPartyVerification
final JsonField<Entity.ThirdPartyVerification> _thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
_trust
final JsonField<Entity.Trust> _trust()
Details of the trust entity. Will be present if
structureis equal totrust.
-
_type
final JsonField<Entity.Type> _type()
A constant representing the object's type. For this resource it will always be
entity.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Builder toBuilder()
-
builder
final static Entity.Builder builder()
-
-
-
-