Class Entity.Builder
-
- All Implemented Interfaces:
public final class Entity.BuilderA builder for Entity.
-
-
Method Summary
Modifier and Type Method Description final Entity.Builderid(String id)The entity's identifier. final Entity.Builderid(JsonField<String> id)The entity's identifier. final Entity.Buildercorporation(Entity.Corporation corporation)Details of the corporation entity. final Entity.Buildercorporation(Optional<Entity.Corporation> corporation)Details of the corporation entity. final Entity.Buildercorporation(JsonField<Entity.Corporation> corporation)Details of the corporation entity. final Entity.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Entity was created. final Entity.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 time at which the Entity was created. final Entity.Builderdescription(String description)The entity's description for display purposes. final Entity.Builderdescription(Optional<String> description)The entity's description for display purposes. final Entity.Builderdescription(JsonField<String> description)The entity's description for display purposes. final Entity.BuilderdetailsConfirmedAt(OffsetDateTime detailsConfirmedAt)The ISO 8601 time at which the Entity's details were most recently confirmed. final Entity.BuilderdetailsConfirmedAt(Optional<OffsetDateTime> detailsConfirmedAt)The ISO 8601 time at which the Entity's details were most recently confirmed. final Entity.BuilderdetailsConfirmedAt(JsonField<OffsetDateTime> detailsConfirmedAt)The ISO 8601 time at which the Entity's details were most recently confirmed. final Entity.BuildergovernmentAuthority(Entity.GovernmentAuthority governmentAuthority)Details of the government authority entity. final Entity.BuildergovernmentAuthority(Optional<Entity.GovernmentAuthority> governmentAuthority)Details of the government authority entity. final Entity.BuildergovernmentAuthority(JsonField<Entity.GovernmentAuthority> governmentAuthority)Details of the government authority entity. final Entity.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Entity.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final Entity.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final Entity.Builderjoint(Entity.Joint joint)Details of the joint entity. final Entity.Builderjoint(Optional<Entity.Joint> joint)Details of the joint entity. final Entity.Builderjoint(JsonField<Entity.Joint> joint)Details of the joint entity. final Entity.BuildernaturalPerson(Entity.NaturalPerson naturalPerson)Details of the natural person entity. final Entity.BuildernaturalPerson(Optional<Entity.NaturalPerson> naturalPerson)Details of the natural person entity. final Entity.BuildernaturalPerson(JsonField<Entity.NaturalPerson> naturalPerson)Details of the natural person entity. final Entity.Builderstatus(Entity.Status status)The status of the entity. final Entity.Builderstatus(JsonField<Entity.Status> status)The status of the entity. final Entity.Builderstructure(Entity.Structure structure)The entity's legal structure. final Entity.Builderstructure(JsonField<Entity.Structure> structure)The entity's legal structure. final Entity.BuildersupplementalDocuments(List<EntitySupplementalDocument> supplementalDocuments)Additional documentation associated with the entity. final Entity.BuildersupplementalDocuments(JsonField<List<EntitySupplementalDocument>> supplementalDocuments)Additional documentation associated with the entity. final Entity.BuilderaddSupplementalDocument(EntitySupplementalDocument supplementalDocument)Additional documentation associated with the entity. final Entity.BuilderthirdPartyVerification(Entity.ThirdPartyVerification thirdPartyVerification)A reference to data stored in a third-party verification service. final Entity.BuilderthirdPartyVerification(Optional<Entity.ThirdPartyVerification> thirdPartyVerification)A reference to data stored in a third-party verification service. final Entity.BuilderthirdPartyVerification(JsonField<Entity.ThirdPartyVerification> thirdPartyVerification)A reference to data stored in a third-party verification service. final Entity.Buildertrust(Entity.Trust trust)Details of the trust entity. final Entity.Buildertrust(Optional<Entity.Trust> trust)Details of the trust entity. final Entity.Buildertrust(JsonField<Entity.Trust> trust)Details of the trust entity. final Entity.Buildertype(Entity.Type type)A constant representing the object's type. final Entity.Buildertype(JsonField<Entity.Type> type)A constant representing the object's type. final Entity.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.BuilderputAdditionalProperty(String key, JsonValue value)final Entity.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.BuilderremoveAdditionalProperty(String key)final Entity.BuilderremoveAllAdditionalProperties(Set<String> keys)final Entitybuild()-
-
Method Detail
-
id
final Entity.Builder id(String id)
The entity's identifier.
-
id
final Entity.Builder id(JsonField<String> id)
The entity's identifier.
-
corporation
final Entity.Builder corporation(Entity.Corporation corporation)
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
corporation
final Entity.Builder corporation(Optional<Entity.Corporation> corporation)
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
corporation
final Entity.Builder corporation(JsonField<Entity.Corporation> corporation)
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
createdAt
final Entity.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Entity was created.
-
createdAt
final Entity.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Entity was created.
-
description
final Entity.Builder description(String description)
The entity's description for display purposes.
-
description
final Entity.Builder description(Optional<String> description)
The entity's description for display purposes.
-
description
final Entity.Builder description(JsonField<String> description)
The entity's description for display purposes.
-
detailsConfirmedAt
final Entity.Builder detailsConfirmedAt(OffsetDateTime detailsConfirmedAt)
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
detailsConfirmedAt
final Entity.Builder detailsConfirmedAt(Optional<OffsetDateTime> detailsConfirmedAt)
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
detailsConfirmedAt
final Entity.Builder detailsConfirmedAt(JsonField<OffsetDateTime> detailsConfirmedAt)
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
governmentAuthority
final Entity.Builder governmentAuthority(Entity.GovernmentAuthority governmentAuthority)
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
governmentAuthority
final Entity.Builder governmentAuthority(Optional<Entity.GovernmentAuthority> governmentAuthority)
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
governmentAuthority
final Entity.Builder governmentAuthority(JsonField<Entity.GovernmentAuthority> governmentAuthority)
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
idempotencyKey
final Entity.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Entity.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Entity.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
joint
final Entity.Builder joint(Entity.Joint joint)
Details of the joint entity. Will be present if
structureis equal tojoint.
-
joint
final Entity.Builder joint(Optional<Entity.Joint> joint)
Details of the joint entity. Will be present if
structureis equal tojoint.
-
joint
final Entity.Builder joint(JsonField<Entity.Joint> joint)
Details of the joint entity. Will be present if
structureis equal tojoint.
-
naturalPerson
final Entity.Builder naturalPerson(Entity.NaturalPerson naturalPerson)
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
naturalPerson
final Entity.Builder naturalPerson(Optional<Entity.NaturalPerson> naturalPerson)
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
naturalPerson
final Entity.Builder naturalPerson(JsonField<Entity.NaturalPerson> naturalPerson)
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
status
final Entity.Builder status(Entity.Status status)
The status of the entity.
-
status
final Entity.Builder status(JsonField<Entity.Status> status)
The status of the entity.
-
structure
final Entity.Builder structure(Entity.Structure structure)
The entity's legal structure.
-
structure
final Entity.Builder structure(JsonField<Entity.Structure> structure)
The entity's legal structure.
-
supplementalDocuments
final Entity.Builder supplementalDocuments(List<EntitySupplementalDocument> supplementalDocuments)
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
supplementalDocuments
final Entity.Builder supplementalDocuments(JsonField<List<EntitySupplementalDocument>> supplementalDocuments)
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
addSupplementalDocument
final Entity.Builder addSupplementalDocument(EntitySupplementalDocument supplementalDocument)
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
thirdPartyVerification
final Entity.Builder thirdPartyVerification(Entity.ThirdPartyVerification thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
thirdPartyVerification
final Entity.Builder thirdPartyVerification(Optional<Entity.ThirdPartyVerification> thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
thirdPartyVerification
final Entity.Builder thirdPartyVerification(JsonField<Entity.ThirdPartyVerification> thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
trust
final Entity.Builder trust(Entity.Trust trust)
Details of the trust entity. Will be present if
structureis equal totrust.
-
trust
final Entity.Builder trust(Optional<Entity.Trust> trust)
Details of the trust entity. Will be present if
structureis equal totrust.
-
trust
final Entity.Builder trust(JsonField<Entity.Trust> trust)
Details of the trust entity. Will be present if
structureis equal totrust.
-
type
final Entity.Builder type(Entity.Type type)
A constant representing the object's type. For this resource it will always be
entity.
-
type
final Entity.Builder type(JsonField<Entity.Type> type)
A constant representing the object's type. For this resource it will always be
entity.
-
additionalProperties
final Entity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-