Class Entity.Corporation
-
- All Implemented Interfaces:
public final class Entity.CorporationDetails of the corporation entity. Will be present if
structureis equal tocorporation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Corporation.BuilderA builder for Corporation.
public final classEntity.Corporation.AddressThe corporation's address.
public final classEntity.Corporation.BeneficialOwner
-
Method Summary
Modifier and Type Method Description final Entity.Corporation.Addressaddress()The corporation's address. final List<Entity.Corporation.BeneficialOwner>beneficialOwners()The identifying details of anyone controlling or owning 25% or more of the corporation. final Optional<String>incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final Optional<String>industryCode()The numeric North American Industry Classification System (NAICS) code submitted for the corporation. final Stringname()The legal name of the corporation. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) for the corporation. final Optional<String>website()The website of the corporation. final JsonField<Entity.Corporation.Address>_address()The corporation's address. final JsonField<List<Entity.Corporation.BeneficialOwner>>_beneficialOwners()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<String>_incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final JsonField<String>_industryCode()The numeric North American Industry Classification System (NAICS) code submitted for the corporation. final JsonField<String>_name()The legal name of the corporation. final JsonField<String>_taxIdentifier()The Employer Identification Number (EIN) for the corporation. final JsonField<String>_website()The website of the corporation. final Map<String, JsonValue>_additionalProperties()final Entity.Corporationvalidate()final Entity.Corporation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Corporation.Builderbuilder()-
-
Method Detail
-
address
final Entity.Corporation.Address address()
The corporation's address.
-
beneficialOwners
final List<Entity.Corporation.BeneficialOwner> beneficialOwners()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
incorporationState
final Optional<String> incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
industryCode
final Optional<String> industryCode()
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) for the corporation.
-
_address
final JsonField<Entity.Corporation.Address> _address()
The corporation's address.
-
_beneficialOwners
final JsonField<List<Entity.Corporation.BeneficialOwner>> _beneficialOwners()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_incorporationState
final JsonField<String> _incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
_industryCode
final JsonField<String> _industryCode()
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
The Employer Identification Number (EIN) for the corporation.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Entity.Corporation validate()
-
toBuilder
final Entity.Corporation.Builder toBuilder()
-
builder
final static Entity.Corporation.Builder builder()
-
-
-
-