Package com.increase.api.models
Class Entity.Corporation.BeneficialOwner
-
- All Implemented Interfaces:
public final class Entity.Corporation.BeneficialOwner
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Corporation.BeneficialOwner.BuilderA builder for BeneficialOwner.
public final classEntity.Corporation.BeneficialOwner.IndividualPersonal details for the beneficial owner.
public final classEntity.Corporation.BeneficialOwner.ProngWhy this person is considered a beneficial owner of the entity.
-
Method Summary
Modifier and Type Method Description final StringbeneficialOwnerId()The identifier of this beneficial owner. final Optional<String>companyTitle()This person's role or title within the entity. final Entity.Corporation.BeneficialOwner.Individualindividual()Personal details for the beneficial owner. final Entity.Corporation.BeneficialOwner.Prongprong()Why this person is considered a beneficial owner of the entity. final JsonField<String>_beneficialOwnerId()The identifier of this beneficial owner. final JsonField<String>_companyTitle()This person's role or title within the entity. final JsonField<Entity.Corporation.BeneficialOwner.Individual>_individual()Personal details for the beneficial owner. final JsonField<Entity.Corporation.BeneficialOwner.Prong>_prong()Why this person is considered a beneficial owner of the entity. final Map<String, JsonValue>_additionalProperties()final Entity.Corporation.BeneficialOwnervalidate()final Entity.Corporation.BeneficialOwner.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Corporation.BeneficialOwner.Builderbuilder()-
-
Method Detail
-
beneficialOwnerId
final String beneficialOwnerId()
The identifier of this beneficial owner.
-
companyTitle
final Optional<String> companyTitle()
This person's role or title within the entity.
-
individual
final Entity.Corporation.BeneficialOwner.Individual individual()
Personal details for the beneficial owner.
-
prong
final Entity.Corporation.BeneficialOwner.Prong prong()
Why this person is considered a beneficial owner of the entity.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
The identifier of this beneficial owner.
-
_companyTitle
final JsonField<String> _companyTitle()
This person's role or title within the entity.
-
_individual
final JsonField<Entity.Corporation.BeneficialOwner.Individual> _individual()
Personal details for the beneficial owner.
-
_prong
final JsonField<Entity.Corporation.BeneficialOwner.Prong> _prong()
Why this person is considered a beneficial owner of the entity.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Entity.Corporation.BeneficialOwner validate()
-
toBuilder
final Entity.Corporation.BeneficialOwner.Builder toBuilder()
-
builder
final static Entity.Corporation.BeneficialOwner.Builder builder()
-
-
-
-