Package com.increase.api.models
Class Entity.GovernmentAuthority
-
- All Implemented Interfaces:
public final class Entity.GovernmentAuthorityDetails of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
public final classEntity.GovernmentAuthority.AddressThe government authority's address.
public final classEntity.GovernmentAuthority.AuthorizedPersonpublic final classEntity.GovernmentAuthority.CategoryThe category of the government authority.
-
Method Summary
Modifier and Type Method Description final Entity.GovernmentAuthority.Addressaddress()The government authority's address. final List<Entity.GovernmentAuthority.AuthorizedPerson>authorizedPersons()The identifying details of authorized persons of the government authority. final Entity.GovernmentAuthority.Categorycategory()The category of the government authority. final Stringname()The government authority's name. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) of the government authority. final Optional<String>website()The government authority's website. final JsonField<Entity.GovernmentAuthority.Address>_address()The government authority's address. final JsonField<List<Entity.GovernmentAuthority.AuthorizedPerson>>_authorizedPersons()The identifying details of authorized persons of the government authority. final JsonField<Entity.GovernmentAuthority.Category>_category()The category of the government authority. final JsonField<String>_name()The government authority's name. final JsonField<String>_taxIdentifier()The Employer Identification Number (EIN) of the government authority. final JsonField<String>_website()The government authority's website. final Map<String, JsonValue>_additionalProperties()final Entity.GovernmentAuthorityvalidate()final Entity.GovernmentAuthority.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.GovernmentAuthority.Builderbuilder()-
-
Method Detail
-
address
final Entity.GovernmentAuthority.Address address()
The government authority's address.
-
authorizedPersons
final List<Entity.GovernmentAuthority.AuthorizedPerson> authorizedPersons()
The identifying details of authorized persons of the government authority.
-
category
final Entity.GovernmentAuthority.Category category()
The category of the government authority.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) of the government authority.
-
_address
final JsonField<Entity.GovernmentAuthority.Address> _address()
The government authority's address.
-
_authorizedPersons
final JsonField<List<Entity.GovernmentAuthority.AuthorizedPerson>> _authorizedPersons()
The identifying details of authorized persons of the government authority.
-
_category
final JsonField<Entity.GovernmentAuthority.Category> _category()
The category of the government authority.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
The Employer Identification Number (EIN) of the government authority.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Entity.GovernmentAuthority validate()
-
toBuilder
final Entity.GovernmentAuthority.Builder toBuilder()
-
builder
final static Entity.GovernmentAuthority.Builder builder()
-
-
-
-