Class Entity.Trust
-
- All Implemented Interfaces:
public final class Entity.TrustDetails of the trust entity. Will be present if
structureis equal totrust.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Trust.BuilderA builder for Trust.
public final classEntity.Trust.AddressThe trust's address.
public final classEntity.Trust.CategoryWhether the trust is
revocableorirrevocable.public final classEntity.Trust.GrantorThe grantor of the trust. Will be present if the
categoryisrevocable.public final classEntity.Trust.Trustee
-
Method Summary
Modifier and Type Method Description final Entity.Trust.Addressaddress()The trust's address. final Entity.Trust.Categorycategory()Whether the trust is revocableorirrevocable.final Optional<String>formationDocumentFileId()The ID for the File containing the formation document of the trust. final Optional<String>formationState()The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Optional<Entity.Trust.Grantor>grantor()The grantor of the trust. final Stringname()The trust's name. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) of the trust itself. final List<Entity.Trust.Trustee>trustees()The trustees of the trust. final JsonField<Entity.Trust.Address>_address()The trust's address. final JsonField<Entity.Trust.Category>_category()Whether the trust is revocableorirrevocable.final JsonField<String>_formationDocumentFileId()The ID for the File containing the formation document of the trust. final JsonField<String>_formationState()The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final JsonField<Entity.Trust.Grantor>_grantor()The grantor of the trust. final JsonField<String>_name()The trust's name. final JsonField<String>_taxIdentifier()The Employer Identification Number (EIN) of the trust itself. final JsonField<List<Entity.Trust.Trustee>>_trustees()The trustees of the trust. final Map<String, JsonValue>_additionalProperties()final Entity.Trustvalidate()final Entity.Trust.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Trust.Builderbuilder()-
-
Method Detail
-
address
final Entity.Trust.Address address()
The trust's address.
-
category
final Entity.Trust.Category category()
Whether the trust is
revocableorirrevocable.
-
formationDocumentFileId
final Optional<String> formationDocumentFileId()
The ID for the File containing the formation document of the trust.
-
formationState
final Optional<String> formationState()
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
grantor
final Optional<Entity.Trust.Grantor> grantor()
The grantor of the trust. Will be present if the
categoryisrevocable.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) of the trust itself.
-
trustees
final List<Entity.Trust.Trustee> trustees()
The trustees of the trust.
-
_address
final JsonField<Entity.Trust.Address> _address()
The trust's address.
-
_category
final JsonField<Entity.Trust.Category> _category()
Whether the trust is
revocableorirrevocable.
-
_formationDocumentFileId
final JsonField<String> _formationDocumentFileId()
The ID for the File containing the formation document of the trust.
-
_formationState
final JsonField<String> _formationState()
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
_grantor
final JsonField<Entity.Trust.Grantor> _grantor()
The grantor of the trust. Will be present if the
categoryisrevocable.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
The Employer Identification Number (EIN) of the trust itself.
-
_trustees
final JsonField<List<Entity.Trust.Trustee>> _trustees()
The trustees of the trust.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Entity.Trust validate()
-
toBuilder
final Entity.Trust.Builder toBuilder()
-
builder
final static Entity.Trust.Builder builder()
-
-
-
-