Class Entity.Trust.Builder
-
- All Implemented Interfaces:
public final class Entity.Trust.BuilderA builder for Trust.
-
-
Method Summary
Modifier and Type Method Description final Entity.Trust.Builderaddress(Entity.Trust.Address address)The trust's address. final Entity.Trust.Builderaddress(JsonField<Entity.Trust.Address> address)The trust's address. final Entity.Trust.Buildercategory(Entity.Trust.Category category)Whether the trust is revocableorirrevocable.final Entity.Trust.Buildercategory(JsonField<Entity.Trust.Category> category)Whether the trust is revocableorirrevocable.final Entity.Trust.BuilderformationDocumentFileId(String formationDocumentFileId)The ID for the File containing the formation document of the trust. final Entity.Trust.BuilderformationDocumentFileId(Optional<String> formationDocumentFileId)The ID for the File containing the formation document of the trust. final Entity.Trust.BuilderformationDocumentFileId(JsonField<String> formationDocumentFileId)The ID for the File containing the formation document of the trust. final Entity.Trust.BuilderformationState(String formationState)The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Entity.Trust.BuilderformationState(Optional<String> formationState)The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Entity.Trust.BuilderformationState(JsonField<String> formationState)The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Entity.Trust.Buildergrantor(Entity.Trust.Grantor grantor)The grantor of the trust. final Entity.Trust.Buildergrantor(Optional<Entity.Trust.Grantor> grantor)The grantor of the trust. final Entity.Trust.Buildergrantor(JsonField<Entity.Trust.Grantor> grantor)The grantor of the trust. final Entity.Trust.Buildername(String name)The trust's name. final Entity.Trust.Buildername(JsonField<String> name)The trust's name. final Entity.Trust.BuildertaxIdentifier(String taxIdentifier)The Employer Identification Number (EIN) of the trust itself. final Entity.Trust.BuildertaxIdentifier(Optional<String> taxIdentifier)The Employer Identification Number (EIN) of the trust itself. final Entity.Trust.BuildertaxIdentifier(JsonField<String> taxIdentifier)The Employer Identification Number (EIN) of the trust itself. final Entity.Trust.Buildertrustees(List<Entity.Trust.Trustee> trustees)The trustees of the trust. final Entity.Trust.Buildertrustees(JsonField<List<Entity.Trust.Trustee>> trustees)The trustees of the trust. final Entity.Trust.BuilderaddTrustee(Entity.Trust.Trustee trustee)The trustees of the trust. final Entity.Trust.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.Trust.BuilderputAdditionalProperty(String key, JsonValue value)final Entity.Trust.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.Trust.BuilderremoveAdditionalProperty(String key)final Entity.Trust.BuilderremoveAllAdditionalProperties(Set<String> keys)final Entity.Trustbuild()-
-
Method Detail
-
address
final Entity.Trust.Builder address(Entity.Trust.Address address)
The trust's address.
-
address
final Entity.Trust.Builder address(JsonField<Entity.Trust.Address> address)
The trust's address.
-
category
final Entity.Trust.Builder category(Entity.Trust.Category category)
Whether the trust is
revocableorirrevocable.
-
category
final Entity.Trust.Builder category(JsonField<Entity.Trust.Category> category)
Whether the trust is
revocableorirrevocable.
-
formationDocumentFileId
final Entity.Trust.Builder formationDocumentFileId(String formationDocumentFileId)
The ID for the File containing the formation document of the trust.
-
formationDocumentFileId
final Entity.Trust.Builder formationDocumentFileId(Optional<String> formationDocumentFileId)
The ID for the File containing the formation document of the trust.
-
formationDocumentFileId
final Entity.Trust.Builder formationDocumentFileId(JsonField<String> formationDocumentFileId)
The ID for the File containing the formation document of the trust.
-
formationState
final Entity.Trust.Builder formationState(String formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
formationState
final Entity.Trust.Builder formationState(Optional<String> formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
formationState
final Entity.Trust.Builder formationState(JsonField<String> formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
grantor
final Entity.Trust.Builder grantor(Entity.Trust.Grantor grantor)
The grantor of the trust. Will be present if the
categoryisrevocable.
-
grantor
final Entity.Trust.Builder grantor(Optional<Entity.Trust.Grantor> grantor)
The grantor of the trust. Will be present if the
categoryisrevocable.
-
grantor
final Entity.Trust.Builder grantor(JsonField<Entity.Trust.Grantor> grantor)
The grantor of the trust. Will be present if the
categoryisrevocable.
-
name
final Entity.Trust.Builder name(String name)
The trust's name.
-
name
final Entity.Trust.Builder name(JsonField<String> name)
The trust's name.
-
taxIdentifier
final Entity.Trust.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) of the trust itself.
-
taxIdentifier
final Entity.Trust.Builder taxIdentifier(Optional<String> taxIdentifier)
The Employer Identification Number (EIN) of the trust itself.
-
taxIdentifier
final Entity.Trust.Builder taxIdentifier(JsonField<String> taxIdentifier)
The Employer Identification Number (EIN) of the trust itself.
-
trustees
final Entity.Trust.Builder trustees(List<Entity.Trust.Trustee> trustees)
The trustees of the trust.
-
trustees
final Entity.Trust.Builder trustees(JsonField<List<Entity.Trust.Trustee>> trustees)
The trustees of the trust.
-
addTrustee
final Entity.Trust.Builder addTrustee(Entity.Trust.Trustee trustee)
The trustees of the trust.
-
additionalProperties
final Entity.Trust.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Trust.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Trust.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Trust.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Trust.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Trust build()
-
-
-
-