Package com.increase.api.models
Class Entity.Trust.Trustee.Individual.Identification
-
- All Implemented Interfaces:
public final class Entity.Trust.Trustee.Individual.IdentificationA means of verifying the person's identity.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Trust.Trustee.Individual.Identification.BuilderA builder for Identification.
public final classEntity.Trust.Trustee.Individual.Identification.MethodA method that can be used to verify the individual's identity.
-
Method Summary
Modifier and Type Method Description final Entity.Trust.Trustee.Individual.Identification.Methodmethod()A method that can be used to verify the individual's identity. final StringnumberLast4()The last 4 digits of the identification number that can be used to verify the individual's identity. final JsonField<Entity.Trust.Trustee.Individual.Identification.Method>_method()A method that can be used to verify the individual's identity. final JsonField<String>_numberLast4()The last 4 digits of the identification number that can be used to verify the individual's identity. final Map<String, JsonValue>_additionalProperties()final Entity.Trust.Trustee.Individual.Identificationvalidate()final Entity.Trust.Trustee.Individual.Identification.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Trust.Trustee.Individual.Identification.Builderbuilder()-
-
Method Detail
-
method
final Entity.Trust.Trustee.Individual.Identification.Method method()
A method that can be used to verify the individual's identity.
-
numberLast4
final String numberLast4()
The last 4 digits of the identification number that can be used to verify the individual's identity.
-
_method
final JsonField<Entity.Trust.Trustee.Individual.Identification.Method> _method()
A method that can be used to verify the individual's identity.
-
_numberLast4
final JsonField<String> _numberLast4()
The last 4 digits of the identification number that can be used to verify the individual's identity.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Entity.Trust.Trustee.Individual.Identification validate()
-
toBuilder
final Entity.Trust.Trustee.Individual.Identification.Builder toBuilder()
-
builder
final static Entity.Trust.Trustee.Individual.Identification.Builder builder()
-
-
-
-