Package com.increase.api.models
Class EntityArchiveBeneficialOwnerParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityArchiveBeneficialOwnerParams implements Params
Archive a beneficial owner for a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityArchiveBeneficialOwnerParams.Bodypublic final classEntityArchiveBeneficialOwnerParams.BuilderA builder for EntityArchiveBeneficialOwnerParams.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity associated with the Beneficial Owner that is being archived. final StringbeneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<String>_beneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final EntityArchiveBeneficialOwnerParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityArchiveBeneficialOwnerParams.Builderbuilder()-
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity associated with the Beneficial Owner that is being archived.
-
beneficialOwnerId
final String beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final EntityArchiveBeneficialOwnerParams.Builder toBuilder()
-
builder
final static EntityArchiveBeneficialOwnerParams.Builder builder()
-
-
-
-