Package com.increase.api.models
Class EntityArchiveBeneficialOwnerParams.Body
-
- All Implemented Interfaces:
public final class EntityArchiveBeneficialOwnerParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityArchiveBeneficialOwnerParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringbeneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<String>_beneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final Map<String, JsonValue>_additionalProperties()final EntityArchiveBeneficialOwnerParams.Bodyvalidate()final EntityArchiveBeneficialOwnerParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityArchiveBeneficialOwnerParams.Body.Builderbuilder()-
-
Method Detail
-
beneficialOwnerId
final String beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityArchiveBeneficialOwnerParams.Body validate()
-
toBuilder
final EntityArchiveBeneficialOwnerParams.Body.Builder toBuilder()
-
builder
final static EntityArchiveBeneficialOwnerParams.Body.Builder builder()
-
-
-
-