Package com.increase.api.models
Class EntityCreateBeneficialOwnerParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityCreateBeneficialOwnerParams implements Params
Create a beneficial owner for a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateBeneficialOwnerParams.Bodypublic final classEntityCreateBeneficialOwnerParams.BuilderA builder for EntityCreateBeneficialOwnerParams.
public final classEntityCreateBeneficialOwnerParams.BeneficialOwnerThe identifying details of anyone controlling or owning 25% or more of the corporation.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to associate with the new Beneficial Owner. final EntityCreateBeneficialOwnerParams.BeneficialOwnerbeneficialOwner()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner>_beneficialOwner()The identifying details of anyone controlling or owning 25% or more of the corporation. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final EntityCreateBeneficialOwnerParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateBeneficialOwnerParams.Builderbuilder()-
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to associate with the new Beneficial Owner.
-
beneficialOwner
final EntityCreateBeneficialOwnerParams.BeneficialOwner beneficialOwner()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwner
final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner> _beneficialOwner()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final EntityCreateBeneficialOwnerParams.Builder toBuilder()
-
builder
final static EntityCreateBeneficialOwnerParams.Builder builder()
-
-
-
-