Class EntityCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityCreateParams implements Params
Create an Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Bodypublic final classEntityCreateParams.BuilderA builder for EntityCreateParams.
public final classEntityCreateParams.StructureThe type of Entity to create.
public final classEntityCreateParams.CorporationDetails of the corporation entity to create. Required if
structureis equal tocorporation.public final classEntityCreateParams.GovernmentAuthorityDetails of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.public final classEntityCreateParams.JointDetails of the joint entity to create. Required if
structureis equal tojoint.public final classEntityCreateParams.NaturalPersonDetails of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.public final classEntityCreateParams.SupplementalDocumentpublic final classEntityCreateParams.ThirdPartyVerificationA reference to data stored in a third-party verification service. Your integration may or may not use this field.
public final classEntityCreateParams.TrustDetails of the trust entity to create. Required if
structureis equal totrust.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Structurestructure()The type of Entity to create. final Optional<EntityCreateParams.Corporation>corporation()Details of the corporation entity to create. final Optional<String>description()The description you choose to give the entity. final Optional<EntityCreateParams.GovernmentAuthority>governmentAuthority()Details of the Government Authority entity to create. final Optional<EntityCreateParams.Joint>joint()Details of the joint entity to create. final Optional<EntityCreateParams.NaturalPerson>naturalPerson()Details of the natural person entity to create. final Optional<List<EntityCreateParams.SupplementalDocument>>supplementalDocuments()Additional documentation associated with the entity. final Optional<EntityCreateParams.ThirdPartyVerification>thirdPartyVerification()A reference to data stored in a third-party verification service. final Optional<EntityCreateParams.Trust>trust()Details of the trust entity to create. final JsonField<EntityCreateParams.Structure>_structure()The type of Entity to create. final JsonField<EntityCreateParams.Corporation>_corporation()Details of the corporation entity to create. final JsonField<String>_description()The description you choose to give the entity. final JsonField<EntityCreateParams.GovernmentAuthority>_governmentAuthority()Details of the Government Authority entity to create. final JsonField<EntityCreateParams.Joint>_joint()Details of the joint entity to create. final JsonField<EntityCreateParams.NaturalPerson>_naturalPerson()Details of the natural person entity to create. final JsonField<List<EntityCreateParams.SupplementalDocument>>_supplementalDocuments()Additional documentation associated with the entity. final JsonField<EntityCreateParams.ThirdPartyVerification>_thirdPartyVerification()A reference to data stored in a third-party verification service. final JsonField<EntityCreateParams.Trust>_trust()Details of the trust entity to create. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final EntityCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Builderbuilder()-
-
Method Detail
-
structure
final EntityCreateParams.Structure structure()
The type of Entity to create.
-
corporation
final Optional<EntityCreateParams.Corporation> corporation()
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
description
final Optional<String> description()
The description you choose to give the entity.
-
governmentAuthority
final Optional<EntityCreateParams.GovernmentAuthority> governmentAuthority()
Details of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
joint
final Optional<EntityCreateParams.Joint> joint()
Details of the joint entity to create. Required if
structureis equal tojoint.
-
naturalPerson
final Optional<EntityCreateParams.NaturalPerson> naturalPerson()
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
supplementalDocuments
final Optional<List<EntityCreateParams.SupplementalDocument>> supplementalDocuments()
Additional documentation associated with the entity.
-
thirdPartyVerification
final Optional<EntityCreateParams.ThirdPartyVerification> thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
trust
final Optional<EntityCreateParams.Trust> trust()
Details of the trust entity to create. Required if
structureis equal totrust.
-
_structure
final JsonField<EntityCreateParams.Structure> _structure()
The type of Entity to create.
-
_corporation
final JsonField<EntityCreateParams.Corporation> _corporation()
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
_description
final JsonField<String> _description()
The description you choose to give the entity.
-
_governmentAuthority
final JsonField<EntityCreateParams.GovernmentAuthority> _governmentAuthority()
Details of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
_joint
final JsonField<EntityCreateParams.Joint> _joint()
Details of the joint entity to create. Required if
structureis equal tojoint.
-
_naturalPerson
final JsonField<EntityCreateParams.NaturalPerson> _naturalPerson()
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
_supplementalDocuments
final JsonField<List<EntityCreateParams.SupplementalDocument>> _supplementalDocuments()
Additional documentation associated with the entity.
-
_thirdPartyVerification
final JsonField<EntityCreateParams.ThirdPartyVerification> _thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
_trust
final JsonField<EntityCreateParams.Trust> _trust()
Details of the trust entity to create. Required if
structureis equal totrust.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final EntityCreateParams.Builder toBuilder()
-
builder
final static EntityCreateParams.Builder builder()
-
-
-
-