Class EntityCreateParams.Body
-
- All Implemented Interfaces:
public final class EntityCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Structurestructure()The type of Entity to create. final Optional<EntityCreateParams.Corporation>corporation()Details of the corporation entity to create. final Optional<String>description()The description you choose to give the entity. final Optional<EntityCreateParams.GovernmentAuthority>governmentAuthority()Details of the Government Authority entity to create. final Optional<EntityCreateParams.Joint>joint()Details of the joint entity to create. final Optional<EntityCreateParams.NaturalPerson>naturalPerson()Details of the natural person entity to create. final Optional<List<EntityCreateParams.SupplementalDocument>>supplementalDocuments()Additional documentation associated with the entity. final Optional<EntityCreateParams.ThirdPartyVerification>thirdPartyVerification()A reference to data stored in a third-party verification service. final Optional<EntityCreateParams.Trust>trust()Details of the trust entity to create. final JsonField<EntityCreateParams.Structure>_structure()The type of Entity to create. final JsonField<EntityCreateParams.Corporation>_corporation()Details of the corporation entity to create. final JsonField<String>_description()The description you choose to give the entity. final JsonField<EntityCreateParams.GovernmentAuthority>_governmentAuthority()Details of the Government Authority entity to create. final JsonField<EntityCreateParams.Joint>_joint()Details of the joint entity to create. final JsonField<EntityCreateParams.NaturalPerson>_naturalPerson()Details of the natural person entity to create. final JsonField<List<EntityCreateParams.SupplementalDocument>>_supplementalDocuments()Additional documentation associated with the entity. final JsonField<EntityCreateParams.ThirdPartyVerification>_thirdPartyVerification()A reference to data stored in a third-party verification service. final JsonField<EntityCreateParams.Trust>_trust()Details of the trust entity to create. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Bodyvalidate()final EntityCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Body.Builderbuilder()-
-
Method Detail
-
structure
final EntityCreateParams.Structure structure()
The type of Entity to create.
-
corporation
final Optional<EntityCreateParams.Corporation> corporation()
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
description
final Optional<String> description()
The description you choose to give the entity.
-
governmentAuthority
final Optional<EntityCreateParams.GovernmentAuthority> governmentAuthority()
Details of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
joint
final Optional<EntityCreateParams.Joint> joint()
Details of the joint entity to create. Required if
structureis equal tojoint.
-
naturalPerson
final Optional<EntityCreateParams.NaturalPerson> naturalPerson()
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
supplementalDocuments
final Optional<List<EntityCreateParams.SupplementalDocument>> supplementalDocuments()
Additional documentation associated with the entity.
-
thirdPartyVerification
final Optional<EntityCreateParams.ThirdPartyVerification> thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
trust
final Optional<EntityCreateParams.Trust> trust()
Details of the trust entity to create. Required if
structureis equal totrust.
-
_structure
final JsonField<EntityCreateParams.Structure> _structure()
The type of Entity to create.
-
_corporation
final JsonField<EntityCreateParams.Corporation> _corporation()
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
_description
final JsonField<String> _description()
The description you choose to give the entity.
-
_governmentAuthority
final JsonField<EntityCreateParams.GovernmentAuthority> _governmentAuthority()
Details of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
_joint
final JsonField<EntityCreateParams.Joint> _joint()
Details of the joint entity to create. Required if
structureis equal tojoint.
-
_naturalPerson
final JsonField<EntityCreateParams.NaturalPerson> _naturalPerson()
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
_supplementalDocuments
final JsonField<List<EntityCreateParams.SupplementalDocument>> _supplementalDocuments()
Additional documentation associated with the entity.
-
_thirdPartyVerification
final JsonField<EntityCreateParams.ThirdPartyVerification> _thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
_trust
final JsonField<EntityCreateParams.Trust> _trust()
Details of the trust entity to create. Required if
structureis equal totrust.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.Body validate()
-
toBuilder
final EntityCreateParams.Body.Builder toBuilder()
-
builder
final static EntityCreateParams.Body.Builder builder()
-
-
-
-