Class EntityCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
structure
final EntityCreateParams.Body.Builder structure(EntityCreateParams.Structure structure)
The type of Entity to create.
-
structure
final EntityCreateParams.Body.Builder structure(JsonField<EntityCreateParams.Structure> structure)
The type of Entity to create.
-
corporation
final EntityCreateParams.Body.Builder corporation(EntityCreateParams.Corporation corporation)
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
corporation
final EntityCreateParams.Body.Builder corporation(JsonField<EntityCreateParams.Corporation> corporation)
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
description
final EntityCreateParams.Body.Builder description(String description)
The description you choose to give the entity.
-
description
final EntityCreateParams.Body.Builder description(JsonField<String> description)
The description you choose to give the entity.
-
governmentAuthority
final EntityCreateParams.Body.Builder governmentAuthority(EntityCreateParams.GovernmentAuthority governmentAuthority)
Details of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
governmentAuthority
final EntityCreateParams.Body.Builder governmentAuthority(JsonField<EntityCreateParams.GovernmentAuthority> governmentAuthority)
Details of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
joint
final EntityCreateParams.Body.Builder joint(EntityCreateParams.Joint joint)
Details of the joint entity to create. Required if
structureis equal tojoint.
-
joint
final EntityCreateParams.Body.Builder joint(JsonField<EntityCreateParams.Joint> joint)
Details of the joint entity to create. Required if
structureis equal tojoint.
-
naturalPerson
final EntityCreateParams.Body.Builder naturalPerson(EntityCreateParams.NaturalPerson naturalPerson)
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
naturalPerson
final EntityCreateParams.Body.Builder naturalPerson(JsonField<EntityCreateParams.NaturalPerson> naturalPerson)
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
supplementalDocuments
final EntityCreateParams.Body.Builder supplementalDocuments(List<EntityCreateParams.SupplementalDocument> supplementalDocuments)
Additional documentation associated with the entity.
-
supplementalDocuments
final EntityCreateParams.Body.Builder supplementalDocuments(JsonField<List<EntityCreateParams.SupplementalDocument>> supplementalDocuments)
Additional documentation associated with the entity.
-
addSupplementalDocument
final EntityCreateParams.Body.Builder addSupplementalDocument(EntityCreateParams.SupplementalDocument supplementalDocument)
Additional documentation associated with the entity.
-
thirdPartyVerification
final EntityCreateParams.Body.Builder thirdPartyVerification(EntityCreateParams.ThirdPartyVerification thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
thirdPartyVerification
final EntityCreateParams.Body.Builder thirdPartyVerification(JsonField<EntityCreateParams.ThirdPartyVerification> thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
trust
final EntityCreateParams.Body.Builder trust(EntityCreateParams.Trust trust)
Details of the trust entity to create. Required if
structureis equal totrust.
-
trust
final EntityCreateParams.Body.Builder trust(JsonField<EntityCreateParams.Trust> trust)
Details of the trust entity to create. Required if
structureis equal totrust.
-
additionalProperties
final EntityCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Body build()
-
-
-
-