Class EntityCreateParams.Corporation
-
- All Implemented Interfaces:
public final class EntityCreateParams.CorporationDetails of the corporation entity to create. Required if
structureis equal tocorporation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Corporation.BuilderA builder for Corporation.
public final classEntityCreateParams.Corporation.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.Corporation.BeneficialOwner
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Corporation.Addressaddress()The entity's physical address. final List<EntityCreateParams.Corporation.BeneficialOwner>beneficialOwners()The identifying details of anyone controlling or owning 25% or more of the corporation. final Stringname()The legal name of the corporation. final StringtaxIdentifier()The Employer Identification Number (EIN) for the corporation. final Optional<String>incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final Optional<String>industryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final Optional<String>website()The website of the corporation. final JsonField<EntityCreateParams.Corporation.Address>_address()The entity's physical address. final JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>>_beneficialOwners()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<String>_name()The legal name of the corporation. final JsonField<String>_taxIdentifier()The Employer Identification Number (EIN) for the corporation. final JsonField<String>_incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final JsonField<String>_industryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final JsonField<String>_website()The website of the corporation. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Corporationvalidate()final EntityCreateParams.Corporation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Corporation.Builderbuilder()-
-
Method Detail
-
address
final EntityCreateParams.Corporation.Address address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
beneficialOwners
final List<EntityCreateParams.Corporation.BeneficialOwner> beneficialOwners()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
taxIdentifier
final String taxIdentifier()
The Employer Identification Number (EIN) for the corporation.
-
incorporationState
final Optional<String> incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
industryCode
final Optional<String> industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_address
final JsonField<EntityCreateParams.Corporation.Address> _address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
_beneficialOwners
final JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>> _beneficialOwners()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
The Employer Identification Number (EIN) for the corporation.
-
_incorporationState
final JsonField<String> _incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
_industryCode
final JsonField<String> _industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.Corporation validate()
-
toBuilder
final EntityCreateParams.Corporation.Builder toBuilder()
-
builder
final static EntityCreateParams.Corporation.Builder builder()
-
-
-
-