Package com.increase.api.models
Class EntityCreateParams.Corporation.BeneficialOwner
-
- All Implemented Interfaces:
public final class EntityCreateParams.Corporation.BeneficialOwner
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Corporation.BeneficialOwner.BuilderA builder for BeneficialOwner.
public final classEntityCreateParams.Corporation.BeneficialOwner.IndividualPersonal details for the beneficial owner.
public final classEntityCreateParams.Corporation.BeneficialOwner.Prong
-
Method Summary
-
-
Method Detail
-
individual
final EntityCreateParams.Corporation.BeneficialOwner.Individual individual()
Personal details for the beneficial owner.
-
prongs
final List<EntityCreateParams.Corporation.BeneficialOwner.Prong> prongs()
Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both.
-
companyTitle
final Optional<String> companyTitle()
This person's role or title within the entity.
-
_individual
final JsonField<EntityCreateParams.Corporation.BeneficialOwner.Individual> _individual()
Personal details for the beneficial owner.
-
_prongs
final JsonField<List<EntityCreateParams.Corporation.BeneficialOwner.Prong>> _prongs()
Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both.
-
_companyTitle
final JsonField<String> _companyTitle()
This person's role or title within the entity.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.Corporation.BeneficialOwner validate()
-
toBuilder
final EntityCreateParams.Corporation.BeneficialOwner.Builder toBuilder()
-
builder
final static EntityCreateParams.Corporation.BeneficialOwner.Builder builder()
-
-
-
-