Class EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification
-
- All Implemented Interfaces:
public final class EntityCreateParams.Corporation.BeneficialOwner.Individual.IdentificationA means of verifying the person's identity.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.BuilderA builder for Identification.
public final classEntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.MethodA method that can be used to verify the individual's identity.
public final classEntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.DriversLicenseInformation about the United States driver's license used for identification. Required if
methodis equal todrivers_license.public final classEntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.OtherInformation about the identification document provided. Required if
methodis equal toother.public final classEntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.PassportInformation about the passport used for identification. Required if
methodis equal topassport.
-
Method Summary
-
-
Method Detail
-
method
final EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Method method()
A method that can be used to verify the individual's identity.
-
number
final String number()
An identification number that can be used to verify the individual's identity, such as a social security number.
-
driversLicense
final Optional<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.DriversLicense> driversLicense()
Information about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
other
final Optional<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Other> other()
Information about the identification document provided. Required if
methodis equal toother.
-
passport
final Optional<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Passport> passport()
Information about the passport used for identification. Required if
methodis equal topassport.
-
_method
final JsonField<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Method> _method()
A method that can be used to verify the individual's identity.
-
_number
final JsonField<String> _number()
An identification number that can be used to verify the individual's identity, such as a social security number.
-
_driversLicense
final JsonField<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.DriversLicense> _driversLicense()
Information about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
_other
final JsonField<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Other> _other()
Information about the identification document provided. Required if
methodis equal toother.
-
_passport
final JsonField<EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Passport> _passport()
Information about the passport used for identification. Required if
methodis equal topassport.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Builder toBuilder()
-
builder
final static EntityCreateParams.Corporation.BeneficialOwner.Individual.Identification.Builder builder()
-
-
-
-