Class EntityCreateParams.Corporation.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Corporation.BuilderA builder for Corporation.
-
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Corporation.Builderaddress(EntityCreateParams.Corporation.Address address)The entity's physical address. final EntityCreateParams.Corporation.Builderaddress(JsonField<EntityCreateParams.Corporation.Address> address)The entity's physical address. final EntityCreateParams.Corporation.BuilderbeneficialOwners(List<EntityCreateParams.Corporation.BeneficialOwner> beneficialOwners)The identifying details of anyone controlling or owning 25% or more of the corporation. final EntityCreateParams.Corporation.BuilderbeneficialOwners(JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>> beneficialOwners)The identifying details of anyone controlling or owning 25% or more of the corporation. final EntityCreateParams.Corporation.BuilderaddBeneficialOwner(EntityCreateParams.Corporation.BeneficialOwner beneficialOwner)The identifying details of anyone controlling or owning 25% or more of the corporation. final EntityCreateParams.Corporation.Buildername(String name)The legal name of the corporation. final EntityCreateParams.Corporation.Buildername(JsonField<String> name)The legal name of the corporation. final EntityCreateParams.Corporation.BuildertaxIdentifier(String taxIdentifier)The Employer Identification Number (EIN) for the corporation. final EntityCreateParams.Corporation.BuildertaxIdentifier(JsonField<String> taxIdentifier)The Employer Identification Number (EIN) for the corporation. final EntityCreateParams.Corporation.BuilderincorporationState(String incorporationState)The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final EntityCreateParams.Corporation.BuilderincorporationState(JsonField<String> incorporationState)The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final EntityCreateParams.Corporation.BuilderindustryCode(String industryCode)The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final EntityCreateParams.Corporation.BuilderindustryCode(JsonField<String> industryCode)The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final EntityCreateParams.Corporation.Builderwebsite(String website)The website of the corporation. final EntityCreateParams.Corporation.Builderwebsite(JsonField<String> website)The website of the corporation. final EntityCreateParams.Corporation.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final EntityCreateParams.Corporation.BuilderputAdditionalProperty(String key, JsonValue value)final EntityCreateParams.Corporation.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final EntityCreateParams.Corporation.BuilderremoveAdditionalProperty(String key)final EntityCreateParams.Corporation.BuilderremoveAllAdditionalProperties(Set<String> keys)final EntityCreateParams.Corporationbuild()-
-
Method Detail
-
address
final EntityCreateParams.Corporation.Builder address(EntityCreateParams.Corporation.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.Corporation.Builder address(JsonField<EntityCreateParams.Corporation.Address> address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
beneficialOwners
final EntityCreateParams.Corporation.Builder beneficialOwners(List<EntityCreateParams.Corporation.BeneficialOwner> beneficialOwners)
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
beneficialOwners
final EntityCreateParams.Corporation.Builder beneficialOwners(JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>> beneficialOwners)
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
addBeneficialOwner
final EntityCreateParams.Corporation.Builder addBeneficialOwner(EntityCreateParams.Corporation.BeneficialOwner beneficialOwner)
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
name
final EntityCreateParams.Corporation.Builder name(String name)
The legal name of the corporation.
-
name
final EntityCreateParams.Corporation.Builder name(JsonField<String> name)
The legal name of the corporation.
-
taxIdentifier
final EntityCreateParams.Corporation.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the corporation.
-
taxIdentifier
final EntityCreateParams.Corporation.Builder taxIdentifier(JsonField<String> taxIdentifier)
The Employer Identification Number (EIN) for the corporation.
-
incorporationState
final EntityCreateParams.Corporation.Builder incorporationState(String incorporationState)
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
incorporationState
final EntityCreateParams.Corporation.Builder incorporationState(JsonField<String> incorporationState)
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
industryCode
final EntityCreateParams.Corporation.Builder industryCode(String industryCode)
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
industryCode
final EntityCreateParams.Corporation.Builder industryCode(JsonField<String> industryCode)
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
website
final EntityCreateParams.Corporation.Builder website(String website)
The website of the corporation.
-
website
final EntityCreateParams.Corporation.Builder website(JsonField<String> website)
The website of the corporation.
-
additionalProperties
final EntityCreateParams.Corporation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Corporation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Corporation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Corporation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Corporation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Corporation build()
-
-
-
-