Class EntityCreateParams.GovernmentAuthority
-
- All Implemented Interfaces:
public final class EntityCreateParams.GovernmentAuthorityDetails of the Government Authority entity to create. Required if
structureis equal toGovernment Authority.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
public final classEntityCreateParams.GovernmentAuthority.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.GovernmentAuthority.AuthorizedPersonpublic final classEntityCreateParams.GovernmentAuthority.CategoryThe category of the government authority.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.GovernmentAuthority.Addressaddress()The entity's physical address. final List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>authorizedPersons()The identifying details of authorized officials acting on the entity's behalf. final EntityCreateParams.GovernmentAuthority.Categorycategory()The category of the government authority. final Stringname()The legal name of the government authority. final StringtaxIdentifier()The Employer Identification Number (EIN) for the government authority. final Optional<String>website()The website of the government authority. final JsonField<EntityCreateParams.GovernmentAuthority.Address>_address()The entity's physical address. final JsonField<List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>>_authorizedPersons()The identifying details of authorized officials acting on the entity's behalf. final JsonField<EntityCreateParams.GovernmentAuthority.Category>_category()The category of the government authority. final JsonField<String>_name()The legal name of the government authority. final JsonField<String>_taxIdentifier()The Employer Identification Number (EIN) for the government authority. final JsonField<String>_website()The website of the government authority. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.GovernmentAuthorityvalidate()final EntityCreateParams.GovernmentAuthority.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.GovernmentAuthority.Builderbuilder()-
-
Method Detail
-
address
final EntityCreateParams.GovernmentAuthority.Address address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
authorizedPersons
final List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson> authorizedPersons()
The identifying details of authorized officials acting on the entity's behalf.
-
category
final EntityCreateParams.GovernmentAuthority.Category category()
The category of the government authority.
-
taxIdentifier
final String taxIdentifier()
The Employer Identification Number (EIN) for the government authority.
-
_address
final JsonField<EntityCreateParams.GovernmentAuthority.Address> _address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
_authorizedPersons
final JsonField<List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>> _authorizedPersons()
The identifying details of authorized officials acting on the entity's behalf.
-
_category
final JsonField<EntityCreateParams.GovernmentAuthority.Category> _category()
The category of the government authority.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
The Employer Identification Number (EIN) for the government authority.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.GovernmentAuthority validate()
-
toBuilder
final EntityCreateParams.GovernmentAuthority.Builder toBuilder()
-
builder
final static EntityCreateParams.GovernmentAuthority.Builder builder()
-
-
-
-