Class EntityCreateParams.GovernmentAuthority.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityCreateParams.GovernmentAuthority.Builder address(EntityCreateParams.GovernmentAuthority.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.GovernmentAuthority.Builder address(JsonField<EntityCreateParams.GovernmentAuthority.Address> address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
authorizedPersons
final EntityCreateParams.GovernmentAuthority.Builder authorizedPersons(List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson> authorizedPersons)
The identifying details of authorized officials acting on the entity's behalf.
-
authorizedPersons
final EntityCreateParams.GovernmentAuthority.Builder authorizedPersons(JsonField<List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>> authorizedPersons)
The identifying details of authorized officials acting on the entity's behalf.
-
addAuthorizedPerson
final EntityCreateParams.GovernmentAuthority.Builder addAuthorizedPerson(EntityCreateParams.GovernmentAuthority.AuthorizedPerson authorizedPerson)
The identifying details of authorized officials acting on the entity's behalf.
-
category
final EntityCreateParams.GovernmentAuthority.Builder category(EntityCreateParams.GovernmentAuthority.Category category)
The category of the government authority.
-
category
final EntityCreateParams.GovernmentAuthority.Builder category(JsonField<EntityCreateParams.GovernmentAuthority.Category> category)
The category of the government authority.
-
name
final EntityCreateParams.GovernmentAuthority.Builder name(String name)
The legal name of the government authority.
-
name
final EntityCreateParams.GovernmentAuthority.Builder name(JsonField<String> name)
The legal name of the government authority.
-
taxIdentifier
final EntityCreateParams.GovernmentAuthority.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the government authority.
-
taxIdentifier
final EntityCreateParams.GovernmentAuthority.Builder taxIdentifier(JsonField<String> taxIdentifier)
The Employer Identification Number (EIN) for the government authority.
-
website
final EntityCreateParams.GovernmentAuthority.Builder website(String website)
The website of the government authority.
-
website
final EntityCreateParams.GovernmentAuthority.Builder website(JsonField<String> website)
The website of the government authority.
-
additionalProperties
final EntityCreateParams.GovernmentAuthority.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.GovernmentAuthority.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.GovernmentAuthority.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.GovernmentAuthority.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.GovernmentAuthority.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.GovernmentAuthority build()
-
-
-
-