Package com.increase.api.models
Class EntityCreateParams.Joint.Individual.Identification.Other
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual.Identification.OtherInformation about the identification document provided. Required if
methodis equal toother.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Joint.Individual.Identification.Other.BuilderA builder for Other.
-
Method Summary
Modifier and Type Method Description final Stringcountry()The two-character ISO 3166-1 code representing the country that issued the document. final Stringdescription()A description of the document submitted. final StringfileId()The identifier of the File containing the front of the document. final Optional<String>backFileId()The identifier of the File containing the back of the document. final Optional<LocalDate>expirationDate()The document's expiration date in YYYY-MM-DD format. final JsonField<String>_country()The two-character ISO 3166-1 code representing the country that issued the document. final JsonField<String>_description()A description of the document submitted. final JsonField<String>_fileId()The identifier of the File containing the front of the document. final JsonField<String>_backFileId()The identifier of the File containing the back of the document. final JsonField<LocalDate>_expirationDate()The document's expiration date in YYYY-MM-DD format. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Joint.Individual.Identification.Othervalidate()final EntityCreateParams.Joint.Individual.Identification.Other.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Joint.Individual.Identification.Other.Builderbuilder()-
-
Method Detail
-
country
final String country()
The two-character ISO 3166-1 code representing the country that issued the document.
-
description
final String description()
A description of the document submitted.
-
backFileId
final Optional<String> backFileId()
The identifier of the File containing the back of the document. Not every document has a reverse side.
-
expirationDate
final Optional<LocalDate> expirationDate()
The document's expiration date in YYYY-MM-DD format.
-
_country
final JsonField<String> _country()
The two-character ISO 3166-1 code representing the country that issued the document.
-
_description
final JsonField<String> _description()
A description of the document submitted.
-
_fileId
final JsonField<String> _fileId()
The identifier of the File containing the front of the document.
-
_backFileId
final JsonField<String> _backFileId()
The identifier of the File containing the back of the document. Not every document has a reverse side.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
The document's expiration date in YYYY-MM-DD format.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.Joint.Individual.Identification.Other validate()
-
toBuilder
final EntityCreateParams.Joint.Individual.Identification.Other.Builder toBuilder()
-
builder
final static EntityCreateParams.Joint.Individual.Identification.Other.Builder builder()
-
-
-
-