Class EntityCreateParams.NaturalPerson.Identification
-
- All Implemented Interfaces:
public final class EntityCreateParams.NaturalPerson.IdentificationA means of verifying the person's identity.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.NaturalPerson.Identification.BuilderA builder for Identification.
public final classEntityCreateParams.NaturalPerson.Identification.MethodA method that can be used to verify the individual's identity.
public final classEntityCreateParams.NaturalPerson.Identification.DriversLicenseInformation about the United States driver's license used for identification. Required if
methodis equal todrivers_license.public final classEntityCreateParams.NaturalPerson.Identification.OtherInformation about the identification document provided. Required if
methodis equal toother.public final classEntityCreateParams.NaturalPerson.Identification.PassportInformation about the passport used for identification. Required if
methodis equal topassport.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.NaturalPerson.Identification.Methodmethod()A method that can be used to verify the individual's identity. final Stringnumber()An identification number that can be used to verify the individual's identity, such as a social security number. final Optional<EntityCreateParams.NaturalPerson.Identification.DriversLicense>driversLicense()Information about the United States driver's license used for identification. final Optional<EntityCreateParams.NaturalPerson.Identification.Other>other()Information about the identification document provided. final Optional<EntityCreateParams.NaturalPerson.Identification.Passport>passport()Information about the passport used for identification. final JsonField<EntityCreateParams.NaturalPerson.Identification.Method>_method()A method that can be used to verify the individual's identity. final JsonField<String>_number()An identification number that can be used to verify the individual's identity, such as a social security number. final JsonField<EntityCreateParams.NaturalPerson.Identification.DriversLicense>_driversLicense()Information about the United States driver's license used for identification. final JsonField<EntityCreateParams.NaturalPerson.Identification.Other>_other()Information about the identification document provided. final JsonField<EntityCreateParams.NaturalPerson.Identification.Passport>_passport()Information about the passport used for identification. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.NaturalPerson.Identificationvalidate()final EntityCreateParams.NaturalPerson.Identification.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.NaturalPerson.Identification.Builderbuilder()-
-
Method Detail
-
method
final EntityCreateParams.NaturalPerson.Identification.Method method()
A method that can be used to verify the individual's identity.
-
number
final String number()
An identification number that can be used to verify the individual's identity, such as a social security number.
-
driversLicense
final Optional<EntityCreateParams.NaturalPerson.Identification.DriversLicense> driversLicense()
Information about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
other
final Optional<EntityCreateParams.NaturalPerson.Identification.Other> other()
Information about the identification document provided. Required if
methodis equal toother.
-
passport
final Optional<EntityCreateParams.NaturalPerson.Identification.Passport> passport()
Information about the passport used for identification. Required if
methodis equal topassport.
-
_method
final JsonField<EntityCreateParams.NaturalPerson.Identification.Method> _method()
A method that can be used to verify the individual's identity.
-
_number
final JsonField<String> _number()
An identification number that can be used to verify the individual's identity, such as a social security number.
-
_driversLicense
final JsonField<EntityCreateParams.NaturalPerson.Identification.DriversLicense> _driversLicense()
Information about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
_other
final JsonField<EntityCreateParams.NaturalPerson.Identification.Other> _other()
Information about the identification document provided. Required if
methodis equal toother.
-
_passport
final JsonField<EntityCreateParams.NaturalPerson.Identification.Passport> _passport()
Information about the passport used for identification. Required if
methodis equal topassport.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.NaturalPerson.Identification validate()
-
toBuilder
final EntityCreateParams.NaturalPerson.Identification.Builder toBuilder()
-
builder
final static EntityCreateParams.NaturalPerson.Identification.Builder builder()
-
-
-
-