Package com.increase.api.models
Class EntityCreateParams.ThirdPartyVerification
-
- All Implemented Interfaces:
public final class EntityCreateParams.ThirdPartyVerificationA reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.ThirdPartyVerification.BuilderA builder for ThirdPartyVerification.
public final classEntityCreateParams.ThirdPartyVerification.VendorThe vendor that was used to perform the verification.
-
Method Summary
Modifier and Type Method Description final Stringreference()The reference identifier for the third party verification. final EntityCreateParams.ThirdPartyVerification.Vendorvendor()The vendor that was used to perform the verification. final JsonField<String>_reference()The reference identifier for the third party verification. final JsonField<EntityCreateParams.ThirdPartyVerification.Vendor>_vendor()The vendor that was used to perform the verification. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.ThirdPartyVerificationvalidate()final EntityCreateParams.ThirdPartyVerification.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.ThirdPartyVerification.Builderbuilder()-
-
Method Detail
-
vendor
final EntityCreateParams.ThirdPartyVerification.Vendor vendor()
The vendor that was used to perform the verification.
-
_reference
final JsonField<String> _reference()
The reference identifier for the third party verification.
-
_vendor
final JsonField<EntityCreateParams.ThirdPartyVerification.Vendor> _vendor()
The vendor that was used to perform the verification.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.ThirdPartyVerification validate()
-
toBuilder
final EntityCreateParams.ThirdPartyVerification.Builder toBuilder()
-
builder
final static EntityCreateParams.ThirdPartyVerification.Builder builder()
-
-
-
-