Class EntityCreateParams.Trust
-
- All Implemented Interfaces:
public final class EntityCreateParams.TrustDetails of the trust entity to create. Required if
structureis equal totrust.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Trust.BuilderA builder for Trust.
public final classEntityCreateParams.Trust.AddressThe trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.Trust.CategoryWhether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.public final classEntityCreateParams.Trust.Trusteepublic final classEntityCreateParams.Trust.GrantorThe grantor of the trust. Required if
categoryis equal torevocable.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Trust.Addressaddress()The trust's physical address. final EntityCreateParams.Trust.Categorycategory()Whether the trust is revocableorirrevocable.final Stringname()The legal name of the trust. final List<EntityCreateParams.Trust.Trustee>trustees()The trustees of the trust. final Optional<String>formationDocumentFileId()The identifier of the File containing the formation document of the trust. final Optional<String>formationState()The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Optional<EntityCreateParams.Trust.Grantor>grantor()The grantor of the trust. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) for the trust. final JsonField<EntityCreateParams.Trust.Address>_address()The trust's physical address. final JsonField<EntityCreateParams.Trust.Category>_category()Whether the trust is revocableorirrevocable.final JsonField<String>_name()The legal name of the trust. final JsonField<List<EntityCreateParams.Trust.Trustee>>_trustees()The trustees of the trust. final JsonField<String>_formationDocumentFileId()The identifier of the File containing the formation document of the trust. final JsonField<String>_formationState()The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final JsonField<EntityCreateParams.Trust.Grantor>_grantor()The grantor of the trust. final JsonField<String>_taxIdentifier()The Employer Identification Number (EIN) for the trust. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Trustvalidate()final EntityCreateParams.Trust.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Trust.Builderbuilder()-
-
Method Detail
-
address
final EntityCreateParams.Trust.Address address()
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
category
final EntityCreateParams.Trust.Category category()
Whether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.
-
trustees
final List<EntityCreateParams.Trust.Trustee> trustees()
The trustees of the trust.
-
formationDocumentFileId
final Optional<String> formationDocumentFileId()
The identifier of the File containing the formation document of the trust.
-
formationState
final Optional<String> formationState()
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
grantor
final Optional<EntityCreateParams.Trust.Grantor> grantor()
The grantor of the trust. Required if
categoryis equal torevocable.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) for the trust. Required if
categoryis equal toirrevocable.
-
_address
final JsonField<EntityCreateParams.Trust.Address> _address()
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
_category
final JsonField<EntityCreateParams.Trust.Category> _category()
Whether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.
-
_trustees
final JsonField<List<EntityCreateParams.Trust.Trustee>> _trustees()
The trustees of the trust.
-
_formationDocumentFileId
final JsonField<String> _formationDocumentFileId()
The identifier of the File containing the formation document of the trust.
-
_formationState
final JsonField<String> _formationState()
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
_grantor
final JsonField<EntityCreateParams.Trust.Grantor> _grantor()
The grantor of the trust. Required if
categoryis equal torevocable.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
The Employer Identification Number (EIN) for the trust. Required if
categoryis equal toirrevocable.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.Trust validate()
-
toBuilder
final EntityCreateParams.Trust.Builder toBuilder()
-
builder
final static EntityCreateParams.Trust.Builder builder()
-
-
-
-