Class EntityCreateParams.Trust.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Trust.BuilderA builder for Trust.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityCreateParams.Trust.Builder address(EntityCreateParams.Trust.Address address)
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.Trust.Builder address(JsonField<EntityCreateParams.Trust.Address> address)
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
category
final EntityCreateParams.Trust.Builder category(EntityCreateParams.Trust.Category category)
Whether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.
-
category
final EntityCreateParams.Trust.Builder category(JsonField<EntityCreateParams.Trust.Category> category)
Whether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.
-
name
final EntityCreateParams.Trust.Builder name(String name)
The legal name of the trust.
-
name
final EntityCreateParams.Trust.Builder name(JsonField<String> name)
The legal name of the trust.
-
trustees
final EntityCreateParams.Trust.Builder trustees(List<EntityCreateParams.Trust.Trustee> trustees)
The trustees of the trust.
-
trustees
final EntityCreateParams.Trust.Builder trustees(JsonField<List<EntityCreateParams.Trust.Trustee>> trustees)
The trustees of the trust.
-
addTrustee
final EntityCreateParams.Trust.Builder addTrustee(EntityCreateParams.Trust.Trustee trustee)
The trustees of the trust.
-
formationDocumentFileId
final EntityCreateParams.Trust.Builder formationDocumentFileId(String formationDocumentFileId)
The identifier of the File containing the formation document of the trust.
-
formationDocumentFileId
final EntityCreateParams.Trust.Builder formationDocumentFileId(JsonField<String> formationDocumentFileId)
The identifier of the File containing the formation document of the trust.
-
formationState
final EntityCreateParams.Trust.Builder formationState(String formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
formationState
final EntityCreateParams.Trust.Builder formationState(JsonField<String> formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
grantor
final EntityCreateParams.Trust.Builder grantor(EntityCreateParams.Trust.Grantor grantor)
The grantor of the trust. Required if
categoryis equal torevocable.
-
grantor
final EntityCreateParams.Trust.Builder grantor(JsonField<EntityCreateParams.Trust.Grantor> grantor)
The grantor of the trust. Required if
categoryis equal torevocable.
-
taxIdentifier
final EntityCreateParams.Trust.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the trust. Required if
categoryis equal toirrevocable.
-
taxIdentifier
final EntityCreateParams.Trust.Builder taxIdentifier(JsonField<String> taxIdentifier)
The Employer Identification Number (EIN) for the trust. Required if
categoryis equal toirrevocable.
-
additionalProperties
final EntityCreateParams.Trust.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Trust.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Trust.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Trust.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Trust.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Trust build()
-
-
-
-