Package com.increase.api.models
Class EntityCreateParams.Trust.Grantor.Identification.DriversLicense
-
- All Implemented Interfaces:
public final class EntityCreateParams.Trust.Grantor.Identification.DriversLicenseInformation about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Trust.Grantor.Identification.DriversLicense.BuilderA builder for DriversLicense.
-
Method Summary
Modifier and Type Method Description final LocalDateexpirationDate()The driver's license's expiration date in YYYY-MM-DD format. final StringfileId()The identifier of the File containing the front of the driver's license. final Stringstate()The state that issued the provided driver's license. final Optional<String>backFileId()The identifier of the File containing the back of the driver's license. final JsonField<LocalDate>_expirationDate()The driver's license's expiration date in YYYY-MM-DD format. final JsonField<String>_fileId()The identifier of the File containing the front of the driver's license. final JsonField<String>_state()The state that issued the provided driver's license. final JsonField<String>_backFileId()The identifier of the File containing the back of the driver's license. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Trust.Grantor.Identification.DriversLicensevalidate()final EntityCreateParams.Trust.Grantor.Identification.DriversLicense.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Trust.Grantor.Identification.DriversLicense.Builderbuilder()-
-
Method Detail
-
expirationDate
final LocalDate expirationDate()
The driver's license's expiration date in YYYY-MM-DD format.
-
fileId
final String fileId()
The identifier of the File containing the front of the driver's license.
-
backFileId
final Optional<String> backFileId()
The identifier of the File containing the back of the driver's license.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
The driver's license's expiration date in YYYY-MM-DD format.
-
_fileId
final JsonField<String> _fileId()
The identifier of the File containing the front of the driver's license.
-
_backFileId
final JsonField<String> _backFileId()
The identifier of the File containing the back of the driver's license.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntityCreateParams.Trust.Grantor.Identification.DriversLicense validate()
-
builder
final static EntityCreateParams.Trust.Grantor.Identification.DriversLicense.Builder builder()
-
-
-
-