Package com.increase.api.models
Class EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Trust.Trustee.Individual.Identification.Other.BuilderA builder for Other.
-
-
Method Summary
-
-
Method Detail
-
country
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder country(String country)
The two-character ISO 3166-1 code representing the country that issued the document.
-
country
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder country(JsonField<String> country)
The two-character ISO 3166-1 code representing the country that issued the document.
-
description
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder description(String description)
A description of the document submitted.
-
description
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder description(JsonField<String> description)
A description of the document submitted.
-
fileId
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder fileId(String fileId)
The identifier of the File containing the front of the document.
-
fileId
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder fileId(JsonField<String> fileId)
The identifier of the File containing the front of the document.
-
backFileId
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder backFileId(String backFileId)
The identifier of the File containing the back of the document. Not every document has a reverse side.
-
backFileId
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder backFileId(JsonField<String> backFileId)
The identifier of the File containing the back of the document. Not every document has a reverse side.
-
expirationDate
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder expirationDate(LocalDate expirationDate)
The document's expiration date in YYYY-MM-DD format.
-
expirationDate
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder expirationDate(JsonField<LocalDate> expirationDate)
The document's expiration date in YYYY-MM-DD format.
-
additionalProperties
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Trust.Trustee.Individual.Identification.Other.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-