Class EntitySupplementalDocument
-
- All Implemented Interfaces:
public final class EntitySupplementalDocumentSupplemental Documents are uploaded files connected to an Entity during onboarding.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntitySupplementalDocument.BuilderA builder for EntitySupplementalDocument.
public final classEntitySupplementalDocument.TypeA constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecreatedAt()The ISO 8601 time at which the Supplemental Document was created. final StringentityId()The Entity the supplemental document is attached to. final StringfileId()The File containing the document. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final EntitySupplementalDocument.Typetype()A constant representing the object's type. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Supplemental Document was created. final JsonField<String>_entityId()The Entity the supplemental document is attached to. final JsonField<String>_fileId()The File containing the document. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<EntitySupplementalDocument.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final EntitySupplementalDocumentvalidate()final EntitySupplementalDocument.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntitySupplementalDocument.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Supplemental Document was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final EntitySupplementalDocument.Type type()
A constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Supplemental Document was created.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_type
final JsonField<EntitySupplementalDocument.Type> _type()
A constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EntitySupplementalDocument validate()
-
toBuilder
final EntitySupplementalDocument.Builder toBuilder()
-
builder
final static EntitySupplementalDocument.Builder builder()
-
-
-
-