Class EntitySupplementalDocument.Builder
-
- All Implemented Interfaces:
public final class EntitySupplementalDocument.BuilderA builder for EntitySupplementalDocument.
-
-
Method Summary
-
-
Method Detail
-
createdAt
final EntitySupplementalDocument.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Supplemental Document was created.
-
createdAt
final EntitySupplementalDocument.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Supplemental Document was created.
-
entityId
final EntitySupplementalDocument.Builder entityId(String entityId)
The Entity the supplemental document is attached to.
-
entityId
final EntitySupplementalDocument.Builder entityId(JsonField<String> entityId)
The Entity the supplemental document is attached to.
-
fileId
final EntitySupplementalDocument.Builder fileId(String fileId)
The File containing the document.
-
fileId
final EntitySupplementalDocument.Builder fileId(JsonField<String> fileId)
The File containing the document.
-
idempotencyKey
final EntitySupplementalDocument.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final EntitySupplementalDocument.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final EntitySupplementalDocument.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final EntitySupplementalDocument.Builder type(EntitySupplementalDocument.Type type)
A constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
type
final EntitySupplementalDocument.Builder type(JsonField<EntitySupplementalDocument.Type> type)
A constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
additionalProperties
final EntitySupplementalDocument.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntitySupplementalDocument.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntitySupplementalDocument.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntitySupplementalDocument.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntitySupplementalDocument.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntitySupplementalDocument build()
-
-
-
-