Class EntityUpdateIndustryCodeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityUpdateIndustryCodeParams implements Params
Update the industry code for a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateIndustryCodeParams.Bodypublic final classEntityUpdateIndustryCodeParams.BuilderA builder for EntityUpdateIndustryCodeParams.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to update. final StringindustryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final JsonField<String>_industryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final EntityUpdateIndustryCodeParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateIndustryCodeParams.Builderbuilder()-
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to update. This endpoint only accepts
corporationentities.
-
industryCode
final String industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_industryCode
final JsonField<String> _industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final EntityUpdateIndustryCodeParams.Builder toBuilder()
-
builder
final static EntityUpdateIndustryCodeParams.Builder builder()
-
-
-
-