Class Event
-
- All Implemented Interfaces:
public final class EventEvents are records of things that happened to objects at Increase. Events are accessible via the List Events endpoint and can be delivered to your application via webhooks. For more information, see our webhooks guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEvent.BuilderA builder for Event.
public final classEvent.CategoryThe category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classEvent.TypeA constant representing the object's type. For this resource it will always be
event.
-
Method Summary
Modifier and Type Method Description final Stringid()The Event identifier. final StringassociatedObjectId()The identifier of the object that generated this Event. final StringassociatedObjectType()The type of the object that generated this Event. final Event.Categorycategory()The category of the Event. final OffsetDateTimecreatedAt()The time the Event was created. final Event.Typetype()A constant representing the object's type. final JsonField<String>_id()The Event identifier. final JsonField<String>_associatedObjectId()The identifier of the object that generated this Event. final JsonField<String>_associatedObjectType()The type of the object that generated this Event. final JsonField<Event.Category>_category()The category of the Event. final JsonField<OffsetDateTime>_createdAt()The time the Event was created. final JsonField<Event.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Eventvalidate()final Event.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Event.Builderbuilder()-
-
Method Detail
-
associatedObjectId
final String associatedObjectId()
The identifier of the object that generated this Event.
-
associatedObjectType
final String associatedObjectType()
The type of the object that generated this Event.
-
category
final Event.Category category()
The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
createdAt
final OffsetDateTime createdAt()
The time the Event was created.
-
type
final Event.Type type()
A constant representing the object's type. For this resource it will always be
event.
-
_associatedObjectId
final JsonField<String> _associatedObjectId()
The identifier of the object that generated this Event.
-
_associatedObjectType
final JsonField<String> _associatedObjectType()
The type of the object that generated this Event.
-
_category
final JsonField<Event.Category> _category()
The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The time the Event was created.
-
_type
final JsonField<Event.Type> _type()
A constant representing the object's type. For this resource it will always be
event.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Event.Builder toBuilder()
-
builder
final static Event.Builder builder()
-
-
-
-