Class EventSubscription
-
- All Implemented Interfaces:
public final class EventSubscriptionWebhooks are event notifications we send to you by HTTPS POST requests. Event Subscriptions are how you configure your application to listen for them. You can create an Event Subscription through your developer dashboard or the API. For more information, see our webhooks guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscription.BuilderA builder for EventSubscription.
public final classEventSubscription.SelectedEventCategoryIf specified, this subscription will only receive webhooks for Events with the specified
category.public final classEventSubscription.StatusThis indicates if we'll send notifications to this subscription.
public final classEventSubscription.TypeA constant representing the object's type. For this resource it will always be
event_subscription.
-
Method Summary
Modifier and Type Method Description final Stringid()The event subscription identifier. final OffsetDateTimecreatedAt()The time the event subscription was created. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection. final Optional<EventSubscription.SelectedEventCategory>selectedEventCategory()If specified, this subscription will only receive webhooks for Events with the specified category.final EventSubscription.Statusstatus()This indicates if we'll send notifications to this subscription. final EventSubscription.Typetype()A constant representing the object's type. final Stringurl()The webhook url where we'll send notifications. final JsonField<String>_id()The event subscription identifier. final JsonField<OffsetDateTime>_createdAt()The time the event subscription was created. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection. final JsonField<EventSubscription.SelectedEventCategory>_selectedEventCategory()If specified, this subscription will only receive webhooks for Events with the specified category.final JsonField<EventSubscription.Status>_status()This indicates if we'll send notifications to this subscription. final JsonField<EventSubscription.Type>_type()A constant representing the object's type. final JsonField<String>_url()The webhook url where we'll send notifications. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionvalidate()final EventSubscription.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscription.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The time the event subscription was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
oauthConnectionId
final Optional<String> oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
selectedEventCategory
final Optional<EventSubscription.SelectedEventCategory> selectedEventCategory()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
status
final EventSubscription.Status status()
This indicates if we'll send notifications to this subscription.
-
type
final EventSubscription.Type type()
A constant representing the object's type. For this resource it will always be
event_subscription.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The time the event subscription was created.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_oauthConnectionId
final JsonField<String> _oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
_selectedEventCategory
final JsonField<EventSubscription.SelectedEventCategory> _selectedEventCategory()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
_status
final JsonField<EventSubscription.Status> _status()
This indicates if we'll send notifications to this subscription.
-
_type
final JsonField<EventSubscription.Type> _type()
A constant representing the object's type. For this resource it will always be
event_subscription.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EventSubscription validate()
-
toBuilder
final EventSubscription.Builder toBuilder()
-
builder
final static EventSubscription.Builder builder()
-
-
-
-