Class EventSubscription.Builder
-
- All Implemented Interfaces:
public final class EventSubscription.BuilderA builder for EventSubscription.
-
-
Method Summary
Modifier and Type Method Description final EventSubscription.Builderid(String id)The event subscription identifier. final EventSubscription.Builderid(JsonField<String> id)The event subscription identifier. final EventSubscription.BuildercreatedAt(OffsetDateTime createdAt)The time the event subscription was created. final EventSubscription.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The time the event subscription was created. final EventSubscription.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final EventSubscription.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final EventSubscription.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final EventSubscription.BuilderoauthConnectionId(String oauthConnectionId)If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection. final EventSubscription.BuilderoauthConnectionId(Optional<String> oauthConnectionId)If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection. final EventSubscription.BuilderoauthConnectionId(JsonField<String> oauthConnectionId)If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection. final EventSubscription.BuilderselectedEventCategory(EventSubscription.SelectedEventCategory selectedEventCategory)If specified, this subscription will only receive webhooks for Events with the specified category.final EventSubscription.BuilderselectedEventCategory(Optional<EventSubscription.SelectedEventCategory> selectedEventCategory)If specified, this subscription will only receive webhooks for Events with the specified category.final EventSubscription.BuilderselectedEventCategory(JsonField<EventSubscription.SelectedEventCategory> selectedEventCategory)If specified, this subscription will only receive webhooks for Events with the specified category.final EventSubscription.Builderstatus(EventSubscription.Status status)This indicates if we'll send notifications to this subscription. final EventSubscription.Builderstatus(JsonField<EventSubscription.Status> status)This indicates if we'll send notifications to this subscription. final EventSubscription.Buildertype(EventSubscription.Type type)A constant representing the object's type. final EventSubscription.Buildertype(JsonField<EventSubscription.Type> type)A constant representing the object's type. final EventSubscription.Builderurl(String url)The webhook url where we'll send notifications. final EventSubscription.Builderurl(JsonField<String> url)The webhook url where we'll send notifications. final EventSubscription.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final EventSubscription.BuilderputAdditionalProperty(String key, JsonValue value)final EventSubscription.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final EventSubscription.BuilderremoveAdditionalProperty(String key)final EventSubscription.BuilderremoveAllAdditionalProperties(Set<String> keys)final EventSubscriptionbuild()-
-
Method Detail
-
id
final EventSubscription.Builder id(String id)
The event subscription identifier.
-
id
final EventSubscription.Builder id(JsonField<String> id)
The event subscription identifier.
-
createdAt
final EventSubscription.Builder createdAt(OffsetDateTime createdAt)
The time the event subscription was created.
-
createdAt
final EventSubscription.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The time the event subscription was created.
-
idempotencyKey
final EventSubscription.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final EventSubscription.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final EventSubscription.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
oauthConnectionId
final EventSubscription.Builder oauthConnectionId(String oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
oauthConnectionId
final EventSubscription.Builder oauthConnectionId(Optional<String> oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
oauthConnectionId
final EventSubscription.Builder oauthConnectionId(JsonField<String> oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
selectedEventCategory
final EventSubscription.Builder selectedEventCategory(EventSubscription.SelectedEventCategory selectedEventCategory)
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
selectedEventCategory
final EventSubscription.Builder selectedEventCategory(Optional<EventSubscription.SelectedEventCategory> selectedEventCategory)
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
selectedEventCategory
final EventSubscription.Builder selectedEventCategory(JsonField<EventSubscription.SelectedEventCategory> selectedEventCategory)
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
status
final EventSubscription.Builder status(EventSubscription.Status status)
This indicates if we'll send notifications to this subscription.
-
status
final EventSubscription.Builder status(JsonField<EventSubscription.Status> status)
This indicates if we'll send notifications to this subscription.
-
type
final EventSubscription.Builder type(EventSubscription.Type type)
A constant representing the object's type. For this resource it will always be
event_subscription.
-
type
final EventSubscription.Builder type(JsonField<EventSubscription.Type> type)
A constant representing the object's type. For this resource it will always be
event_subscription.
-
url
final EventSubscription.Builder url(String url)
The webhook url where we'll send notifications.
-
url
final EventSubscription.Builder url(JsonField<String> url)
The webhook url where we'll send notifications.
-
additionalProperties
final EventSubscription.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EventSubscription.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EventSubscription.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EventSubscription.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EventSubscription.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EventSubscription build()
-
-
-
-