Package com.increase.api.models
Class EventSubscriptionCreateParams.Body
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringurl()The URL you'd like us to send webhooks to. final Optional<String>oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection. final Optional<EventSubscriptionCreateParams.SelectedEventCategory>selectedEventCategory()If specified, this subscription will only receive webhooks for Events with the specified category.final Optional<String>sharedSecret()The key that will be used to sign webhooks. final JsonField<String>_url()The URL you'd like us to send webhooks to. final JsonField<String>_oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection. final JsonField<EventSubscriptionCreateParams.SelectedEventCategory>_selectedEventCategory()If specified, this subscription will only receive webhooks for Events with the specified category.final JsonField<String>_sharedSecret()The key that will be used to sign webhooks. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionCreateParams.Bodyvalidate()final EventSubscriptionCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionCreateParams.Body.Builderbuilder()-
-
Method Detail
-
oauthConnectionId
final Optional<String> oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
selectedEventCategory
final Optional<EventSubscriptionCreateParams.SelectedEventCategory> selectedEventCategory()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
sharedSecret
final Optional<String> sharedSecret()
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
_oauthConnectionId
final JsonField<String> _oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
_selectedEventCategory
final JsonField<EventSubscriptionCreateParams.SelectedEventCategory> _selectedEventCategory()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
_sharedSecret
final JsonField<String> _sharedSecret()
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final EventSubscriptionCreateParams.Body validate()
-
toBuilder
final EventSubscriptionCreateParams.Body.Builder toBuilder()
-
builder
final static EventSubscriptionCreateParams.Body.Builder builder()
-
-
-
-