Package com.increase.api.models
Class EventSubscriptionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
url
final EventSubscriptionCreateParams.Body.Builder url(String url)
The URL you'd like us to send webhooks to.
-
url
final EventSubscriptionCreateParams.Body.Builder url(JsonField<String> url)
The URL you'd like us to send webhooks to.
-
oauthConnectionId
final EventSubscriptionCreateParams.Body.Builder oauthConnectionId(String oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
oauthConnectionId
final EventSubscriptionCreateParams.Body.Builder oauthConnectionId(JsonField<String> oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
selectedEventCategory
final EventSubscriptionCreateParams.Body.Builder selectedEventCategory(EventSubscriptionCreateParams.SelectedEventCategory selectedEventCategory)
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
selectedEventCategory
final EventSubscriptionCreateParams.Body.Builder selectedEventCategory(JsonField<EventSubscriptionCreateParams.SelectedEventCategory> selectedEventCategory)
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
sharedSecret
final EventSubscriptionCreateParams.Body.Builder sharedSecret(String sharedSecret)
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
sharedSecret
final EventSubscriptionCreateParams.Body.Builder sharedSecret(JsonField<String> sharedSecret)
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
additionalProperties
final EventSubscriptionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EventSubscriptionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EventSubscriptionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EventSubscriptionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EventSubscriptionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EventSubscriptionCreateParams.Body build()
-
-
-
-