Class Export
-
- All Implemented Interfaces:
public final class ExportExports are batch summaries of your Increase data. You can make them from the API or dashboard. Since they can take a while, they are generated asynchronously. We send a webhook when they are ready. For more information, please read our Exports documentation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.BuilderA builder for Export.
public final classExport.CategoryThe category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
public final classExport.StatusThe status of the Export.
public final classExport.TypeA constant representing the object's type. For this resource it will always be
export.
-
Method Summary
Modifier and Type Method Description final Stringid()The Export identifier. final Export.Categorycategory()The category of the Export. final OffsetDateTimecreatedAt()The time the Export was created. final Optional<String>fileDownloadUrl()A URL at which the Export's file can be downloaded. final Optional<String>fileId()The File containing the contents of the Export. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Export.Statusstatus()The status of the Export. final Export.Typetype()A constant representing the object's type. final JsonField<String>_id()The Export identifier. final JsonField<Export.Category>_category()The category of the Export. final JsonField<OffsetDateTime>_createdAt()The time the Export was created. final JsonField<String>_fileDownloadUrl()A URL at which the Export's file can be downloaded. final JsonField<String>_fileId()The File containing the contents of the Export. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<Export.Status>_status()The status of the Export. final JsonField<Export.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Exportvalidate()final Export.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.Builderbuilder()-
-
Method Detail
-
category
final Export.Category category()
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
createdAt
final OffsetDateTime createdAt()
The time the Export was created.
-
fileDownloadUrl
final Optional<String> fileDownloadUrl()
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileId
final Optional<String> fileId()
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final Export.Status status()
The status of the Export.
-
type
final Export.Type type()
A constant representing the object's type. For this resource it will always be
export.
-
_category
final JsonField<Export.Category> _category()
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The time the Export was created.
-
_fileDownloadUrl
final JsonField<String> _fileDownloadUrl()
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
_fileId
final JsonField<String> _fileId()
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_status
final JsonField<Export.Status> _status()
The status of the Export.
-
_type
final JsonField<Export.Type> _type()
A constant representing the object's type. For this resource it will always be
export.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.Builder toBuilder()
-
builder
final static Export.Builder builder()
-
-
-
-