Class Export.Builder
-
- All Implemented Interfaces:
public final class Export.BuilderA builder for Export.
-
-
Method Summary
Modifier and Type Method Description final Export.Builderid(String id)The Export identifier. final Export.Builderid(JsonField<String> id)The Export identifier. final Export.Buildercategory(Export.Category category)The category of the Export. final Export.Buildercategory(JsonField<Export.Category> category)The category of the Export. final Export.BuildercreatedAt(OffsetDateTime createdAt)The time the Export was created. final Export.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The time the Export was created. final Export.BuilderfileDownloadUrl(String fileDownloadUrl)A URL at which the Export's file can be downloaded. final Export.BuilderfileDownloadUrl(Optional<String> fileDownloadUrl)A URL at which the Export's file can be downloaded. final Export.BuilderfileDownloadUrl(JsonField<String> fileDownloadUrl)A URL at which the Export's file can be downloaded. final Export.BuilderfileId(String fileId)The File containing the contents of the Export. final Export.BuilderfileId(Optional<String> fileId)The File containing the contents of the Export. final Export.BuilderfileId(JsonField<String> fileId)The File containing the contents of the Export. final Export.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Export.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final Export.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final Export.Builderstatus(Export.Status status)The status of the Export. final Export.Builderstatus(JsonField<Export.Status> status)The status of the Export. final Export.Buildertype(Export.Type type)A constant representing the object's type. final Export.Buildertype(JsonField<Export.Type> type)A constant representing the object's type. final Export.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Export.BuilderputAdditionalProperty(String key, JsonValue value)final Export.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Export.BuilderremoveAdditionalProperty(String key)final Export.BuilderremoveAllAdditionalProperties(Set<String> keys)final Exportbuild()-
-
Method Detail
-
id
final Export.Builder id(String id)
The Export identifier.
-
id
final Export.Builder id(JsonField<String> id)
The Export identifier.
-
category
final Export.Builder category(Export.Category category)
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
category
final Export.Builder category(JsonField<Export.Category> category)
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
createdAt
final Export.Builder createdAt(OffsetDateTime createdAt)
The time the Export was created.
-
createdAt
final Export.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The time the Export was created.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(String fileDownloadUrl)
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(Optional<String> fileDownloadUrl)
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(JsonField<String> fileDownloadUrl)
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileId
final Export.Builder fileId(String fileId)
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
fileId
final Export.Builder fileId(Optional<String> fileId)
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
fileId
final Export.Builder fileId(JsonField<String> fileId)
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
idempotencyKey
final Export.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Export.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Export.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final Export.Builder status(Export.Status status)
The status of the Export.
-
status
final Export.Builder status(JsonField<Export.Status> status)
The status of the Export.
-
type
final Export.Builder type(Export.Type type)
A constant representing the object's type. For this resource it will always be
export.
-
type
final Export.Builder type(JsonField<Export.Type> type)
A constant representing the object's type. For this resource it will always be
export.
-
additionalProperties
final Export.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-