Enum Export.Category.Known

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      ACCOUNT_STATEMENT_OFX

      Export an Open Financial Exchange (OFX) file of transactions and balances for a given time range and Account.

      TRANSACTION_CSV

      Export a CSV of all transactions for a given time range.

      BALANCE_CSV

      Export a CSV of account balances for the dates in a given range.

      BOOKKEEPING_ACCOUNT_BALANCE_CSV

      Export a CSV of bookkeeping account balances for the dates in a given range.

      ENTITY_CSV

      Export a CSV of entities with a given status.

      VENDOR_CSV

      Export a CSV of vendors added to the third-party risk management dashboard.

      DASHBOARD_TABLE_CSV

      Certain dashboard tables are available as CSV exports. This export cannot be created via the API.

    • Method Summary

      Modifier and Type Method Description
      final Export.Category.Known valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<Export.Category.Known> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<Export.Category.Known> getEntries() An enum containing Category's known values.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail