Enum Export.Category.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum Export.Category.Value
    extends Enum<Export.Category.Value>
                        

    An enum containing Category's known values, as well as an _UNKNOWN member.

    An instance of Category can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      ACCOUNT_STATEMENT_OFX

      Export an Open Financial Exchange (OFX) file of transactions and balances for a given time range and Account.

      TRANSACTION_CSV

      Export a CSV of all transactions for a given time range.

      BALANCE_CSV

      Export a CSV of account balances for the dates in a given range.

      BOOKKEEPING_ACCOUNT_BALANCE_CSV

      Export a CSV of bookkeeping account balances for the dates in a given range.

      ENTITY_CSV

      Export a CSV of entities with a given status.

      VENDOR_CSV

      Export a CSV of vendors added to the third-party risk management dashboard.

      DASHBOARD_TABLE_CSV

      Certain dashboard tables are available as CSV exports. This export cannot be created via the API.

      _UNKNOWN

      An enum member indicating that Category was instantiated with an unknown value.

    • Method Summary

      Modifier and Type Method Description
      final Export.Category.Value valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<Export.Category.Value> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<Export.Category.Value> getEntries() An enum containing Category's known values, as well as an _UNKNOWN member.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • valueOf

         final Export.Category.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • values

         final Array<Export.Category.Value> values()

        Returns an array containing the constants of this enum type, in the order they're declared.

        This method may be used to iterate over the constants.

      • getEntries

         final EnumEntries<Export.Category.Value> getEntries()

        An enum containing Category's known values, as well as an _UNKNOWN member.

        An instance of Category can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.