Enum ExportCreateParams.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ExportCreateParams.Category.Known extends Enum<ExportCreateParams.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ExportCreateParams.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_STATEMENT_OFXExport an Open Financial Exchange (OFX) file of transactions and balances for a given time range and Account.
TRANSACTION_CSVExport a CSV of all transactions for a given time range.
BALANCE_CSVExport a CSV of account balances for the dates in a given range.
BOOKKEEPING_ACCOUNT_BALANCE_CSVExport a CSV of bookkeeping account balances for the dates in a given range.
ENTITY_CSVExport a CSV of entities with a given status.
VENDOR_CSVExport a CSV of vendors added to the third-party risk management dashboard.
-
Method Summary
Modifier and Type Method Description final ExportCreateParams.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ExportCreateParams.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ExportCreateParams.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final ExportCreateParams.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ExportCreateParams.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ExportCreateParams.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-