Class ExternalAccount
-
- All Implemented Interfaces:
public final class ExternalAccountExternal Accounts represent accounts at financial institutions other than Increase. You can use this API to store their details for reuse.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccount.BuilderA builder for ExternalAccount.
public final classExternalAccount.AccountHolderThe type of entity that owns the External Account.
public final classExternalAccount.FundingThe type of the account to which the transfer will be sent.
public final classExternalAccount.StatusThe External Account's status.
public final classExternalAccount.TypeA constant representing the object's type. For this resource it will always be
external_account.public final classExternalAccount.VerificationStatusIf you have verified ownership of the External Account.
-
Method Summary
Modifier and Type Method Description final Stringid()The External Account's identifier. final ExternalAccount.AccountHolderaccountHolder()The type of entity that owns the External Account. final StringaccountNumber()The destination account number. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the External Account was created. final Stringdescription()The External Account's description for display purposes. final ExternalAccount.Fundingfunding()The type of the account to which the transfer will be sent. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final ExternalAccount.Statusstatus()The External Account's status. final ExternalAccount.Typetype()A constant representing the object's type. final ExternalAccount.VerificationStatusverificationStatus()If you have verified ownership of the External Account. final JsonField<String>_id()The External Account's identifier. final JsonField<ExternalAccount.AccountHolder>_accountHolder()The type of entity that owns the External Account. final JsonField<String>_accountNumber()The destination account number. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the External Account was created. final JsonField<String>_description()The External Account's description for display purposes. final JsonField<ExternalAccount.Funding>_funding()The type of the account to which the transfer will be sent. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<ExternalAccount.Status>_status()The External Account's status. final JsonField<ExternalAccount.Type>_type()A constant representing the object's type. final JsonField<ExternalAccount.VerificationStatus>_verificationStatus()If you have verified ownership of the External Account. final Map<String, JsonValue>_additionalProperties()final ExternalAccountvalidate()final ExternalAccount.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccount.Builderbuilder()-
-
Method Detail
-
accountHolder
final ExternalAccount.AccountHolder accountHolder()
The type of entity that owns the External Account.
-
accountNumber
final String accountNumber()
The destination account number.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the External Account was created.
-
description
final String description()
The External Account's description for display purposes.
-
funding
final ExternalAccount.Funding funding()
The type of the account to which the transfer will be sent.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final ExternalAccount.Status status()
The External Account's status.
-
type
final ExternalAccount.Type type()
A constant representing the object's type. For this resource it will always be
external_account.
-
verificationStatus
final ExternalAccount.VerificationStatus verificationStatus()
If you have verified ownership of the External Account.
-
_accountHolder
final JsonField<ExternalAccount.AccountHolder> _accountHolder()
The type of entity that owns the External Account.
-
_accountNumber
final JsonField<String> _accountNumber()
The destination account number.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the External Account was created.
-
_description
final JsonField<String> _description()
The External Account's description for display purposes.
-
_funding
final JsonField<ExternalAccount.Funding> _funding()
The type of the account to which the transfer will be sent.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_status
final JsonField<ExternalAccount.Status> _status()
The External Account's status.
-
_type
final JsonField<ExternalAccount.Type> _type()
A constant representing the object's type. For this resource it will always be
external_account.
-
_verificationStatus
final JsonField<ExternalAccount.VerificationStatus> _verificationStatus()
If you have verified ownership of the External Account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ExternalAccount validate()
-
toBuilder
final ExternalAccount.Builder toBuilder()
-
builder
final static ExternalAccount.Builder builder()
-
-
-
-