Class ExternalAccount.Builder
-
- All Implemented Interfaces:
public final class ExternalAccount.BuilderA builder for ExternalAccount.
-
-
Method Summary
Modifier and Type Method Description final ExternalAccount.Builderid(String id)The External Account's identifier. final ExternalAccount.Builderid(JsonField<String> id)The External Account's identifier. final ExternalAccount.BuilderaccountHolder(ExternalAccount.AccountHolder accountHolder)The type of entity that owns the External Account. final ExternalAccount.BuilderaccountHolder(JsonField<ExternalAccount.AccountHolder> accountHolder)The type of entity that owns the External Account. final ExternalAccount.BuilderaccountNumber(String accountNumber)The destination account number. final ExternalAccount.BuilderaccountNumber(JsonField<String> accountNumber)The destination account number. final ExternalAccount.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the External Account was created. final ExternalAccount.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the External Account was created. final ExternalAccount.Builderdescription(String description)The External Account's description for display purposes. final ExternalAccount.Builderdescription(JsonField<String> description)The External Account's description for display purposes. final ExternalAccount.Builderfunding(ExternalAccount.Funding funding)The type of the account to which the transfer will be sent. final ExternalAccount.Builderfunding(JsonField<ExternalAccount.Funding> funding)The type of the account to which the transfer will be sent. final ExternalAccount.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final ExternalAccount.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final ExternalAccount.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final ExternalAccount.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final ExternalAccount.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final ExternalAccount.Builderstatus(ExternalAccount.Status status)The External Account's status. final ExternalAccount.Builderstatus(JsonField<ExternalAccount.Status> status)The External Account's status. final ExternalAccount.Buildertype(ExternalAccount.Type type)A constant representing the object's type. final ExternalAccount.Buildertype(JsonField<ExternalAccount.Type> type)A constant representing the object's type. final ExternalAccount.BuilderverificationStatus(ExternalAccount.VerificationStatus verificationStatus)If you have verified ownership of the External Account. final ExternalAccount.BuilderverificationStatus(JsonField<ExternalAccount.VerificationStatus> verificationStatus)If you have verified ownership of the External Account. final ExternalAccount.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ExternalAccount.BuilderputAdditionalProperty(String key, JsonValue value)final ExternalAccount.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ExternalAccount.BuilderremoveAdditionalProperty(String key)final ExternalAccount.BuilderremoveAllAdditionalProperties(Set<String> keys)final ExternalAccountbuild()-
-
Method Detail
-
id
final ExternalAccount.Builder id(String id)
The External Account's identifier.
-
id
final ExternalAccount.Builder id(JsonField<String> id)
The External Account's identifier.
-
accountHolder
final ExternalAccount.Builder accountHolder(ExternalAccount.AccountHolder accountHolder)
The type of entity that owns the External Account.
-
accountHolder
final ExternalAccount.Builder accountHolder(JsonField<ExternalAccount.AccountHolder> accountHolder)
The type of entity that owns the External Account.
-
accountNumber
final ExternalAccount.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final ExternalAccount.Builder accountNumber(JsonField<String> accountNumber)
The destination account number.
-
createdAt
final ExternalAccount.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the External Account was created.
-
createdAt
final ExternalAccount.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the External Account was created.
-
description
final ExternalAccount.Builder description(String description)
The External Account's description for display purposes.
-
description
final ExternalAccount.Builder description(JsonField<String> description)
The External Account's description for display purposes.
-
funding
final ExternalAccount.Builder funding(ExternalAccount.Funding funding)
The type of the account to which the transfer will be sent.
-
funding
final ExternalAccount.Builder funding(JsonField<ExternalAccount.Funding> funding)
The type of the account to which the transfer will be sent.
-
idempotencyKey
final ExternalAccount.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final ExternalAccount.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final ExternalAccount.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
routingNumber
final ExternalAccount.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final ExternalAccount.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final ExternalAccount.Builder status(ExternalAccount.Status status)
The External Account's status.
-
status
final ExternalAccount.Builder status(JsonField<ExternalAccount.Status> status)
The External Account's status.
-
type
final ExternalAccount.Builder type(ExternalAccount.Type type)
A constant representing the object's type. For this resource it will always be
external_account.
-
type
final ExternalAccount.Builder type(JsonField<ExternalAccount.Type> type)
A constant representing the object's type. For this resource it will always be
external_account.
-
verificationStatus
final ExternalAccount.Builder verificationStatus(ExternalAccount.VerificationStatus verificationStatus)
If you have verified ownership of the External Account.
-
verificationStatus
final ExternalAccount.Builder verificationStatus(JsonField<ExternalAccount.VerificationStatus> verificationStatus)
If you have verified ownership of the External Account.
-
additionalProperties
final ExternalAccount.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalAccount.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalAccount.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalAccount.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalAccount.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalAccount build()
-
-
-
-