Class ExternalAccountCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExternalAccountCreateParams implements Params
Create an External Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountCreateParams.Bodypublic final classExternalAccountCreateParams.BuilderA builder for ExternalAccountCreateParams.
public final classExternalAccountCreateParams.AccountHolderThe type of entity that owns the External Account.
public final classExternalAccountCreateParams.FundingThe type of the destination account. Defaults to
checking.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number for the destination account. final Stringdescription()The name you choose for the Account. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<ExternalAccountCreateParams.AccountHolder>accountHolder()The type of entity that owns the External Account. final Optional<ExternalAccountCreateParams.Funding>funding()The type of the destination account. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<String>_description()The name you choose for the Account. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<ExternalAccountCreateParams.AccountHolder>_accountHolder()The type of entity that owns the External Account. final JsonField<ExternalAccountCreateParams.Funding>_funding()The type of the destination account. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final ExternalAccountCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountCreateParams.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
description
final String description()
The name you choose for the Account.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
accountHolder
final Optional<ExternalAccountCreateParams.AccountHolder> accountHolder()
The type of entity that owns the External Account.
-
funding
final Optional<ExternalAccountCreateParams.Funding> funding()
The type of the destination account. Defaults to
checking.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_description
final JsonField<String> _description()
The name you choose for the Account.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_accountHolder
final JsonField<ExternalAccountCreateParams.AccountHolder> _accountHolder()
The type of entity that owns the External Account.
-
_funding
final JsonField<ExternalAccountCreateParams.Funding> _funding()
The type of the destination account. Defaults to
checking.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final ExternalAccountCreateParams.Builder toBuilder()
-
builder
final static ExternalAccountCreateParams.Builder builder()
-
-
-
-