Package com.increase.api.models
Class ExternalAccountCreateParams.Body
-
- All Implemented Interfaces:
public final class ExternalAccountCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number for the destination account. final Stringdescription()The name you choose for the Account. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<ExternalAccountCreateParams.AccountHolder>accountHolder()The type of entity that owns the External Account. final Optional<ExternalAccountCreateParams.Funding>funding()The type of the destination account. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<String>_description()The name you choose for the Account. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<ExternalAccountCreateParams.AccountHolder>_accountHolder()The type of entity that owns the External Account. final JsonField<ExternalAccountCreateParams.Funding>_funding()The type of the destination account. final Map<String, JsonValue>_additionalProperties()final ExternalAccountCreateParams.Bodyvalidate()final ExternalAccountCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountCreateParams.Body.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
description
final String description()
The name you choose for the Account.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
accountHolder
final Optional<ExternalAccountCreateParams.AccountHolder> accountHolder()
The type of entity that owns the External Account.
-
funding
final Optional<ExternalAccountCreateParams.Funding> funding()
The type of the destination account. Defaults to
checking.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_description
final JsonField<String> _description()
The name you choose for the Account.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_accountHolder
final JsonField<ExternalAccountCreateParams.AccountHolder> _accountHolder()
The type of entity that owns the External Account.
-
_funding
final JsonField<ExternalAccountCreateParams.Funding> _funding()
The type of the destination account. Defaults to
checking.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ExternalAccountCreateParams.Body validate()
-
toBuilder
final ExternalAccountCreateParams.Body.Builder toBuilder()
-
builder
final static ExternalAccountCreateParams.Body.Builder builder()
-
-
-
-