Package com.increase.api.models
Class ExternalAccountCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ExternalAccountCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumber
final ExternalAccountCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final ExternalAccountCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
The account number for the destination account.
-
description
final ExternalAccountCreateParams.Body.Builder description(String description)
The name you choose for the Account.
-
description
final ExternalAccountCreateParams.Body.Builder description(JsonField<String> description)
The name you choose for the Account.
-
routingNumber
final ExternalAccountCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final ExternalAccountCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
accountHolder
final ExternalAccountCreateParams.Body.Builder accountHolder(ExternalAccountCreateParams.AccountHolder accountHolder)
The type of entity that owns the External Account.
-
accountHolder
final ExternalAccountCreateParams.Body.Builder accountHolder(JsonField<ExternalAccountCreateParams.AccountHolder> accountHolder)
The type of entity that owns the External Account.
-
funding
final ExternalAccountCreateParams.Body.Builder funding(ExternalAccountCreateParams.Funding funding)
The type of the destination account. Defaults to
checking.
-
funding
final ExternalAccountCreateParams.Body.Builder funding(JsonField<ExternalAccountCreateParams.Funding> funding)
The type of the destination account. Defaults to
checking.
-
additionalProperties
final ExternalAccountCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalAccountCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalAccountCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalAccountCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalAccountCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalAccountCreateParams.Body build()
-
-
-
-