Class ExternalAccountUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExternalAccountUpdateParams implements Params
Update an External Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountUpdateParams.Bodypublic final classExternalAccountUpdateParams.BuilderA builder for ExternalAccountUpdateParams.
public final classExternalAccountUpdateParams.AccountHolderThe type of entity that owns the External Account.
public final classExternalAccountUpdateParams.FundingThe funding type of the External Account.
public final classExternalAccountUpdateParams.StatusThe status of the External Account.
-
Method Summary
Modifier and Type Method Description final StringexternalAccountId()The external account identifier. final Optional<ExternalAccountUpdateParams.AccountHolder>accountHolder()The type of entity that owns the External Account. final Optional<String>description()The description you choose to give the external account. final Optional<ExternalAccountUpdateParams.Funding>funding()The funding type of the External Account. final Optional<ExternalAccountUpdateParams.Status>status()The status of the External Account. final JsonField<ExternalAccountUpdateParams.AccountHolder>_accountHolder()The type of entity that owns the External Account. final JsonField<String>_description()The description you choose to give the external account. final JsonField<ExternalAccountUpdateParams.Funding>_funding()The funding type of the External Account. final JsonField<ExternalAccountUpdateParams.Status>_status()The status of the External Account. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final ExternalAccountUpdateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountUpdateParams.Builderbuilder()-
-
Method Detail
-
externalAccountId
final String externalAccountId()
The external account identifier.
-
accountHolder
final Optional<ExternalAccountUpdateParams.AccountHolder> accountHolder()
The type of entity that owns the External Account.
-
description
final Optional<String> description()
The description you choose to give the external account.
-
funding
final Optional<ExternalAccountUpdateParams.Funding> funding()
The funding type of the External Account.
-
status
final Optional<ExternalAccountUpdateParams.Status> status()
The status of the External Account.
-
_accountHolder
final JsonField<ExternalAccountUpdateParams.AccountHolder> _accountHolder()
The type of entity that owns the External Account.
-
_description
final JsonField<String> _description()
The description you choose to give the external account.
-
_funding
final JsonField<ExternalAccountUpdateParams.Funding> _funding()
The funding type of the External Account.
-
_status
final JsonField<ExternalAccountUpdateParams.Status> _status()
The status of the External Account.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final ExternalAccountUpdateParams.Builder toBuilder()
-
builder
final static ExternalAccountUpdateParams.Builder builder()
-
-
-
-