Package com.increase.api.models
Enum ExternalAccountUpdateParams.AccountHolder.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ExternalAccountUpdateParams.AccountHolder.Known extends Enum<ExternalAccountUpdateParams.AccountHolder.Known>
An enum containing AccountHolder's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ExternalAccountUpdateParams.AccountHolder.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description BUSINESSThe External Account is owned by a business.
INDIVIDUALThe External Account is owned by an individual.
-
Method Summary
Modifier and Type Method Description final ExternalAccountUpdateParams.AccountHolder.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ExternalAccountUpdateParams.AccountHolder.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ExternalAccountUpdateParams.AccountHolder.Known>getEntries()An enum containing AccountHolder's known values. -
-
Method Detail
-
valueOf
final ExternalAccountUpdateParams.AccountHolder.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ExternalAccountUpdateParams.AccountHolder.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ExternalAccountUpdateParams.AccountHolder.Known> getEntries()
An enum containing AccountHolder's known values.
-
-
-
-