Class File
-
- All Implemented Interfaces:
public final class FileFiles are objects that represent a file hosted on Increase's servers. The file may have been uploaded by you (for example, when uploading a check image) or it may have been created by Increase (for example, an autogenerated statement PDF).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFile.BuilderA builder for File.
public final classFile.DirectionWhether the File was generated by Increase or by you and sent to Increase.
public final classFile.PurposeWhat the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classFile.TypeA constant representing the object's type. For this resource it will always be
file.
-
Method Summary
Modifier and Type Method Description final Stringid()The File's identifier. final OffsetDateTimecreatedAt()The time the File was created. final Optional<String>description()A description of the File. final File.Directiondirection()Whether the File was generated by Increase or by you and sent to Increase. final Optional<String>downloadUrl()A URL from where the File can be downloaded at this point in time. final Optional<String>filename()The filename that was provided upon upload or generated by Increase. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringmimeType()The MIME type of the file. final File.Purposepurpose()What the File will be used for. final File.Typetype()A constant representing the object's type. final JsonField<String>_id()The File's identifier. final JsonField<OffsetDateTime>_createdAt()The time the File was created. final JsonField<String>_description()A description of the File. final JsonField<File.Direction>_direction()Whether the File was generated by Increase or by you and sent to Increase. final JsonField<String>_downloadUrl()A URL from where the File can be downloaded at this point in time. final JsonField<String>_filename()The filename that was provided upon upload or generated by Increase. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_mimeType()The MIME type of the file. final JsonField<File.Purpose>_purpose()What the File will be used for. final JsonField<File.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Filevalidate()final File.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static File.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The time the File was created.
-
description
final Optional<String> description()
A description of the File.
-
direction
final File.Direction direction()
Whether the File was generated by Increase or by you and sent to Increase.
-
downloadUrl
final Optional<String> downloadUrl()
A URL from where the File can be downloaded at this point in time. The location of this URL may change over time.
-
filename
final Optional<String> filename()
The filename that was provided upon upload or generated by Increase.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
purpose
final File.Purpose purpose()
What the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
type
final File.Type type()
A constant representing the object's type. For this resource it will always be
file.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The time the File was created.
-
_description
final JsonField<String> _description()
A description of the File.
-
_direction
final JsonField<File.Direction> _direction()
Whether the File was generated by Increase or by you and sent to Increase.
-
_downloadUrl
final JsonField<String> _downloadUrl()
A URL from where the File can be downloaded at this point in time. The location of this URL may change over time.
-
_filename
final JsonField<String> _filename()
The filename that was provided upon upload or generated by Increase.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_purpose
final JsonField<File.Purpose> _purpose()
What the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
_type
final JsonField<File.Type> _type()
A constant representing the object's type. For this resource it will always be
file.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final File.Builder toBuilder()
-
builder
final static File.Builder builder()
-
-
-
-