Class File.Builder
-
- All Implemented Interfaces:
public final class File.BuilderA builder for File.
-
-
Method Summary
Modifier and Type Method Description final File.Builderid(String id)The File's identifier. final File.Builderid(JsonField<String> id)The File's identifier. final File.BuildercreatedAt(OffsetDateTime createdAt)The time the File was created. final File.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The time the File was created. final File.Builderdescription(String description)A description of the File. final File.Builderdescription(Optional<String> description)A description of the File. final File.Builderdescription(JsonField<String> description)A description of the File. final File.Builderdirection(File.Direction direction)Whether the File was generated by Increase or by you and sent to Increase. final File.Builderdirection(JsonField<File.Direction> direction)Whether the File was generated by Increase or by you and sent to Increase. final File.BuilderdownloadUrl(String downloadUrl)A URL from where the File can be downloaded at this point in time. final File.BuilderdownloadUrl(Optional<String> downloadUrl)A URL from where the File can be downloaded at this point in time. final File.BuilderdownloadUrl(JsonField<String> downloadUrl)A URL from where the File can be downloaded at this point in time. final File.Builderfilename(String filename)The filename that was provided upon upload or generated by Increase. final File.Builderfilename(Optional<String> filename)The filename that was provided upon upload or generated by Increase. final File.Builderfilename(JsonField<String> filename)The filename that was provided upon upload or generated by Increase. final File.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final File.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final File.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final File.BuildermimeType(String mimeType)The MIME type of the file. final File.BuildermimeType(JsonField<String> mimeType)The MIME type of the file. final File.Builderpurpose(File.Purpose purpose)What the File will be used for. final File.Builderpurpose(JsonField<File.Purpose> purpose)What the File will be used for. final File.Buildertype(File.Type type)A constant representing the object's type. final File.Buildertype(JsonField<File.Type> type)A constant representing the object's type. final File.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final File.BuilderputAdditionalProperty(String key, JsonValue value)final File.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final File.BuilderremoveAdditionalProperty(String key)final File.BuilderremoveAllAdditionalProperties(Set<String> keys)final Filebuild()-
-
Method Detail
-
id
final File.Builder id(String id)
The File's identifier.
-
id
final File.Builder id(JsonField<String> id)
The File's identifier.
-
createdAt
final File.Builder createdAt(OffsetDateTime createdAt)
The time the File was created.
-
createdAt
final File.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The time the File was created.
-
description
final File.Builder description(String description)
A description of the File.
-
description
final File.Builder description(Optional<String> description)
A description of the File.
-
description
final File.Builder description(JsonField<String> description)
A description of the File.
-
direction
final File.Builder direction(File.Direction direction)
Whether the File was generated by Increase or by you and sent to Increase.
-
direction
final File.Builder direction(JsonField<File.Direction> direction)
Whether the File was generated by Increase or by you and sent to Increase.
-
downloadUrl
final File.Builder downloadUrl(String downloadUrl)
A URL from where the File can be downloaded at this point in time. The location of this URL may change over time.
-
downloadUrl
final File.Builder downloadUrl(Optional<String> downloadUrl)
A URL from where the File can be downloaded at this point in time. The location of this URL may change over time.
-
downloadUrl
final File.Builder downloadUrl(JsonField<String> downloadUrl)
A URL from where the File can be downloaded at this point in time. The location of this URL may change over time.
-
filename
final File.Builder filename(String filename)
The filename that was provided upon upload or generated by Increase.
-
filename
final File.Builder filename(Optional<String> filename)
The filename that was provided upon upload or generated by Increase.
-
filename
final File.Builder filename(JsonField<String> filename)
The filename that was provided upon upload or generated by Increase.
-
idempotencyKey
final File.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final File.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final File.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
mimeType
final File.Builder mimeType(String mimeType)
The MIME type of the file.
-
mimeType
final File.Builder mimeType(JsonField<String> mimeType)
The MIME type of the file.
-
purpose
final File.Builder purpose(File.Purpose purpose)
What the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
purpose
final File.Builder purpose(JsonField<File.Purpose> purpose)
What the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
type
final File.Builder type(File.Type type)
A constant representing the object's type. For this resource it will always be
file.
-
type
final File.Builder type(JsonField<File.Type> type)
A constant representing the object's type. For this resource it will always be
file.
-
additionalProperties
final File.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final File.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final File.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final File.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final File.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-