Class InboundAchTransfer
-
- All Implemented Interfaces:
public final class InboundAchTransferAn Inbound ACH Transfer is an ACH transfer initiated outside of Increase to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.BuilderA builder for InboundAchTransfer.
public final classInboundAchTransfer.AcceptanceIf your transfer is accepted, this will contain details of the acceptance.
public final classInboundAchTransfer.AddendaAdditional information sent from the originator.
public final classInboundAchTransfer.DeclineIf your transfer is declined, this will contain details of the decline.
public final classInboundAchTransfer.DirectionThe direction of the transfer.
public final classInboundAchTransfer.ExpectedSettlementScheduleThe settlement schedule the transfer is expected to follow.
public final classInboundAchTransfer.InternationalAddendaIf the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
public final classInboundAchTransfer.NotificationOfChangeIf you initiate a notification of change in response to the transfer, this will contain its details.
public final classInboundAchTransfer.StandardEntryClassCodeThe Standard Entry Class (SEC) code of the transfer.
public final classInboundAchTransfer.StatusThe status of the transfer.
public final classInboundAchTransfer.TransferReturnIf your transfer is returned, this will contain details of the return.
public final classInboundAchTransfer.TypeA constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The inbound ACH transfer's identifier. final Optional<InboundAchTransfer.Acceptance>acceptance()If your transfer is accepted, this will contain details of the acceptance. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumberId()The identifier of the Account Number to which this transfer was sent. final Optional<InboundAchTransfer.Addenda>addenda()Additional information sent from the originator. final Longamount()The transfer amount in USD cents. final OffsetDateTimeautomaticallyResolvesAt()The time at which the transfer will be automatically resolved. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound ACH transfer was created. final Optional<InboundAchTransfer.Decline>decline()If your transfer is declined, this will contain details of the decline. final InboundAchTransfer.Directiondirection()The direction of the transfer. final LocalDateeffectiveDate()The effective date of the transfer. final InboundAchTransfer.ExpectedSettlementScheduleexpectedSettlementSchedule()The settlement schedule the transfer is expected to follow. final Optional<InboundAchTransfer.InternationalAddenda>internationalAddenda()If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction. final Optional<InboundAchTransfer.NotificationOfChange>notificationOfChange()If you initiate a notification of change in response to the transfer, this will contain its details. final Optional<String>originatorCompanyDescriptiveDate()The descriptive date of the transfer. final Optional<String>originatorCompanyDiscretionaryData()The additional information included with the transfer. final StringoriginatorCompanyEntryDescription()The description of the transfer. final StringoriginatorCompanyId()The id of the company that initiated the transfer. final StringoriginatorCompanyName()The name of the company that initiated the transfer. final StringoriginatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>receiverIdNumber()The id of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final InboundAchTransfer.StandardEntryClassCodestandardEntryClassCode()The Standard Entry Class (SEC) code of the transfer. final InboundAchTransfer.Statusstatus()The status of the transfer. final StringtraceNumber()A 15 digit number set by the sending bank and transmitted to the receiving bank. final Optional<InboundAchTransfer.TransferReturn>transferReturn()If your transfer is returned, this will contain details of the return. final InboundAchTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The inbound ACH transfer's identifier. final JsonField<InboundAchTransfer.Acceptance>_acceptance()If your transfer is accepted, this will contain details of the acceptance. final JsonField<String>_accountId()The Account to which the transfer belongs. final JsonField<String>_accountNumberId()The identifier of the Account Number to which this transfer was sent. final JsonField<InboundAchTransfer.Addenda>_addenda()Additional information sent from the originator. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<OffsetDateTime>_automaticallyResolvesAt()The time at which the transfer will be automatically resolved. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the inbound ACH transfer was created. final JsonField<InboundAchTransfer.Decline>_decline()If your transfer is declined, this will contain details of the decline. final JsonField<InboundAchTransfer.Direction>_direction()The direction of the transfer. final JsonField<LocalDate>_effectiveDate()The effective date of the transfer. final JsonField<InboundAchTransfer.ExpectedSettlementSchedule>_expectedSettlementSchedule()The settlement schedule the transfer is expected to follow. final JsonField<InboundAchTransfer.InternationalAddenda>_internationalAddenda()If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction. final JsonField<InboundAchTransfer.NotificationOfChange>_notificationOfChange()If you initiate a notification of change in response to the transfer, this will contain its details. final JsonField<String>_originatorCompanyDescriptiveDate()The descriptive date of the transfer. final JsonField<String>_originatorCompanyDiscretionaryData()The additional information included with the transfer. final JsonField<String>_originatorCompanyEntryDescription()The description of the transfer. final JsonField<String>_originatorCompanyId()The id of the company that initiated the transfer. final JsonField<String>_originatorCompanyName()The name of the company that initiated the transfer. final JsonField<String>_originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final JsonField<String>_receiverIdNumber()The id of the receiver of the transfer. final JsonField<String>_receiverName()The name of the receiver of the transfer. final JsonField<InboundAchTransfer.StandardEntryClassCode>_standardEntryClassCode()The Standard Entry Class (SEC) code of the transfer. final JsonField<InboundAchTransfer.Status>_status()The status of the transfer. final JsonField<String>_traceNumber()A 15 digit number set by the sending bank and transmitted to the receiving bank. final JsonField<InboundAchTransfer.TransferReturn>_transferReturn()If your transfer is returned, this will contain details of the return. final JsonField<InboundAchTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfervalidate()final InboundAchTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Builderbuilder()-
-
Method Detail
-
acceptance
final Optional<InboundAchTransfer.Acceptance> acceptance()
If your transfer is accepted, this will contain details of the acceptance.
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
addenda
final Optional<InboundAchTransfer.Addenda> addenda()
Additional information sent from the originator.
-
automaticallyResolvesAt
final OffsetDateTime automaticallyResolvesAt()
The time at which the transfer will be automatically resolved.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound ACH transfer was created.
-
decline
final Optional<InboundAchTransfer.Decline> decline()
If your transfer is declined, this will contain details of the decline.
-
direction
final InboundAchTransfer.Direction direction()
The direction of the transfer.
-
effectiveDate
final LocalDate effectiveDate()
The effective date of the transfer. This is sent by the sending bank and is a factor in determining funds availability.
-
expectedSettlementSchedule
final InboundAchTransfer.ExpectedSettlementSchedule expectedSettlementSchedule()
The settlement schedule the transfer is expected to follow.
-
internationalAddenda
final Optional<InboundAchTransfer.InternationalAddenda> internationalAddenda()
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
notificationOfChange
final Optional<InboundAchTransfer.NotificationOfChange> notificationOfChange()
If you initiate a notification of change in response to the transfer, this will contain its details.
-
originatorCompanyDescriptiveDate
final Optional<String> originatorCompanyDescriptiveDate()
The descriptive date of the transfer.
-
originatorCompanyDiscretionaryData
final Optional<String> originatorCompanyDiscretionaryData()
The additional information included with the transfer.
-
originatorCompanyEntryDescription
final String originatorCompanyEntryDescription()
The description of the transfer.
-
originatorCompanyId
final String originatorCompanyId()
The id of the company that initiated the transfer.
-
originatorCompanyName
final String originatorCompanyName()
The name of the company that initiated the transfer.
-
originatorRoutingNumber
final String originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The id of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
standardEntryClassCode
final InboundAchTransfer.StandardEntryClassCode standardEntryClassCode()
The Standard Entry Class (SEC) code of the transfer.
-
status
final InboundAchTransfer.Status status()
The status of the transfer.
-
traceNumber
final String traceNumber()
A 15 digit number set by the sending bank and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer. ACH trace numbers are not unique, but are used to correlate returns.
-
transferReturn
final Optional<InboundAchTransfer.TransferReturn> transferReturn()
If your transfer is returned, this will contain details of the return.
-
type
final InboundAchTransfer.Type type()
A constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
_acceptance
final JsonField<InboundAchTransfer.Acceptance> _acceptance()
If your transfer is accepted, this will contain details of the acceptance.
-
_accountId
final JsonField<String> _accountId()
The Account to which the transfer belongs.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
_addenda
final JsonField<InboundAchTransfer.Addenda> _addenda()
Additional information sent from the originator.
-
_automaticallyResolvesAt
final JsonField<OffsetDateTime> _automaticallyResolvesAt()
The time at which the transfer will be automatically resolved.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the inbound ACH transfer was created.
-
_decline
final JsonField<InboundAchTransfer.Decline> _decline()
If your transfer is declined, this will contain details of the decline.
-
_direction
final JsonField<InboundAchTransfer.Direction> _direction()
The direction of the transfer.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
The effective date of the transfer. This is sent by the sending bank and is a factor in determining funds availability.
-
_expectedSettlementSchedule
final JsonField<InboundAchTransfer.ExpectedSettlementSchedule> _expectedSettlementSchedule()
The settlement schedule the transfer is expected to follow.
-
_internationalAddenda
final JsonField<InboundAchTransfer.InternationalAddenda> _internationalAddenda()
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
_notificationOfChange
final JsonField<InboundAchTransfer.NotificationOfChange> _notificationOfChange()
If you initiate a notification of change in response to the transfer, this will contain its details.
-
_originatorCompanyDescriptiveDate
final JsonField<String> _originatorCompanyDescriptiveDate()
The descriptive date of the transfer.
-
_originatorCompanyDiscretionaryData
final JsonField<String> _originatorCompanyDiscretionaryData()
The additional information included with the transfer.
-
_originatorCompanyEntryDescription
final JsonField<String> _originatorCompanyEntryDescription()
The description of the transfer.
-
_originatorCompanyId
final JsonField<String> _originatorCompanyId()
The id of the company that initiated the transfer.
-
_originatorCompanyName
final JsonField<String> _originatorCompanyName()
The name of the company that initiated the transfer.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
The id of the receiver of the transfer.
-
_receiverName
final JsonField<String> _receiverName()
The name of the receiver of the transfer.
-
_standardEntryClassCode
final JsonField<InboundAchTransfer.StandardEntryClassCode> _standardEntryClassCode()
The Standard Entry Class (SEC) code of the transfer.
-
_status
final JsonField<InboundAchTransfer.Status> _status()
The status of the transfer.
-
_traceNumber
final JsonField<String> _traceNumber()
A 15 digit number set by the sending bank and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer. ACH trace numbers are not unique, but are used to correlate returns.
-
_transferReturn
final JsonField<InboundAchTransfer.TransferReturn> _transferReturn()
If your transfer is returned, this will contain details of the return.
-
_type
final JsonField<InboundAchTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransfer validate()
-
toBuilder
final InboundAchTransfer.Builder toBuilder()
-
builder
final static InboundAchTransfer.Builder builder()
-
-
-
-