Package com.increase.api.models
Class InboundAchTransfer.Acceptance
-
- All Implemented Interfaces:
public final class InboundAchTransfer.AcceptanceIf your transfer is accepted, this will contain details of the acceptance.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.Acceptance.BuilderA builder for Acceptance.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The time at which the transfer was accepted. final StringtransactionId()The id of the transaction for the accepted transfer. final JsonField<OffsetDateTime>_acceptedAt()The time at which the transfer was accepted. final JsonField<String>_transactionId()The id of the transaction for the accepted transfer. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.Acceptancevalidate()final InboundAchTransfer.Acceptance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Acceptance.Builderbuilder()-
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The time at which the transfer was accepted.
-
transactionId
final String transactionId()
The id of the transaction for the accepted transfer.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
The time at which the transfer was accepted.
-
_transactionId
final JsonField<String> _transactionId()
The id of the transaction for the accepted transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransfer.Acceptance validate()
-
toBuilder
final InboundAchTransfer.Acceptance.Builder toBuilder()
-
builder
final static InboundAchTransfer.Acceptance.Builder builder()
-
-
-
-