Class InboundAchTransfer.Builder
-
- All Implemented Interfaces:
public final class InboundAchTransfer.BuilderA builder for InboundAchTransfer.
-
-
Method Summary
Modifier and Type Method Description final InboundAchTransfer.Builderid(String id)The inbound ACH transfer's identifier. final InboundAchTransfer.Builderid(JsonField<String> id)The inbound ACH transfer's identifier. final InboundAchTransfer.Builderacceptance(InboundAchTransfer.Acceptance acceptance)If your transfer is accepted, this will contain details of the acceptance. final InboundAchTransfer.Builderacceptance(Optional<InboundAchTransfer.Acceptance> acceptance)If your transfer is accepted, this will contain details of the acceptance. final InboundAchTransfer.Builderacceptance(JsonField<InboundAchTransfer.Acceptance> acceptance)If your transfer is accepted, this will contain details of the acceptance. final InboundAchTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final InboundAchTransfer.BuilderaccountId(JsonField<String> accountId)The Account to which the transfer belongs. final InboundAchTransfer.BuilderaccountNumberId(String accountNumberId)The identifier of the Account Number to which this transfer was sent. final InboundAchTransfer.BuilderaccountNumberId(JsonField<String> accountNumberId)The identifier of the Account Number to which this transfer was sent. final InboundAchTransfer.Builderaddenda(InboundAchTransfer.Addenda addenda)Additional information sent from the originator. final InboundAchTransfer.Builderaddenda(Optional<InboundAchTransfer.Addenda> addenda)Additional information sent from the originator. final InboundAchTransfer.Builderaddenda(JsonField<InboundAchTransfer.Addenda> addenda)Additional information sent from the originator. final InboundAchTransfer.Builderamount(Long amount)The transfer amount in USD cents. final InboundAchTransfer.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final InboundAchTransfer.BuilderautomaticallyResolvesAt(OffsetDateTime automaticallyResolvesAt)The time at which the transfer will be automatically resolved. final InboundAchTransfer.BuilderautomaticallyResolvesAt(JsonField<OffsetDateTime> automaticallyResolvesAt)The time at which the transfer will be automatically resolved. final InboundAchTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the inbound ACH transfer was created. final InboundAchTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the inbound ACH transfer was created. final InboundAchTransfer.Builderdecline(InboundAchTransfer.Decline decline)If your transfer is declined, this will contain details of the decline. final InboundAchTransfer.Builderdecline(Optional<InboundAchTransfer.Decline> decline)If your transfer is declined, this will contain details of the decline. final InboundAchTransfer.Builderdecline(JsonField<InboundAchTransfer.Decline> decline)If your transfer is declined, this will contain details of the decline. final InboundAchTransfer.Builderdirection(InboundAchTransfer.Direction direction)The direction of the transfer. final InboundAchTransfer.Builderdirection(JsonField<InboundAchTransfer.Direction> direction)The direction of the transfer. final InboundAchTransfer.BuildereffectiveDate(LocalDate effectiveDate)The effective date of the transfer. final InboundAchTransfer.BuildereffectiveDate(JsonField<LocalDate> effectiveDate)The effective date of the transfer. final InboundAchTransfer.BuilderexpectedSettlementSchedule(InboundAchTransfer.ExpectedSettlementSchedule expectedSettlementSchedule)The settlement schedule the transfer is expected to follow. final InboundAchTransfer.BuilderexpectedSettlementSchedule(JsonField<InboundAchTransfer.ExpectedSettlementSchedule> expectedSettlementSchedule)The settlement schedule the transfer is expected to follow. final InboundAchTransfer.BuilderinternationalAddenda(InboundAchTransfer.InternationalAddenda internationalAddenda)If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction. final InboundAchTransfer.BuilderinternationalAddenda(Optional<InboundAchTransfer.InternationalAddenda> internationalAddenda)If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction. final InboundAchTransfer.BuilderinternationalAddenda(JsonField<InboundAchTransfer.InternationalAddenda> internationalAddenda)If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction. final InboundAchTransfer.BuildernotificationOfChange(InboundAchTransfer.NotificationOfChange notificationOfChange)If you initiate a notification of change in response to the transfer, this will contain its details. final InboundAchTransfer.BuildernotificationOfChange(Optional<InboundAchTransfer.NotificationOfChange> notificationOfChange)If you initiate a notification of change in response to the transfer, this will contain its details. final InboundAchTransfer.BuildernotificationOfChange(JsonField<InboundAchTransfer.NotificationOfChange> notificationOfChange)If you initiate a notification of change in response to the transfer, this will contain its details. final InboundAchTransfer.BuilderoriginatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)The descriptive date of the transfer. final InboundAchTransfer.BuilderoriginatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)The descriptive date of the transfer. final InboundAchTransfer.BuilderoriginatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)The descriptive date of the transfer. final InboundAchTransfer.BuilderoriginatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)The additional information included with the transfer. final InboundAchTransfer.BuilderoriginatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)The additional information included with the transfer. final InboundAchTransfer.BuilderoriginatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)The additional information included with the transfer. final InboundAchTransfer.BuilderoriginatorCompanyEntryDescription(String originatorCompanyEntryDescription)The description of the transfer. final InboundAchTransfer.BuilderoriginatorCompanyEntryDescription(JsonField<String> originatorCompanyEntryDescription)The description of the transfer. final InboundAchTransfer.BuilderoriginatorCompanyId(String originatorCompanyId)The id of the company that initiated the transfer. final InboundAchTransfer.BuilderoriginatorCompanyId(JsonField<String> originatorCompanyId)The id of the company that initiated the transfer. final InboundAchTransfer.BuilderoriginatorCompanyName(String originatorCompanyName)The name of the company that initiated the transfer. final InboundAchTransfer.BuilderoriginatorCompanyName(JsonField<String> originatorCompanyName)The name of the company that initiated the transfer. final InboundAchTransfer.BuilderoriginatorRoutingNumber(String originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final InboundAchTransfer.BuilderoriginatorRoutingNumber(JsonField<String> originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final InboundAchTransfer.BuilderreceiverIdNumber(String receiverIdNumber)The id of the receiver of the transfer. final InboundAchTransfer.BuilderreceiverIdNumber(Optional<String> receiverIdNumber)The id of the receiver of the transfer. final InboundAchTransfer.BuilderreceiverIdNumber(JsonField<String> receiverIdNumber)The id of the receiver of the transfer. final InboundAchTransfer.BuilderreceiverName(String receiverName)The name of the receiver of the transfer. final InboundAchTransfer.BuilderreceiverName(Optional<String> receiverName)The name of the receiver of the transfer. final InboundAchTransfer.BuilderreceiverName(JsonField<String> receiverName)The name of the receiver of the transfer. final InboundAchTransfer.BuilderstandardEntryClassCode(InboundAchTransfer.StandardEntryClassCode standardEntryClassCode)The Standard Entry Class (SEC) code of the transfer. final InboundAchTransfer.BuilderstandardEntryClassCode(JsonField<InboundAchTransfer.StandardEntryClassCode> standardEntryClassCode)The Standard Entry Class (SEC) code of the transfer. final InboundAchTransfer.Builderstatus(InboundAchTransfer.Status status)The status of the transfer. final InboundAchTransfer.Builderstatus(JsonField<InboundAchTransfer.Status> status)The status of the transfer. final InboundAchTransfer.BuildertraceNumber(String traceNumber)A 15 digit number set by the sending bank and transmitted to the receiving bank. final InboundAchTransfer.BuildertraceNumber(JsonField<String> traceNumber)A 15 digit number set by the sending bank and transmitted to the receiving bank. final InboundAchTransfer.BuildertransferReturn(InboundAchTransfer.TransferReturn transferReturn)If your transfer is returned, this will contain details of the return. final InboundAchTransfer.BuildertransferReturn(Optional<InboundAchTransfer.TransferReturn> transferReturn)If your transfer is returned, this will contain details of the return. final InboundAchTransfer.BuildertransferReturn(JsonField<InboundAchTransfer.TransferReturn> transferReturn)If your transfer is returned, this will contain details of the return. final InboundAchTransfer.Buildertype(InboundAchTransfer.Type type)A constant representing the object's type. final InboundAchTransfer.Buildertype(JsonField<InboundAchTransfer.Type> type)A constant representing the object's type. final InboundAchTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final InboundAchTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final InboundAchTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final InboundAchTransfer.BuilderremoveAdditionalProperty(String key)final InboundAchTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final InboundAchTransferbuild()-
-
Method Detail
-
id
final InboundAchTransfer.Builder id(String id)
The inbound ACH transfer's identifier.
-
id
final InboundAchTransfer.Builder id(JsonField<String> id)
The inbound ACH transfer's identifier.
-
acceptance
final InboundAchTransfer.Builder acceptance(InboundAchTransfer.Acceptance acceptance)
If your transfer is accepted, this will contain details of the acceptance.
-
acceptance
final InboundAchTransfer.Builder acceptance(Optional<InboundAchTransfer.Acceptance> acceptance)
If your transfer is accepted, this will contain details of the acceptance.
-
acceptance
final InboundAchTransfer.Builder acceptance(JsonField<InboundAchTransfer.Acceptance> acceptance)
If your transfer is accepted, this will contain details of the acceptance.
-
accountId
final InboundAchTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final InboundAchTransfer.Builder accountId(JsonField<String> accountId)
The Account to which the transfer belongs.
-
accountNumberId
final InboundAchTransfer.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
accountNumberId
final InboundAchTransfer.Builder accountNumberId(JsonField<String> accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
addenda
final InboundAchTransfer.Builder addenda(InboundAchTransfer.Addenda addenda)
Additional information sent from the originator.
-
addenda
final InboundAchTransfer.Builder addenda(Optional<InboundAchTransfer.Addenda> addenda)
Additional information sent from the originator.
-
addenda
final InboundAchTransfer.Builder addenda(JsonField<InboundAchTransfer.Addenda> addenda)
Additional information sent from the originator.
-
amount
final InboundAchTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final InboundAchTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
automaticallyResolvesAt
final InboundAchTransfer.Builder automaticallyResolvesAt(OffsetDateTime automaticallyResolvesAt)
The time at which the transfer will be automatically resolved.
-
automaticallyResolvesAt
final InboundAchTransfer.Builder automaticallyResolvesAt(JsonField<OffsetDateTime> automaticallyResolvesAt)
The time at which the transfer will be automatically resolved.
-
createdAt
final InboundAchTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound ACH transfer was created.
-
createdAt
final InboundAchTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the inbound ACH transfer was created.
-
decline
final InboundAchTransfer.Builder decline(InboundAchTransfer.Decline decline)
If your transfer is declined, this will contain details of the decline.
-
decline
final InboundAchTransfer.Builder decline(Optional<InboundAchTransfer.Decline> decline)
If your transfer is declined, this will contain details of the decline.
-
decline
final InboundAchTransfer.Builder decline(JsonField<InboundAchTransfer.Decline> decline)
If your transfer is declined, this will contain details of the decline.
-
direction
final InboundAchTransfer.Builder direction(InboundAchTransfer.Direction direction)
The direction of the transfer.
-
direction
final InboundAchTransfer.Builder direction(JsonField<InboundAchTransfer.Direction> direction)
The direction of the transfer.
-
effectiveDate
final InboundAchTransfer.Builder effectiveDate(LocalDate effectiveDate)
The effective date of the transfer. This is sent by the sending bank and is a factor in determining funds availability.
-
effectiveDate
final InboundAchTransfer.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
The effective date of the transfer. This is sent by the sending bank and is a factor in determining funds availability.
-
expectedSettlementSchedule
final InboundAchTransfer.Builder expectedSettlementSchedule(InboundAchTransfer.ExpectedSettlementSchedule expectedSettlementSchedule)
The settlement schedule the transfer is expected to follow.
-
expectedSettlementSchedule
final InboundAchTransfer.Builder expectedSettlementSchedule(JsonField<InboundAchTransfer.ExpectedSettlementSchedule> expectedSettlementSchedule)
The settlement schedule the transfer is expected to follow.
-
internationalAddenda
final InboundAchTransfer.Builder internationalAddenda(InboundAchTransfer.InternationalAddenda internationalAddenda)
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
internationalAddenda
final InboundAchTransfer.Builder internationalAddenda(Optional<InboundAchTransfer.InternationalAddenda> internationalAddenda)
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
internationalAddenda
final InboundAchTransfer.Builder internationalAddenda(JsonField<InboundAchTransfer.InternationalAddenda> internationalAddenda)
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
notificationOfChange
final InboundAchTransfer.Builder notificationOfChange(InboundAchTransfer.NotificationOfChange notificationOfChange)
If you initiate a notification of change in response to the transfer, this will contain its details.
-
notificationOfChange
final InboundAchTransfer.Builder notificationOfChange(Optional<InboundAchTransfer.NotificationOfChange> notificationOfChange)
If you initiate a notification of change in response to the transfer, this will contain its details.
-
notificationOfChange
final InboundAchTransfer.Builder notificationOfChange(JsonField<InboundAchTransfer.NotificationOfChange> notificationOfChange)
If you initiate a notification of change in response to the transfer, this will contain its details.
-
originatorCompanyDescriptiveDate
final InboundAchTransfer.Builder originatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDescriptiveDate
final InboundAchTransfer.Builder originatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDescriptiveDate
final InboundAchTransfer.Builder originatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDiscretionaryData
final InboundAchTransfer.Builder originatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyDiscretionaryData
final InboundAchTransfer.Builder originatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyDiscretionaryData
final InboundAchTransfer.Builder originatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyEntryDescription
final InboundAchTransfer.Builder originatorCompanyEntryDescription(String originatorCompanyEntryDescription)
The description of the transfer.
-
originatorCompanyEntryDescription
final InboundAchTransfer.Builder originatorCompanyEntryDescription(JsonField<String> originatorCompanyEntryDescription)
The description of the transfer.
-
originatorCompanyId
final InboundAchTransfer.Builder originatorCompanyId(String originatorCompanyId)
The id of the company that initiated the transfer.
-
originatorCompanyId
final InboundAchTransfer.Builder originatorCompanyId(JsonField<String> originatorCompanyId)
The id of the company that initiated the transfer.
-
originatorCompanyName
final InboundAchTransfer.Builder originatorCompanyName(String originatorCompanyName)
The name of the company that initiated the transfer.
-
originatorCompanyName
final InboundAchTransfer.Builder originatorCompanyName(JsonField<String> originatorCompanyName)
The name of the company that initiated the transfer.
-
originatorRoutingNumber
final InboundAchTransfer.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final InboundAchTransfer.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
receiverIdNumber
final InboundAchTransfer.Builder receiverIdNumber(String receiverIdNumber)
The id of the receiver of the transfer.
-
receiverIdNumber
final InboundAchTransfer.Builder receiverIdNumber(Optional<String> receiverIdNumber)
The id of the receiver of the transfer.
-
receiverIdNumber
final InboundAchTransfer.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
The id of the receiver of the transfer.
-
receiverName
final InboundAchTransfer.Builder receiverName(String receiverName)
The name of the receiver of the transfer.
-
receiverName
final InboundAchTransfer.Builder receiverName(Optional<String> receiverName)
The name of the receiver of the transfer.
-
receiverName
final InboundAchTransfer.Builder receiverName(JsonField<String> receiverName)
The name of the receiver of the transfer.
-
standardEntryClassCode
final InboundAchTransfer.Builder standardEntryClassCode(InboundAchTransfer.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code of the transfer.
-
standardEntryClassCode
final InboundAchTransfer.Builder standardEntryClassCode(JsonField<InboundAchTransfer.StandardEntryClassCode> standardEntryClassCode)
The Standard Entry Class (SEC) code of the transfer.
-
status
final InboundAchTransfer.Builder status(InboundAchTransfer.Status status)
The status of the transfer.
-
status
final InboundAchTransfer.Builder status(JsonField<InboundAchTransfer.Status> status)
The status of the transfer.
-
traceNumber
final InboundAchTransfer.Builder traceNumber(String traceNumber)
A 15 digit number set by the sending bank and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer. ACH trace numbers are not unique, but are used to correlate returns.
-
traceNumber
final InboundAchTransfer.Builder traceNumber(JsonField<String> traceNumber)
A 15 digit number set by the sending bank and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer. ACH trace numbers are not unique, but are used to correlate returns.
-
transferReturn
final InboundAchTransfer.Builder transferReturn(InboundAchTransfer.TransferReturn transferReturn)
If your transfer is returned, this will contain details of the return.
-
transferReturn
final InboundAchTransfer.Builder transferReturn(Optional<InboundAchTransfer.TransferReturn> transferReturn)
If your transfer is returned, this will contain details of the return.
-
transferReturn
final InboundAchTransfer.Builder transferReturn(JsonField<InboundAchTransfer.TransferReturn> transferReturn)
If your transfer is returned, this will contain details of the return.
-
type
final InboundAchTransfer.Builder type(InboundAchTransfer.Type type)
A constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
type
final InboundAchTransfer.Builder type(JsonField<InboundAchTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
additionalProperties
final InboundAchTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundAchTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundAchTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundAchTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundAchTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundAchTransfer build()
-
-
-
-