Package com.increase.api.models
Class InboundAchTransfer.Decline
-
- All Implemented Interfaces:
public final class InboundAchTransfer.DeclineIf your transfer is declined, this will contain details of the decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.Decline.BuilderA builder for Decline.
public final classInboundAchTransfer.Decline.ReasonThe reason for the transfer decline.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimedeclinedAt()The time at which the transfer was declined. final StringdeclinedTransactionId()The id of the transaction for the declined transfer. final InboundAchTransfer.Decline.Reasonreason()The reason for the transfer decline. final JsonField<OffsetDateTime>_declinedAt()The time at which the transfer was declined. final JsonField<String>_declinedTransactionId()The id of the transaction for the declined transfer. final JsonField<InboundAchTransfer.Decline.Reason>_reason()The reason for the transfer decline. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.Declinevalidate()final InboundAchTransfer.Decline.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Decline.Builderbuilder()-
-
Method Detail
-
declinedAt
final OffsetDateTime declinedAt()
The time at which the transfer was declined.
-
declinedTransactionId
final String declinedTransactionId()
The id of the transaction for the declined transfer.
-
reason
final InboundAchTransfer.Decline.Reason reason()
The reason for the transfer decline.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
The time at which the transfer was declined.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
The id of the transaction for the declined transfer.
-
_reason
final JsonField<InboundAchTransfer.Decline.Reason> _reason()
The reason for the transfer decline.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransfer.Decline validate()
-
toBuilder
final InboundAchTransfer.Decline.Builder toBuilder()
-
builder
final static InboundAchTransfer.Decline.Builder builder()
-
-
-
-