Class InboundAchTransfer.InternationalAddenda
-
- All Implemented Interfaces:
public final class InboundAchTransfer.InternationalAddendaIf the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.InternationalAddenda.BuilderA builder for InternationalAddenda.
public final classInboundAchTransfer.InternationalAddenda.ForeignExchangeIndicatorA description of how the foreign exchange rate was calculated.
public final classInboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicatorAn instruction of how to interpret the
foreign_exchange_referencefield for this Transaction.public final classInboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCodeThe type of transfer. Set by the originator.
public final classInboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifierAn instruction of how to interpret the
originating_depository_financial_institution_idfield for this Transaction.public final classInboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifierAn instruction of how to interpret the
receiving_depository_financial_institution_idfield for this Transaction.
-
Method Summary
Modifier and Type Method Description final StringdestinationCountryCode()The ISO 3166, Alpha-2 country code of the destination country. final StringdestinationCurrencyCode()The ISO 4217 currency code for the destination bank account. final InboundAchTransfer.InternationalAddenda.ForeignExchangeIndicatorforeignExchangeIndicator()A description of how the foreign exchange rate was calculated. final Optional<String>foreignExchangeReference()Depending on the foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.final InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicatorforeignExchangeReferenceIndicator()An instruction of how to interpret the foreign_exchange_referencefield for this Transaction.final LongforeignPaymentAmount()The amount in the minor unit of the foreign payment currency. final Optional<String>foreignTraceNumber()A reference number in the foreign banking infrastructure. final InboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCodeinternationalTransactionTypeCode()The type of transfer. final StringoriginatingCurrencyCode()The ISO 4217 currency code for the originating bank account. final StringoriginatingDepositoryFinancialInstitutionBranchCountry()The ISO 3166, Alpha-2 country code of the originating branch country. final StringoriginatingDepositoryFinancialInstitutionId()An identifier for the originating bank. final InboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifieroriginatingDepositoryFinancialInstitutionIdQualifier()An instruction of how to interpret the originating_depository_financial_institution_idfield for this Transaction.final StringoriginatingDepositoryFinancialInstitutionName()The name of the originating bank. final StringoriginatorCity()A portion of the originator address. final StringoriginatorCountry()A portion of the originator address. final StringoriginatorIdentification()An identifier for the originating company. final StringoriginatorName()Either the name of the originator or an intermediary money transmitter. final Optional<String>originatorPostalCode()A portion of the originator address. final Optional<String>originatorStateOrProvince()A portion of the originator address. final StringoriginatorStreetAddress()A portion of the originator address. final Optional<String>paymentRelatedInformation()A description field set by the originator. final Optional<String>paymentRelatedInformation2()A description field set by the originator. final StringreceiverCity()A portion of the receiver address. final StringreceiverCountry()A portion of the receiver address. final Optional<String>receiverIdentificationNumber()An identification number the originator uses for the receiver. final Optional<String>receiverPostalCode()A portion of the receiver address. final Optional<String>receiverStateOrProvince()A portion of the receiver address. final StringreceiverStreetAddress()A portion of the receiver address. final StringreceivingCompanyOrIndividualName()The name of the receiver of the transfer. final StringreceivingDepositoryFinancialInstitutionCountry()The ISO 3166, Alpha-2 country code of the receiving bank country. final StringreceivingDepositoryFinancialInstitutionId()An identifier for the receiving bank. final InboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifierreceivingDepositoryFinancialInstitutionIdQualifier()An instruction of how to interpret the receiving_depository_financial_institution_idfield for this Transaction.final StringreceivingDepositoryFinancialInstitutionName()The name of the receiving bank, as set by the sending financial institution. final JsonField<String>_destinationCountryCode()The ISO 3166, Alpha-2 country code of the destination country. final JsonField<String>_destinationCurrencyCode()The ISO 4217 currency code for the destination bank account. final JsonField<InboundAchTransfer.InternationalAddenda.ForeignExchangeIndicator>_foreignExchangeIndicator()A description of how the foreign exchange rate was calculated. final JsonField<String>_foreignExchangeReference()Depending on the foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.final JsonField<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator>_foreignExchangeReferenceIndicator()An instruction of how to interpret the foreign_exchange_referencefield for this Transaction.final JsonField<Long>_foreignPaymentAmount()The amount in the minor unit of the foreign payment currency. final JsonField<String>_foreignTraceNumber()A reference number in the foreign banking infrastructure. final JsonField<InboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCode>_internationalTransactionTypeCode()The type of transfer. final JsonField<String>_originatingCurrencyCode()The ISO 4217 currency code for the originating bank account. final JsonField<String>_originatingDepositoryFinancialInstitutionBranchCountry()The ISO 3166, Alpha-2 country code of the originating branch country. final JsonField<String>_originatingDepositoryFinancialInstitutionId()An identifier for the originating bank. final JsonField<InboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifier>_originatingDepositoryFinancialInstitutionIdQualifier()An instruction of how to interpret the originating_depository_financial_institution_idfield for this Transaction.final JsonField<String>_originatingDepositoryFinancialInstitutionName()The name of the originating bank. final JsonField<String>_originatorCity()A portion of the originator address. final JsonField<String>_originatorCountry()A portion of the originator address. final JsonField<String>_originatorIdentification()An identifier for the originating company. final JsonField<String>_originatorName()Either the name of the originator or an intermediary money transmitter. final JsonField<String>_originatorPostalCode()A portion of the originator address. final JsonField<String>_originatorStateOrProvince()A portion of the originator address. final JsonField<String>_originatorStreetAddress()A portion of the originator address. final JsonField<String>_paymentRelatedInformation()A description field set by the originator. final JsonField<String>_paymentRelatedInformation2()A description field set by the originator. final JsonField<String>_receiverCity()A portion of the receiver address. final JsonField<String>_receiverCountry()A portion of the receiver address. final JsonField<String>_receiverIdentificationNumber()An identification number the originator uses for the receiver. final JsonField<String>_receiverPostalCode()A portion of the receiver address. final JsonField<String>_receiverStateOrProvince()A portion of the receiver address. final JsonField<String>_receiverStreetAddress()A portion of the receiver address. final JsonField<String>_receivingCompanyOrIndividualName()The name of the receiver of the transfer. final JsonField<String>_receivingDepositoryFinancialInstitutionCountry()The ISO 3166, Alpha-2 country code of the receiving bank country. final JsonField<String>_receivingDepositoryFinancialInstitutionId()An identifier for the receiving bank. final JsonField<InboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifier>_receivingDepositoryFinancialInstitutionIdQualifier()An instruction of how to interpret the receiving_depository_financial_institution_idfield for this Transaction.final JsonField<String>_receivingDepositoryFinancialInstitutionName()The name of the receiving bank, as set by the sending financial institution. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.InternationalAddendavalidate()final InboundAchTransfer.InternationalAddenda.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.InternationalAddenda.Builderbuilder()-
-
Method Detail
-
destinationCountryCode
final String destinationCountryCode()
The ISO 3166, Alpha-2 country code of the destination country.
-
destinationCurrencyCode
final String destinationCurrencyCode()
The ISO 4217 currency code for the destination bank account.
-
foreignExchangeIndicator
final InboundAchTransfer.InternationalAddenda.ForeignExchangeIndicator foreignExchangeIndicator()
A description of how the foreign exchange rate was calculated.
-
foreignExchangeReference
final Optional<String> foreignExchangeReference()
Depending on the
foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.
-
foreignExchangeReferenceIndicator
final InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator foreignExchangeReferenceIndicator()
An instruction of how to interpret the
foreign_exchange_referencefield for this Transaction.
-
foreignPaymentAmount
final Long foreignPaymentAmount()
The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.
-
foreignTraceNumber
final Optional<String> foreignTraceNumber()
A reference number in the foreign banking infrastructure.
-
internationalTransactionTypeCode
final InboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCode internationalTransactionTypeCode()
The type of transfer. Set by the originator.
-
originatingCurrencyCode
final String originatingCurrencyCode()
The ISO 4217 currency code for the originating bank account.
-
originatingDepositoryFinancialInstitutionBranchCountry
final String originatingDepositoryFinancialInstitutionBranchCountry()
The ISO 3166, Alpha-2 country code of the originating branch country.
-
originatingDepositoryFinancialInstitutionId
final String originatingDepositoryFinancialInstitutionId()
An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
originatingDepositoryFinancialInstitutionIdQualifier
final InboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifier originatingDepositoryFinancialInstitutionIdQualifier()
An instruction of how to interpret the
originating_depository_financial_institution_idfield for this Transaction.
-
originatingDepositoryFinancialInstitutionName
final String originatingDepositoryFinancialInstitutionName()
The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.
-
originatorCity
final String originatorCity()
A portion of the originator address. This may be incomplete.
-
originatorCountry
final String originatorCountry()
A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.
-
originatorIdentification
final String originatorIdentification()
An identifier for the originating company. This is generally stable across multiple ACH transfers.
-
originatorName
final String originatorName()
Either the name of the originator or an intermediary money transmitter.
-
originatorPostalCode
final Optional<String> originatorPostalCode()
A portion of the originator address. This may be incomplete.
-
originatorStateOrProvince
final Optional<String> originatorStateOrProvince()
A portion of the originator address. This may be incomplete.
-
originatorStreetAddress
final String originatorStreetAddress()
A portion of the originator address. This may be incomplete.
-
paymentRelatedInformation
final Optional<String> paymentRelatedInformation()
A description field set by the originator.
-
paymentRelatedInformation2
final Optional<String> paymentRelatedInformation2()
A description field set by the originator.
-
receiverCity
final String receiverCity()
A portion of the receiver address. This may be incomplete.
-
receiverCountry
final String receiverCountry()
A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.
-
receiverIdentificationNumber
final Optional<String> receiverIdentificationNumber()
An identification number the originator uses for the receiver.
-
receiverPostalCode
final Optional<String> receiverPostalCode()
A portion of the receiver address. This may be incomplete.
-
receiverStateOrProvince
final Optional<String> receiverStateOrProvince()
A portion of the receiver address. This may be incomplete.
-
receiverStreetAddress
final String receiverStreetAddress()
A portion of the receiver address. This may be incomplete.
-
receivingCompanyOrIndividualName
final String receivingCompanyOrIndividualName()
The name of the receiver of the transfer. This is not verified by Increase.
-
receivingDepositoryFinancialInstitutionCountry
final String receivingDepositoryFinancialInstitutionCountry()
The ISO 3166, Alpha-2 country code of the receiving bank country.
-
receivingDepositoryFinancialInstitutionId
final String receivingDepositoryFinancialInstitutionId()
An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
receivingDepositoryFinancialInstitutionIdQualifier
final InboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifier receivingDepositoryFinancialInstitutionIdQualifier()
An instruction of how to interpret the
receiving_depository_financial_institution_idfield for this Transaction.
-
receivingDepositoryFinancialInstitutionName
final String receivingDepositoryFinancialInstitutionName()
The name of the receiving bank, as set by the sending financial institution.
-
_destinationCountryCode
final JsonField<String> _destinationCountryCode()
The ISO 3166, Alpha-2 country code of the destination country.
-
_destinationCurrencyCode
final JsonField<String> _destinationCurrencyCode()
The ISO 4217 currency code for the destination bank account.
-
_foreignExchangeIndicator
final JsonField<InboundAchTransfer.InternationalAddenda.ForeignExchangeIndicator> _foreignExchangeIndicator()
A description of how the foreign exchange rate was calculated.
-
_foreignExchangeReference
final JsonField<String> _foreignExchangeReference()
Depending on the
foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.
-
_foreignExchangeReferenceIndicator
final JsonField<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator> _foreignExchangeReferenceIndicator()
An instruction of how to interpret the
foreign_exchange_referencefield for this Transaction.
-
_foreignPaymentAmount
final JsonField<Long> _foreignPaymentAmount()
The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.
-
_foreignTraceNumber
final JsonField<String> _foreignTraceNumber()
A reference number in the foreign banking infrastructure.
-
_internationalTransactionTypeCode
final JsonField<InboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCode> _internationalTransactionTypeCode()
The type of transfer. Set by the originator.
-
_originatingCurrencyCode
final JsonField<String> _originatingCurrencyCode()
The ISO 4217 currency code for the originating bank account.
-
_originatingDepositoryFinancialInstitutionBranchCountry
final JsonField<String> _originatingDepositoryFinancialInstitutionBranchCountry()
The ISO 3166, Alpha-2 country code of the originating branch country.
-
_originatingDepositoryFinancialInstitutionId
final JsonField<String> _originatingDepositoryFinancialInstitutionId()
An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
_originatingDepositoryFinancialInstitutionIdQualifier
final JsonField<InboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifier> _originatingDepositoryFinancialInstitutionIdQualifier()
An instruction of how to interpret the
originating_depository_financial_institution_idfield for this Transaction.
-
_originatingDepositoryFinancialInstitutionName
final JsonField<String> _originatingDepositoryFinancialInstitutionName()
The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.
-
_originatorCity
final JsonField<String> _originatorCity()
A portion of the originator address. This may be incomplete.
-
_originatorCountry
final JsonField<String> _originatorCountry()
A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.
-
_originatorIdentification
final JsonField<String> _originatorIdentification()
An identifier for the originating company. This is generally stable across multiple ACH transfers.
-
_originatorName
final JsonField<String> _originatorName()
Either the name of the originator or an intermediary money transmitter.
-
_originatorPostalCode
final JsonField<String> _originatorPostalCode()
A portion of the originator address. This may be incomplete.
-
_originatorStateOrProvince
final JsonField<String> _originatorStateOrProvince()
A portion of the originator address. This may be incomplete.
-
_originatorStreetAddress
final JsonField<String> _originatorStreetAddress()
A portion of the originator address. This may be incomplete.
-
_paymentRelatedInformation
final JsonField<String> _paymentRelatedInformation()
A description field set by the originator.
-
_paymentRelatedInformation2
final JsonField<String> _paymentRelatedInformation2()
A description field set by the originator.
-
_receiverCity
final JsonField<String> _receiverCity()
A portion of the receiver address. This may be incomplete.
-
_receiverCountry
final JsonField<String> _receiverCountry()
A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.
-
_receiverIdentificationNumber
final JsonField<String> _receiverIdentificationNumber()
An identification number the originator uses for the receiver.
-
_receiverPostalCode
final JsonField<String> _receiverPostalCode()
A portion of the receiver address. This may be incomplete.
-
_receiverStateOrProvince
final JsonField<String> _receiverStateOrProvince()
A portion of the receiver address. This may be incomplete.
-
_receiverStreetAddress
final JsonField<String> _receiverStreetAddress()
A portion of the receiver address. This may be incomplete.
-
_receivingCompanyOrIndividualName
final JsonField<String> _receivingCompanyOrIndividualName()
The name of the receiver of the transfer. This is not verified by Increase.
-
_receivingDepositoryFinancialInstitutionCountry
final JsonField<String> _receivingDepositoryFinancialInstitutionCountry()
The ISO 3166, Alpha-2 country code of the receiving bank country.
-
_receivingDepositoryFinancialInstitutionId
final JsonField<String> _receivingDepositoryFinancialInstitutionId()
An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
_receivingDepositoryFinancialInstitutionIdQualifier
final JsonField<InboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifier> _receivingDepositoryFinancialInstitutionIdQualifier()
An instruction of how to interpret the
receiving_depository_financial_institution_idfield for this Transaction.
-
_receivingDepositoryFinancialInstitutionName
final JsonField<String> _receivingDepositoryFinancialInstitutionName()
The name of the receiving bank, as set by the sending financial institution.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransfer.InternationalAddenda validate()
-
toBuilder
final InboundAchTransfer.InternationalAddenda.Builder toBuilder()
-
builder
final static InboundAchTransfer.InternationalAddenda.Builder builder()
-
-
-
-