Class InboundAchTransfer.InternationalAddenda.Builder
-
- All Implemented Interfaces:
public final class InboundAchTransfer.InternationalAddenda.BuilderA builder for InternationalAddenda.
-
-
Method Summary
-
-
Method Detail
-
destinationCountryCode
final InboundAchTransfer.InternationalAddenda.Builder destinationCountryCode(String destinationCountryCode)
The ISO 3166, Alpha-2 country code of the destination country.
-
destinationCountryCode
final InboundAchTransfer.InternationalAddenda.Builder destinationCountryCode(JsonField<String> destinationCountryCode)
The ISO 3166, Alpha-2 country code of the destination country.
-
destinationCurrencyCode
final InboundAchTransfer.InternationalAddenda.Builder destinationCurrencyCode(String destinationCurrencyCode)
The ISO 4217 currency code for the destination bank account.
-
destinationCurrencyCode
final InboundAchTransfer.InternationalAddenda.Builder destinationCurrencyCode(JsonField<String> destinationCurrencyCode)
The ISO 4217 currency code for the destination bank account.
-
foreignExchangeIndicator
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeIndicator(InboundAchTransfer.InternationalAddenda.ForeignExchangeIndicator foreignExchangeIndicator)
A description of how the foreign exchange rate was calculated.
-
foreignExchangeIndicator
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeIndicator(JsonField<InboundAchTransfer.InternationalAddenda.ForeignExchangeIndicator> foreignExchangeIndicator)
A description of how the foreign exchange rate was calculated.
-
foreignExchangeReference
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeReference(String foreignExchangeReference)
Depending on the
foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.
-
foreignExchangeReference
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeReference(Optional<String> foreignExchangeReference)
Depending on the
foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.
-
foreignExchangeReference
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeReference(JsonField<String> foreignExchangeReference)
Depending on the
foreign_exchange_reference_indicator, an exchange rate or a reference to a well-known rate.
-
foreignExchangeReferenceIndicator
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeReferenceIndicator(InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator foreignExchangeReferenceIndicator)
An instruction of how to interpret the
foreign_exchange_referencefield for this Transaction.
-
foreignExchangeReferenceIndicator
final InboundAchTransfer.InternationalAddenda.Builder foreignExchangeReferenceIndicator(JsonField<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator> foreignExchangeReferenceIndicator)
An instruction of how to interpret the
foreign_exchange_referencefield for this Transaction.
-
foreignPaymentAmount
final InboundAchTransfer.InternationalAddenda.Builder foreignPaymentAmount(Long foreignPaymentAmount)
The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.
-
foreignPaymentAmount
final InboundAchTransfer.InternationalAddenda.Builder foreignPaymentAmount(JsonField<Long> foreignPaymentAmount)
The amount in the minor unit of the foreign payment currency. For dollars, for example, this is cents.
-
foreignTraceNumber
final InboundAchTransfer.InternationalAddenda.Builder foreignTraceNumber(String foreignTraceNumber)
A reference number in the foreign banking infrastructure.
-
foreignTraceNumber
final InboundAchTransfer.InternationalAddenda.Builder foreignTraceNumber(Optional<String> foreignTraceNumber)
A reference number in the foreign banking infrastructure.
-
foreignTraceNumber
final InboundAchTransfer.InternationalAddenda.Builder foreignTraceNumber(JsonField<String> foreignTraceNumber)
A reference number in the foreign banking infrastructure.
-
internationalTransactionTypeCode
final InboundAchTransfer.InternationalAddenda.Builder internationalTransactionTypeCode(InboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCode internationalTransactionTypeCode)
The type of transfer. Set by the originator.
-
internationalTransactionTypeCode
final InboundAchTransfer.InternationalAddenda.Builder internationalTransactionTypeCode(JsonField<InboundAchTransfer.InternationalAddenda.InternationalTransactionTypeCode> internationalTransactionTypeCode)
The type of transfer. Set by the originator.
-
originatingCurrencyCode
final InboundAchTransfer.InternationalAddenda.Builder originatingCurrencyCode(String originatingCurrencyCode)
The ISO 4217 currency code for the originating bank account.
-
originatingCurrencyCode
final InboundAchTransfer.InternationalAddenda.Builder originatingCurrencyCode(JsonField<String> originatingCurrencyCode)
The ISO 4217 currency code for the originating bank account.
-
originatingDepositoryFinancialInstitutionBranchCountry
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionBranchCountry(String originatingDepositoryFinancialInstitutionBranchCountry)
The ISO 3166, Alpha-2 country code of the originating branch country.
-
originatingDepositoryFinancialInstitutionBranchCountry
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionBranchCountry(JsonField<String> originatingDepositoryFinancialInstitutionBranchCountry)
The ISO 3166, Alpha-2 country code of the originating branch country.
-
originatingDepositoryFinancialInstitutionId
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionId(String originatingDepositoryFinancialInstitutionId)
An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
originatingDepositoryFinancialInstitutionId
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionId(JsonField<String> originatingDepositoryFinancialInstitutionId)
An identifier for the originating bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
originatingDepositoryFinancialInstitutionIdQualifier
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionIdQualifier(InboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifier originatingDepositoryFinancialInstitutionIdQualifier)
An instruction of how to interpret the
originating_depository_financial_institution_idfield for this Transaction.
-
originatingDepositoryFinancialInstitutionIdQualifier
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionIdQualifier(JsonField<InboundAchTransfer.InternationalAddenda.OriginatingDepositoryFinancialInstitutionIdQualifier> originatingDepositoryFinancialInstitutionIdQualifier)
An instruction of how to interpret the
originating_depository_financial_institution_idfield for this Transaction.
-
originatingDepositoryFinancialInstitutionName
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionName(String originatingDepositoryFinancialInstitutionName)
The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.
-
originatingDepositoryFinancialInstitutionName
final InboundAchTransfer.InternationalAddenda.Builder originatingDepositoryFinancialInstitutionName(JsonField<String> originatingDepositoryFinancialInstitutionName)
The name of the originating bank. Sometimes this will refer to an American bank and obscure the correspondent foreign bank.
-
originatorCity
final InboundAchTransfer.InternationalAddenda.Builder originatorCity(String originatorCity)
A portion of the originator address. This may be incomplete.
-
originatorCity
final InboundAchTransfer.InternationalAddenda.Builder originatorCity(JsonField<String> originatorCity)
A portion of the originator address. This may be incomplete.
-
originatorCountry
final InboundAchTransfer.InternationalAddenda.Builder originatorCountry(String originatorCountry)
A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.
-
originatorCountry
final InboundAchTransfer.InternationalAddenda.Builder originatorCountry(JsonField<String> originatorCountry)
A portion of the originator address. The ISO 3166, Alpha-2 country code of the originator country.
-
originatorIdentification
final InboundAchTransfer.InternationalAddenda.Builder originatorIdentification(String originatorIdentification)
An identifier for the originating company. This is generally stable across multiple ACH transfers.
-
originatorIdentification
final InboundAchTransfer.InternationalAddenda.Builder originatorIdentification(JsonField<String> originatorIdentification)
An identifier for the originating company. This is generally stable across multiple ACH transfers.
-
originatorName
final InboundAchTransfer.InternationalAddenda.Builder originatorName(String originatorName)
Either the name of the originator or an intermediary money transmitter.
-
originatorName
final InboundAchTransfer.InternationalAddenda.Builder originatorName(JsonField<String> originatorName)
Either the name of the originator or an intermediary money transmitter.
-
originatorPostalCode
final InboundAchTransfer.InternationalAddenda.Builder originatorPostalCode(String originatorPostalCode)
A portion of the originator address. This may be incomplete.
-
originatorPostalCode
final InboundAchTransfer.InternationalAddenda.Builder originatorPostalCode(Optional<String> originatorPostalCode)
A portion of the originator address. This may be incomplete.
-
originatorPostalCode
final InboundAchTransfer.InternationalAddenda.Builder originatorPostalCode(JsonField<String> originatorPostalCode)
A portion of the originator address. This may be incomplete.
-
originatorStateOrProvince
final InboundAchTransfer.InternationalAddenda.Builder originatorStateOrProvince(String originatorStateOrProvince)
A portion of the originator address. This may be incomplete.
-
originatorStateOrProvince
final InboundAchTransfer.InternationalAddenda.Builder originatorStateOrProvince(Optional<String> originatorStateOrProvince)
A portion of the originator address. This may be incomplete.
-
originatorStateOrProvince
final InboundAchTransfer.InternationalAddenda.Builder originatorStateOrProvince(JsonField<String> originatorStateOrProvince)
A portion of the originator address. This may be incomplete.
-
originatorStreetAddress
final InboundAchTransfer.InternationalAddenda.Builder originatorStreetAddress(String originatorStreetAddress)
A portion of the originator address. This may be incomplete.
-
originatorStreetAddress
final InboundAchTransfer.InternationalAddenda.Builder originatorStreetAddress(JsonField<String> originatorStreetAddress)
A portion of the originator address. This may be incomplete.
-
paymentRelatedInformation
final InboundAchTransfer.InternationalAddenda.Builder paymentRelatedInformation(String paymentRelatedInformation)
A description field set by the originator.
-
paymentRelatedInformation
final InboundAchTransfer.InternationalAddenda.Builder paymentRelatedInformation(Optional<String> paymentRelatedInformation)
A description field set by the originator.
-
paymentRelatedInformation
final InboundAchTransfer.InternationalAddenda.Builder paymentRelatedInformation(JsonField<String> paymentRelatedInformation)
A description field set by the originator.
-
paymentRelatedInformation2
final InboundAchTransfer.InternationalAddenda.Builder paymentRelatedInformation2(String paymentRelatedInformation2)
A description field set by the originator.
-
paymentRelatedInformation2
final InboundAchTransfer.InternationalAddenda.Builder paymentRelatedInformation2(Optional<String> paymentRelatedInformation2)
A description field set by the originator.
-
paymentRelatedInformation2
final InboundAchTransfer.InternationalAddenda.Builder paymentRelatedInformation2(JsonField<String> paymentRelatedInformation2)
A description field set by the originator.
-
receiverCity
final InboundAchTransfer.InternationalAddenda.Builder receiverCity(String receiverCity)
A portion of the receiver address. This may be incomplete.
-
receiverCity
final InboundAchTransfer.InternationalAddenda.Builder receiverCity(JsonField<String> receiverCity)
A portion of the receiver address. This may be incomplete.
-
receiverCountry
final InboundAchTransfer.InternationalAddenda.Builder receiverCountry(String receiverCountry)
A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.
-
receiverCountry
final InboundAchTransfer.InternationalAddenda.Builder receiverCountry(JsonField<String> receiverCountry)
A portion of the receiver address. The ISO 3166, Alpha-2 country code of the receiver country.
-
receiverIdentificationNumber
final InboundAchTransfer.InternationalAddenda.Builder receiverIdentificationNumber(String receiverIdentificationNumber)
An identification number the originator uses for the receiver.
-
receiverIdentificationNumber
final InboundAchTransfer.InternationalAddenda.Builder receiverIdentificationNumber(Optional<String> receiverIdentificationNumber)
An identification number the originator uses for the receiver.
-
receiverIdentificationNumber
final InboundAchTransfer.InternationalAddenda.Builder receiverIdentificationNumber(JsonField<String> receiverIdentificationNumber)
An identification number the originator uses for the receiver.
-
receiverPostalCode
final InboundAchTransfer.InternationalAddenda.Builder receiverPostalCode(String receiverPostalCode)
A portion of the receiver address. This may be incomplete.
-
receiverPostalCode
final InboundAchTransfer.InternationalAddenda.Builder receiverPostalCode(Optional<String> receiverPostalCode)
A portion of the receiver address. This may be incomplete.
-
receiverPostalCode
final InboundAchTransfer.InternationalAddenda.Builder receiverPostalCode(JsonField<String> receiverPostalCode)
A portion of the receiver address. This may be incomplete.
-
receiverStateOrProvince
final InboundAchTransfer.InternationalAddenda.Builder receiverStateOrProvince(String receiverStateOrProvince)
A portion of the receiver address. This may be incomplete.
-
receiverStateOrProvince
final InboundAchTransfer.InternationalAddenda.Builder receiverStateOrProvince(Optional<String> receiverStateOrProvince)
A portion of the receiver address. This may be incomplete.
-
receiverStateOrProvince
final InboundAchTransfer.InternationalAddenda.Builder receiverStateOrProvince(JsonField<String> receiverStateOrProvince)
A portion of the receiver address. This may be incomplete.
-
receiverStreetAddress
final InboundAchTransfer.InternationalAddenda.Builder receiverStreetAddress(String receiverStreetAddress)
A portion of the receiver address. This may be incomplete.
-
receiverStreetAddress
final InboundAchTransfer.InternationalAddenda.Builder receiverStreetAddress(JsonField<String> receiverStreetAddress)
A portion of the receiver address. This may be incomplete.
-
receivingCompanyOrIndividualName
final InboundAchTransfer.InternationalAddenda.Builder receivingCompanyOrIndividualName(String receivingCompanyOrIndividualName)
The name of the receiver of the transfer. This is not verified by Increase.
-
receivingCompanyOrIndividualName
final InboundAchTransfer.InternationalAddenda.Builder receivingCompanyOrIndividualName(JsonField<String> receivingCompanyOrIndividualName)
The name of the receiver of the transfer. This is not verified by Increase.
-
receivingDepositoryFinancialInstitutionCountry
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionCountry(String receivingDepositoryFinancialInstitutionCountry)
The ISO 3166, Alpha-2 country code of the receiving bank country.
-
receivingDepositoryFinancialInstitutionCountry
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionCountry(JsonField<String> receivingDepositoryFinancialInstitutionCountry)
The ISO 3166, Alpha-2 country code of the receiving bank country.
-
receivingDepositoryFinancialInstitutionId
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionId(String receivingDepositoryFinancialInstitutionId)
An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
receivingDepositoryFinancialInstitutionId
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionId(JsonField<String> receivingDepositoryFinancialInstitutionId)
An identifier for the receiving bank. One of an International Bank Account Number (IBAN) bank identifier, SWIFT Bank Identification Code (BIC), or a domestic identifier like a US Routing Number.
-
receivingDepositoryFinancialInstitutionIdQualifier
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionIdQualifier(InboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifier receivingDepositoryFinancialInstitutionIdQualifier)
An instruction of how to interpret the
receiving_depository_financial_institution_idfield for this Transaction.
-
receivingDepositoryFinancialInstitutionIdQualifier
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionIdQualifier(JsonField<InboundAchTransfer.InternationalAddenda.ReceivingDepositoryFinancialInstitutionIdQualifier> receivingDepositoryFinancialInstitutionIdQualifier)
An instruction of how to interpret the
receiving_depository_financial_institution_idfield for this Transaction.
-
receivingDepositoryFinancialInstitutionName
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionName(String receivingDepositoryFinancialInstitutionName)
The name of the receiving bank, as set by the sending financial institution.
-
receivingDepositoryFinancialInstitutionName
final InboundAchTransfer.InternationalAddenda.Builder receivingDepositoryFinancialInstitutionName(JsonField<String> receivingDepositoryFinancialInstitutionName)
The name of the receiving bank, as set by the sending financial institution.
-
additionalProperties
final InboundAchTransfer.InternationalAddenda.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundAchTransfer.InternationalAddenda.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundAchTransfer.InternationalAddenda.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundAchTransfer.InternationalAddenda.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundAchTransfer.InternationalAddenda.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundAchTransfer.InternationalAddenda build()
-
-
-
-