Enum InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value extends Enum<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value>
An enum containing ForeignExchangeReferenceIndicator's known values, as well as an _UNKNOWN member.
An instance of ForeignExchangeReferenceIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FOREIGN_EXCHANGE_RATEThe ACH file contains a foreign exchange rate.
FOREIGN_EXCHANGE_REFERENCE_NUMBERThe ACH file contains a reference to a well-known foreign exchange rate.
BLANKThere is no foreign exchange for this transfer, so the
foreign_exchange_referencefield is blank._UNKNOWNAn enum member indicating that ForeignExchangeReferenceIndicator was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value>getEntries()An enum containing ForeignExchangeReferenceIndicator's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundAchTransfer.InternationalAddenda.ForeignExchangeReferenceIndicator.Value> getEntries()
An enum containing ForeignExchangeReferenceIndicator's known values, as well as an _UNKNOWN member.
An instance of ForeignExchangeReferenceIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-