Package com.increase.api.models
Class InboundAchTransfer.NotificationOfChange
-
- All Implemented Interfaces:
public final class InboundAchTransfer.NotificationOfChangeIf you initiate a notification of change in response to the transfer, this will contain its details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.NotificationOfChange.BuilderA builder for NotificationOfChange.
-
Method Summary
Modifier and Type Method Description final Optional<String>updatedAccountNumber()The new account number provided in the notification of change. final Optional<String>updatedRoutingNumber()The new account number provided in the notification of change. final JsonField<String>_updatedAccountNumber()The new account number provided in the notification of change. final JsonField<String>_updatedRoutingNumber()The new account number provided in the notification of change. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.NotificationOfChangevalidate()final InboundAchTransfer.NotificationOfChange.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.NotificationOfChange.Builderbuilder()-
-
Method Detail
-
updatedAccountNumber
final Optional<String> updatedAccountNumber()
The new account number provided in the notification of change.
-
updatedRoutingNumber
final Optional<String> updatedRoutingNumber()
The new account number provided in the notification of change.
-
_updatedAccountNumber
final JsonField<String> _updatedAccountNumber()
The new account number provided in the notification of change.
-
_updatedRoutingNumber
final JsonField<String> _updatedRoutingNumber()
The new account number provided in the notification of change.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransfer.NotificationOfChange validate()
-
toBuilder
final InboundAchTransfer.NotificationOfChange.Builder toBuilder()
-
builder
final static InboundAchTransfer.NotificationOfChange.Builder builder()
-
-
-
-