Package com.increase.api.models
Class InboundAchTransfer.NotificationOfChange.Builder
-
- All Implemented Interfaces:
public final class InboundAchTransfer.NotificationOfChange.BuilderA builder for NotificationOfChange.
-
-
Method Summary
-
-
Method Detail
-
updatedAccountNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedAccountNumber(String updatedAccountNumber)
The new account number provided in the notification of change.
-
updatedAccountNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedAccountNumber(Optional<String> updatedAccountNumber)
The new account number provided in the notification of change.
-
updatedAccountNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedAccountNumber(JsonField<String> updatedAccountNumber)
The new account number provided in the notification of change.
-
updatedRoutingNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedRoutingNumber(String updatedRoutingNumber)
The new account number provided in the notification of change.
-
updatedRoutingNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedRoutingNumber(Optional<String> updatedRoutingNumber)
The new account number provided in the notification of change.
-
updatedRoutingNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedRoutingNumber(JsonField<String> updatedRoutingNumber)
The new account number provided in the notification of change.
-
additionalProperties
final InboundAchTransfer.NotificationOfChange.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundAchTransfer.NotificationOfChange.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundAchTransfer.NotificationOfChange.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundAchTransfer.NotificationOfChange.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundAchTransfer.NotificationOfChange.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundAchTransfer.NotificationOfChange build()
-
-
-
-