Enum InboundAchTransfer.TransferReturn.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundAchTransfer.TransferReturn.Reason.Known extends Enum<InboundAchTransfer.TransferReturn.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundAchTransfer.TransferReturn.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description INSUFFICIENT_FUNDSThe customer's account has insufficient funds. This reason is only allowed for debits. The Nacha return code is R01.
RETURNED_PER_ODFI_REQUESTThe originating financial institution asked for this transfer to be returned. The receiving bank is complying with the request. The Nacha return code is R06.
AUTHORIZATION_REVOKED_BY_CUSTOMERThe customer no longer authorizes this transaction. The Nacha return code is R07.
PAYMENT_STOPPEDThe customer asked for the payment to be stopped. This reason is only allowed for debits. The Nacha return code is R08.
CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETEThe customer advises that the debit was unauthorized. The Nacha return code is R10.
REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITYThe payee is deceased. The Nacha return code is R14.
BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASEDThe account holder is deceased. The Nacha return code is R15.
CREDIT_ENTRY_REFUSED_BY_RECEIVERThe customer refused a credit entry. This reason is only allowed for credits. The Nacha return code is R23.
DUPLICATE_ENTRYThe account holder identified this transaction as a duplicate. The Nacha return code is R24.
CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZEDThe corporate customer no longer authorizes this transaction. The Nacha return code is R29.
-
Method Summary
Modifier and Type Method Description final InboundAchTransfer.TransferReturn.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundAchTransfer.TransferReturn.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundAchTransfer.TransferReturn.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final InboundAchTransfer.TransferReturn.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundAchTransfer.TransferReturn.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundAchTransfer.TransferReturn.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-