Package com.increase.api.models
Class InboundAchTransferCreateNotificationOfChangeParams.Body
-
- All Implemented Interfaces:
public final class InboundAchTransferCreateNotificationOfChangeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferCreateNotificationOfChangeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>updatedAccountNumber()The updated account number to send in the notification of change. final Optional<String>updatedRoutingNumber()The updated routing number to send in the notification of change. final JsonField<String>_updatedAccountNumber()The updated account number to send in the notification of change. final JsonField<String>_updatedRoutingNumber()The updated routing number to send in the notification of change. final Map<String, JsonValue>_additionalProperties()final InboundAchTransferCreateNotificationOfChangeParams.Bodyvalidate()final InboundAchTransferCreateNotificationOfChangeParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferCreateNotificationOfChangeParams.Body.Builderbuilder()-
-
Method Detail
-
updatedAccountNumber
final Optional<String> updatedAccountNumber()
The updated account number to send in the notification of change.
-
updatedRoutingNumber
final Optional<String> updatedRoutingNumber()
The updated routing number to send in the notification of change.
-
_updatedAccountNumber
final JsonField<String> _updatedAccountNumber()
The updated account number to send in the notification of change.
-
_updatedRoutingNumber
final JsonField<String> _updatedRoutingNumber()
The updated routing number to send in the notification of change.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransferCreateNotificationOfChangeParams.Body validate()
-
toBuilder
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder toBuilder()
-
builder
final static InboundAchTransferCreateNotificationOfChangeParams.Body.Builder builder()
-
-
-
-