Package com.increase.api.models
Class InboundAchTransferDeclineParams.Body
-
- All Implemented Interfaces:
public final class InboundAchTransferDeclineParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferDeclineParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<InboundAchTransferDeclineParams.Reason>reason()The reason why this transfer will be returned. final JsonField<InboundAchTransferDeclineParams.Reason>_reason()The reason why this transfer will be returned. final Map<String, JsonValue>_additionalProperties()final InboundAchTransferDeclineParams.Bodyvalidate()final InboundAchTransferDeclineParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferDeclineParams.Body.Builderbuilder()-
-
Method Detail
-
reason
final Optional<InboundAchTransferDeclineParams.Reason> reason()
The reason why this transfer will be returned. If this parameter is unset, the return codes will be
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
_reason
final JsonField<InboundAchTransferDeclineParams.Reason> _reason()
The reason why this transfer will be returned. If this parameter is unset, the return codes will be
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundAchTransferDeclineParams.Body validate()
-
toBuilder
final InboundAchTransferDeclineParams.Body.Builder toBuilder()
-
builder
final static InboundAchTransferDeclineParams.Body.Builder builder()
-
-
-
-