Class InboundAchTransferDeclineParams.Reason
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class InboundAchTransferDeclineParams.Reason implements EnumThe reason why this transfer will be returned. If this parameter is unset, the return codes will be
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumInboundAchTransferDeclineParams.Reason.KnownAn enum containing Reason's known values.
public enumInboundAchTransferDeclineParams.Reason.ValueAn enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static InboundAchTransferDeclineParams.ReasonINSUFFICIENT_FUNDSpublic final static InboundAchTransferDeclineParams.ReasonRETURNED_PER_ODFI_REQUESTpublic final static InboundAchTransferDeclineParams.ReasonAUTHORIZATION_REVOKED_BY_CUSTOMERpublic final static InboundAchTransferDeclineParams.ReasonPAYMENT_STOPPEDpublic final static InboundAchTransferDeclineParams.ReasonCUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETEpublic final static InboundAchTransferDeclineParams.ReasonREPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITYpublic final static InboundAchTransferDeclineParams.ReasonBENEFICIARY_OR_ACCOUNT_HOLDER_DECEASEDpublic final static InboundAchTransferDeclineParams.ReasonCREDIT_ENTRY_REFUSED_BY_RECEIVERpublic final static InboundAchTransferDeclineParams.ReasonDUPLICATE_ENTRYpublic final static InboundAchTransferDeclineParams.ReasonCORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final InboundAchTransferDeclineParams.Reason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final InboundAchTransferDeclineParams.Reason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferDeclineParams.Reasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final InboundAchTransferDeclineParams.Reason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final InboundAchTransferDeclineParams.Reason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
of
final static InboundAchTransferDeclineParams.Reason of(String value)
-
-
-
-