Package com.increase.api.models
Class InboundAchTransferListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundAchTransferListParams implements Params
List Inbound ACH Transfers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferListParams.BuilderA builder for InboundAchTransferListParams.
public final classInboundAchTransferListParams.CreatedAtpublic final classInboundAchTransferListParams.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Inbound ACH Transfers to ones belonging to the specified Account. final Optional<String>accountNumberId()Filter Inbound ACH Transfers to ones belonging to the specified Account Number. final Optional<InboundAchTransferListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Optional<InboundAchTransferListParams.Status>status()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final InboundAchTransferListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferListParamsnone()final static InboundAchTransferListParams.Builderbuilder()-
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Inbound ACH Transfers to ones belonging to the specified Account.
-
accountNumberId
final Optional<String> accountNumberId()
Filter Inbound ACH Transfers to ones belonging to the specified Account Number.
-
createdAt
final Optional<InboundAchTransferListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
status
final Optional<InboundAchTransferListParams.Status> status()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final InboundAchTransferListParams.Builder toBuilder()
-
none
final static InboundAchTransferListParams none()
-
builder
final static InboundAchTransferListParams.Builder builder()
-
-
-
-