Package com.increase.api.models
Class InboundAchTransferRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundAchTransferRetrieveParams implements Params
Retrieve an Inbound ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferRetrieveParams.BuilderA builder for InboundAchTransferRetrieveParams.
-
Method Summary
Modifier and Type Method Description final StringinboundAchTransferId()The identifier of the Inbound ACH Transfer to get details for. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final InboundAchTransferRetrieveParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferRetrieveParams.Builderbuilder()-
-
Method Detail
-
inboundAchTransferId
final String inboundAchTransferId()
The identifier of the Inbound ACH Transfer to get details for.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final InboundAchTransferRetrieveParams.Builder toBuilder()
-
builder
final static InboundAchTransferRetrieveParams.Builder builder()
-
-
-
-