Class InboundAchTransferTransferReturnParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundAchTransferTransferReturnParams implements Params
Return an Inbound ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferTransferReturnParams.Bodypublic final classInboundAchTransferTransferReturnParams.BuilderA builder for InboundAchTransferTransferReturnParams.
public final classInboundAchTransferTransferReturnParams.ReasonThe reason why this transfer will be returned. The most usual return codes are
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
Method Summary
Modifier and Type Method Description final StringinboundAchTransferId()The identifier of the Inbound ACH Transfer to return to the originating financial institution. final InboundAchTransferTransferReturnParams.Reasonreason()The reason why this transfer will be returned. final JsonField<InboundAchTransferTransferReturnParams.Reason>_reason()The reason why this transfer will be returned. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final InboundAchTransferTransferReturnParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferTransferReturnParams.Builderbuilder()-
-
Method Detail
-
inboundAchTransferId
final String inboundAchTransferId()
The identifier of the Inbound ACH Transfer to return to the originating financial institution.
-
reason
final InboundAchTransferTransferReturnParams.Reason reason()
The reason why this transfer will be returned. The most usual return codes are
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
_reason
final JsonField<InboundAchTransferTransferReturnParams.Reason> _reason()
The reason why this transfer will be returned. The most usual return codes are
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final InboundAchTransferTransferReturnParams.Builder toBuilder()
-
builder
final static InboundAchTransferTransferReturnParams.Builder builder()
-
-
-
-