Class InboundCheckDeposit
-
- All Implemented Interfaces:
public final class InboundCheckDepositInbound Check Deposits are records of third-parties attempting to deposit checks against your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDeposit.BuilderA builder for InboundCheckDeposit.
public final classInboundCheckDeposit.Adjustmentpublic final classInboundCheckDeposit.CurrencyThe ISO 4217 code for the deposit.
public final classInboundCheckDeposit.DepositReturnIf you requested a return of this deposit, this will contain details of the return.
public final classInboundCheckDeposit.PayeeNameAnalysisWhether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
public final classInboundCheckDeposit.StatusThe status of the Inbound Check Deposit.
public final classInboundCheckDeposit.TypeA constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
Method Summary
Modifier and Type Method Description final Stringid()The deposit's identifier. final Optional<OffsetDateTime>acceptedAt()If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final StringaccountId()The Account the check is being deposited against. final Optional<String>accountNumberId()The Account Number the check is being deposited against. final List<InboundCheckDeposit.Adjustment>adjustments()If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final Longamount()The deposited amount in USD cents. final Optional<String>backImageFileId()The ID for the File containing the image of the back of the check. final Optional<String>bankOfFirstDepositRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final Optional<String>checkNumber()The check number printed on the check being deposited. final Optional<String>checkTransferId()If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the deposit was attempted. final InboundCheckDeposit.Currencycurrency()The ISO 4217 code for the deposit. final Optional<OffsetDateTime>declinedAt()If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final Optional<String>declinedTransactionId()If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final Optional<InboundCheckDeposit.DepositReturn>depositReturn()If you requested a return of this deposit, this will contain details of the return. final Optional<String>frontImageFileId()The ID for the File containing the image of the front of the check. final InboundCheckDeposit.PayeeNameAnalysispayeeNameAnalysis()Whether the details on the check match the recipient name of the check transfer. final InboundCheckDeposit.Statusstatus()The status of the Inbound Check Deposit. final Optional<String>transactionId()If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final InboundCheckDeposit.Typetype()A constant representing the object's type. final JsonField<String>_id()The deposit's identifier. final JsonField<OffsetDateTime>_acceptedAt()If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final JsonField<String>_accountId()The Account the check is being deposited against. final JsonField<String>_accountNumberId()The Account Number the check is being deposited against. final JsonField<List<InboundCheckDeposit.Adjustment>>_adjustments()If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final JsonField<Long>_amount()The deposited amount in USD cents. final JsonField<String>_backImageFileId()The ID for the File containing the image of the back of the check. final JsonField<String>_bankOfFirstDepositRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final JsonField<String>_checkNumber()The check number printed on the check being deposited. final JsonField<String>_checkTransferId()If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the deposit was attempted. final JsonField<InboundCheckDeposit.Currency>_currency()The ISO 4217 code for the deposit. final JsonField<OffsetDateTime>_declinedAt()If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final JsonField<String>_declinedTransactionId()If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final JsonField<InboundCheckDeposit.DepositReturn>_depositReturn()If you requested a return of this deposit, this will contain details of the return. final JsonField<String>_frontImageFileId()The ID for the File containing the image of the front of the check. final JsonField<InboundCheckDeposit.PayeeNameAnalysis>_payeeNameAnalysis()Whether the details on the check match the recipient name of the check transfer. final JsonField<InboundCheckDeposit.Status>_status()The status of the Inbound Check Deposit. final JsonField<String>_transactionId()If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final JsonField<InboundCheckDeposit.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final InboundCheckDepositvalidate()final InboundCheckDeposit.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDeposit.Builderbuilder()-
-
Method Detail
-
acceptedAt
final Optional<OffsetDateTime> acceptedAt()
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
accountNumberId
final Optional<String> accountNumberId()
The Account Number the check is being deposited against.
-
adjustments
final List<InboundCheckDeposit.Adjustment> adjustments()
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
backImageFileId
final Optional<String> backImageFileId()
The ID for the File containing the image of the back of the check.
-
bankOfFirstDepositRoutingNumber
final Optional<String> bankOfFirstDepositRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
checkNumber
final Optional<String> checkNumber()
The check number printed on the check being deposited.
-
checkTransferId
final Optional<String> checkTransferId()
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the deposit was attempted.
-
currency
final InboundCheckDeposit.Currency currency()
The ISO 4217 code for the deposit.
-
declinedAt
final Optional<OffsetDateTime> declinedAt()
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
declinedTransactionId
final Optional<String> declinedTransactionId()
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
depositReturn
final Optional<InboundCheckDeposit.DepositReturn> depositReturn()
If you requested a return of this deposit, this will contain details of the return.
-
frontImageFileId
final Optional<String> frontImageFileId()
The ID for the File containing the image of the front of the check.
-
payeeNameAnalysis
final InboundCheckDeposit.PayeeNameAnalysis payeeNameAnalysis()
Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
-
status
final InboundCheckDeposit.Status status()
The status of the Inbound Check Deposit.
-
transactionId
final Optional<String> transactionId()
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
type
final InboundCheckDeposit.Type type()
A constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
_accountId
final JsonField<String> _accountId()
The Account the check is being deposited against.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The Account Number the check is being deposited against.
-
_adjustments
final JsonField<List<InboundCheckDeposit.Adjustment>> _adjustments()
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
_backImageFileId
final JsonField<String> _backImageFileId()
The ID for the File containing the image of the back of the check.
-
_bankOfFirstDepositRoutingNumber
final JsonField<String> _bankOfFirstDepositRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
_checkNumber
final JsonField<String> _checkNumber()
The check number printed on the check being deposited.
-
_checkTransferId
final JsonField<String> _checkTransferId()
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the deposit was attempted.
-
_currency
final JsonField<InboundCheckDeposit.Currency> _currency()
The ISO 4217 code for the deposit.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
_depositReturn
final JsonField<InboundCheckDeposit.DepositReturn> _depositReturn()
If you requested a return of this deposit, this will contain details of the return.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The ID for the File containing the image of the front of the check.
-
_payeeNameAnalysis
final JsonField<InboundCheckDeposit.PayeeNameAnalysis> _payeeNameAnalysis()
Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
-
_status
final JsonField<InboundCheckDeposit.Status> _status()
The status of the Inbound Check Deposit.
-
_transactionId
final JsonField<String> _transactionId()
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
_type
final JsonField<InboundCheckDeposit.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundCheckDeposit validate()
-
toBuilder
final InboundCheckDeposit.Builder toBuilder()
-
builder
final static InboundCheckDeposit.Builder builder()
-
-
-
-