Package com.increase.api.models
Class InboundCheckDeposit.Adjustment
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.Adjustment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDeposit.Adjustment.BuilderA builder for Adjustment.
public final classInboundCheckDeposit.Adjustment.ReasonThe reason for the adjustment.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeadjustedAt()The time at which the return adjustment was received. final Longamount()The amount of the adjustment. final InboundCheckDeposit.Adjustment.Reasonreason()The reason for the adjustment. final StringtransactionId()The id of the transaction for the adjustment. final JsonField<OffsetDateTime>_adjustedAt()The time at which the return adjustment was received. final JsonField<Long>_amount()The amount of the adjustment. final JsonField<InboundCheckDeposit.Adjustment.Reason>_reason()The reason for the adjustment. final JsonField<String>_transactionId()The id of the transaction for the adjustment. final Map<String, JsonValue>_additionalProperties()final InboundCheckDeposit.Adjustmentvalidate()final InboundCheckDeposit.Adjustment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDeposit.Adjustment.Builderbuilder()-
-
Method Detail
-
adjustedAt
final OffsetDateTime adjustedAt()
The time at which the return adjustment was received.
-
reason
final InboundCheckDeposit.Adjustment.Reason reason()
The reason for the adjustment.
-
transactionId
final String transactionId()
The id of the transaction for the adjustment.
-
_adjustedAt
final JsonField<OffsetDateTime> _adjustedAt()
The time at which the return adjustment was received.
-
_reason
final JsonField<InboundCheckDeposit.Adjustment.Reason> _reason()
The reason for the adjustment.
-
_transactionId
final JsonField<String> _transactionId()
The id of the transaction for the adjustment.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundCheckDeposit.Adjustment validate()
-
toBuilder
final InboundCheckDeposit.Adjustment.Builder toBuilder()
-
builder
final static InboundCheckDeposit.Adjustment.Builder builder()
-
-
-
-