Package com.increase.api.models
Class InboundCheckDeposit.Adjustment.Builder
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.Adjustment.BuilderA builder for Adjustment.
-
-
Method Summary
-
-
Method Detail
-
adjustedAt
final InboundCheckDeposit.Adjustment.Builder adjustedAt(OffsetDateTime adjustedAt)
The time at which the return adjustment was received.
-
adjustedAt
final InboundCheckDeposit.Adjustment.Builder adjustedAt(JsonField<OffsetDateTime> adjustedAt)
The time at which the return adjustment was received.
-
amount
final InboundCheckDeposit.Adjustment.Builder amount(Long amount)
The amount of the adjustment.
-
amount
final InboundCheckDeposit.Adjustment.Builder amount(JsonField<Long> amount)
The amount of the adjustment.
-
reason
final InboundCheckDeposit.Adjustment.Builder reason(InboundCheckDeposit.Adjustment.Reason reason)
The reason for the adjustment.
-
reason
final InboundCheckDeposit.Adjustment.Builder reason(JsonField<InboundCheckDeposit.Adjustment.Reason> reason)
The reason for the adjustment.
-
transactionId
final InboundCheckDeposit.Adjustment.Builder transactionId(String transactionId)
The id of the transaction for the adjustment.
-
transactionId
final InboundCheckDeposit.Adjustment.Builder transactionId(JsonField<String> transactionId)
The id of the transaction for the adjustment.
-
additionalProperties
final InboundCheckDeposit.Adjustment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundCheckDeposit.Adjustment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundCheckDeposit.Adjustment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundCheckDeposit.Adjustment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundCheckDeposit.Adjustment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundCheckDeposit.Adjustment build()
-
-
-
-