Class InboundCheckDeposit.Builder
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.BuilderA builder for InboundCheckDeposit.
-
-
Method Summary
Modifier and Type Method Description final InboundCheckDeposit.Builderid(String id)The deposit's identifier. final InboundCheckDeposit.Builderid(JsonField<String> id)The deposit's identifier. final InboundCheckDeposit.BuilderacceptedAt(OffsetDateTime acceptedAt)If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderacceptedAt(Optional<OffsetDateTime> acceptedAt)If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderacceptedAt(JsonField<OffsetDateTime> acceptedAt)If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderaccountId(String accountId)The Account the check is being deposited against. final InboundCheckDeposit.BuilderaccountId(JsonField<String> accountId)The Account the check is being deposited against. final InboundCheckDeposit.BuilderaccountNumberId(String accountNumberId)The Account Number the check is being deposited against. final InboundCheckDeposit.BuilderaccountNumberId(Optional<String> accountNumberId)The Account Number the check is being deposited against. final InboundCheckDeposit.BuilderaccountNumberId(JsonField<String> accountNumberId)The Account Number the check is being deposited against. final InboundCheckDeposit.Builderadjustments(List<InboundCheckDeposit.Adjustment> adjustments)If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final InboundCheckDeposit.Builderadjustments(JsonField<List<InboundCheckDeposit.Adjustment>> adjustments)If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final InboundCheckDeposit.BuilderaddAdjustment(InboundCheckDeposit.Adjustment adjustment)If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final InboundCheckDeposit.Builderamount(Long amount)The deposited amount in USD cents. final InboundCheckDeposit.Builderamount(JsonField<Long> amount)The deposited amount in USD cents. final InboundCheckDeposit.BuilderbackImageFileId(String backImageFileId)The ID for the File containing the image of the back of the check. final InboundCheckDeposit.BuilderbackImageFileId(Optional<String> backImageFileId)The ID for the File containing the image of the back of the check. final InboundCheckDeposit.BuilderbackImageFileId(JsonField<String> backImageFileId)The ID for the File containing the image of the back of the check. final InboundCheckDeposit.BuilderbankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final InboundCheckDeposit.BuilderbankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final InboundCheckDeposit.BuilderbankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final InboundCheckDeposit.BuildercheckNumber(String checkNumber)The check number printed on the check being deposited. final InboundCheckDeposit.BuildercheckNumber(Optional<String> checkNumber)The check number printed on the check being deposited. final InboundCheckDeposit.BuildercheckNumber(JsonField<String> checkNumber)The check number printed on the check being deposited. final InboundCheckDeposit.BuildercheckTransferId(String checkTransferId)If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final InboundCheckDeposit.BuildercheckTransferId(Optional<String> checkTransferId)If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final InboundCheckDeposit.BuildercheckTransferId(JsonField<String> checkTransferId)If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final InboundCheckDeposit.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the deposit was attempted. final InboundCheckDeposit.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the deposit was attempted. final InboundCheckDeposit.Buildercurrency(InboundCheckDeposit.Currency currency)The ISO 4217 code for the deposit. final InboundCheckDeposit.Buildercurrency(JsonField<InboundCheckDeposit.Currency> currency)The ISO 4217 code for the deposit. final InboundCheckDeposit.BuilderdeclinedAt(OffsetDateTime declinedAt)If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderdeclinedAt(Optional<OffsetDateTime> declinedAt)If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderdeclinedAt(JsonField<OffsetDateTime> declinedAt)If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderdeclinedTransactionId(String declinedTransactionId)If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final InboundCheckDeposit.BuilderdeclinedTransactionId(Optional<String> declinedTransactionId)If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final InboundCheckDeposit.BuilderdeclinedTransactionId(JsonField<String> declinedTransactionId)If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final InboundCheckDeposit.BuilderdepositReturn(InboundCheckDeposit.DepositReturn depositReturn)If you requested a return of this deposit, this will contain details of the return. final InboundCheckDeposit.BuilderdepositReturn(Optional<InboundCheckDeposit.DepositReturn> depositReturn)If you requested a return of this deposit, this will contain details of the return. final InboundCheckDeposit.BuilderdepositReturn(JsonField<InboundCheckDeposit.DepositReturn> depositReturn)If you requested a return of this deposit, this will contain details of the return. final InboundCheckDeposit.BuilderfrontImageFileId(String frontImageFileId)The ID for the File containing the image of the front of the check. final InboundCheckDeposit.BuilderfrontImageFileId(Optional<String> frontImageFileId)The ID for the File containing the image of the front of the check. final InboundCheckDeposit.BuilderfrontImageFileId(JsonField<String> frontImageFileId)The ID for the File containing the image of the front of the check. final InboundCheckDeposit.BuilderpayeeNameAnalysis(InboundCheckDeposit.PayeeNameAnalysis payeeNameAnalysis)Whether the details on the check match the recipient name of the check transfer. final InboundCheckDeposit.BuilderpayeeNameAnalysis(JsonField<InboundCheckDeposit.PayeeNameAnalysis> payeeNameAnalysis)Whether the details on the check match the recipient name of the check transfer. final InboundCheckDeposit.Builderstatus(InboundCheckDeposit.Status status)The status of the Inbound Check Deposit. final InboundCheckDeposit.Builderstatus(JsonField<InboundCheckDeposit.Status> status)The status of the Inbound Check Deposit. final InboundCheckDeposit.BuildertransactionId(String transactionId)If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final InboundCheckDeposit.BuildertransactionId(Optional<String> transactionId)If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final InboundCheckDeposit.BuildertransactionId(JsonField<String> transactionId)If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final InboundCheckDeposit.Buildertype(InboundCheckDeposit.Type type)A constant representing the object's type. final InboundCheckDeposit.Buildertype(JsonField<InboundCheckDeposit.Type> type)A constant representing the object's type. final InboundCheckDeposit.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final InboundCheckDeposit.BuilderputAdditionalProperty(String key, JsonValue value)final InboundCheckDeposit.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final InboundCheckDeposit.BuilderremoveAdditionalProperty(String key)final InboundCheckDeposit.BuilderremoveAllAdditionalProperties(Set<String> keys)final InboundCheckDepositbuild()-
-
Method Detail
-
id
final InboundCheckDeposit.Builder id(String id)
The deposit's identifier.
-
id
final InboundCheckDeposit.Builder id(JsonField<String> id)
The deposit's identifier.
-
acceptedAt
final InboundCheckDeposit.Builder acceptedAt(OffsetDateTime acceptedAt)
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
acceptedAt
final InboundCheckDeposit.Builder acceptedAt(Optional<OffsetDateTime> acceptedAt)
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
acceptedAt
final InboundCheckDeposit.Builder acceptedAt(JsonField<OffsetDateTime> acceptedAt)
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
accountId
final InboundCheckDeposit.Builder accountId(String accountId)
The Account the check is being deposited against.
-
accountId
final InboundCheckDeposit.Builder accountId(JsonField<String> accountId)
The Account the check is being deposited against.
-
accountNumberId
final InboundCheckDeposit.Builder accountNumberId(String accountNumberId)
The Account Number the check is being deposited against.
-
accountNumberId
final InboundCheckDeposit.Builder accountNumberId(Optional<String> accountNumberId)
The Account Number the check is being deposited against.
-
accountNumberId
final InboundCheckDeposit.Builder accountNumberId(JsonField<String> accountNumberId)
The Account Number the check is being deposited against.
-
adjustments
final InboundCheckDeposit.Builder adjustments(List<InboundCheckDeposit.Adjustment> adjustments)
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
adjustments
final InboundCheckDeposit.Builder adjustments(JsonField<List<InboundCheckDeposit.Adjustment>> adjustments)
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
addAdjustment
final InboundCheckDeposit.Builder addAdjustment(InboundCheckDeposit.Adjustment adjustment)
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
amount
final InboundCheckDeposit.Builder amount(Long amount)
The deposited amount in USD cents.
-
amount
final InboundCheckDeposit.Builder amount(JsonField<Long> amount)
The deposited amount in USD cents.
-
backImageFileId
final InboundCheckDeposit.Builder backImageFileId(String backImageFileId)
The ID for the File containing the image of the back of the check.
-
backImageFileId
final InboundCheckDeposit.Builder backImageFileId(Optional<String> backImageFileId)
The ID for the File containing the image of the back of the check.
-
backImageFileId
final InboundCheckDeposit.Builder backImageFileId(JsonField<String> backImageFileId)
The ID for the File containing the image of the back of the check.
-
bankOfFirstDepositRoutingNumber
final InboundCheckDeposit.Builder bankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
bankOfFirstDepositRoutingNumber
final InboundCheckDeposit.Builder bankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
bankOfFirstDepositRoutingNumber
final InboundCheckDeposit.Builder bankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
checkNumber
final InboundCheckDeposit.Builder checkNumber(String checkNumber)
The check number printed on the check being deposited.
-
checkNumber
final InboundCheckDeposit.Builder checkNumber(Optional<String> checkNumber)
The check number printed on the check being deposited.
-
checkNumber
final InboundCheckDeposit.Builder checkNumber(JsonField<String> checkNumber)
The check number printed on the check being deposited.
-
checkTransferId
final InboundCheckDeposit.Builder checkTransferId(String checkTransferId)
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
checkTransferId
final InboundCheckDeposit.Builder checkTransferId(Optional<String> checkTransferId)
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
checkTransferId
final InboundCheckDeposit.Builder checkTransferId(JsonField<String> checkTransferId)
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
createdAt
final InboundCheckDeposit.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the deposit was attempted.
-
createdAt
final InboundCheckDeposit.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the deposit was attempted.
-
currency
final InboundCheckDeposit.Builder currency(InboundCheckDeposit.Currency currency)
The ISO 4217 code for the deposit.
-
currency
final InboundCheckDeposit.Builder currency(JsonField<InboundCheckDeposit.Currency> currency)
The ISO 4217 code for the deposit.
-
declinedAt
final InboundCheckDeposit.Builder declinedAt(OffsetDateTime declinedAt)
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
declinedAt
final InboundCheckDeposit.Builder declinedAt(Optional<OffsetDateTime> declinedAt)
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
declinedAt
final InboundCheckDeposit.Builder declinedAt(JsonField<OffsetDateTime> declinedAt)
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
declinedTransactionId
final InboundCheckDeposit.Builder declinedTransactionId(String declinedTransactionId)
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
declinedTransactionId
final InboundCheckDeposit.Builder declinedTransactionId(Optional<String> declinedTransactionId)
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
declinedTransactionId
final InboundCheckDeposit.Builder declinedTransactionId(JsonField<String> declinedTransactionId)
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
depositReturn
final InboundCheckDeposit.Builder depositReturn(InboundCheckDeposit.DepositReturn depositReturn)
If you requested a return of this deposit, this will contain details of the return.
-
depositReturn
final InboundCheckDeposit.Builder depositReturn(Optional<InboundCheckDeposit.DepositReturn> depositReturn)
If you requested a return of this deposit, this will contain details of the return.
-
depositReturn
final InboundCheckDeposit.Builder depositReturn(JsonField<InboundCheckDeposit.DepositReturn> depositReturn)
If you requested a return of this deposit, this will contain details of the return.
-
frontImageFileId
final InboundCheckDeposit.Builder frontImageFileId(String frontImageFileId)
The ID for the File containing the image of the front of the check.
-
frontImageFileId
final InboundCheckDeposit.Builder frontImageFileId(Optional<String> frontImageFileId)
The ID for the File containing the image of the front of the check.
-
frontImageFileId
final InboundCheckDeposit.Builder frontImageFileId(JsonField<String> frontImageFileId)
The ID for the File containing the image of the front of the check.
-
payeeNameAnalysis
final InboundCheckDeposit.Builder payeeNameAnalysis(InboundCheckDeposit.PayeeNameAnalysis payeeNameAnalysis)
Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
-
payeeNameAnalysis
final InboundCheckDeposit.Builder payeeNameAnalysis(JsonField<InboundCheckDeposit.PayeeNameAnalysis> payeeNameAnalysis)
Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
-
status
final InboundCheckDeposit.Builder status(InboundCheckDeposit.Status status)
The status of the Inbound Check Deposit.
-
status
final InboundCheckDeposit.Builder status(JsonField<InboundCheckDeposit.Status> status)
The status of the Inbound Check Deposit.
-
transactionId
final InboundCheckDeposit.Builder transactionId(String transactionId)
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
transactionId
final InboundCheckDeposit.Builder transactionId(Optional<String> transactionId)
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
transactionId
final InboundCheckDeposit.Builder transactionId(JsonField<String> transactionId)
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
type
final InboundCheckDeposit.Builder type(InboundCheckDeposit.Type type)
A constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
type
final InboundCheckDeposit.Builder type(JsonField<InboundCheckDeposit.Type> type)
A constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
additionalProperties
final InboundCheckDeposit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundCheckDeposit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundCheckDeposit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundCheckDeposit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundCheckDeposit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundCheckDeposit build()
-
-
-
-