Package com.increase.api.models
Class InboundCheckDeposit.DepositReturn
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.DepositReturnIf you requested a return of this deposit, this will contain details of the return.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDeposit.DepositReturn.BuilderA builder for DepositReturn.
public final classInboundCheckDeposit.DepositReturn.ReasonThe reason the deposit was returned.
-
Method Summary
Modifier and Type Method Description final InboundCheckDeposit.DepositReturn.Reasonreason()The reason the deposit was returned. final OffsetDateTimereturnedAt()The time at which the deposit was returned. final StringtransactionId()The id of the transaction for the returned deposit. final JsonField<InboundCheckDeposit.DepositReturn.Reason>_reason()The reason the deposit was returned. final JsonField<OffsetDateTime>_returnedAt()The time at which the deposit was returned. final JsonField<String>_transactionId()The id of the transaction for the returned deposit. final Map<String, JsonValue>_additionalProperties()final InboundCheckDeposit.DepositReturnvalidate()final InboundCheckDeposit.DepositReturn.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDeposit.DepositReturn.Builderbuilder()-
-
Method Detail
-
reason
final InboundCheckDeposit.DepositReturn.Reason reason()
The reason the deposit was returned.
-
returnedAt
final OffsetDateTime returnedAt()
The time at which the deposit was returned.
-
transactionId
final String transactionId()
The id of the transaction for the returned deposit.
-
_reason
final JsonField<InboundCheckDeposit.DepositReturn.Reason> _reason()
The reason the deposit was returned.
-
_returnedAt
final JsonField<OffsetDateTime> _returnedAt()
The time at which the deposit was returned.
-
_transactionId
final JsonField<String> _transactionId()
The id of the transaction for the returned deposit.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundCheckDeposit.DepositReturn validate()
-
toBuilder
final InboundCheckDeposit.DepositReturn.Builder toBuilder()
-
builder
final static InboundCheckDeposit.DepositReturn.Builder builder()
-
-
-
-