Package com.increase.api.models
Enum InboundCheckDeposit.PayeeNameAnalysis.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundCheckDeposit.PayeeNameAnalysis.Known extends Enum<InboundCheckDeposit.PayeeNameAnalysis.Known>
An enum containing PayeeNameAnalysis's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundCheckDeposit.PayeeNameAnalysis.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NAME_MATCHESThe details on the check match the recipient name of the check transfer.
DOES_NOT_MATCHThe details on the check do not match the recipient name of the check transfer.
NOT_EVALUATEDThe payee name analysis was not evaluated.
-
Method Summary
Modifier and Type Method Description final InboundCheckDeposit.PayeeNameAnalysis.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundCheckDeposit.PayeeNameAnalysis.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundCheckDeposit.PayeeNameAnalysis.Known>getEntries()An enum containing PayeeNameAnalysis's known values. -
-
Method Detail
-
valueOf
final InboundCheckDeposit.PayeeNameAnalysis.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundCheckDeposit.PayeeNameAnalysis.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundCheckDeposit.PayeeNameAnalysis.Known> getEntries()
An enum containing PayeeNameAnalysis's known values.
-
-
-
-