Package com.increase.api.models
Class InboundCheckDepositListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundCheckDepositListParams implements Params
List Inbound Check Deposits
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositListParams.BuilderA builder for InboundCheckDepositListParams.
public final classInboundCheckDepositListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Inbound Check Deposits to those belonging to the specified Account. final Optional<String>checkTransferId()Filter Inbound Check Deposits to those belonging to the specified Check Transfer. final Optional<InboundCheckDepositListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final InboundCheckDepositListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDepositListParamsnone()final static InboundCheckDepositListParams.Builderbuilder()-
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Inbound Check Deposits to those belonging to the specified Account.
-
checkTransferId
final Optional<String> checkTransferId()
Filter Inbound Check Deposits to those belonging to the specified Check Transfer.
-
createdAt
final Optional<InboundCheckDepositListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final InboundCheckDepositListParams.Builder toBuilder()
-
none
final static InboundCheckDepositListParams none()
-
builder
final static InboundCheckDepositListParams.Builder builder()
-
-
-
-