Package com.increase.api.models
Enum InboundCheckDepositReturnParams.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundCheckDepositReturnParams.Reason.Known extends Enum<InboundCheckDepositReturnParams.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundCheckDepositReturnParams.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ALTERED_OR_FICTITIOUSThe check was altered or fictitious.
NOT_AUTHORIZEDThe check was not authorized.
DUPLICATE_PRESENTMENTThe check was a duplicate presentment.
ENDORSEMENT_MISSINGThe check was not endorsed.
ENDORSEMENT_IRREGULARThe check was not endorsed by the payee.
-
Method Summary
Modifier and Type Method Description final InboundCheckDepositReturnParams.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundCheckDepositReturnParams.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundCheckDepositReturnParams.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final InboundCheckDepositReturnParams.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundCheckDepositReturnParams.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundCheckDepositReturnParams.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-