Enum InboundCheckDepositReturnParams.Reason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundCheckDepositReturnParams.Reason.Value extends Enum<InboundCheckDepositReturnParams.Reason.Value>
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundCheckDepositReturnParams.Reason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ALTERED_OR_FICTITIOUSThe check was altered or fictitious.
NOT_AUTHORIZEDThe check was not authorized.
DUPLICATE_PRESENTMENTThe check was a duplicate presentment.
ENDORSEMENT_MISSINGThe check was not endorsed.
ENDORSEMENT_IRREGULARThe check was not endorsed by the payee.
_UNKNOWNAn enum member indicating that Reason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final InboundCheckDepositReturnParams.Reason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundCheckDepositReturnParams.Reason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundCheckDepositReturnParams.Reason.Value>getEntries()An enum containing Reason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final InboundCheckDepositReturnParams.Reason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundCheckDepositReturnParams.Reason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundCheckDepositReturnParams.Reason.Value> getEntries()
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-