Class InboundMailItem
-
- All Implemented Interfaces:
public final class InboundMailItemInbound Mail Items represent pieces of physical mail delivered to a Lockbox.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItem.BuilderA builder for InboundMailItem.
public final classInboundMailItem.RejectionReasonIf the mail item has been rejected, why it was rejected.
public final classInboundMailItem.StatusIf the mail item has been processed.
public final classInboundMailItem.TypeA constant representing the object's type. For this resource it will always be
inbound_mail_item.
-
Method Summary
Modifier and Type Method Description final Stringid()The Inbound Mail Item identifier. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Inbound Mail Item was created. final StringfileId()The identifier for the File containing the scanned contents of the mail item. final Optional<String>lockboxId()The identifier for the Lockbox that received this mail item. final Optional<String>recipientName()The recipient name as written on the mail item. final Optional<InboundMailItem.RejectionReason>rejectionReason()If the mail item has been rejected, why it was rejected. final InboundMailItem.Statusstatus()If the mail item has been processed. final InboundMailItem.Typetype()A constant representing the object's type. final JsonField<String>_id()The Inbound Mail Item identifier. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Inbound Mail Item was created. final JsonField<String>_fileId()The identifier for the File containing the scanned contents of the mail item. final JsonField<String>_lockboxId()The identifier for the Lockbox that received this mail item. final JsonField<String>_recipientName()The recipient name as written on the mail item. final JsonField<InboundMailItem.RejectionReason>_rejectionReason()If the mail item has been rejected, why it was rejected. final JsonField<InboundMailItem.Status>_status()If the mail item has been processed. final JsonField<InboundMailItem.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final InboundMailItemvalidate()final InboundMailItem.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItem.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Inbound Mail Item was created.
-
fileId
final String fileId()
The identifier for the File containing the scanned contents of the mail item.
-
lockboxId
final Optional<String> lockboxId()
The identifier for the Lockbox that received this mail item. For mail items that could not be processed due to an invalid address, this will be null.
-
recipientName
final Optional<String> recipientName()
The recipient name as written on the mail item.
-
rejectionReason
final Optional<InboundMailItem.RejectionReason> rejectionReason()
If the mail item has been rejected, why it was rejected.
-
status
final InboundMailItem.Status status()
If the mail item has been processed.
-
type
final InboundMailItem.Type type()
A constant representing the object's type. For this resource it will always be
inbound_mail_item.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Inbound Mail Item was created.
-
_fileId
final JsonField<String> _fileId()
The identifier for the File containing the scanned contents of the mail item.
-
_lockboxId
final JsonField<String> _lockboxId()
The identifier for the Lockbox that received this mail item. For mail items that could not be processed due to an invalid address, this will be null.
-
_recipientName
final JsonField<String> _recipientName()
The recipient name as written on the mail item.
-
_rejectionReason
final JsonField<InboundMailItem.RejectionReason> _rejectionReason()
If the mail item has been rejected, why it was rejected.
-
_status
final JsonField<InboundMailItem.Status> _status()
If the mail item has been processed.
-
_type
final JsonField<InboundMailItem.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_mail_item.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundMailItem validate()
-
toBuilder
final InboundMailItem.Builder toBuilder()
-
builder
final static InboundMailItem.Builder builder()
-
-
-
-