Class InboundRealTimePaymentsTransfer
-
- All Implemented Interfaces:
public final class InboundRealTimePaymentsTransferAn Inbound Real-Time Payments Transfer is a Real-Time Payments transfer initiated outside of Increase to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundRealTimePaymentsTransfer.BuilderA builder for InboundRealTimePaymentsTransfer.
public final classInboundRealTimePaymentsTransfer.ConfirmationIf your transfer is confirmed, this will contain details of the confirmation.
public final classInboundRealTimePaymentsTransfer.CurrencyThe ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
public final classInboundRealTimePaymentsTransfer.DeclineIf your transfer is declined, this will contain details of the decline.
public final classInboundRealTimePaymentsTransfer.StatusThe lifecycle status of the transfer.
public final classInboundRealTimePaymentsTransfer.TypeA constant representing the object's type. For this resource it will always be
inbound_real_time_payments_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The inbound Real-Time Payments transfer's identifier. final StringaccountId()The Account to which the transfer was sent. final StringaccountNumberId()The identifier of the Account Number to which this transfer was sent. final Longamount()The amount in USD cents. final Optional<InboundRealTimePaymentsTransfer.Confirmation>confirmation()If your transfer is confirmed, this will contain details of the confirmation. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final StringcreditorName()The name the sender of the transfer specified as the recipient of the transfer. final InboundRealTimePaymentsTransfer.Currencycurrency()The ISO 4217 code of the transfer's currency. final StringdebtorAccountNumber()The account number of the account that sent the transfer. final StringdebtorName()The name provided by the sender of the transfer. final StringdebtorRoutingNumber()The routing number of the account that sent the transfer. final Optional<InboundRealTimePaymentsTransfer.Decline>decline()If your transfer is declined, this will contain details of the decline. final Optional<String>remittanceInformation()Additional information included with the transfer. final InboundRealTimePaymentsTransfer.Statusstatus()The lifecycle status of the transfer. final StringtransactionIdentification()The Real-Time Payments network identification of the transfer. final InboundRealTimePaymentsTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The inbound Real-Time Payments transfer's identifier. final JsonField<String>_accountId()The Account to which the transfer was sent. final JsonField<String>_accountNumberId()The identifier of the Account Number to which this transfer was sent. final JsonField<Long>_amount()The amount in USD cents. final JsonField<InboundRealTimePaymentsTransfer.Confirmation>_confirmation()If your transfer is confirmed, this will contain details of the confirmation. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<String>_creditorName()The name the sender of the transfer specified as the recipient of the transfer. final JsonField<InboundRealTimePaymentsTransfer.Currency>_currency()The ISO 4217 code of the transfer's currency. final JsonField<String>_debtorAccountNumber()The account number of the account that sent the transfer. final JsonField<String>_debtorName()The name provided by the sender of the transfer. final JsonField<String>_debtorRoutingNumber()The routing number of the account that sent the transfer. final JsonField<InboundRealTimePaymentsTransfer.Decline>_decline()If your transfer is declined, this will contain details of the decline. final JsonField<String>_remittanceInformation()Additional information included with the transfer. final JsonField<InboundRealTimePaymentsTransfer.Status>_status()The lifecycle status of the transfer. final JsonField<String>_transactionIdentification()The Real-Time Payments network identification of the transfer. final JsonField<InboundRealTimePaymentsTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final InboundRealTimePaymentsTransfervalidate()final InboundRealTimePaymentsTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundRealTimePaymentsTransfer.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
confirmation
final Optional<InboundRealTimePaymentsTransfer.Confirmation> confirmation()
If your transfer is confirmed, this will contain details of the confirmation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
creditorName
final String creditorName()
The name the sender of the transfer specified as the recipient of the transfer.
-
currency
final InboundRealTimePaymentsTransfer.Currency currency()
The ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
debtorAccountNumber
final String debtorAccountNumber()
The account number of the account that sent the transfer.
-
debtorName
final String debtorName()
The name provided by the sender of the transfer.
-
debtorRoutingNumber
final String debtorRoutingNumber()
The routing number of the account that sent the transfer.
-
decline
final Optional<InboundRealTimePaymentsTransfer.Decline> decline()
If your transfer is declined, this will contain details of the decline.
-
remittanceInformation
final Optional<String> remittanceInformation()
Additional information included with the transfer.
-
status
final InboundRealTimePaymentsTransfer.Status status()
The lifecycle status of the transfer.
-
transactionIdentification
final String transactionIdentification()
The Real-Time Payments network identification of the transfer.
-
type
final InboundRealTimePaymentsTransfer.Type type()
A constant representing the object's type. For this resource it will always be
inbound_real_time_payments_transfer.
-
_accountId
final JsonField<String> _accountId()
The Account to which the transfer was sent.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
_confirmation
final JsonField<InboundRealTimePaymentsTransfer.Confirmation> _confirmation()
If your transfer is confirmed, this will contain details of the confirmation.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_creditorName
final JsonField<String> _creditorName()
The name the sender of the transfer specified as the recipient of the transfer.
-
_currency
final JsonField<InboundRealTimePaymentsTransfer.Currency> _currency()
The ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
The account number of the account that sent the transfer.
-
_debtorName
final JsonField<String> _debtorName()
The name provided by the sender of the transfer.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
The routing number of the account that sent the transfer.
-
_decline
final JsonField<InboundRealTimePaymentsTransfer.Decline> _decline()
If your transfer is declined, this will contain details of the decline.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Additional information included with the transfer.
-
_status
final JsonField<InboundRealTimePaymentsTransfer.Status> _status()
The lifecycle status of the transfer.
-
_transactionIdentification
final JsonField<String> _transactionIdentification()
The Real-Time Payments network identification of the transfer.
-
_type
final JsonField<InboundRealTimePaymentsTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_real_time_payments_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundRealTimePaymentsTransfer validate()
-
toBuilder
final InboundRealTimePaymentsTransfer.Builder toBuilder()
-
builder
final static InboundRealTimePaymentsTransfer.Builder builder()
-
-
-
-