Package com.increase.api.models
Class InboundRealTimePaymentsTransfer.Confirmation
-
- All Implemented Interfaces:
public final class InboundRealTimePaymentsTransfer.ConfirmationIf your transfer is confirmed, this will contain details of the confirmation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundRealTimePaymentsTransfer.Confirmation.BuilderA builder for Confirmation.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeconfirmedAt()The time at which the transfer was confirmed. final StringtransactionId()The id of the transaction for the confirmed transfer. final JsonField<OffsetDateTime>_confirmedAt()The time at which the transfer was confirmed. final JsonField<String>_transactionId()The id of the transaction for the confirmed transfer. final Map<String, JsonValue>_additionalProperties()final InboundRealTimePaymentsTransfer.Confirmationvalidate()final InboundRealTimePaymentsTransfer.Confirmation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundRealTimePaymentsTransfer.Confirmation.Builderbuilder()-
-
Method Detail
-
confirmedAt
final OffsetDateTime confirmedAt()
The time at which the transfer was confirmed.
-
transactionId
final String transactionId()
The id of the transaction for the confirmed transfer.
-
_confirmedAt
final JsonField<OffsetDateTime> _confirmedAt()
The time at which the transfer was confirmed.
-
_transactionId
final JsonField<String> _transactionId()
The id of the transaction for the confirmed transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundRealTimePaymentsTransfer.Confirmation validate()
-
toBuilder
final InboundRealTimePaymentsTransfer.Confirmation.Builder toBuilder()
-
builder
final static InboundRealTimePaymentsTransfer.Confirmation.Builder builder()
-
-
-
-