Class InboundRealTimePaymentsTransfer.Currency
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class InboundRealTimePaymentsTransfer.Currency implements EnumThe ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumInboundRealTimePaymentsTransfer.Currency.KnownAn enum containing Currency's known values.
public enumInboundRealTimePaymentsTransfer.Currency.ValueAn enum containing Currency's known values, as well as an _UNKNOWN member.
An instance of Currency can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static InboundRealTimePaymentsTransfer.CurrencyCADpublic final static InboundRealTimePaymentsTransfer.CurrencyCHFpublic final static InboundRealTimePaymentsTransfer.CurrencyEURpublic final static InboundRealTimePaymentsTransfer.CurrencyGBPpublic final static InboundRealTimePaymentsTransfer.CurrencyJPYpublic final static InboundRealTimePaymentsTransfer.CurrencyUSD
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final InboundRealTimePaymentsTransfer.Currency.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final InboundRealTimePaymentsTransfer.Currency.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundRealTimePaymentsTransfer.Currencyof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final InboundRealTimePaymentsTransfer.Currency.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final InboundRealTimePaymentsTransfer.Currency.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
of
final static InboundRealTimePaymentsTransfer.Currency of(String value)
-
-
-
-