Package com.increase.api.models
Class InboundRealTimePaymentsTransfer.Decline
-
- All Implemented Interfaces:
public final class InboundRealTimePaymentsTransfer.DeclineIf your transfer is declined, this will contain details of the decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundRealTimePaymentsTransfer.Decline.BuilderA builder for Decline.
public final classInboundRealTimePaymentsTransfer.Decline.ReasonThe reason for the transfer decline.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimedeclinedAt()The time at which the transfer was declined. final StringdeclinedTransactionId()The id of the transaction for the declined transfer. final InboundRealTimePaymentsTransfer.Decline.Reasonreason()The reason for the transfer decline. final JsonField<OffsetDateTime>_declinedAt()The time at which the transfer was declined. final JsonField<String>_declinedTransactionId()The id of the transaction for the declined transfer. final JsonField<InboundRealTimePaymentsTransfer.Decline.Reason>_reason()The reason for the transfer decline. final Map<String, JsonValue>_additionalProperties()final InboundRealTimePaymentsTransfer.Declinevalidate()final InboundRealTimePaymentsTransfer.Decline.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundRealTimePaymentsTransfer.Decline.Builderbuilder()-
-
Method Detail
-
declinedAt
final OffsetDateTime declinedAt()
The time at which the transfer was declined.
-
declinedTransactionId
final String declinedTransactionId()
The id of the transaction for the declined transfer.
-
reason
final InboundRealTimePaymentsTransfer.Decline.Reason reason()
The reason for the transfer decline.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
The time at which the transfer was declined.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
The id of the transaction for the declined transfer.
-
_reason
final JsonField<InboundRealTimePaymentsTransfer.Decline.Reason> _reason()
The reason for the transfer decline.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundRealTimePaymentsTransfer.Decline validate()
-
toBuilder
final InboundRealTimePaymentsTransfer.Decline.Builder toBuilder()
-
builder
final static InboundRealTimePaymentsTransfer.Decline.Builder builder()
-
-
-
-