Package com.increase.api.models
Class InboundRealTimePaymentsTransfer.Decline.Builder
-
- All Implemented Interfaces:
public final class InboundRealTimePaymentsTransfer.Decline.BuilderA builder for Decline.
-
-
Method Summary
-
-
Method Detail
-
declinedAt
final InboundRealTimePaymentsTransfer.Decline.Builder declinedAt(OffsetDateTime declinedAt)
The time at which the transfer was declined.
-
declinedAt
final InboundRealTimePaymentsTransfer.Decline.Builder declinedAt(JsonField<OffsetDateTime> declinedAt)
The time at which the transfer was declined.
-
declinedTransactionId
final InboundRealTimePaymentsTransfer.Decline.Builder declinedTransactionId(String declinedTransactionId)
The id of the transaction for the declined transfer.
-
declinedTransactionId
final InboundRealTimePaymentsTransfer.Decline.Builder declinedTransactionId(JsonField<String> declinedTransactionId)
The id of the transaction for the declined transfer.
-
reason
final InboundRealTimePaymentsTransfer.Decline.Builder reason(InboundRealTimePaymentsTransfer.Decline.Reason reason)
The reason for the transfer decline.
-
reason
final InboundRealTimePaymentsTransfer.Decline.Builder reason(JsonField<InboundRealTimePaymentsTransfer.Decline.Reason> reason)
The reason for the transfer decline.
-
additionalProperties
final InboundRealTimePaymentsTransfer.Decline.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundRealTimePaymentsTransfer.Decline.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundRealTimePaymentsTransfer.Decline.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundRealTimePaymentsTransfer.Decline.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundRealTimePaymentsTransfer.Decline.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundRealTimePaymentsTransfer.Decline build()
-
-
-
-