Package com.increase.api.models
Class InboundRealTimePaymentsTransferListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundRealTimePaymentsTransferListParams implements Params
List Inbound Real-Time Payments Transfers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundRealTimePaymentsTransferListParams.BuilderA builder for InboundRealTimePaymentsTransferListParams.
public final classInboundRealTimePaymentsTransferListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Inbound Real-Time Payments Transfers to those belonging to the specified Account. final Optional<String>accountNumberId()Filter Inbound Real-Time Payments Transfers to ones belonging to the specified Account Number. final Optional<InboundRealTimePaymentsTransferListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final InboundRealTimePaymentsTransferListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundRealTimePaymentsTransferListParamsnone()final static InboundRealTimePaymentsTransferListParams.Builderbuilder()-
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Inbound Real-Time Payments Transfers to those belonging to the specified Account.
-
accountNumberId
final Optional<String> accountNumberId()
Filter Inbound Real-Time Payments Transfers to ones belonging to the specified Account Number.
-
createdAt
final Optional<InboundRealTimePaymentsTransferListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final InboundRealTimePaymentsTransferListParams.Builder toBuilder()
-
none
final static InboundRealTimePaymentsTransferListParams none()
-
builder
final static InboundRealTimePaymentsTransferListParams.Builder builder()
-
-
-
-