Class InboundWireDrawdownRequest
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestInbound wire drawdown requests are requests from someone else to send them a wire. This feature is in beta; reach out to [email protected] to learn more.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequest.BuilderA builder for InboundWireDrawdownRequest.
public final classInboundWireDrawdownRequest.TypeA constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Wire drawdown request identifier. final Longamount()The amount being requested in cents. final StringbeneficiaryAccountNumber()The drawdown request's beneficiary's account number. final Optional<String>beneficiaryAddressLine1()Line 1 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryAddressLine2()Line 2 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryAddressLine3()Line 3 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryName()The drawdown request's beneficiary's name. final StringbeneficiaryRoutingNumber()The drawdown request's beneficiary's routing number. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound wire drawdown requested was created. final Stringcurrency()The ISO 4217 code for the amount being requested. final Optional<String>messageToRecipient()A message from the drawdown request's originator. final StringoriginatorAccountNumber()The drawdown request's originator's account number. final Optional<String>originatorAddressLine1()Line 1 of the drawdown request's originator's address. final Optional<String>originatorAddressLine2()Line 2 of the drawdown request's originator's address. final Optional<String>originatorAddressLine3()Line 3 of the drawdown request's originator's address. final Optional<String>originatorName()The drawdown request's originator's name. final StringoriginatorRoutingNumber()The drawdown request's originator's routing number. final Optional<String>originatorToBeneficiaryInformationLine1()Line 1 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine2()Line 2 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine3()Line 3 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine4()Line 4 of the information conveyed from the originator of the message to the beneficiary. final StringrecipientAccountNumberId()The Account Number from which the recipient of this request is being requested to send funds. final InboundWireDrawdownRequest.Typetype()A constant representing the object's type. final JsonField<String>_id()The Wire drawdown request identifier. final JsonField<Long>_amount()The amount being requested in cents. final JsonField<String>_beneficiaryAccountNumber()The drawdown request's beneficiary's account number. final JsonField<String>_beneficiaryAddressLine1()Line 1 of the drawdown request's beneficiary's address. final JsonField<String>_beneficiaryAddressLine2()Line 2 of the drawdown request's beneficiary's address. final JsonField<String>_beneficiaryAddressLine3()Line 3 of the drawdown request's beneficiary's address. final JsonField<String>_beneficiaryName()The drawdown request's beneficiary's name. final JsonField<String>_beneficiaryRoutingNumber()The drawdown request's beneficiary's routing number. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the inbound wire drawdown requested was created. final JsonField<String>_currency()The ISO 4217 code for the amount being requested. final JsonField<String>_messageToRecipient()A message from the drawdown request's originator. final JsonField<String>_originatorAccountNumber()The drawdown request's originator's account number. final JsonField<String>_originatorAddressLine1()Line 1 of the drawdown request's originator's address. final JsonField<String>_originatorAddressLine2()Line 2 of the drawdown request's originator's address. final JsonField<String>_originatorAddressLine3()Line 3 of the drawdown request's originator's address. final JsonField<String>_originatorName()The drawdown request's originator's name. final JsonField<String>_originatorRoutingNumber()The drawdown request's originator's routing number. final JsonField<String>_originatorToBeneficiaryInformationLine1()Line 1 of the information conveyed from the originator of the message to the beneficiary. final JsonField<String>_originatorToBeneficiaryInformationLine2()Line 2 of the information conveyed from the originator of the message to the beneficiary. final JsonField<String>_originatorToBeneficiaryInformationLine3()Line 3 of the information conveyed from the originator of the message to the beneficiary. final JsonField<String>_originatorToBeneficiaryInformationLine4()Line 4 of the information conveyed from the originator of the message to the beneficiary. final JsonField<String>_recipientAccountNumberId()The Account Number from which the recipient of this request is being requested to send funds. final JsonField<InboundWireDrawdownRequest.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final InboundWireDrawdownRequestvalidate()final InboundWireDrawdownRequest.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequest.Builderbuilder()-
-
Method Detail
-
beneficiaryAccountNumber
final String beneficiaryAccountNumber()
The drawdown request's beneficiary's account number.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryName
final Optional<String> beneficiaryName()
The drawdown request's beneficiary's name.
-
beneficiaryRoutingNumber
final String beneficiaryRoutingNumber()
The drawdown request's beneficiary's routing number.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound wire drawdown requested was created.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
messageToRecipient
final Optional<String> messageToRecipient()
A message from the drawdown request's originator.
-
originatorAccountNumber
final String originatorAccountNumber()
The drawdown request's originator's account number.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
Line 3 of the drawdown request's originator's address.
-
originatorName
final Optional<String> originatorName()
The drawdown request's originator's name.
-
originatorRoutingNumber
final String originatorRoutingNumber()
The drawdown request's originator's routing number.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
recipientAccountNumberId
final String recipientAccountNumberId()
The Account Number from which the recipient of this request is being requested to send funds.
-
type
final InboundWireDrawdownRequest.Type type()
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
_beneficiaryAccountNumber
final JsonField<String> _beneficiaryAccountNumber()
The drawdown request's beneficiary's account number.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Line 1 of the drawdown request's beneficiary's address.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Line 2 of the drawdown request's beneficiary's address.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Line 3 of the drawdown request's beneficiary's address.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
The drawdown request's beneficiary's name.
-
_beneficiaryRoutingNumber
final JsonField<String> _beneficiaryRoutingNumber()
The drawdown request's beneficiary's routing number.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the inbound wire drawdown requested was created.
-
_currency
final JsonField<String> _currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
A message from the drawdown request's originator.
-
_originatorAccountNumber
final JsonField<String> _originatorAccountNumber()
The drawdown request's originator's account number.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Line 1 of the drawdown request's originator's address.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Line 2 of the drawdown request's originator's address.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Line 3 of the drawdown request's originator's address.
-
_originatorName
final JsonField<String> _originatorName()
The drawdown request's originator's name.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
The drawdown request's originator's routing number.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
_recipientAccountNumberId
final JsonField<String> _recipientAccountNumberId()
The Account Number from which the recipient of this request is being requested to send funds.
-
_type
final JsonField<InboundWireDrawdownRequest.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundWireDrawdownRequest validate()
-
toBuilder
final InboundWireDrawdownRequest.Builder toBuilder()
-
builder
final static InboundWireDrawdownRequest.Builder builder()
-
-
-
-