Class InboundWireDrawdownRequest.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequest.BuilderA builder for InboundWireDrawdownRequest.
-
-
Method Summary
Modifier and Type Method Description final InboundWireDrawdownRequest.Builderid(String id)The Wire drawdown request identifier. final InboundWireDrawdownRequest.Builderid(JsonField<String> id)The Wire drawdown request identifier. final InboundWireDrawdownRequest.Builderamount(Long amount)The amount being requested in cents. final InboundWireDrawdownRequest.Builderamount(JsonField<Long> amount)The amount being requested in cents. final InboundWireDrawdownRequest.BuilderbeneficiaryAccountNumber(String beneficiaryAccountNumber)The drawdown request's beneficiary's account number. final InboundWireDrawdownRequest.BuilderbeneficiaryAccountNumber(JsonField<String> beneficiaryAccountNumber)The drawdown request's beneficiary's account number. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)Line 1 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)Line 1 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)Line 1 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)Line 2 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)Line 2 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)Line 2 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)Line 3 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)Line 3 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)Line 3 of the drawdown request's beneficiary's address. final InboundWireDrawdownRequest.BuilderbeneficiaryName(String beneficiaryName)The drawdown request's beneficiary's name. final InboundWireDrawdownRequest.BuilderbeneficiaryName(Optional<String> beneficiaryName)The drawdown request's beneficiary's name. final InboundWireDrawdownRequest.BuilderbeneficiaryName(JsonField<String> beneficiaryName)The drawdown request's beneficiary's name. final InboundWireDrawdownRequest.BuilderbeneficiaryRoutingNumber(String beneficiaryRoutingNumber)The drawdown request's beneficiary's routing number. final InboundWireDrawdownRequest.BuilderbeneficiaryRoutingNumber(JsonField<String> beneficiaryRoutingNumber)The drawdown request's beneficiary's routing number. final InboundWireDrawdownRequest.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the inbound wire drawdown requested was created. final InboundWireDrawdownRequest.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the inbound wire drawdown requested was created. final InboundWireDrawdownRequest.Buildercurrency(String currency)The ISO 4217 code for the amount being requested. final InboundWireDrawdownRequest.Buildercurrency(JsonField<String> currency)The ISO 4217 code for the amount being requested. final InboundWireDrawdownRequest.BuildermessageToRecipient(String messageToRecipient)A message from the drawdown request's originator. final InboundWireDrawdownRequest.BuildermessageToRecipient(Optional<String> messageToRecipient)A message from the drawdown request's originator. final InboundWireDrawdownRequest.BuildermessageToRecipient(JsonField<String> messageToRecipient)A message from the drawdown request's originator. final InboundWireDrawdownRequest.BuilderoriginatorAccountNumber(String originatorAccountNumber)The drawdown request's originator's account number. final InboundWireDrawdownRequest.BuilderoriginatorAccountNumber(JsonField<String> originatorAccountNumber)The drawdown request's originator's account number. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine1(String originatorAddressLine1)Line 1 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine1(Optional<String> originatorAddressLine1)Line 1 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)Line 1 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine2(String originatorAddressLine2)Line 2 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine2(Optional<String> originatorAddressLine2)Line 2 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)Line 2 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine3(String originatorAddressLine3)Line 3 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine3(Optional<String> originatorAddressLine3)Line 3 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)Line 3 of the drawdown request's originator's address. final InboundWireDrawdownRequest.BuilderoriginatorName(String originatorName)The drawdown request's originator's name. final InboundWireDrawdownRequest.BuilderoriginatorName(Optional<String> originatorName)The drawdown request's originator's name. final InboundWireDrawdownRequest.BuilderoriginatorName(JsonField<String> originatorName)The drawdown request's originator's name. final InboundWireDrawdownRequest.BuilderoriginatorRoutingNumber(String originatorRoutingNumber)The drawdown request's originator's routing number. final InboundWireDrawdownRequest.BuilderoriginatorRoutingNumber(JsonField<String> originatorRoutingNumber)The drawdown request's originator's routing number. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)Line 1 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)Line 1 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)Line 1 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)Line 2 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)Line 2 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)Line 2 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)Line 3 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)Line 3 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)Line 3 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)Line 4 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)Line 4 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderoriginatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)Line 4 of the information conveyed from the originator of the message to the beneficiary. final InboundWireDrawdownRequest.BuilderrecipientAccountNumberId(String recipientAccountNumberId)The Account Number from which the recipient of this request is being requested to send funds. final InboundWireDrawdownRequest.BuilderrecipientAccountNumberId(JsonField<String> recipientAccountNumberId)The Account Number from which the recipient of this request is being requested to send funds. final InboundWireDrawdownRequest.Buildertype(InboundWireDrawdownRequest.Type type)A constant representing the object's type. final InboundWireDrawdownRequest.Buildertype(JsonField<InboundWireDrawdownRequest.Type> type)A constant representing the object's type. final InboundWireDrawdownRequest.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final InboundWireDrawdownRequest.BuilderputAdditionalProperty(String key, JsonValue value)final InboundWireDrawdownRequest.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final InboundWireDrawdownRequest.BuilderremoveAdditionalProperty(String key)final InboundWireDrawdownRequest.BuilderremoveAllAdditionalProperties(Set<String> keys)final InboundWireDrawdownRequestbuild()-
-
Method Detail
-
id
final InboundWireDrawdownRequest.Builder id(String id)
The Wire drawdown request identifier.
-
id
final InboundWireDrawdownRequest.Builder id(JsonField<String> id)
The Wire drawdown request identifier.
-
amount
final InboundWireDrawdownRequest.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final InboundWireDrawdownRequest.Builder amount(JsonField<Long> amount)
The amount being requested in cents.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequest.Builder beneficiaryAccountNumber(String beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequest.Builder beneficiaryAccountNumber(JsonField<String> beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryName
final InboundWireDrawdownRequest.Builder beneficiaryName(String beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryName
final InboundWireDrawdownRequest.Builder beneficiaryName(Optional<String> beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryName
final InboundWireDrawdownRequest.Builder beneficiaryName(JsonField<String> beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequest.Builder beneficiaryRoutingNumber(String beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequest.Builder beneficiaryRoutingNumber(JsonField<String> beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
createdAt
final InboundWireDrawdownRequest.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound wire drawdown requested was created.
-
createdAt
final InboundWireDrawdownRequest.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the inbound wire drawdown requested was created.
-
currency
final InboundWireDrawdownRequest.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final InboundWireDrawdownRequest.Builder currency(JsonField<String> currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
messageToRecipient
final InboundWireDrawdownRequest.Builder messageToRecipient(String messageToRecipient)
A message from the drawdown request's originator.
-
messageToRecipient
final InboundWireDrawdownRequest.Builder messageToRecipient(Optional<String> messageToRecipient)
A message from the drawdown request's originator.
-
messageToRecipient
final InboundWireDrawdownRequest.Builder messageToRecipient(JsonField<String> messageToRecipient)
A message from the drawdown request's originator.
-
originatorAccountNumber
final InboundWireDrawdownRequest.Builder originatorAccountNumber(String originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorAccountNumber
final InboundWireDrawdownRequest.Builder originatorAccountNumber(JsonField<String> originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorAddressLine1
final InboundWireDrawdownRequest.Builder originatorAddressLine1(String originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine1
final InboundWireDrawdownRequest.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine1
final InboundWireDrawdownRequest.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine2
final InboundWireDrawdownRequest.Builder originatorAddressLine2(String originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine2
final InboundWireDrawdownRequest.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine2
final InboundWireDrawdownRequest.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine3
final InboundWireDrawdownRequest.Builder originatorAddressLine3(String originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorAddressLine3
final InboundWireDrawdownRequest.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorAddressLine3
final InboundWireDrawdownRequest.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorName
final InboundWireDrawdownRequest.Builder originatorName(String originatorName)
The drawdown request's originator's name.
-
originatorName
final InboundWireDrawdownRequest.Builder originatorName(Optional<String> originatorName)
The drawdown request's originator's name.
-
originatorName
final InboundWireDrawdownRequest.Builder originatorName(JsonField<String> originatorName)
The drawdown request's originator's name.
-
originatorRoutingNumber
final InboundWireDrawdownRequest.Builder originatorRoutingNumber(String originatorRoutingNumber)
The drawdown request's originator's routing number.
-
originatorRoutingNumber
final InboundWireDrawdownRequest.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
The drawdown request's originator's routing number.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
recipientAccountNumberId
final InboundWireDrawdownRequest.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number from which the recipient of this request is being requested to send funds.
-
recipientAccountNumberId
final InboundWireDrawdownRequest.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
The Account Number from which the recipient of this request is being requested to send funds.
-
type
final InboundWireDrawdownRequest.Builder type(InboundWireDrawdownRequest.Type type)
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
type
final InboundWireDrawdownRequest.Builder type(JsonField<InboundWireDrawdownRequest.Type> type)
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
additionalProperties
final InboundWireDrawdownRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireDrawdownRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireDrawdownRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireDrawdownRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireDrawdownRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireDrawdownRequest build()
-
-
-
-