Class InboundWireTransfer
-
- All Implemented Interfaces:
public final class InboundWireTransferAn Inbound Wire Transfer is a wire transfer initiated outside of Increase to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransfer.BuilderA builder for InboundWireTransfer.
public final classInboundWireTransfer.StatusThe status of the transfer.
public final classInboundWireTransfer.TypeA constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The inbound wire transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumberId()The identifier of the Account Number to which this transfer was sent. final Longamount()The amount in USD cents. final Optional<String>beneficiaryAddressLine1()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine2()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine3()A free-form address field set by the sender. final Optional<String>beneficiaryName()A name set by the sender. final Optional<String>beneficiaryReference()A free-form reference string set by the sender, to help identify the transfer. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound wire transfer was created. final Stringdescription()An Increase-constructed description of the transfer. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>originatorAddressLine1()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine2()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine3()The address of the wire originator, set by the sending bank. final Optional<String>originatorName()The originator of the wire, set by the sending bank. final Optional<String>originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>originatorToBeneficiaryInformation()An Increase-created concatenation of the Originator-to-Beneficiary lines. final Optional<String>originatorToBeneficiaryInformationLine1()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine2()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine3()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine4()A free-form message set by the wire originator. final Optional<String>senderReference()The sending bank's reference number for the wire transfer. final InboundWireTransfer.Statusstatus()The status of the transfer. final InboundWireTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The inbound wire transfer's identifier. final JsonField<String>_accountId()The Account to which the transfer belongs. final JsonField<String>_accountNumberId()The identifier of the Account Number to which this transfer was sent. final JsonField<Long>_amount()The amount in USD cents. final JsonField<String>_beneficiaryAddressLine1()A free-form address field set by the sender. final JsonField<String>_beneficiaryAddressLine2()A free-form address field set by the sender. final JsonField<String>_beneficiaryAddressLine3()A free-form address field set by the sender. final JsonField<String>_beneficiaryName()A name set by the sender. final JsonField<String>_beneficiaryReference()A free-form reference string set by the sender, to help identify the transfer. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the inbound wire transfer was created. final JsonField<String>_description()An Increase-constructed description of the transfer. final JsonField<String>_inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final JsonField<String>_originatorAddressLine1()The address of the wire originator, set by the sending bank. final JsonField<String>_originatorAddressLine2()The address of the wire originator, set by the sending bank. final JsonField<String>_originatorAddressLine3()The address of the wire originator, set by the sending bank. final JsonField<String>_originatorName()The originator of the wire, set by the sending bank. final JsonField<String>_originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final JsonField<String>_originatorToBeneficiaryInformation()An Increase-created concatenation of the Originator-to-Beneficiary lines. final JsonField<String>_originatorToBeneficiaryInformationLine1()A free-form message set by the wire originator. final JsonField<String>_originatorToBeneficiaryInformationLine2()A free-form message set by the wire originator. final JsonField<String>_originatorToBeneficiaryInformationLine3()A free-form message set by the wire originator. final JsonField<String>_originatorToBeneficiaryInformationLine4()A free-form message set by the wire originator. final JsonField<String>_senderReference()The sending bank's reference number for the wire transfer. final JsonField<InboundWireTransfer.Status>_status()The status of the transfer. final JsonField<InboundWireTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final InboundWireTransfervalidate()final InboundWireTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransfer.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
A free-form address field set by the sender.
-
beneficiaryName
final Optional<String> beneficiaryName()
A name set by the sender.
-
beneficiaryReference
final Optional<String> beneficiaryReference()
A free-form reference string set by the sender, to help identify the transfer.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound wire transfer was created.
-
description
final String description()
An Increase-constructed description of the transfer.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The address of the wire originator, set by the sending bank.
-
originatorName
final Optional<String> originatorName()
The originator of the wire, set by the sending bank.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final Optional<String> originatorToBeneficiaryInformation()
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
A free-form message set by the wire originator.
-
senderReference
final Optional<String> senderReference()
The sending bank's reference number for the wire transfer.
-
status
final InboundWireTransfer.Status status()
The status of the transfer.
-
type
final InboundWireTransfer.Type type()
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
_accountId
final JsonField<String> _accountId()
The Account to which the transfer belongs.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
A free-form address field set by the sender.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
A free-form address field set by the sender.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
A free-form address field set by the sender.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
A name set by the sender.
-
_beneficiaryReference
final JsonField<String> _beneficiaryReference()
A free-form reference string set by the sender, to help identify the transfer.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the inbound wire transfer was created.
-
_description
final JsonField<String> _description()
An Increase-constructed description of the transfer.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
The address of the wire originator, set by the sending bank.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
The address of the wire originator, set by the sending bank.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
The address of the wire originator, set by the sending bank.
-
_originatorName
final JsonField<String> _originatorName()
The originator of the wire, set by the sending bank.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
_originatorToBeneficiaryInformation
final JsonField<String> _originatorToBeneficiaryInformation()
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
A free-form message set by the wire originator.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
A free-form message set by the wire originator.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
A free-form message set by the wire originator.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
A free-form message set by the wire originator.
-
_senderReference
final JsonField<String> _senderReference()
The sending bank's reference number for the wire transfer.
-
_status
final JsonField<InboundWireTransfer.Status> _status()
The status of the transfer.
-
_type
final JsonField<InboundWireTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundWireTransfer validate()
-
toBuilder
final InboundWireTransfer.Builder toBuilder()
-
builder
final static InboundWireTransfer.Builder builder()
-
-
-
-