Class InboundWireTransfer.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
-
Method Summary
Modifier and Type Method Description final InboundWireTransfer.Builderid(String id)The inbound wire transfer's identifier. final InboundWireTransfer.Builderid(JsonField<String> id)The inbound wire transfer's identifier. final InboundWireTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final InboundWireTransfer.BuilderaccountId(JsonField<String> accountId)The Account to which the transfer belongs. final InboundWireTransfer.BuilderaccountNumberId(String accountNumberId)The identifier of the Account Number to which this transfer was sent. final InboundWireTransfer.BuilderaccountNumberId(JsonField<String> accountNumberId)The identifier of the Account Number to which this transfer was sent. final InboundWireTransfer.Builderamount(Long amount)The amount in USD cents. final InboundWireTransfer.Builderamount(JsonField<Long> amount)The amount in USD cents. final InboundWireTransfer.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryName(String beneficiaryName)A name set by the sender. final InboundWireTransfer.BuilderbeneficiaryName(Optional<String> beneficiaryName)A name set by the sender. final InboundWireTransfer.BuilderbeneficiaryName(JsonField<String> beneficiaryName)A name set by the sender. final InboundWireTransfer.BuilderbeneficiaryReference(String beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final InboundWireTransfer.BuilderbeneficiaryReference(Optional<String> beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final InboundWireTransfer.BuilderbeneficiaryReference(JsonField<String> beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final InboundWireTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the inbound wire transfer was created. final InboundWireTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the inbound wire transfer was created. final InboundWireTransfer.Builderdescription(String description)An Increase-constructed description of the transfer. final InboundWireTransfer.Builderdescription(JsonField<String> description)An Increase-constructed description of the transfer. final InboundWireTransfer.BuilderinputMessageAccountabilityData(String inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final InboundWireTransfer.BuilderinputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final InboundWireTransfer.BuilderinputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final InboundWireTransfer.BuilderoriginatorAddressLine1(String originatorAddressLine1)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine1(Optional<String> originatorAddressLine1)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine2(String originatorAddressLine2)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine2(Optional<String> originatorAddressLine2)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine3(String originatorAddressLine3)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine3(Optional<String> originatorAddressLine3)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorName(String originatorName)The originator of the wire, set by the sending bank. final InboundWireTransfer.BuilderoriginatorName(Optional<String> originatorName)The originator of the wire, set by the sending bank. final InboundWireTransfer.BuilderoriginatorName(JsonField<String> originatorName)The originator of the wire, set by the sending bank. final InboundWireTransfer.BuilderoriginatorRoutingNumber(String originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final InboundWireTransfer.BuilderoriginatorRoutingNumber(Optional<String> originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final InboundWireTransfer.BuilderoriginatorRoutingNumber(JsonField<String> originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final InboundWireTransfer.BuildersenderReference(String senderReference)The sending bank's reference number for the wire transfer. final InboundWireTransfer.BuildersenderReference(Optional<String> senderReference)The sending bank's reference number for the wire transfer. final InboundWireTransfer.BuildersenderReference(JsonField<String> senderReference)The sending bank's reference number for the wire transfer. final InboundWireTransfer.Builderstatus(InboundWireTransfer.Status status)The status of the transfer. final InboundWireTransfer.Builderstatus(JsonField<InboundWireTransfer.Status> status)The status of the transfer. final InboundWireTransfer.Buildertype(InboundWireTransfer.Type type)A constant representing the object's type. final InboundWireTransfer.Buildertype(JsonField<InboundWireTransfer.Type> type)A constant representing the object's type. final InboundWireTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final InboundWireTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final InboundWireTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final InboundWireTransfer.BuilderremoveAdditionalProperty(String key)final InboundWireTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final InboundWireTransferbuild()-
-
Method Detail
-
id
final InboundWireTransfer.Builder id(String id)
The inbound wire transfer's identifier.
-
id
final InboundWireTransfer.Builder id(JsonField<String> id)
The inbound wire transfer's identifier.
-
accountId
final InboundWireTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final InboundWireTransfer.Builder accountId(JsonField<String> accountId)
The Account to which the transfer belongs.
-
accountNumberId
final InboundWireTransfer.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
accountNumberId
final InboundWireTransfer.Builder accountNumberId(JsonField<String> accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
amount
final InboundWireTransfer.Builder amount(Long amount)
The amount in USD cents.
-
amount
final InboundWireTransfer.Builder amount(JsonField<Long> amount)
The amount in USD cents.
-
beneficiaryAddressLine1
final InboundWireTransfer.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine1
final InboundWireTransfer.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine1
final InboundWireTransfer.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final InboundWireTransfer.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final InboundWireTransfer.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final InboundWireTransfer.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final InboundWireTransfer.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final InboundWireTransfer.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final InboundWireTransfer.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryName
final InboundWireTransfer.Builder beneficiaryName(String beneficiaryName)
A name set by the sender.
-
beneficiaryName
final InboundWireTransfer.Builder beneficiaryName(Optional<String> beneficiaryName)
A name set by the sender.
-
beneficiaryName
final InboundWireTransfer.Builder beneficiaryName(JsonField<String> beneficiaryName)
A name set by the sender.
-
beneficiaryReference
final InboundWireTransfer.Builder beneficiaryReference(String beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
beneficiaryReference
final InboundWireTransfer.Builder beneficiaryReference(Optional<String> beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
beneficiaryReference
final InboundWireTransfer.Builder beneficiaryReference(JsonField<String> beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
createdAt
final InboundWireTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound wire transfer was created.
-
createdAt
final InboundWireTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the inbound wire transfer was created.
-
description
final InboundWireTransfer.Builder description(String description)
An Increase-constructed description of the transfer.
-
description
final InboundWireTransfer.Builder description(JsonField<String> description)
An Increase-constructed description of the transfer.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
originatorAddressLine1
final InboundWireTransfer.Builder originatorAddressLine1(String originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine1
final InboundWireTransfer.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine1
final InboundWireTransfer.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final InboundWireTransfer.Builder originatorAddressLine2(String originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final InboundWireTransfer.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final InboundWireTransfer.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final InboundWireTransfer.Builder originatorAddressLine3(String originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final InboundWireTransfer.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final InboundWireTransfer.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorName
final InboundWireTransfer.Builder originatorName(String originatorName)
The originator of the wire, set by the sending bank.
-
originatorName
final InboundWireTransfer.Builder originatorName(Optional<String> originatorName)
The originator of the wire, set by the sending bank.
-
originatorName
final InboundWireTransfer.Builder originatorName(JsonField<String> originatorName)
The originator of the wire, set by the sending bank.
-
originatorRoutingNumber
final InboundWireTransfer.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final InboundWireTransfer.Builder originatorRoutingNumber(Optional<String> originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final InboundWireTransfer.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final InboundWireTransfer.Builder originatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformation
final InboundWireTransfer.Builder originatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformation
final InboundWireTransfer.Builder originatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
senderReference
final InboundWireTransfer.Builder senderReference(String senderReference)
The sending bank's reference number for the wire transfer.
-
senderReference
final InboundWireTransfer.Builder senderReference(Optional<String> senderReference)
The sending bank's reference number for the wire transfer.
-
senderReference
final InboundWireTransfer.Builder senderReference(JsonField<String> senderReference)
The sending bank's reference number for the wire transfer.
-
status
final InboundWireTransfer.Builder status(InboundWireTransfer.Status status)
The status of the transfer.
-
status
final InboundWireTransfer.Builder status(JsonField<InboundWireTransfer.Status> status)
The status of the transfer.
-
type
final InboundWireTransfer.Builder type(InboundWireTransfer.Type type)
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
type
final InboundWireTransfer.Builder type(JsonField<InboundWireTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
additionalProperties
final InboundWireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireTransfer build()
-
-
-
-