Class IntrafiAccountEnrollment
-
- All Implemented Interfaces:
public final class IntrafiAccountEnrollmentIntraFi is a network of financial institutions that allows Increase users to sweep funds to multiple banks, in addition to Increase's main bank partners. This enables accounts to become eligible for additional Federal Deposit Insurance Corporation (FDIC) insurance. An IntraFi Account Enrollment object represents the status of an account in the network. Sweeping an account to IntraFi doesn't affect funds availability.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiAccountEnrollment.BuilderA builder for IntrafiAccountEnrollment.
public final classIntrafiAccountEnrollment.StatusThe status of the account in the network. An account takes about one business day to go from
pending_enrollingtoenrolled.public final classIntrafiAccountEnrollment.TypeA constant representing the object's type. For this resource it will always be
intrafi_account_enrollment.
-
Method Summary
Modifier and Type Method Description final Stringid()The identifier of this enrollment at IntraFi. final StringaccountId()The identifier of the Increase Account being swept into the network. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the enrollment was created. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringintrafiId()The identifier of the account in IntraFi's system. final IntrafiAccountEnrollment.Statusstatus()The status of the account in the network. final IntrafiAccountEnrollment.Typetype()A constant representing the object's type. final JsonField<String>_id()The identifier of this enrollment at IntraFi. final JsonField<String>_accountId()The identifier of the Increase Account being swept into the network. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the enrollment was created. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_intrafiId()The identifier of the account in IntraFi's system. final JsonField<IntrafiAccountEnrollment.Status>_status()The status of the account in the network. final JsonField<IntrafiAccountEnrollment.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final IntrafiAccountEnrollmentvalidate()final IntrafiAccountEnrollment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiAccountEnrollment.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier of the Increase Account being swept into the network.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the enrollment was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
intrafiId
final String intrafiId()
The identifier of the account in IntraFi's system. This identifier will be printed on any IntraFi statements or documents.
-
status
final IntrafiAccountEnrollment.Status status()
The status of the account in the network. An account takes about one business day to go from
pending_enrollingtoenrolled.
-
type
final IntrafiAccountEnrollment.Type type()
A constant representing the object's type. For this resource it will always be
intrafi_account_enrollment.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Increase Account being swept into the network.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the enrollment was created.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_intrafiId
final JsonField<String> _intrafiId()
The identifier of the account in IntraFi's system. This identifier will be printed on any IntraFi statements or documents.
-
_status
final JsonField<IntrafiAccountEnrollment.Status> _status()
The status of the account in the network. An account takes about one business day to go from
pending_enrollingtoenrolled.
-
_type
final JsonField<IntrafiAccountEnrollment.Type> _type()
A constant representing the object's type. For this resource it will always be
intrafi_account_enrollment.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final IntrafiAccountEnrollment validate()
-
toBuilder
final IntrafiAccountEnrollment.Builder toBuilder()
-
builder
final static IntrafiAccountEnrollment.Builder builder()
-
-
-
-