Class IntrafiAccountEnrollment.Builder
-
- All Implemented Interfaces:
public final class IntrafiAccountEnrollment.BuilderA builder for IntrafiAccountEnrollment.
-
-
Method Summary
-
-
Method Detail
-
id
final IntrafiAccountEnrollment.Builder id(String id)
The identifier of this enrollment at IntraFi.
-
id
final IntrafiAccountEnrollment.Builder id(JsonField<String> id)
The identifier of this enrollment at IntraFi.
-
accountId
final IntrafiAccountEnrollment.Builder accountId(String accountId)
The identifier of the Increase Account being swept into the network.
-
accountId
final IntrafiAccountEnrollment.Builder accountId(JsonField<String> accountId)
The identifier of the Increase Account being swept into the network.
-
createdAt
final IntrafiAccountEnrollment.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the enrollment was created.
-
createdAt
final IntrafiAccountEnrollment.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the enrollment was created.
-
idempotencyKey
final IntrafiAccountEnrollment.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final IntrafiAccountEnrollment.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final IntrafiAccountEnrollment.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
intrafiId
final IntrafiAccountEnrollment.Builder intrafiId(String intrafiId)
The identifier of the account in IntraFi's system. This identifier will be printed on any IntraFi statements or documents.
-
intrafiId
final IntrafiAccountEnrollment.Builder intrafiId(JsonField<String> intrafiId)
The identifier of the account in IntraFi's system. This identifier will be printed on any IntraFi statements or documents.
-
status
final IntrafiAccountEnrollment.Builder status(IntrafiAccountEnrollment.Status status)
The status of the account in the network. An account takes about one business day to go from
pending_enrollingtoenrolled.
-
status
final IntrafiAccountEnrollment.Builder status(JsonField<IntrafiAccountEnrollment.Status> status)
The status of the account in the network. An account takes about one business day to go from
pending_enrollingtoenrolled.
-
type
final IntrafiAccountEnrollment.Builder type(IntrafiAccountEnrollment.Type type)
A constant representing the object's type. For this resource it will always be
intrafi_account_enrollment.
-
type
final IntrafiAccountEnrollment.Builder type(JsonField<IntrafiAccountEnrollment.Type> type)
A constant representing the object's type. For this resource it will always be
intrafi_account_enrollment.
-
additionalProperties
final IntrafiAccountEnrollment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final IntrafiAccountEnrollment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final IntrafiAccountEnrollment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final IntrafiAccountEnrollment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final IntrafiAccountEnrollment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final IntrafiAccountEnrollment build()
-
-
-
-