Class IntrafiAccountEnrollment.Status
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class IntrafiAccountEnrollment.Status implements EnumThe status of the account in the network. An account takes about one business day to go from
pending_enrollingtoenrolled.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumIntrafiAccountEnrollment.Status.KnownAn enum containing Status's known values.
public enumIntrafiAccountEnrollment.Status.ValueAn enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static IntrafiAccountEnrollment.StatusPENDING_ENROLLINGpublic final static IntrafiAccountEnrollment.StatusENROLLEDpublic final static IntrafiAccountEnrollment.StatusPENDING_UNENROLLINGpublic final static IntrafiAccountEnrollment.StatusUNENROLLEDpublic final static IntrafiAccountEnrollment.StatusREQUIRES_ATTENTION
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final IntrafiAccountEnrollment.Status.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final IntrafiAccountEnrollment.Status.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiAccountEnrollment.Statusof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final IntrafiAccountEnrollment.Status.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final IntrafiAccountEnrollment.Status.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
of
final static IntrafiAccountEnrollment.Status of(String value)
-
-
-
-