Package com.increase.api.models
Enum IntrafiAccountEnrollment.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum IntrafiAccountEnrollment.Status.Known extends Enum<IntrafiAccountEnrollment.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<IntrafiAccountEnrollment.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_ENROLLINGThe account is being added to the IntraFi network.
ENROLLEDThe account has been enrolled with IntraFi.
PENDING_UNENROLLINGThe account is being unenrolled from IntraFi's deposit sweep.
UNENROLLEDThe account was once enrolled, but is no longer enrolled at IntraFi.
REQUIRES_ATTENTIONSomething unexpected happened with this account. Contact Increase support.
-
Method Summary
Modifier and Type Method Description final IntrafiAccountEnrollment.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<IntrafiAccountEnrollment.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<IntrafiAccountEnrollment.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final IntrafiAccountEnrollment.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<IntrafiAccountEnrollment.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<IntrafiAccountEnrollment.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-