Package com.increase.api.models
Class IntrafiAccountEnrollmentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class IntrafiAccountEnrollmentCreateParams implements Params
Enroll an account in the IntraFi deposit sweep network
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiAccountEnrollmentCreateParams.Bodypublic final classIntrafiAccountEnrollmentCreateParams.BuilderA builder for IntrafiAccountEnrollmentCreateParams.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account to be added to IntraFi. final StringemailAddress()The contact email for the account owner, to be shared with IntraFi. final JsonField<String>_accountId()The identifier for the account to be added to IntraFi. final JsonField<String>_emailAddress()The contact email for the account owner, to be shared with IntraFi. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final IntrafiAccountEnrollmentCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiAccountEnrollmentCreateParams.Builderbuilder()-
-
Method Detail
-
emailAddress
final String emailAddress()
The contact email for the account owner, to be shared with IntraFi.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account to be added to IntraFi.
-
_emailAddress
final JsonField<String> _emailAddress()
The contact email for the account owner, to be shared with IntraFi.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final IntrafiAccountEnrollmentCreateParams.Builder toBuilder()
-
builder
final static IntrafiAccountEnrollmentCreateParams.Builder builder()
-
-
-
-