Enum IntrafiAccountEnrollmentListParams.Status.In.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum IntrafiAccountEnrollmentListParams.Status.In.Value extends Enum<IntrafiAccountEnrollmentListParams.Status.In.Value>
An enum containing In's known values, as well as an _UNKNOWN member.
An instance of In can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<IntrafiAccountEnrollmentListParams.Status.In.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_ENROLLINGThe account is being added to the IntraFi network.
ENROLLEDThe account has been enrolled with IntraFi.
PENDING_UNENROLLINGThe account is being unenrolled from IntraFi's deposit sweep.
UNENROLLEDThe account was once enrolled, but is no longer enrolled at IntraFi.
REQUIRES_ATTENTIONSomething unexpected happened with this account. Contact Increase support.
_UNKNOWNAn enum member indicating that In was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final IntrafiAccountEnrollmentListParams.Status.In.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<IntrafiAccountEnrollmentListParams.Status.In.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<IntrafiAccountEnrollmentListParams.Status.In.Value>getEntries()An enum containing In's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final IntrafiAccountEnrollmentListParams.Status.In.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<IntrafiAccountEnrollmentListParams.Status.In.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<IntrafiAccountEnrollmentListParams.Status.In.Value> getEntries()
An enum containing In's known values, as well as an _UNKNOWN member.
An instance of In can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-