Class IntrafiBalance
-
- All Implemented Interfaces:
public final class IntrafiBalanceWhen using IntraFi, each account's balance over the standard FDIC insurance amount are swept to various other institutions. Funds are rebalanced across banks as needed once per business day.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiBalance.BuilderA builder for IntrafiBalance.
public final classIntrafiBalance.Balancepublic final classIntrafiBalance.CurrencyThe ISO 4217 code for the account currency.
public final classIntrafiBalance.TypeA constant representing the object's type. For this resource it will always be
intrafi_balance.
-
Method Summary
Modifier and Type Method Description final Stringid()The identifier of this balance. final List<IntrafiBalance.Balance>balances()Each entry represents a balance held at a different bank. final IntrafiBalance.Currencycurrency()The ISO 4217 code for the account currency. final LocalDateeffectiveDate()The date this balance reflects. final LongtotalBalance()The total balance, in minor units of currency.final IntrafiBalance.Typetype()A constant representing the object's type. final JsonField<String>_id()The identifier of this balance. final JsonField<List<IntrafiBalance.Balance>>_balances()Each entry represents a balance held at a different bank. final JsonField<IntrafiBalance.Currency>_currency()The ISO 4217 code for the account currency. final JsonField<LocalDate>_effectiveDate()The date this balance reflects. final JsonField<Long>_totalBalance()The total balance, in minor units of currency.final JsonField<IntrafiBalance.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final IntrafiBalancevalidate()final IntrafiBalance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiBalance.Builderbuilder()-
-
Method Detail
-
balances
final List<IntrafiBalance.Balance> balances()
Each entry represents a balance held at a different bank. IntraFi separates the total balance across many participating banks in the network.
-
currency
final IntrafiBalance.Currency currency()
The ISO 4217 code for the account currency.
-
effectiveDate
final LocalDate effectiveDate()
The date this balance reflects.
-
totalBalance
final Long totalBalance()
The total balance, in minor units of
currency. Increase reports this balance to IntraFi daily.
-
type
final IntrafiBalance.Type type()
A constant representing the object's type. For this resource it will always be
intrafi_balance.
-
_balances
final JsonField<List<IntrafiBalance.Balance>> _balances()
Each entry represents a balance held at a different bank. IntraFi separates the total balance across many participating banks in the network.
-
_currency
final JsonField<IntrafiBalance.Currency> _currency()
The ISO 4217 code for the account currency.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
The date this balance reflects.
-
_totalBalance
final JsonField<Long> _totalBalance()
The total balance, in minor units of
currency. Increase reports this balance to IntraFi daily.
-
_type
final JsonField<IntrafiBalance.Type> _type()
A constant representing the object's type. For this resource it will always be
intrafi_balance.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final IntrafiBalance validate()
-
toBuilder
final IntrafiBalance.Builder toBuilder()
-
builder
final static IntrafiBalance.Builder builder()
-
-
-
-