Package com.increase.api.models
Class IntrafiExclusionCreateParams.Body
-
- All Implemented Interfaces:
public final class IntrafiExclusionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiExclusionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringbankName()The name of the financial institution to be excluded. final StringentityId()The identifier of the Entity whose deposits will be excluded. final JsonField<String>_bankName()The name of the financial institution to be excluded. final JsonField<String>_entityId()The identifier of the Entity whose deposits will be excluded. final Map<String, JsonValue>_additionalProperties()final IntrafiExclusionCreateParams.Bodyvalidate()final IntrafiExclusionCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiExclusionCreateParams.Body.Builderbuilder()-
-
Method Detail
-
_entityId
final JsonField<String> _entityId()
The identifier of the Entity whose deposits will be excluded.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final IntrafiExclusionCreateParams.Body validate()
-
toBuilder
final IntrafiExclusionCreateParams.Body.Builder toBuilder()
-
builder
final static IntrafiExclusionCreateParams.Body.Builder builder()
-
-
-
-