Class Lockbox
-
- All Implemented Interfaces:
public final class LockboxLockboxes are physical locations that can receive mail containing paper checks. Increase will automatically create a Check Deposit for checks received this way.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockbox.BuilderA builder for Lockbox.
public final classLockbox.AddressThe mailing address for the Lockbox.
public final classLockbox.StatusThis indicates if mail can be sent to this address.
public final classLockbox.TypeA constant representing the object's type. For this resource it will always be
lockbox.
-
Method Summary
Modifier and Type Method Description final Stringid()The Lockbox identifier. final StringaccountId()The identifier for the Account checks sent to this lockbox will be deposited into. final Lockbox.Addressaddress()The mailing address for the Lockbox. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Lockbox was created. final Optional<String>description()The description you choose for the Lockbox. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>recipientName()The recipient name you choose for the Lockbox. final Lockbox.Statusstatus()This indicates if mail can be sent to this address. final Lockbox.Typetype()A constant representing the object's type. final JsonField<String>_id()The Lockbox identifier. final JsonField<String>_accountId()The identifier for the Account checks sent to this lockbox will be deposited into. final JsonField<Lockbox.Address>_address()The mailing address for the Lockbox. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Lockbox was created. final JsonField<String>_description()The description you choose for the Lockbox. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_recipientName()The recipient name you choose for the Lockbox. final JsonField<Lockbox.Status>_status()This indicates if mail can be sent to this address. final JsonField<Lockbox.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Lockboxvalidate()final Lockbox.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Lockbox.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account checks sent to this lockbox will be deposited into.
-
address
final Lockbox.Address address()
The mailing address for the Lockbox.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Lockbox was created.
-
description
final Optional<String> description()
The description you choose for the Lockbox.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
recipientName
final Optional<String> recipientName()
The recipient name you choose for the Lockbox.
-
status
final Lockbox.Status status()
This indicates if mail can be sent to this address.
-
type
final Lockbox.Type type()
A constant representing the object's type. For this resource it will always be
lockbox.
-
_accountId
final JsonField<String> _accountId()
The identifier for the Account checks sent to this lockbox will be deposited into.
-
_address
final JsonField<Lockbox.Address> _address()
The mailing address for the Lockbox.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Lockbox was created.
-
_description
final JsonField<String> _description()
The description you choose for the Lockbox.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_recipientName
final JsonField<String> _recipientName()
The recipient name you choose for the Lockbox.
-
_status
final JsonField<Lockbox.Status> _status()
This indicates if mail can be sent to this address.
-
_type
final JsonField<Lockbox.Type> _type()
A constant representing the object's type. For this resource it will always be
lockbox.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Lockbox.Builder toBuilder()
-
builder
final static Lockbox.Builder builder()
-
-
-
-