Class Lockbox.Address
-
- All Implemented Interfaces:
public final class Lockbox.AddressThe mailing address for the Lockbox.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockbox.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the address. final Stringline1()The first line of the address. final Stringline2()The second line of the address. final StringpostalCode()The postal code of the address. final Optional<String>recipient()The recipient line of the address. final Stringstate()The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final JsonField<String>_city()The city of the address. final JsonField<String>_line1()The first line of the address. final JsonField<String>_line2()The second line of the address. final JsonField<String>_postalCode()The postal code of the address. final JsonField<String>_recipient()The recipient line of the address. final JsonField<String>_state()The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final Map<String, JsonValue>_additionalProperties()final Lockbox.Addressvalidate()final Lockbox.Address.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Lockbox.Address.Builderbuilder()-
-
Method Detail
-
postalCode
final String postalCode()
The postal code of the address.
-
recipient
final Optional<String> recipient()
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
state
final String state()
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
_postalCode
final JsonField<String> _postalCode()
The postal code of the address.
-
_recipient
final JsonField<String> _recipient()
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
_state
final JsonField<String> _state()
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Lockbox.Address validate()
-
toBuilder
final Lockbox.Address.Builder toBuilder()
-
builder
final static Lockbox.Address.Builder builder()
-
-
-
-