Class Lockbox.Address.Builder
-
- All Implemented Interfaces:
public final class Lockbox.Address.BuilderA builder for Address.
-
-
Method Summary
Modifier and Type Method Description final Lockbox.Address.Buildercity(String city)The city of the address. final Lockbox.Address.Buildercity(JsonField<String> city)The city of the address. final Lockbox.Address.Builderline1(String line1)The first line of the address. final Lockbox.Address.Builderline1(JsonField<String> line1)The first line of the address. final Lockbox.Address.Builderline2(String line2)The second line of the address. final Lockbox.Address.Builderline2(JsonField<String> line2)The second line of the address. final Lockbox.Address.BuilderpostalCode(String postalCode)The postal code of the address. final Lockbox.Address.BuilderpostalCode(JsonField<String> postalCode)The postal code of the address. final Lockbox.Address.Builderrecipient(String recipient)The recipient line of the address. final Lockbox.Address.Builderrecipient(Optional<String> recipient)The recipient line of the address. final Lockbox.Address.Builderrecipient(JsonField<String> recipient)The recipient line of the address. final Lockbox.Address.Builderstate(String state)The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final Lockbox.Address.Builderstate(JsonField<String> state)The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final Lockbox.Address.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Lockbox.Address.BuilderputAdditionalProperty(String key, JsonValue value)final Lockbox.Address.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Lockbox.Address.BuilderremoveAdditionalProperty(String key)final Lockbox.Address.BuilderremoveAllAdditionalProperties(Set<String> keys)final Lockbox.Addressbuild()-
-
Method Detail
-
city
final Lockbox.Address.Builder city(String city)
The city of the address.
-
city
final Lockbox.Address.Builder city(JsonField<String> city)
The city of the address.
-
line1
final Lockbox.Address.Builder line1(String line1)
The first line of the address.
-
line1
final Lockbox.Address.Builder line1(JsonField<String> line1)
The first line of the address.
-
line2
final Lockbox.Address.Builder line2(String line2)
The second line of the address.
-
line2
final Lockbox.Address.Builder line2(JsonField<String> line2)
The second line of the address.
-
postalCode
final Lockbox.Address.Builder postalCode(String postalCode)
The postal code of the address.
-
postalCode
final Lockbox.Address.Builder postalCode(JsonField<String> postalCode)
The postal code of the address.
-
recipient
final Lockbox.Address.Builder recipient(String recipient)
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
recipient
final Lockbox.Address.Builder recipient(Optional<String> recipient)
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
recipient
final Lockbox.Address.Builder recipient(JsonField<String> recipient)
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
state
final Lockbox.Address.Builder state(String state)
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
state
final Lockbox.Address.Builder state(JsonField<String> state)
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
additionalProperties
final Lockbox.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Lockbox.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Lockbox.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Lockbox.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Lockbox.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Lockbox.Address build()
-
-
-
-