Package com.increase.api.models
Class LockboxCreateParams.Body
-
- All Implemented Interfaces:
public final class LockboxCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account checks sent to this Lockbox should be deposited into. final Optional<String>description()The description you choose for the Lockbox, for display purposes. final Optional<String>recipientName()The name of the recipient that will receive mail at this location. final JsonField<String>_accountId()The Account checks sent to this Lockbox should be deposited into. final JsonField<String>_description()The description you choose for the Lockbox, for display purposes. final JsonField<String>_recipientName()The name of the recipient that will receive mail at this location. final Map<String, JsonValue>_additionalProperties()final LockboxCreateParams.Bodyvalidate()final LockboxCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxCreateParams.Body.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The Account checks sent to this Lockbox should be deposited into.
-
description
final Optional<String> description()
The description you choose for the Lockbox, for display purposes.
-
recipientName
final Optional<String> recipientName()
The name of the recipient that will receive mail at this location.
-
_accountId
final JsonField<String> _accountId()
The Account checks sent to this Lockbox should be deposited into.
-
_description
final JsonField<String> _description()
The description you choose for the Lockbox, for display purposes.
-
_recipientName
final JsonField<String> _recipientName()
The name of the recipient that will receive mail at this location.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final LockboxCreateParams.Body validate()
-
toBuilder
final LockboxCreateParams.Body.Builder toBuilder()
-
builder
final static LockboxCreateParams.Body.Builder builder()
-
-
-
-