Package com.increase.api.models
Class LockboxCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class LockboxCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final LockboxCreateParams.Body.BuilderaccountId(String accountId)The Account checks sent to this Lockbox should be deposited into. final LockboxCreateParams.Body.BuilderaccountId(JsonField<String> accountId)The Account checks sent to this Lockbox should be deposited into. final LockboxCreateParams.Body.Builderdescription(String description)The description you choose for the Lockbox, for display purposes. final LockboxCreateParams.Body.Builderdescription(JsonField<String> description)The description you choose for the Lockbox, for display purposes. final LockboxCreateParams.Body.BuilderrecipientName(String recipientName)The name of the recipient that will receive mail at this location. final LockboxCreateParams.Body.BuilderrecipientName(JsonField<String> recipientName)The name of the recipient that will receive mail at this location. final LockboxCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final LockboxCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final LockboxCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final LockboxCreateParams.Body.BuilderremoveAdditionalProperty(String key)final LockboxCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final LockboxCreateParams.Bodybuild()-
-
Method Detail
-
accountId
final LockboxCreateParams.Body.Builder accountId(String accountId)
The Account checks sent to this Lockbox should be deposited into.
-
accountId
final LockboxCreateParams.Body.Builder accountId(JsonField<String> accountId)
The Account checks sent to this Lockbox should be deposited into.
-
description
final LockboxCreateParams.Body.Builder description(String description)
The description you choose for the Lockbox, for display purposes.
-
description
final LockboxCreateParams.Body.Builder description(JsonField<String> description)
The description you choose for the Lockbox, for display purposes.
-
recipientName
final LockboxCreateParams.Body.Builder recipientName(String recipientName)
The name of the recipient that will receive mail at this location.
-
recipientName
final LockboxCreateParams.Body.Builder recipientName(JsonField<String> recipientName)
The name of the recipient that will receive mail at this location.
-
additionalProperties
final LockboxCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxCreateParams.Body build()
-
-
-
-