Package com.increase.api.models
Class LockboxUpdateParams.Body
-
- All Implemented Interfaces:
public final class LockboxUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The description you choose for the Lockbox. final Optional<String>recipientName()The recipient name you choose for the Lockbox. final Optional<LockboxUpdateParams.Status>status()This indicates if checks can be sent to the Lockbox. final JsonField<String>_description()The description you choose for the Lockbox. final JsonField<String>_recipientName()The recipient name you choose for the Lockbox. final JsonField<LockboxUpdateParams.Status>_status()This indicates if checks can be sent to the Lockbox. final Map<String, JsonValue>_additionalProperties()final LockboxUpdateParams.Bodyvalidate()final LockboxUpdateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxUpdateParams.Body.Builderbuilder()-
-
Method Detail
-
description
final Optional<String> description()
The description you choose for the Lockbox.
-
recipientName
final Optional<String> recipientName()
The recipient name you choose for the Lockbox.
-
status
final Optional<LockboxUpdateParams.Status> status()
This indicates if checks can be sent to the Lockbox.
-
_description
final JsonField<String> _description()
The description you choose for the Lockbox.
-
_recipientName
final JsonField<String> _recipientName()
The recipient name you choose for the Lockbox.
-
_status
final JsonField<LockboxUpdateParams.Status> _status()
This indicates if checks can be sent to the Lockbox.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final LockboxUpdateParams.Body validate()
-
toBuilder
final LockboxUpdateParams.Body.Builder toBuilder()
-
builder
final static LockboxUpdateParams.Body.Builder builder()
-
-
-
-