Class OAuthApplication
-
- All Implemented Interfaces:
public final class OAuthApplicationAn OAuth Application lets you build an application for others to use with their Increase data. You can create an OAuth Application via the Dashboard and read information about it with the API. Learn more about OAuth here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplication.BuilderA builder for OAuthApplication.
public final classOAuthApplication.StatusWhether the application is active.
public final classOAuthApplication.TypeA constant representing the object's type. For this resource it will always be
oauth_application.
-
Method Summary
Modifier and Type Method Description final Stringid()The OAuth Application's identifier. final StringclientId()The OAuth Application's client_id. final OffsetDateTimecreatedAt()The ISO 8601 timestamp when the OAuth Application was created. final Optional<OffsetDateTime>deletedAt()The ISO 8601 timestamp when the OAuth Application was deleted. final Optional<String>name()The name you chose for this OAuth Application. final OAuthApplication.Statusstatus()Whether the application is active. final OAuthApplication.Typetype()A constant representing the object's type. final JsonField<String>_id()The OAuth Application's identifier. final JsonField<String>_clientId()The OAuth Application's client_id. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 timestamp when the OAuth Application was created. final JsonField<OffsetDateTime>_deletedAt()The ISO 8601 timestamp when the OAuth Application was deleted. final JsonField<String>_name()The name you chose for this OAuth Application. final JsonField<OAuthApplication.Status>_status()Whether the application is active. final JsonField<OAuthApplication.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final OAuthApplicationvalidate()final OAuthApplication.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplication.Builderbuilder()-
-
Method Detail
-
clientId
final String clientId()
The OAuth Application's client_id. Use this to authenticate with the OAuth Application.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 timestamp when the OAuth Application was created.
-
deletedAt
final Optional<OffsetDateTime> deletedAt()
The ISO 8601 timestamp when the OAuth Application was deleted.
-
status
final OAuthApplication.Status status()
Whether the application is active.
-
type
final OAuthApplication.Type type()
A constant representing the object's type. For this resource it will always be
oauth_application.
-
_clientId
final JsonField<String> _clientId()
The OAuth Application's client_id. Use this to authenticate with the OAuth Application.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 timestamp when the OAuth Application was created.
-
_deletedAt
final JsonField<OffsetDateTime> _deletedAt()
The ISO 8601 timestamp when the OAuth Application was deleted.
-
_status
final JsonField<OAuthApplication.Status> _status()
Whether the application is active.
-
_type
final JsonField<OAuthApplication.Type> _type()
A constant representing the object's type. For this resource it will always be
oauth_application.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final OAuthApplication validate()
-
toBuilder
final OAuthApplication.Builder toBuilder()
-
builder
final static OAuthApplication.Builder builder()
-
-
-
-