Class OAuthConnection
-
- All Implemented Interfaces:
public final class OAuthConnectionWhen a user authorizes your OAuth application, an OAuth Connection object is created. Learn more about OAuth here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnection.BuilderA builder for OAuthConnection.
public final classOAuthConnection.StatusWhether the connection is active.
public final classOAuthConnection.TypeA constant representing the object's type. For this resource it will always be
oauth_connection.
-
Method Summary
Modifier and Type Method Description final Stringid()The OAuth Connection's identifier. final OffsetDateTimecreatedAt()The ISO 8601 timestamp when the OAuth Connection was created. final Optional<OffsetDateTime>deletedAt()The ISO 8601 timestamp when the OAuth Connection was deleted. final StringgroupId()The identifier of the Group that has authorized your OAuth application. final StringoauthApplicationId()The identifier of the OAuth application this connection is for. final OAuthConnection.Statusstatus()Whether the connection is active. final OAuthConnection.Typetype()A constant representing the object's type. final JsonField<String>_id()The OAuth Connection's identifier. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 timestamp when the OAuth Connection was created. final JsonField<OffsetDateTime>_deletedAt()The ISO 8601 timestamp when the OAuth Connection was deleted. final JsonField<String>_groupId()The identifier of the Group that has authorized your OAuth application. final JsonField<String>_oauthApplicationId()The identifier of the OAuth application this connection is for. final JsonField<OAuthConnection.Status>_status()Whether the connection is active. final JsonField<OAuthConnection.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final OAuthConnectionvalidate()final OAuthConnection.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthConnection.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 timestamp when the OAuth Connection was created.
-
deletedAt
final Optional<OffsetDateTime> deletedAt()
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
groupId
final String groupId()
The identifier of the Group that has authorized your OAuth application.
-
oauthApplicationId
final String oauthApplicationId()
The identifier of the OAuth application this connection is for.
-
status
final OAuthConnection.Status status()
Whether the connection is active.
-
type
final OAuthConnection.Type type()
A constant representing the object's type. For this resource it will always be
oauth_connection.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 timestamp when the OAuth Connection was created.
-
_deletedAt
final JsonField<OffsetDateTime> _deletedAt()
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
_groupId
final JsonField<String> _groupId()
The identifier of the Group that has authorized your OAuth application.
-
_oauthApplicationId
final JsonField<String> _oauthApplicationId()
The identifier of the OAuth application this connection is for.
-
_status
final JsonField<OAuthConnection.Status> _status()
Whether the connection is active.
-
_type
final JsonField<OAuthConnection.Type> _type()
A constant representing the object's type. For this resource it will always be
oauth_connection.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final OAuthConnection validate()
-
toBuilder
final OAuthConnection.Builder toBuilder()
-
builder
final static OAuthConnection.Builder builder()
-
-
-
-