Class OAuthConnection.Builder
-
- All Implemented Interfaces:
public final class OAuthConnection.BuilderA builder for OAuthConnection.
-
-
Method Summary
Modifier and Type Method Description final OAuthConnection.Builderid(String id)The OAuth Connection's identifier. final OAuthConnection.Builderid(JsonField<String> id)The OAuth Connection's identifier. final OAuthConnection.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 timestamp when the OAuth Connection was created. final OAuthConnection.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 timestamp when the OAuth Connection was created. final OAuthConnection.BuilderdeletedAt(OffsetDateTime deletedAt)The ISO 8601 timestamp when the OAuth Connection was deleted. final OAuthConnection.BuilderdeletedAt(Optional<OffsetDateTime> deletedAt)The ISO 8601 timestamp when the OAuth Connection was deleted. final OAuthConnection.BuilderdeletedAt(JsonField<OffsetDateTime> deletedAt)The ISO 8601 timestamp when the OAuth Connection was deleted. final OAuthConnection.BuildergroupId(String groupId)The identifier of the Group that has authorized your OAuth application. final OAuthConnection.BuildergroupId(JsonField<String> groupId)The identifier of the Group that has authorized your OAuth application. final OAuthConnection.BuilderoauthApplicationId(String oauthApplicationId)The identifier of the OAuth application this connection is for. final OAuthConnection.BuilderoauthApplicationId(JsonField<String> oauthApplicationId)The identifier of the OAuth application this connection is for. final OAuthConnection.Builderstatus(OAuthConnection.Status status)Whether the connection is active. final OAuthConnection.Builderstatus(JsonField<OAuthConnection.Status> status)Whether the connection is active. final OAuthConnection.Buildertype(OAuthConnection.Type type)A constant representing the object's type. final OAuthConnection.Buildertype(JsonField<OAuthConnection.Type> type)A constant representing the object's type. final OAuthConnection.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final OAuthConnection.BuilderputAdditionalProperty(String key, JsonValue value)final OAuthConnection.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final OAuthConnection.BuilderremoveAdditionalProperty(String key)final OAuthConnection.BuilderremoveAllAdditionalProperties(Set<String> keys)final OAuthConnectionbuild()-
-
Method Detail
-
id
final OAuthConnection.Builder id(String id)
The OAuth Connection's identifier.
-
id
final OAuthConnection.Builder id(JsonField<String> id)
The OAuth Connection's identifier.
-
createdAt
final OAuthConnection.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 timestamp when the OAuth Connection was created.
-
createdAt
final OAuthConnection.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 timestamp when the OAuth Connection was created.
-
deletedAt
final OAuthConnection.Builder deletedAt(OffsetDateTime deletedAt)
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
deletedAt
final OAuthConnection.Builder deletedAt(Optional<OffsetDateTime> deletedAt)
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
deletedAt
final OAuthConnection.Builder deletedAt(JsonField<OffsetDateTime> deletedAt)
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
groupId
final OAuthConnection.Builder groupId(String groupId)
The identifier of the Group that has authorized your OAuth application.
-
groupId
final OAuthConnection.Builder groupId(JsonField<String> groupId)
The identifier of the Group that has authorized your OAuth application.
-
oauthApplicationId
final OAuthConnection.Builder oauthApplicationId(String oauthApplicationId)
The identifier of the OAuth application this connection is for.
-
oauthApplicationId
final OAuthConnection.Builder oauthApplicationId(JsonField<String> oauthApplicationId)
The identifier of the OAuth application this connection is for.
-
status
final OAuthConnection.Builder status(OAuthConnection.Status status)
Whether the connection is active.
-
status
final OAuthConnection.Builder status(JsonField<OAuthConnection.Status> status)
Whether the connection is active.
-
type
final OAuthConnection.Builder type(OAuthConnection.Type type)
A constant representing the object's type. For this resource it will always be
oauth_connection.
-
type
final OAuthConnection.Builder type(JsonField<OAuthConnection.Type> type)
A constant representing the object's type. For this resource it will always be
oauth_connection.
-
additionalProperties
final OAuthConnection.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OAuthConnection.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OAuthConnection.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OAuthConnection.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OAuthConnection.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OAuthConnection build()
-
-
-
-