Package com.increase.api.models
Class OAuthToken
-
- All Implemented Interfaces:
public final class OAuthTokenA token that is returned to your application when a user completes the OAuth flow and may be used to authenticate requests. Learn more about OAuth /documentation/oauth.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthToken.BuilderA builder for OAuthToken.
public final classOAuthToken.TokenTypeThe type of OAuth token.
public final classOAuthToken.TypeA constant representing the object's type. For this resource it will always be
oauth_token.
-
Method Summary
Modifier and Type Method Description final StringaccessToken()You may use this token in place of an API key to make OAuth requests on a user's behalf. final OAuthToken.TokenTypetokenType()The type of OAuth token. final OAuthToken.Typetype()A constant representing the object's type. final JsonField<String>_accessToken()You may use this token in place of an API key to make OAuth requests on a user's behalf. final JsonField<OAuthToken.TokenType>_tokenType()The type of OAuth token. final JsonField<OAuthToken.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final OAuthTokenvalidate()final OAuthToken.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthToken.Builderbuilder()-
-
Method Detail
-
accessToken
final String accessToken()
You may use this token in place of an API key to make OAuth requests on a user's behalf.
-
tokenType
final OAuthToken.TokenType tokenType()
The type of OAuth token.
-
type
final OAuthToken.Type type()
A constant representing the object's type. For this resource it will always be
oauth_token.
-
_accessToken
final JsonField<String> _accessToken()
You may use this token in place of an API key to make OAuth requests on a user's behalf.
-
_tokenType
final JsonField<OAuthToken.TokenType> _tokenType()
The type of OAuth token.
-
_type
final JsonField<OAuthToken.Type> _type()
A constant representing the object's type. For this resource it will always be
oauth_token.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final OAuthToken validate()
-
toBuilder
final OAuthToken.Builder toBuilder()
-
builder
final static OAuthToken.Builder builder()
-
-
-
-