Class PendingTransaction
-
- All Implemented Interfaces:
public final class PendingTransactionPending Transactions are potential future additions and removals of money from your bank account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.BuilderA builder for PendingTransaction.
public final classPendingTransaction.CurrencyThe ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
public final classPendingTransaction.RouteTypeThe type of the route this Pending Transaction came through.
public final classPendingTransaction.SourceThis is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
public final classPendingTransaction.StatusWhether the Pending Transaction has been confirmed and has an associated Transaction.
public final classPendingTransaction.TypeA constant representing the object's type. For this resource it will always be
pending_transaction.
-
Method Summary
Modifier and Type Method Description final Stringid()The Pending Transaction identifier. final StringaccountId()The identifier for the account this Pending Transaction belongs to. final Longamount()The Pending Transaction amount in the minor unit of its currency. final Optional<OffsetDateTime>completedAt()The ISO 8601 date on which the Pending Transaction was completed. final OffsetDateTimecreatedAt()The ISO 8601 date on which the Pending Transaction occurred. final PendingTransaction.Currencycurrency()The ISO 4217 code for the Pending Transaction's currency. final Stringdescription()For a Pending Transaction related to a transfer, this is the description you provide. final Optional<String>routeId()The identifier for the route this Pending Transaction came through. final Optional<PendingTransaction.RouteType>routeType()The type of the route this Pending Transaction came through. final PendingTransaction.Sourcesource()This is an object giving more details on the network-level event that caused the Pending Transaction. final PendingTransaction.Statusstatus()Whether the Pending Transaction has been confirmed and has an associated Transaction. final PendingTransaction.Typetype()A constant representing the object's type. final JsonField<String>_id()The Pending Transaction identifier. final JsonField<String>_accountId()The identifier for the account this Pending Transaction belongs to. final JsonField<Long>_amount()The Pending Transaction amount in the minor unit of its currency. final JsonField<OffsetDateTime>_completedAt()The ISO 8601 date on which the Pending Transaction was completed. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date on which the Pending Transaction occurred. final JsonField<PendingTransaction.Currency>_currency()The ISO 4217 code for the Pending Transaction's currency. final JsonField<String>_description()For a Pending Transaction related to a transfer, this is the description you provide. final JsonField<String>_routeId()The identifier for the route this Pending Transaction came through. final JsonField<PendingTransaction.RouteType>_routeType()The type of the route this Pending Transaction came through. final JsonField<PendingTransaction.Source>_source()This is an object giving more details on the network-level event that caused the Pending Transaction. final JsonField<PendingTransaction.Status>_status()Whether the Pending Transaction has been confirmed and has an associated Transaction. final JsonField<PendingTransaction.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final PendingTransactionvalidate()final PendingTransaction.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier for the account this Pending Transaction belongs to.
-
amount
final Long amount()
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
completedAt
final Optional<OffsetDateTime> completedAt()
The ISO 8601 date on which the Pending Transaction was completed.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date on which the Pending Transaction occurred.
-
currency
final PendingTransaction.Currency currency()
The ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
-
description
final String description()
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
-
routeId
final Optional<String> routeId()
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
routeType
final Optional<PendingTransaction.RouteType> routeType()
The type of the route this Pending Transaction came through.
-
source
final PendingTransaction.Source source()
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
status
final PendingTransaction.Status status()
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
type
final PendingTransaction.Type type()
A constant representing the object's type. For this resource it will always be
pending_transaction.
-
_accountId
final JsonField<String> _accountId()
The identifier for the account this Pending Transaction belongs to.
-
_amount
final JsonField<Long> _amount()
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
The ISO 8601 date on which the Pending Transaction was completed.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date on which the Pending Transaction occurred.
-
_currency
final JsonField<PendingTransaction.Currency> _currency()
The ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
-
_description
final JsonField<String> _description()
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
-
_routeId
final JsonField<String> _routeId()
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
_routeType
final JsonField<PendingTransaction.RouteType> _routeType()
The type of the route this Pending Transaction came through.
-
_source
final JsonField<PendingTransaction.Source> _source()
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
_status
final JsonField<PendingTransaction.Status> _status()
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
_type
final JsonField<PendingTransaction.Type> _type()
A constant representing the object's type. For this resource it will always be
pending_transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction validate()
-
toBuilder
final PendingTransaction.Builder toBuilder()
-
builder
final static PendingTransaction.Builder builder()
-
-
-
-