Class PendingTransaction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.BuilderA builder for PendingTransaction.
-
-
Method Summary
Modifier and Type Method Description final PendingTransaction.Builderid(String id)The Pending Transaction identifier. final PendingTransaction.Builderid(JsonField<String> id)The Pending Transaction identifier. final PendingTransaction.BuilderaccountId(String accountId)The identifier for the account this Pending Transaction belongs to. final PendingTransaction.BuilderaccountId(JsonField<String> accountId)The identifier for the account this Pending Transaction belongs to. final PendingTransaction.Builderamount(Long amount)The Pending Transaction amount in the minor unit of its currency. final PendingTransaction.Builderamount(JsonField<Long> amount)The Pending Transaction amount in the minor unit of its currency. final PendingTransaction.BuildercompletedAt(OffsetDateTime completedAt)The ISO 8601 date on which the Pending Transaction was completed. final PendingTransaction.BuildercompletedAt(Optional<OffsetDateTime> completedAt)The ISO 8601 date on which the Pending Transaction was completed. final PendingTransaction.BuildercompletedAt(JsonField<OffsetDateTime> completedAt)The ISO 8601 date on which the Pending Transaction was completed. final PendingTransaction.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date on which the Pending Transaction occurred. final PendingTransaction.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date on which the Pending Transaction occurred. final PendingTransaction.Buildercurrency(PendingTransaction.Currency currency)The ISO 4217 code for the Pending Transaction's currency. final PendingTransaction.Buildercurrency(JsonField<PendingTransaction.Currency> currency)The ISO 4217 code for the Pending Transaction's currency. final PendingTransaction.Builderdescription(String description)For a Pending Transaction related to a transfer, this is the description you provide. final PendingTransaction.Builderdescription(JsonField<String> description)For a Pending Transaction related to a transfer, this is the description you provide. final PendingTransaction.BuilderrouteId(String routeId)The identifier for the route this Pending Transaction came through. final PendingTransaction.BuilderrouteId(Optional<String> routeId)The identifier for the route this Pending Transaction came through. final PendingTransaction.BuilderrouteId(JsonField<String> routeId)The identifier for the route this Pending Transaction came through. final PendingTransaction.BuilderrouteType(PendingTransaction.RouteType routeType)The type of the route this Pending Transaction came through. final PendingTransaction.BuilderrouteType(Optional<PendingTransaction.RouteType> routeType)The type of the route this Pending Transaction came through. final PendingTransaction.BuilderrouteType(JsonField<PendingTransaction.RouteType> routeType)The type of the route this Pending Transaction came through. final PendingTransaction.Buildersource(PendingTransaction.Source source)This is an object giving more details on the network-level event that caused the Pending Transaction. final PendingTransaction.Buildersource(JsonField<PendingTransaction.Source> source)This is an object giving more details on the network-level event that caused the Pending Transaction. final PendingTransaction.Builderstatus(PendingTransaction.Status status)Whether the Pending Transaction has been confirmed and has an associated Transaction. final PendingTransaction.Builderstatus(JsonField<PendingTransaction.Status> status)Whether the Pending Transaction has been confirmed and has an associated Transaction. final PendingTransaction.Buildertype(PendingTransaction.Type type)A constant representing the object's type. final PendingTransaction.Buildertype(JsonField<PendingTransaction.Type> type)A constant representing the object's type. final PendingTransaction.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final PendingTransaction.BuilderputAdditionalProperty(String key, JsonValue value)final PendingTransaction.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final PendingTransaction.BuilderremoveAdditionalProperty(String key)final PendingTransaction.BuilderremoveAllAdditionalProperties(Set<String> keys)final PendingTransactionbuild()-
-
Method Detail
-
id
final PendingTransaction.Builder id(String id)
The Pending Transaction identifier.
-
id
final PendingTransaction.Builder id(JsonField<String> id)
The Pending Transaction identifier.
-
accountId
final PendingTransaction.Builder accountId(String accountId)
The identifier for the account this Pending Transaction belongs to.
-
accountId
final PendingTransaction.Builder accountId(JsonField<String> accountId)
The identifier for the account this Pending Transaction belongs to.
-
amount
final PendingTransaction.Builder amount(Long amount)
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final PendingTransaction.Builder amount(JsonField<Long> amount)
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
completedAt
final PendingTransaction.Builder completedAt(OffsetDateTime completedAt)
The ISO 8601 date on which the Pending Transaction was completed.
-
completedAt
final PendingTransaction.Builder completedAt(Optional<OffsetDateTime> completedAt)
The ISO 8601 date on which the Pending Transaction was completed.
-
completedAt
final PendingTransaction.Builder completedAt(JsonField<OffsetDateTime> completedAt)
The ISO 8601 date on which the Pending Transaction was completed.
-
createdAt
final PendingTransaction.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date on which the Pending Transaction occurred.
-
createdAt
final PendingTransaction.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date on which the Pending Transaction occurred.
-
currency
final PendingTransaction.Builder currency(PendingTransaction.Currency currency)
The ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
-
currency
final PendingTransaction.Builder currency(JsonField<PendingTransaction.Currency> currency)
The ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
-
description
final PendingTransaction.Builder description(String description)
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
-
description
final PendingTransaction.Builder description(JsonField<String> description)
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
-
routeId
final PendingTransaction.Builder routeId(String routeId)
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
routeId
final PendingTransaction.Builder routeId(Optional<String> routeId)
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
routeId
final PendingTransaction.Builder routeId(JsonField<String> routeId)
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
routeType
final PendingTransaction.Builder routeType(PendingTransaction.RouteType routeType)
The type of the route this Pending Transaction came through.
-
routeType
final PendingTransaction.Builder routeType(Optional<PendingTransaction.RouteType> routeType)
The type of the route this Pending Transaction came through.
-
routeType
final PendingTransaction.Builder routeType(JsonField<PendingTransaction.RouteType> routeType)
The type of the route this Pending Transaction came through.
-
source
final PendingTransaction.Builder source(PendingTransaction.Source source)
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
source
final PendingTransaction.Builder source(JsonField<PendingTransaction.Source> source)
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
status
final PendingTransaction.Builder status(PendingTransaction.Status status)
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
status
final PendingTransaction.Builder status(JsonField<PendingTransaction.Status> status)
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
type
final PendingTransaction.Builder type(PendingTransaction.Type type)
A constant representing the object's type. For this resource it will always be
pending_transaction.
-
type
final PendingTransaction.Builder type(JsonField<PendingTransaction.Type> type)
A constant representing the object's type. For this resource it will always be
pending_transaction.
-
additionalProperties
final PendingTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction build()
-
-
-
-