Package com.increase.api.models
Class PendingTransaction.Source.AccountTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.AccountTransferInstructionAn Account Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.AccountTransferInstruction.BuilderA builder for AccountTransferInstruction.
public final classPendingTransaction.Source.AccountTransferInstruction.CurrencyThe ISO 4217 code for the destination account currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The pending amount in the minor unit of the transaction's currency. final PendingTransaction.Source.AccountTransferInstruction.Currencycurrency()The ISO 4217 code for the destination account currency. final StringtransferId()The identifier of the Account Transfer that led to this Pending Transaction. final JsonField<Long>_amount()The pending amount in the minor unit of the transaction's currency. final JsonField<PendingTransaction.Source.AccountTransferInstruction.Currency>_currency()The ISO 4217 code for the destination account currency. final JsonField<String>_transferId()The identifier of the Account Transfer that led to this Pending Transaction. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.AccountTransferInstructionvalidate()final PendingTransaction.Source.AccountTransferInstruction.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.AccountTransferInstruction.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final PendingTransaction.Source.AccountTransferInstruction.Currency currency()
The ISO 4217 code for the destination account currency.
-
transferId
final String transferId()
The identifier of the Account Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<PendingTransaction.Source.AccountTransferInstruction.Currency> _currency()
The ISO 4217 code for the destination account currency.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Account Transfer that led to this Pending Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.AccountTransferInstruction validate()
-
toBuilder
final PendingTransaction.Source.AccountTransferInstruction.Builder toBuilder()
-
builder
final static PendingTransaction.Source.AccountTransferInstruction.Builder builder()
-
-
-
-