Class PendingTransaction.Source.CardAuthorization
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorizationA Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customers funds with the intent to later clear a transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.BuilderA builder for CardAuthorization.
public final classPendingTransaction.Source.CardAuthorization.ActionerWhether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classPendingTransaction.Source.CardAuthorization.CurrencyThe ISO 4217 code for the transaction's currency.
public final classPendingTransaction.Source.CardAuthorization.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classPendingTransaction.Source.CardAuthorization.NetworkDetailsFields specific to the
network.public final classPendingTransaction.Source.CardAuthorization.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classPendingTransaction.Source.CardAuthorization.ProcessingCategoryThe processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
public final classPendingTransaction.Source.CardAuthorization.TypeA constant representing the object's type. For this resource it will always be
card_authorization.public final classPendingTransaction.Source.CardAuthorization.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Authorization identifier. final PendingTransaction.Source.CardAuthorization.Actioneractioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final Longamount()The pending amount in the minor unit of the transaction's currency. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final PendingTransaction.Source.CardAuthorization.Currencycurrency()The ISO 4217 code for the transaction's currency. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final PendingTransaction.Source.CardAuthorization.Directiondirection()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final OffsetDateTimeexpiresAt()The ISO 8601 when this authorization will expire and the pending transaction will be released. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final PendingTransaction.Source.CardAuthorization.NetworkDetailsnetworkDetails()Fields specific to the network.final PendingTransaction.Source.CardAuthorization.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Transaction. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final LongpresentmentAmount()The pending amount in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final PendingTransaction.Source.CardAuthorization.ProcessingCategoryprocessingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final PendingTransaction.Source.CardAuthorization.Typetype()A constant representing the object's type. final PendingTransaction.Source.CardAuthorization.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_id()The Card Authorization identifier. final JsonField<PendingTransaction.Source.CardAuthorization.Actioner>_actioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final JsonField<Long>_amount()The pending amount in the minor unit of the transaction's currency. final JsonField<String>_cardPaymentId()The ID of the Card Payment this transaction belongs to. final JsonField<PendingTransaction.Source.CardAuthorization.Currency>_currency()The ISO 4217 code for the transaction's currency. final JsonField<String>_digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final JsonField<PendingTransaction.Source.CardAuthorization.Direction>_direction()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final JsonField<OffsetDateTime>_expiresAt()The ISO 8601 when this authorization will expire and the pending transaction will be released. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final JsonField<String>_merchantPostalCode()The merchant's postal code. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails>_networkDetails()Fields specific to the network.final JsonField<PendingTransaction.Source.CardAuthorization.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for a specific request or transaction. final JsonField<Long>_networkRiskScore()The risk score generated by the card network. final JsonField<String>_pendingTransactionId()The identifier of the Pending Transaction associated with this Transaction. final JsonField<String>_physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final JsonField<Long>_presentmentAmount()The pending amount in the minor unit of the transaction's presentment currency. final JsonField<String>_presentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final JsonField<PendingTransaction.Source.CardAuthorization.ProcessingCategory>_processingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final JsonField<String>_realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final JsonField<String>_terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<PendingTransaction.Source.CardAuthorization.Type>_type()A constant representing the object's type. final JsonField<PendingTransaction.Source.CardAuthorization.Verification>_verification()Fields related to verification of cardholder-provided values. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CardAuthorizationvalidate()final PendingTransaction.Source.CardAuthorization.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CardAuthorization.Builderbuilder()-
-
Method Detail
-
actioner
final PendingTransaction.Source.CardAuthorization.Actioner actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
amount
final Long amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
currency
final PendingTransaction.Source.CardAuthorization.Currency currency()
The ISO 4217 code for the transaction's currency.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final PendingTransaction.Source.CardAuthorization.Direction direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
expiresAt
final OffsetDateTime expiresAt()
The ISO 8601 when this authorization will expire and the pending transaction will be released.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final PendingTransaction.Source.CardAuthorization.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final PendingTransaction.Source.CardAuthorization.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Transaction.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final Long presentmentAmount()
The pending amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
processingCategory
final PendingTransaction.Source.CardAuthorization.ProcessingCategory processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final PendingTransaction.Source.CardAuthorization.Type type()
A constant representing the object's type. For this resource it will always be
card_authorization.
-
verification
final PendingTransaction.Source.CardAuthorization.Verification verification()
Fields related to verification of cardholder-provided values.
-
_actioner
final JsonField<PendingTransaction.Source.CardAuthorization.Actioner> _actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
_amount
final JsonField<Long> _amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
_currency
final JsonField<PendingTransaction.Source.CardAuthorization.Currency> _currency()
The ISO 4217 code for the transaction's currency.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
_direction
final JsonField<PendingTransaction.Source.CardAuthorization.Direction> _direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
The ISO 8601 when this authorization will expire and the pending transaction will be released.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_networkDetails
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails> _networkDetails()
Fields specific to the
network.
-
_networkIdentifiers
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The identifier of the Pending Transaction associated with this Transaction.
-
_physicalCardId
final JsonField<String> _physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
The pending amount in the minor unit of the transaction's presentment currency.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
_processingCategory
final JsonField<PendingTransaction.Source.CardAuthorization.ProcessingCategory> _processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
_terminalId
final JsonField<String> _terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_type
final JsonField<PendingTransaction.Source.CardAuthorization.Type> _type()
A constant representing the object's type. For this resource it will always be
card_authorization.
-
_verification
final JsonField<PendingTransaction.Source.CardAuthorization.Verification> _verification()
Fields related to verification of cardholder-provided values.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.CardAuthorization validate()
-
toBuilder
final PendingTransaction.Source.CardAuthorization.Builder toBuilder()
-
builder
final static PendingTransaction.Source.CardAuthorization.Builder builder()
-
-
-
-