Package com.increase.api.models
Class PendingTransaction.Source.CheckTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CheckTransferInstructionA Check Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CheckTransferInstruction.BuilderA builder for CheckTransferInstruction.
public final classPendingTransaction.Source.CheckTransferInstruction.CurrencyThe ISO 4217 code for the check's currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final PendingTransaction.Source.CheckTransferInstruction.Currencycurrency()The ISO 4217 code for the check's currency. final StringtransferId()The identifier of the Check Transfer that led to this Pending Transaction. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<PendingTransaction.Source.CheckTransferInstruction.Currency>_currency()The ISO 4217 code for the check's currency. final JsonField<String>_transferId()The identifier of the Check Transfer that led to this Pending Transaction. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CheckTransferInstructionvalidate()final PendingTransaction.Source.CheckTransferInstruction.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CheckTransferInstruction.Builderbuilder()-
-
Method Detail
-
currency
final PendingTransaction.Source.CheckTransferInstruction.Currency currency()
The ISO 4217 code for the check's currency.
-
transferId
final String transferId()
The identifier of the Check Transfer that led to this Pending Transaction.
-
_currency
final JsonField<PendingTransaction.Source.CheckTransferInstruction.Currency> _currency()
The ISO 4217 code for the check's currency.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Check Transfer that led to this Pending Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.CheckTransferInstruction validate()
-
toBuilder
final PendingTransaction.Source.CheckTransferInstruction.Builder toBuilder()
-
builder
final static PendingTransaction.Source.CheckTransferInstruction.Builder builder()
-
-
-
-