Class PendingTransaction.Source.InboundFundsHold
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.InboundFundsHoldAn Inbound Funds Hold object. This field will be present in the JSON response if and only if
categoryis equal toinbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.InboundFundsHold.BuilderA builder for InboundFundsHold.
public final classPendingTransaction.Source.InboundFundsHold.CurrencyThe ISO 4217 code for the hold's currency.
public final classPendingTransaction.Source.InboundFundsHold.StatusThe status of the hold.
public final classPendingTransaction.Source.InboundFundsHold.TypeA constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
Method Summary
Modifier and Type Method Description final Stringid()The Inbound Funds Hold identifier. final Longamount()The held amount in the minor unit of the account's currency. final OffsetDateTimeautomaticallyReleasesAt()When the hold will be released automatically. final OffsetDateTimecreatedAt()The ISO 8601 time at which the hold was created. final PendingTransaction.Source.InboundFundsHold.Currencycurrency()The ISO 4217 code for the hold's currency. final Optional<String>heldTransactionId()The ID of the Transaction for which funds were held. final Optional<String>pendingTransactionId()The ID of the Pending Transaction representing the held funds. final Optional<OffsetDateTime>releasedAt()When the hold was released (if it has been released). final PendingTransaction.Source.InboundFundsHold.Statusstatus()The status of the hold. final PendingTransaction.Source.InboundFundsHold.Typetype()A constant representing the object's type. final JsonField<String>_id()The Inbound Funds Hold identifier. final JsonField<Long>_amount()The held amount in the minor unit of the account's currency. final JsonField<OffsetDateTime>_automaticallyReleasesAt()When the hold will be released automatically. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the hold was created. final JsonField<PendingTransaction.Source.InboundFundsHold.Currency>_currency()The ISO 4217 code for the hold's currency. final JsonField<String>_heldTransactionId()The ID of the Transaction for which funds were held. final JsonField<String>_pendingTransactionId()The ID of the Pending Transaction representing the held funds. final JsonField<OffsetDateTime>_releasedAt()When the hold was released (if it has been released). final JsonField<PendingTransaction.Source.InboundFundsHold.Status>_status()The status of the hold. final JsonField<PendingTransaction.Source.InboundFundsHold.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.InboundFundsHoldvalidate()final PendingTransaction.Source.InboundFundsHold.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.InboundFundsHold.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final OffsetDateTime automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the hold was created.
-
currency
final PendingTransaction.Source.InboundFundsHold.Currency currency()
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final Optional<String> heldTransactionId()
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final Optional<OffsetDateTime> releasedAt()
When the hold was released (if it has been released).
-
status
final PendingTransaction.Source.InboundFundsHold.Status status()
The status of the hold.
-
type
final PendingTransaction.Source.InboundFundsHold.Type type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_amount
final JsonField<Long> _amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
_automaticallyReleasesAt
final JsonField<OffsetDateTime> _automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the hold was created.
-
_currency
final JsonField<PendingTransaction.Source.InboundFundsHold.Currency> _currency()
The ISO 4217 code for the hold's currency.
-
_heldTransactionId
final JsonField<String> _heldTransactionId()
The ID of the Transaction for which funds were held.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
_releasedAt
final JsonField<OffsetDateTime> _releasedAt()
When the hold was released (if it has been released).
-
_status
final JsonField<PendingTransaction.Source.InboundFundsHold.Status> _status()
The status of the hold.
-
_type
final JsonField<PendingTransaction.Source.InboundFundsHold.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.InboundFundsHold validate()
-
toBuilder
final PendingTransaction.Source.InboundFundsHold.Builder toBuilder()
-
builder
final static PendingTransaction.Source.InboundFundsHold.Builder builder()
-
-
-
-