Class PendingTransaction.Source.InboundFundsHold.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.InboundFundsHold.BuilderA builder for InboundFundsHold.
-
-
Method Summary
-
-
Method Detail
-
id
final PendingTransaction.Source.InboundFundsHold.Builder id(String id)
The Inbound Funds Hold identifier.
-
id
final PendingTransaction.Source.InboundFundsHold.Builder id(JsonField<String> id)
The Inbound Funds Hold identifier.
-
amount
final PendingTransaction.Source.InboundFundsHold.Builder amount(Long amount)
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
amount
final PendingTransaction.Source.InboundFundsHold.Builder amount(JsonField<Long> amount)
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final PendingTransaction.Source.InboundFundsHold.Builder automaticallyReleasesAt(OffsetDateTime automaticallyReleasesAt)
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
automaticallyReleasesAt
final PendingTransaction.Source.InboundFundsHold.Builder automaticallyReleasesAt(JsonField<OffsetDateTime> automaticallyReleasesAt)
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final PendingTransaction.Source.InboundFundsHold.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the hold was created.
-
createdAt
final PendingTransaction.Source.InboundFundsHold.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the hold was created.
-
currency
final PendingTransaction.Source.InboundFundsHold.Builder currency(PendingTransaction.Source.InboundFundsHold.Currency currency)
The ISO 4217 code for the hold's currency.
-
currency
final PendingTransaction.Source.InboundFundsHold.Builder currency(JsonField<PendingTransaction.Source.InboundFundsHold.Currency> currency)
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder heldTransactionId(String heldTransactionId)
The ID of the Transaction for which funds were held.
-
heldTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder heldTransactionId(Optional<String> heldTransactionId)
The ID of the Transaction for which funds were held.
-
heldTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder heldTransactionId(JsonField<String> heldTransactionId)
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder pendingTransactionId(String pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
pendingTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
pendingTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final PendingTransaction.Source.InboundFundsHold.Builder releasedAt(OffsetDateTime releasedAt)
When the hold was released (if it has been released).
-
releasedAt
final PendingTransaction.Source.InboundFundsHold.Builder releasedAt(Optional<OffsetDateTime> releasedAt)
When the hold was released (if it has been released).
-
releasedAt
final PendingTransaction.Source.InboundFundsHold.Builder releasedAt(JsonField<OffsetDateTime> releasedAt)
When the hold was released (if it has been released).
-
status
final PendingTransaction.Source.InboundFundsHold.Builder status(PendingTransaction.Source.InboundFundsHold.Status status)
The status of the hold.
-
status
final PendingTransaction.Source.InboundFundsHold.Builder status(JsonField<PendingTransaction.Source.InboundFundsHold.Status> status)
The status of the hold.
-
type
final PendingTransaction.Source.InboundFundsHold.Builder type(PendingTransaction.Source.InboundFundsHold.Type type)
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
type
final PendingTransaction.Source.InboundFundsHold.Builder type(JsonField<PendingTransaction.Source.InboundFundsHold.Type> type)
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
additionalProperties
final PendingTransaction.Source.InboundFundsHold.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.InboundFundsHold.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.InboundFundsHold.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.InboundFundsHold.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.InboundFundsHold.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.InboundFundsHold build()
-
-
-
-