Package com.increase.api.models
Class PendingTransaction.Source.InboundWireTransferReversal
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.InboundWireTransferReversalAn Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.InboundWireTransferReversal.BuilderA builder for InboundWireTransferReversal.
-
Method Summary
Modifier and Type Method Description final StringinboundWireTransferId()The ID of the Inbound Wire Transfer that is being reversed. final JsonField<String>_inboundWireTransferId()The ID of the Inbound Wire Transfer that is being reversed. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.InboundWireTransferReversalvalidate()final PendingTransaction.Source.InboundWireTransferReversal.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.InboundWireTransferReversal.Builderbuilder()-
-
Method Detail
-
inboundWireTransferId
final String inboundWireTransferId()
The ID of the Inbound Wire Transfer that is being reversed.
-
_inboundWireTransferId
final JsonField<String> _inboundWireTransferId()
The ID of the Inbound Wire Transfer that is being reversed.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.InboundWireTransferReversal validate()
-
toBuilder
final PendingTransaction.Source.InboundWireTransferReversal.Builder toBuilder()
-
builder
final static PendingTransaction.Source.InboundWireTransferReversal.Builder builder()
-
-
-
-