Package com.increase.api.models
Class PendingTransaction.Source.WireTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.WireTransferInstructionA Wire Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.WireTransferInstruction.BuilderA builder for WireTransferInstruction.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number for the destination account. final Longamount()The transfer amount in USD cents. final StringmessageToRecipient()The message that will show on the recipient's bank statement. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final StringtransferId()The identifier of the Wire Transfer that led to this Pending Transaction. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<String>_messageToRecipient()The message that will show on the recipient's bank statement. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<String>_transferId()The identifier of the Wire Transfer that led to this Pending Transaction. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.WireTransferInstructionvalidate()final PendingTransaction.Source.WireTransferInstruction.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.WireTransferInstruction.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
messageToRecipient
final String messageToRecipient()
The message that will show on the recipient's bank statement.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
transferId
final String transferId()
The identifier of the Wire Transfer that led to this Pending Transaction.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
The message that will show on the recipient's bank statement.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Wire Transfer that led to this Pending Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.WireTransferInstruction validate()
-
toBuilder
final PendingTransaction.Source.WireTransferInstruction.Builder toBuilder()
-
builder
final static PendingTransaction.Source.WireTransferInstruction.Builder builder()
-
-
-
-