Package com.increase.api.models
Class PhysicalCard.Shipment.Tracking
-
- All Implemented Interfaces:
public final class PhysicalCard.Shipment.TrackingTracking details for the shipment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.Shipment.Tracking.BuilderA builder for Tracking.
-
Method Summary
Modifier and Type Method Description final Stringnumber()The tracking number. final Optional<String>returnNumber()For returned shipments, the tracking number of the return shipment. final Optional<String>returnReason()For returned shipments, this describes why the package was returned. final OffsetDateTimeshippedAt()The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier. final JsonField<String>_number()The tracking number. final JsonField<String>_returnNumber()For returned shipments, the tracking number of the return shipment. final JsonField<String>_returnReason()For returned shipments, this describes why the package was returned. final JsonField<OffsetDateTime>_shippedAt()The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier. final Map<String, JsonValue>_additionalProperties()final PhysicalCard.Shipment.Trackingvalidate()final PhysicalCard.Shipment.Tracking.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCard.Shipment.Tracking.Builderbuilder()-
-
Method Detail
-
returnNumber
final Optional<String> returnNumber()
For returned shipments, the tracking number of the return shipment.
-
returnReason
final Optional<String> returnReason()
For returned shipments, this describes why the package was returned.
-
shippedAt
final OffsetDateTime shippedAt()
The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier.
-
_returnNumber
final JsonField<String> _returnNumber()
For returned shipments, the tracking number of the return shipment.
-
_returnReason
final JsonField<String> _returnReason()
For returned shipments, this describes why the package was returned.
-
_shippedAt
final JsonField<OffsetDateTime> _shippedAt()
The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCard.Shipment.Tracking validate()
-
toBuilder
final PhysicalCard.Shipment.Tracking.Builder toBuilder()
-
builder
final static PhysicalCard.Shipment.Tracking.Builder builder()
-
-
-
-