Class PhysicalCardCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardCreateParams implements Params
Create a Physical Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Bodypublic final classPhysicalCardCreateParams.BuilderA builder for PhysicalCardCreateParams.
public final classPhysicalCardCreateParams.CardholderDetails about the cardholder, as it will appear on the physical card.
public final classPhysicalCardCreateParams.ShipmentThe details used to ship this physical card.
-
Method Summary
Modifier and Type Method Description final StringcardId()The underlying card representing this physical card. final PhysicalCardCreateParams.Cardholdercardholder()Details about the cardholder, as it will appear on the physical card. final PhysicalCardCreateParams.Shipmentshipment()The details used to ship this physical card. final Optional<String>physicalCardProfileId()The physical card profile to use for this physical card. final JsonField<String>_cardId()The underlying card representing this physical card. final JsonField<PhysicalCardCreateParams.Cardholder>_cardholder()Details about the cardholder, as it will appear on the physical card. final JsonField<PhysicalCardCreateParams.Shipment>_shipment()The details used to ship this physical card. final JsonField<String>_physicalCardProfileId()The physical card profile to use for this physical card. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final PhysicalCardCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Builderbuilder()-
-
Method Detail
-
cardholder
final PhysicalCardCreateParams.Cardholder cardholder()
Details about the cardholder, as it will appear on the physical card.
-
shipment
final PhysicalCardCreateParams.Shipment shipment()
The details used to ship this physical card.
-
physicalCardProfileId
final Optional<String> physicalCardProfileId()
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
_cardholder
final JsonField<PhysicalCardCreateParams.Cardholder> _cardholder()
Details about the cardholder, as it will appear on the physical card.
-
_shipment
final JsonField<PhysicalCardCreateParams.Shipment> _shipment()
The details used to ship this physical card.
-
_physicalCardProfileId
final JsonField<String> _physicalCardProfileId()
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final PhysicalCardCreateParams.Builder toBuilder()
-
builder
final static PhysicalCardCreateParams.Builder builder()
-
-
-
-