Package com.increase.api.models
Class PhysicalCardCreateParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardId()The underlying card representing this physical card. final PhysicalCardCreateParams.Cardholdercardholder()Details about the cardholder, as it will appear on the physical card. final PhysicalCardCreateParams.Shipmentshipment()The details used to ship this physical card. final Optional<String>physicalCardProfileId()The physical card profile to use for this physical card. final JsonField<String>_cardId()The underlying card representing this physical card. final JsonField<PhysicalCardCreateParams.Cardholder>_cardholder()Details about the cardholder, as it will appear on the physical card. final JsonField<PhysicalCardCreateParams.Shipment>_shipment()The details used to ship this physical card. final JsonField<String>_physicalCardProfileId()The physical card profile to use for this physical card. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Bodyvalidate()final PhysicalCardCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Body.Builderbuilder()-
-
Method Detail
-
cardholder
final PhysicalCardCreateParams.Cardholder cardholder()
Details about the cardholder, as it will appear on the physical card.
-
shipment
final PhysicalCardCreateParams.Shipment shipment()
The details used to ship this physical card.
-
physicalCardProfileId
final Optional<String> physicalCardProfileId()
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
_cardholder
final JsonField<PhysicalCardCreateParams.Cardholder> _cardholder()
Details about the cardholder, as it will appear on the physical card.
-
_shipment
final JsonField<PhysicalCardCreateParams.Shipment> _shipment()
The details used to ship this physical card.
-
_physicalCardProfileId
final JsonField<String> _physicalCardProfileId()
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCardCreateParams.Body validate()
-
toBuilder
final PhysicalCardCreateParams.Body.Builder toBuilder()
-
builder
final static PhysicalCardCreateParams.Body.Builder builder()
-
-
-
-