Package com.increase.api.models
Class PhysicalCardCreateParams.Shipment
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.ShipmentThe details used to ship this physical card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Shipment.BuilderA builder for Shipment.
public final classPhysicalCardCreateParams.Shipment.AddressThe address to where the card should be shipped.
public final classPhysicalCardCreateParams.Shipment.MethodThe shipping method to use.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Shipment.Addressaddress()The address to where the card should be shipped. final PhysicalCardCreateParams.Shipment.Methodmethod()The shipping method to use. final JsonField<PhysicalCardCreateParams.Shipment.Address>_address()The address to where the card should be shipped. final JsonField<PhysicalCardCreateParams.Shipment.Method>_method()The shipping method to use. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Shipmentvalidate()final PhysicalCardCreateParams.Shipment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Shipment.Builderbuilder()-
-
Method Detail
-
address
final PhysicalCardCreateParams.Shipment.Address address()
The address to where the card should be shipped.
-
method
final PhysicalCardCreateParams.Shipment.Method method()
The shipping method to use.
-
_address
final JsonField<PhysicalCardCreateParams.Shipment.Address> _address()
The address to where the card should be shipped.
-
_method
final JsonField<PhysicalCardCreateParams.Shipment.Method> _method()
The shipping method to use.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCardCreateParams.Shipment validate()
-
toBuilder
final PhysicalCardCreateParams.Shipment.Builder toBuilder()
-
builder
final static PhysicalCardCreateParams.Shipment.Builder builder()
-
-
-
-