Package com.increase.api.models
Class PhysicalCardCreateParams.Shipment.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Shipment.BuilderA builder for Shipment.
-
-
Method Summary
-
-
Method Detail
-
address
final PhysicalCardCreateParams.Shipment.Builder address(PhysicalCardCreateParams.Shipment.Address address)
The address to where the card should be shipped.
-
address
final PhysicalCardCreateParams.Shipment.Builder address(JsonField<PhysicalCardCreateParams.Shipment.Address> address)
The address to where the card should be shipped.
-
method
final PhysicalCardCreateParams.Shipment.Builder method(PhysicalCardCreateParams.Shipment.Method method)
The shipping method to use.
-
method
final PhysicalCardCreateParams.Shipment.Builder method(JsonField<PhysicalCardCreateParams.Shipment.Method> method)
The shipping method to use.
-
additionalProperties
final PhysicalCardCreateParams.Shipment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardCreateParams.Shipment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardCreateParams.Shipment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardCreateParams.Shipment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardCreateParams.Shipment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardCreateParams.Shipment build()
-
-
-
-