Class PhysicalCardProfile
-
- All Implemented Interfaces:
public final class PhysicalCardProfileThis contains artwork and metadata relating to a Physical Card's appearance. For more information, see our guide on physical card artwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfile.BuilderA builder for PhysicalCardProfile.
public final classPhysicalCardProfile.CreatorThe creator of this Physical Card Profile.
public final classPhysicalCardProfile.StatusThe status of the Physical Card Profile.
public final classPhysicalCardProfile.TypeA constant representing the object's type. For this resource it will always be
physical_card_profile.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Profile identifier. final Optional<String>backImageFileId()The identifier of the File containing the physical card's back image. final Optional<String>carrierImageFileId()The identifier of the File containing the physical card's carrier image. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Card Dispute was created. final PhysicalCardProfile.Creatorcreator()The creator of this Physical Card Profile. final Stringdescription()A description you can use to identify the Physical Card Profile. final Optional<String>frontImageFileId()The identifier of the File containing the physical card's front image. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final BooleanisDefault()Whether this Physical Card Profile is the default for all cards in its Increase group. final PhysicalCardProfile.Statusstatus()The status of the Physical Card Profile. final PhysicalCardProfile.Typetype()A constant representing the object's type. final JsonField<String>_id()The Card Profile identifier. final JsonField<String>_backImageFileId()The identifier of the File containing the physical card's back image. final JsonField<String>_carrierImageFileId()The identifier of the File containing the physical card's carrier image. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the Card Dispute was created. final JsonField<PhysicalCardProfile.Creator>_creator()The creator of this Physical Card Profile. final JsonField<String>_description()A description you can use to identify the Physical Card Profile. final JsonField<String>_frontImageFileId()The identifier of the File containing the physical card's front image. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<Boolean>_isDefault()Whether this Physical Card Profile is the default for all cards in its Increase group. final JsonField<PhysicalCardProfile.Status>_status()The status of the Physical Card Profile. final JsonField<PhysicalCardProfile.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfilevalidate()final PhysicalCardProfile.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfile.Builderbuilder()-
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the File containing the physical card's back image.
-
carrierImageFileId
final Optional<String> carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Card Dispute was created.
-
creator
final PhysicalCardProfile.Creator creator()
The creator of this Physical Card Profile.
-
description
final String description()
A description you can use to identify the Physical Card Profile.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the File containing the physical card's front image.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
isDefault
final Boolean isDefault()
Whether this Physical Card Profile is the default for all cards in its Increase group.
-
status
final PhysicalCardProfile.Status status()
The status of the Physical Card Profile.
-
type
final PhysicalCardProfile.Type type()
A constant representing the object's type. For this resource it will always be
physical_card_profile.
-
_backImageFileId
final JsonField<String> _backImageFileId()
The identifier of the File containing the physical card's back image.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the Card Dispute was created.
-
_creator
final JsonField<PhysicalCardProfile.Creator> _creator()
The creator of this Physical Card Profile.
-
_description
final JsonField<String> _description()
A description you can use to identify the Physical Card Profile.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_isDefault
final JsonField<Boolean> _isDefault()
Whether this Physical Card Profile is the default for all cards in its Increase group.
-
_status
final JsonField<PhysicalCardProfile.Status> _status()
The status of the Physical Card Profile.
-
_type
final JsonField<PhysicalCardProfile.Type> _type()
A constant representing the object's type. For this resource it will always be
physical_card_profile.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCardProfile validate()
-
toBuilder
final PhysicalCardProfile.Builder toBuilder()
-
builder
final static PhysicalCardProfile.Builder builder()
-
-
-
-