Class PhysicalCardProfile.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfile.BuilderA builder for PhysicalCardProfile.
-
-
Method Summary
Modifier and Type Method Description final PhysicalCardProfile.Builderid(String id)The Card Profile identifier. final PhysicalCardProfile.Builderid(JsonField<String> id)The Card Profile identifier. final PhysicalCardProfile.BuilderbackImageFileId(String backImageFileId)The identifier of the File containing the physical card's back image. final PhysicalCardProfile.BuilderbackImageFileId(Optional<String> backImageFileId)The identifier of the File containing the physical card's back image. final PhysicalCardProfile.BuilderbackImageFileId(JsonField<String> backImageFileId)The identifier of the File containing the physical card's back image. final PhysicalCardProfile.BuildercarrierImageFileId(String carrierImageFileId)The identifier of the File containing the physical card's carrier image. final PhysicalCardProfile.BuildercarrierImageFileId(Optional<String> carrierImageFileId)The identifier of the File containing the physical card's carrier image. final PhysicalCardProfile.BuildercarrierImageFileId(JsonField<String> carrierImageFileId)The identifier of the File containing the physical card's carrier image. final PhysicalCardProfile.BuildercontactPhone(String contactPhone)A phone number the user can contact to receive support for their card. final PhysicalCardProfile.BuildercontactPhone(Optional<String> contactPhone)A phone number the user can contact to receive support for their card. final PhysicalCardProfile.BuildercontactPhone(JsonField<String> contactPhone)A phone number the user can contact to receive support for their card. final PhysicalCardProfile.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the Card Dispute was created. final PhysicalCardProfile.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the Card Dispute was created. final PhysicalCardProfile.Buildercreator(PhysicalCardProfile.Creator creator)The creator of this Physical Card Profile. final PhysicalCardProfile.Buildercreator(JsonField<PhysicalCardProfile.Creator> creator)The creator of this Physical Card Profile. final PhysicalCardProfile.Builderdescription(String description)A description you can use to identify the Physical Card Profile. final PhysicalCardProfile.Builderdescription(JsonField<String> description)A description you can use to identify the Physical Card Profile. final PhysicalCardProfile.BuilderfrontImageFileId(String frontImageFileId)The identifier of the File containing the physical card's front image. final PhysicalCardProfile.BuilderfrontImageFileId(Optional<String> frontImageFileId)The identifier of the File containing the physical card's front image. final PhysicalCardProfile.BuilderfrontImageFileId(JsonField<String> frontImageFileId)The identifier of the File containing the physical card's front image. final PhysicalCardProfile.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final PhysicalCardProfile.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final PhysicalCardProfile.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final PhysicalCardProfile.BuilderisDefault(Boolean isDefault)Whether this Physical Card Profile is the default for all cards in its Increase group. final PhysicalCardProfile.BuilderisDefault(JsonField<Boolean> isDefault)Whether this Physical Card Profile is the default for all cards in its Increase group. final PhysicalCardProfile.Builderstatus(PhysicalCardProfile.Status status)The status of the Physical Card Profile. final PhysicalCardProfile.Builderstatus(JsonField<PhysicalCardProfile.Status> status)The status of the Physical Card Profile. final PhysicalCardProfile.Buildertype(PhysicalCardProfile.Type type)A constant representing the object's type. final PhysicalCardProfile.Buildertype(JsonField<PhysicalCardProfile.Type> type)A constant representing the object's type. final PhysicalCardProfile.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final PhysicalCardProfile.BuilderputAdditionalProperty(String key, JsonValue value)final PhysicalCardProfile.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final PhysicalCardProfile.BuilderremoveAdditionalProperty(String key)final PhysicalCardProfile.BuilderremoveAllAdditionalProperties(Set<String> keys)final PhysicalCardProfilebuild()-
-
Method Detail
-
id
final PhysicalCardProfile.Builder id(String id)
The Card Profile identifier.
-
id
final PhysicalCardProfile.Builder id(JsonField<String> id)
The Card Profile identifier.
-
backImageFileId
final PhysicalCardProfile.Builder backImageFileId(String backImageFileId)
The identifier of the File containing the physical card's back image.
-
backImageFileId
final PhysicalCardProfile.Builder backImageFileId(Optional<String> backImageFileId)
The identifier of the File containing the physical card's back image.
-
backImageFileId
final PhysicalCardProfile.Builder backImageFileId(JsonField<String> backImageFileId)
The identifier of the File containing the physical card's back image.
-
carrierImageFileId
final PhysicalCardProfile.Builder carrierImageFileId(String carrierImageFileId)
The identifier of the File containing the physical card's carrier image.
-
carrierImageFileId
final PhysicalCardProfile.Builder carrierImageFileId(Optional<String> carrierImageFileId)
The identifier of the File containing the physical card's carrier image.
-
carrierImageFileId
final PhysicalCardProfile.Builder carrierImageFileId(JsonField<String> carrierImageFileId)
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final PhysicalCardProfile.Builder contactPhone(String contactPhone)
A phone number the user can contact to receive support for their card.
-
contactPhone
final PhysicalCardProfile.Builder contactPhone(Optional<String> contactPhone)
A phone number the user can contact to receive support for their card.
-
contactPhone
final PhysicalCardProfile.Builder contactPhone(JsonField<String> contactPhone)
A phone number the user can contact to receive support for their card.
-
createdAt
final PhysicalCardProfile.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Card Dispute was created.
-
createdAt
final PhysicalCardProfile.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the Card Dispute was created.
-
creator
final PhysicalCardProfile.Builder creator(PhysicalCardProfile.Creator creator)
The creator of this Physical Card Profile.
-
creator
final PhysicalCardProfile.Builder creator(JsonField<PhysicalCardProfile.Creator> creator)
The creator of this Physical Card Profile.
-
description
final PhysicalCardProfile.Builder description(String description)
A description you can use to identify the Physical Card Profile.
-
description
final PhysicalCardProfile.Builder description(JsonField<String> description)
A description you can use to identify the Physical Card Profile.
-
frontImageFileId
final PhysicalCardProfile.Builder frontImageFileId(String frontImageFileId)
The identifier of the File containing the physical card's front image.
-
frontImageFileId
final PhysicalCardProfile.Builder frontImageFileId(Optional<String> frontImageFileId)
The identifier of the File containing the physical card's front image.
-
frontImageFileId
final PhysicalCardProfile.Builder frontImageFileId(JsonField<String> frontImageFileId)
The identifier of the File containing the physical card's front image.
-
idempotencyKey
final PhysicalCardProfile.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final PhysicalCardProfile.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final PhysicalCardProfile.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
isDefault
final PhysicalCardProfile.Builder isDefault(Boolean isDefault)
Whether this Physical Card Profile is the default for all cards in its Increase group.
-
isDefault
final PhysicalCardProfile.Builder isDefault(JsonField<Boolean> isDefault)
Whether this Physical Card Profile is the default for all cards in its Increase group.
-
status
final PhysicalCardProfile.Builder status(PhysicalCardProfile.Status status)
The status of the Physical Card Profile.
-
status
final PhysicalCardProfile.Builder status(JsonField<PhysicalCardProfile.Status> status)
The status of the Physical Card Profile.
-
type
final PhysicalCardProfile.Builder type(PhysicalCardProfile.Type type)
A constant representing the object's type. For this resource it will always be
physical_card_profile.
-
type
final PhysicalCardProfile.Builder type(JsonField<PhysicalCardProfile.Type> type)
A constant representing the object's type. For this resource it will always be
physical_card_profile.
-
additionalProperties
final PhysicalCardProfile.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardProfile.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardProfile.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardProfile.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardProfile.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardProfile build()
-
-
-
-