Class PhysicalCardProfileCloneParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardProfileCloneParams implements Params
Clone a Physical Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCloneParams.Bodypublic final classPhysicalCardProfileCloneParams.BuilderA builder for PhysicalCardProfileCloneParams.
public final classPhysicalCardProfileCloneParams.FrontTextText printed on the front of the card. Reach out to [email protected] for more information.
-
Method Summary
Modifier and Type Method Description final StringphysicalCardProfileId()The identifier of the Physical Card Profile to clone. final Optional<String>carrierImageFileId()The identifier of the File containing the physical card's carrier image. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>description()A description you can use to identify the Card Profile. final Optional<String>frontImageFileId()The identifier of the File containing the physical card's front image. final Optional<PhysicalCardProfileCloneParams.FrontText>frontText()Text printed on the front of the card. final JsonField<String>_carrierImageFileId()The identifier of the File containing the physical card's carrier image. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_frontImageFileId()The identifier of the File containing the physical card's front image. final JsonField<PhysicalCardProfileCloneParams.FrontText>_frontText()Text printed on the front of the card. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final PhysicalCardProfileCloneParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCloneParams.Builderbuilder()-
-
Method Detail
-
physicalCardProfileId
final String physicalCardProfileId()
The identifier of the Physical Card Profile to clone.
-
carrierImageFileId
final Optional<String> carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final Optional<String> description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the File containing the physical card's front image.
-
frontText
final Optional<PhysicalCardProfileCloneParams.FrontText> frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_frontText
final JsonField<PhysicalCardProfileCloneParams.FrontText> _frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final PhysicalCardProfileCloneParams.Builder toBuilder()
-
builder
final static PhysicalCardProfileCloneParams.Builder builder()
-
-
-
-