Package com.increase.api.models
Class PhysicalCardProfileCloneParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCloneParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCloneParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>carrierImageFileId()The identifier of the File containing the physical card's carrier image. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>description()A description you can use to identify the Card Profile. final Optional<String>frontImageFileId()The identifier of the File containing the physical card's front image. final Optional<PhysicalCardProfileCloneParams.FrontText>frontText()Text printed on the front of the card. final JsonField<String>_carrierImageFileId()The identifier of the File containing the physical card's carrier image. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_frontImageFileId()The identifier of the File containing the physical card's front image. final JsonField<PhysicalCardProfileCloneParams.FrontText>_frontText()Text printed on the front of the card. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfileCloneParams.Bodyvalidate()final PhysicalCardProfileCloneParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCloneParams.Body.Builderbuilder()-
-
Method Detail
-
carrierImageFileId
final Optional<String> carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final Optional<String> description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the File containing the physical card's front image.
-
frontText
final Optional<PhysicalCardProfileCloneParams.FrontText> frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_frontText
final JsonField<PhysicalCardProfileCloneParams.FrontText> _frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCardProfileCloneParams.Body validate()
-
toBuilder
final PhysicalCardProfileCloneParams.Body.Builder toBuilder()
-
builder
final static PhysicalCardProfileCloneParams.Body.Builder builder()
-
-
-
-