Package com.increase.api.models
Class PhysicalCardProfileCloneParams.FrontText
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCloneParams.FrontTextText printed on the front of the card. Reach out to [email protected] for more information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCloneParams.FrontText.BuilderA builder for FrontText.
-
Method Summary
Modifier and Type Method Description final Stringline1()The first line of text on the front of the card. final Optional<String>line2()The second line of text on the front of the card. final JsonField<String>_line1()The first line of text on the front of the card. final JsonField<String>_line2()The second line of text on the front of the card. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfileCloneParams.FrontTextvalidate()final PhysicalCardProfileCloneParams.FrontText.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCloneParams.FrontText.Builderbuilder()-
-
Method Detail
-
line2
final Optional<String> line2()
The second line of text on the front of the card. Providing a second line moves the first line slightly higher and prints the second line in the spot where the first line would have otherwise been printed.
-
_line2
final JsonField<String> _line2()
The second line of text on the front of the card. Providing a second line moves the first line slightly higher and prints the second line in the spot where the first line would have otherwise been printed.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCardProfileCloneParams.FrontText validate()
-
toBuilder
final PhysicalCardProfileCloneParams.FrontText.Builder toBuilder()
-
builder
final static PhysicalCardProfileCloneParams.FrontText.Builder builder()
-
-
-
-