Class PhysicalCardProfileCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardProfileCreateParams implements Params
Create a Physical Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCreateParams.Bodypublic final classPhysicalCardProfileCreateParams.BuilderA builder for PhysicalCardProfileCreateParams.
-
Method Summary
Modifier and Type Method Description final StringcarrierImageFileId()The identifier of the File containing the physical card's carrier image. final StringcontactPhone()A phone number the user can contact to receive support for their card. final Stringdescription()A description you can use to identify the Card Profile. final StringfrontImageFileId()The identifier of the File containing the physical card's front image. final JsonField<String>_carrierImageFileId()The identifier of the File containing the physical card's carrier image. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_frontImageFileId()The identifier of the File containing the physical card's front image. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final PhysicalCardProfileCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCreateParams.Builderbuilder()-
-
Method Detail
-
carrierImageFileId
final String carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final String contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final String description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final String frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final PhysicalCardProfileCreateParams.Builder toBuilder()
-
builder
final static PhysicalCardProfileCreateParams.Builder builder()
-
-
-
-