Package com.increase.api.models
Class PhysicalCardProfileCreateParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcarrierImageFileId()The identifier of the File containing the physical card's carrier image. final StringcontactPhone()A phone number the user can contact to receive support for their card. final Stringdescription()A description you can use to identify the Card Profile. final StringfrontImageFileId()The identifier of the File containing the physical card's front image. final JsonField<String>_carrierImageFileId()The identifier of the File containing the physical card's carrier image. final JsonField<String>_contactPhone()A phone number the user can contact to receive support for their card. final JsonField<String>_description()A description you can use to identify the Card Profile. final JsonField<String>_frontImageFileId()The identifier of the File containing the physical card's front image. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfileCreateParams.Bodyvalidate()final PhysicalCardProfileCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCreateParams.Body.Builderbuilder()-
-
Method Detail
-
carrierImageFileId
final String carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final String contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final String description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final String frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
_contactPhone
final JsonField<String> _contactPhone()
A phone number the user can contact to receive support for their card.
-
_description
final JsonField<String> _description()
A description you can use to identify the Card Profile.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the File containing the physical card's front image.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PhysicalCardProfileCreateParams.Body validate()
-
toBuilder
final PhysicalCardProfileCreateParams.Body.Builder toBuilder()
-
builder
final static PhysicalCardProfileCreateParams.Body.Builder builder()
-
-
-
-