Package com.increase.api.models
Class PhysicalCardUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardUpdateParams implements Params
Update a Physical Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardUpdateParams.Bodypublic final classPhysicalCardUpdateParams.BuilderA builder for PhysicalCardUpdateParams.
public final classPhysicalCardUpdateParams.StatusThe status to update the Physical Card to.
-
Method Summary
Modifier and Type Method Description final StringphysicalCardId()The Physical Card identifier. final PhysicalCardUpdateParams.Statusstatus()The status to update the Physical Card to. final JsonField<PhysicalCardUpdateParams.Status>_status()The status to update the Physical Card to. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final PhysicalCardUpdateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardUpdateParams.Builderbuilder()-
-
Method Detail
-
physicalCardId
final String physicalCardId()
The Physical Card identifier.
-
status
final PhysicalCardUpdateParams.Status status()
The status to update the Physical Card to.
-
_status
final JsonField<PhysicalCardUpdateParams.Status> _status()
The status to update the Physical Card to.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final PhysicalCardUpdateParams.Builder toBuilder()
-
builder
final static PhysicalCardUpdateParams.Builder builder()
-
-
-
-