Class Program
-
- All Implemented Interfaces:
public final class ProgramPrograms determine the compliance and commercial terms of Accounts. By default, you have a Commercial Banking program for managing your own funds. If you are lending or managing funds on behalf of your customers, or otherwise engaged in regulated activity, we will work together to create additional Programs for you.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgram.BuilderA builder for Program.
public final classProgram.BankThe Bank the Program is with.
public final classProgram.TypeA constant representing the object's type. For this resource it will always be
program.
-
Method Summary
Modifier and Type Method Description final Stringid()The Program identifier. final Program.Bankbank()The Bank the Program is with. final Optional<String>billingAccountId()The Program billing account. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Program was created. final Optional<String>defaultDigitalCardProfileId()The default configuration for digital cards attached to this Program. final StringinterestRate()The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. final Stringname()The name of the Program. final Program.Typetype()A constant representing the object's type. final OffsetDateTimeupdatedAt()The ISO 8601 time at which the Program was last updated. final JsonField<String>_id()The Program identifier. final JsonField<Program.Bank>_bank()The Bank the Program is with. final JsonField<String>_billingAccountId()The Program billing account. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the Program was created. final JsonField<String>_defaultDigitalCardProfileId()The default configuration for digital cards attached to this Program. final JsonField<String>_interestRate()The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. final JsonField<String>_name()The name of the Program. final JsonField<Program.Type>_type()A constant representing the object's type. final JsonField<OffsetDateTime>_updatedAt()The ISO 8601 time at which the Program was last updated. final Map<String, JsonValue>_additionalProperties()final Programvalidate()final Program.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Program.Builderbuilder()-
-
Method Detail
-
bank
final Program.Bank bank()
The Bank the Program is with.
-
billingAccountId
final Optional<String> billingAccountId()
The Program billing account.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Program was created.
-
defaultDigitalCardProfileId
final Optional<String> defaultDigitalCardProfileId()
The default configuration for digital cards attached to this Program.
-
interestRate
final String interestRate()
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
type
final Program.Type type()
A constant representing the object's type. For this resource it will always be
program.
-
updatedAt
final OffsetDateTime updatedAt()
The ISO 8601 time at which the Program was last updated.
-
_bank
final JsonField<Program.Bank> _bank()
The Bank the Program is with.
-
_billingAccountId
final JsonField<String> _billingAccountId()
The Program billing account.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the Program was created.
-
_defaultDigitalCardProfileId
final JsonField<String> _defaultDigitalCardProfileId()
The default configuration for digital cards attached to this Program.
-
_interestRate
final JsonField<String> _interestRate()
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
_type
final JsonField<Program.Type> _type()
A constant representing the object's type. For this resource it will always be
program.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
The ISO 8601 time at which the Program was last updated.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Program.Builder toBuilder()
-
builder
final static Program.Builder builder()
-
-
-
-