Class Program.Builder
-
- All Implemented Interfaces:
public final class Program.BuilderA builder for Program.
-
-
Method Summary
Modifier and Type Method Description final Program.Builderid(String id)The Program identifier. final Program.Builderid(JsonField<String> id)The Program identifier. final Program.Builderbank(Program.Bank bank)The Bank the Program is with. final Program.Builderbank(JsonField<Program.Bank> bank)The Bank the Program is with. final Program.BuilderbillingAccountId(String billingAccountId)The Program billing account. final Program.BuilderbillingAccountId(Optional<String> billingAccountId)The Program billing account. final Program.BuilderbillingAccountId(JsonField<String> billingAccountId)The Program billing account. final Program.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Program was created. final Program.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 time at which the Program was created. final Program.BuilderdefaultDigitalCardProfileId(String defaultDigitalCardProfileId)The default configuration for digital cards attached to this Program. final Program.BuilderdefaultDigitalCardProfileId(Optional<String> defaultDigitalCardProfileId)The default configuration for digital cards attached to this Program. final Program.BuilderdefaultDigitalCardProfileId(JsonField<String> defaultDigitalCardProfileId)The default configuration for digital cards attached to this Program. final Program.BuilderinterestRate(String interestRate)The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. final Program.BuilderinterestRate(JsonField<String> interestRate)The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. final Program.Buildername(String name)The name of the Program. final Program.Buildername(JsonField<String> name)The name of the Program. final Program.Buildertype(Program.Type type)A constant representing the object's type. final Program.Buildertype(JsonField<Program.Type> type)A constant representing the object's type. final Program.BuilderupdatedAt(OffsetDateTime updatedAt)The ISO 8601 time at which the Program was last updated. final Program.BuilderupdatedAt(JsonField<OffsetDateTime> updatedAt)The ISO 8601 time at which the Program was last updated. final Program.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Program.BuilderputAdditionalProperty(String key, JsonValue value)final Program.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Program.BuilderremoveAdditionalProperty(String key)final Program.BuilderremoveAllAdditionalProperties(Set<String> keys)final Programbuild()-
-
Method Detail
-
id
final Program.Builder id(String id)
The Program identifier.
-
id
final Program.Builder id(JsonField<String> id)
The Program identifier.
-
bank
final Program.Builder bank(Program.Bank bank)
The Bank the Program is with.
-
bank
final Program.Builder bank(JsonField<Program.Bank> bank)
The Bank the Program is with.
-
billingAccountId
final Program.Builder billingAccountId(String billingAccountId)
The Program billing account.
-
billingAccountId
final Program.Builder billingAccountId(Optional<String> billingAccountId)
The Program billing account.
-
billingAccountId
final Program.Builder billingAccountId(JsonField<String> billingAccountId)
The Program billing account.
-
createdAt
final Program.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Program was created.
-
createdAt
final Program.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the Program was created.
-
defaultDigitalCardProfileId
final Program.Builder defaultDigitalCardProfileId(String defaultDigitalCardProfileId)
The default configuration for digital cards attached to this Program.
-
defaultDigitalCardProfileId
final Program.Builder defaultDigitalCardProfileId(Optional<String> defaultDigitalCardProfileId)
The default configuration for digital cards attached to this Program.
-
defaultDigitalCardProfileId
final Program.Builder defaultDigitalCardProfileId(JsonField<String> defaultDigitalCardProfileId)
The default configuration for digital cards attached to this Program.
-
interestRate
final Program.Builder interestRate(String interestRate)
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
interestRate
final Program.Builder interestRate(JsonField<String> interestRate)
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
name
final Program.Builder name(String name)
The name of the Program.
-
name
final Program.Builder name(JsonField<String> name)
The name of the Program.
-
type
final Program.Builder type(Program.Type type)
A constant representing the object's type. For this resource it will always be
program.
-
type
final Program.Builder type(JsonField<Program.Type> type)
A constant representing the object's type. For this resource it will always be
program.
-
updatedAt
final Program.Builder updatedAt(OffsetDateTime updatedAt)
The ISO 8601 time at which the Program was last updated.
-
updatedAt
final Program.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
The ISO 8601 time at which the Program was last updated.
-
additionalProperties
final Program.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Program.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Program.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Program.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Program.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-