Class ProofOfAuthorizationRequest
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestA request for proof of authorization for one or more ACH debit transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequest.BuilderA builder for ProofOfAuthorizationRequest.
public final classProofOfAuthorizationRequest.AchTransferpublic final classProofOfAuthorizationRequest.TypeA constant representing the object's type. For this resource it will always be
proof_of_authorization_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Proof of Authorization Request identifier. final List<ProofOfAuthorizationRequest.AchTransfer>achTransfers()The ACH Transfers associated with the request. final OffsetDateTimecreatedAt()The time the Proof of Authorization Request was created. final OffsetDateTimedueOn()The time the Proof of Authorization Request is due. final ProofOfAuthorizationRequest.Typetype()A constant representing the object's type. final OffsetDateTimeupdatedAt()The time the Proof of Authorization Request was last updated. final JsonField<String>_id()The Proof of Authorization Request identifier. final JsonField<List<ProofOfAuthorizationRequest.AchTransfer>>_achTransfers()The ACH Transfers associated with the request. final JsonField<OffsetDateTime>_createdAt()The time the Proof of Authorization Request was created. final JsonField<OffsetDateTime>_dueOn()The time the Proof of Authorization Request is due. final JsonField<ProofOfAuthorizationRequest.Type>_type()A constant representing the object's type. final JsonField<OffsetDateTime>_updatedAt()The time the Proof of Authorization Request was last updated. final Map<String, JsonValue>_additionalProperties()final ProofOfAuthorizationRequestvalidate()final ProofOfAuthorizationRequest.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProofOfAuthorizationRequest.Builderbuilder()-
-
Method Detail
-
achTransfers
final List<ProofOfAuthorizationRequest.AchTransfer> achTransfers()
The ACH Transfers associated with the request.
-
createdAt
final OffsetDateTime createdAt()
The time the Proof of Authorization Request was created.
-
dueOn
final OffsetDateTime dueOn()
The time the Proof of Authorization Request is due.
-
type
final ProofOfAuthorizationRequest.Type type()
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request.
-
updatedAt
final OffsetDateTime updatedAt()
The time the Proof of Authorization Request was last updated.
-
_achTransfers
final JsonField<List<ProofOfAuthorizationRequest.AchTransfer>> _achTransfers()
The ACH Transfers associated with the request.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The time the Proof of Authorization Request was created.
-
_dueOn
final JsonField<OffsetDateTime> _dueOn()
The time the Proof of Authorization Request is due.
-
_type
final JsonField<ProofOfAuthorizationRequest.Type> _type()
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
The time the Proof of Authorization Request was last updated.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ProofOfAuthorizationRequest validate()
-
toBuilder
final ProofOfAuthorizationRequest.Builder toBuilder()
-
builder
final static ProofOfAuthorizationRequest.Builder builder()
-
-
-
-