Class ProofOfAuthorizationRequestSubmission
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestSubmissionInformation submitted in response to a proof of authorization request. Per Nacha's guidance on proof of authorization, the originator must ensure that the authorization complies with applicable legal requirements, is readily identifiable as an authorization, and has clear and readily understandable terms.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestSubmission.BuilderA builder for ProofOfAuthorizationRequestSubmission.
public final classProofOfAuthorizationRequestSubmission.StatusStatus of the proof of authorization request submission.
public final classProofOfAuthorizationRequestSubmission.TypeA constant representing the object's type. For this resource it will always be
proof_of_authorization_request_submission.
-
Method Summary
Modifier and Type Method Description final Stringid()The Proof of Authorization Request Submission identifier. final StringauthorizationTerms()Terms of authorization. final OffsetDateTimeauthorizedAt()Time of authorization. final Optional<String>authorizerCompany()Company of the authorizer. final Optional<String>authorizerEmail()Email of the authorizer. final Optional<String>authorizerIpAddress()IP address of the authorizer. final Optional<String>authorizerName()Name of the authorizer. final OffsetDateTimecreatedAt()The time the Proof of Authorization Request Submission was created. final Optional<Boolean>customerHasBeenOffboarded()Whether the customer has been offboarded. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringproofOfAuthorizationRequestId()ID of the proof of authorization request. final ProofOfAuthorizationRequestSubmission.Statusstatus()Status of the proof of authorization request submission. final ProofOfAuthorizationRequestSubmission.Typetype()A constant representing the object's type. final OffsetDateTimeupdatedAt()The time the Proof of Authorization Request Submission was last updated. final Optional<Boolean>validatedAccountOwnershipViaCredential()Whether account ownership was validated via credential (for instance, Plaid). final Optional<Boolean>validatedAccountOwnershipWithAccountStatement()Whether account ownership was validated with an account statement. final Optional<Boolean>validatedAccountOwnershipWithMicrodeposit()Whether account ownership was validated with microdeposit. final JsonField<String>_id()The Proof of Authorization Request Submission identifier. final JsonField<String>_authorizationTerms()Terms of authorization. final JsonField<OffsetDateTime>_authorizedAt()Time of authorization. final JsonField<String>_authorizerCompany()Company of the authorizer. final JsonField<String>_authorizerEmail()Email of the authorizer. final JsonField<String>_authorizerIpAddress()IP address of the authorizer. final JsonField<String>_authorizerName()Name of the authorizer. final JsonField<OffsetDateTime>_createdAt()The time the Proof of Authorization Request Submission was created. final JsonField<Boolean>_customerHasBeenOffboarded()Whether the customer has been offboarded. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_proofOfAuthorizationRequestId()ID of the proof of authorization request. final JsonField<ProofOfAuthorizationRequestSubmission.Status>_status()Status of the proof of authorization request submission. final JsonField<ProofOfAuthorizationRequestSubmission.Type>_type()A constant representing the object's type. final JsonField<OffsetDateTime>_updatedAt()The time the Proof of Authorization Request Submission was last updated. final JsonField<Boolean>_validatedAccountOwnershipViaCredential()Whether account ownership was validated via credential (for instance, Plaid). final JsonField<Boolean>_validatedAccountOwnershipWithAccountStatement()Whether account ownership was validated with an account statement. final JsonField<Boolean>_validatedAccountOwnershipWithMicrodeposit()Whether account ownership was validated with microdeposit. final Map<String, JsonValue>_additionalProperties()final ProofOfAuthorizationRequestSubmissionvalidate()final ProofOfAuthorizationRequestSubmission.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProofOfAuthorizationRequestSubmission.Builderbuilder()-
-
Method Detail
-
authorizationTerms
final String authorizationTerms()
Terms of authorization.
-
authorizedAt
final OffsetDateTime authorizedAt()
Time of authorization.
-
authorizerCompany
final Optional<String> authorizerCompany()
Company of the authorizer.
-
authorizerEmail
final Optional<String> authorizerEmail()
Email of the authorizer.
-
authorizerIpAddress
final Optional<String> authorizerIpAddress()
IP address of the authorizer.
-
authorizerName
final Optional<String> authorizerName()
Name of the authorizer.
-
createdAt
final OffsetDateTime createdAt()
The time the Proof of Authorization Request Submission was created.
-
customerHasBeenOffboarded
final Optional<Boolean> customerHasBeenOffboarded()
Whether the customer has been offboarded.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
proofOfAuthorizationRequestId
final String proofOfAuthorizationRequestId()
ID of the proof of authorization request.
-
status
final ProofOfAuthorizationRequestSubmission.Status status()
Status of the proof of authorization request submission.
-
type
final ProofOfAuthorizationRequestSubmission.Type type()
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request_submission.
-
updatedAt
final OffsetDateTime updatedAt()
The time the Proof of Authorization Request Submission was last updated.
-
validatedAccountOwnershipViaCredential
final Optional<Boolean> validatedAccountOwnershipViaCredential()
Whether account ownership was validated via credential (for instance, Plaid).
-
validatedAccountOwnershipWithAccountStatement
final Optional<Boolean> validatedAccountOwnershipWithAccountStatement()
Whether account ownership was validated with an account statement.
-
validatedAccountOwnershipWithMicrodeposit
final Optional<Boolean> validatedAccountOwnershipWithMicrodeposit()
Whether account ownership was validated with microdeposit.
-
_authorizationTerms
final JsonField<String> _authorizationTerms()
Terms of authorization.
-
_authorizedAt
final JsonField<OffsetDateTime> _authorizedAt()
Time of authorization.
-
_authorizerCompany
final JsonField<String> _authorizerCompany()
Company of the authorizer.
-
_authorizerEmail
final JsonField<String> _authorizerEmail()
Email of the authorizer.
-
_authorizerIpAddress
final JsonField<String> _authorizerIpAddress()
IP address of the authorizer.
-
_authorizerName
final JsonField<String> _authorizerName()
Name of the authorizer.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The time the Proof of Authorization Request Submission was created.
-
_customerHasBeenOffboarded
final JsonField<Boolean> _customerHasBeenOffboarded()
Whether the customer has been offboarded.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_proofOfAuthorizationRequestId
final JsonField<String> _proofOfAuthorizationRequestId()
ID of the proof of authorization request.
-
_status
final JsonField<ProofOfAuthorizationRequestSubmission.Status> _status()
Status of the proof of authorization request submission.
-
_type
final JsonField<ProofOfAuthorizationRequestSubmission.Type> _type()
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request_submission.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
The time the Proof of Authorization Request Submission was last updated.
-
_validatedAccountOwnershipViaCredential
final JsonField<Boolean> _validatedAccountOwnershipViaCredential()
Whether account ownership was validated via credential (for instance, Plaid).
-
_validatedAccountOwnershipWithAccountStatement
final JsonField<Boolean> _validatedAccountOwnershipWithAccountStatement()
Whether account ownership was validated with an account statement.
-
_validatedAccountOwnershipWithMicrodeposit
final JsonField<Boolean> _validatedAccountOwnershipWithMicrodeposit()
Whether account ownership was validated with microdeposit.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ProofOfAuthorizationRequestSubmission validate()
-
toBuilder
final ProofOfAuthorizationRequestSubmission.Builder toBuilder()
-
builder
final static ProofOfAuthorizationRequestSubmission.Builder builder()
-
-
-
-