Class ProofOfAuthorizationRequestSubmissionCreateParams.Body
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestSubmissionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestSubmissionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringauthorizationTerms()Terms of authorization. final OffsetDateTimeauthorizedAt()Time of authorization. final StringauthorizerEmail()Email of the authorizer. final StringauthorizerName()Name of the authorizer. final BooleancustomerHasBeenOffboarded()Whether the customer has been offboarded or suspended. final StringproofOfAuthorizationRequestId()ID of the proof of authorization request. final BooleanvalidatedAccountOwnershipViaCredential()Whether the account ownership was validated via credential (e.g. final BooleanvalidatedAccountOwnershipWithAccountStatement()Whether the account ownership was validated with an account statement. final BooleanvalidatedAccountOwnershipWithMicrodeposit()Whether the account ownership was validated with a microdeposit. final Optional<String>authorizerCompany()Company of the authorizer. final Optional<String>authorizerIpAddress()IP address of the authorizer. final JsonField<String>_authorizationTerms()Terms of authorization. final JsonField<OffsetDateTime>_authorizedAt()Time of authorization. final JsonField<String>_authorizerEmail()Email of the authorizer. final JsonField<String>_authorizerName()Name of the authorizer. final JsonField<Boolean>_customerHasBeenOffboarded()Whether the customer has been offboarded or suspended. final JsonField<String>_proofOfAuthorizationRequestId()ID of the proof of authorization request. final JsonField<Boolean>_validatedAccountOwnershipViaCredential()Whether the account ownership was validated via credential (e.g. final JsonField<Boolean>_validatedAccountOwnershipWithAccountStatement()Whether the account ownership was validated with an account statement. final JsonField<Boolean>_validatedAccountOwnershipWithMicrodeposit()Whether the account ownership was validated with a microdeposit. final JsonField<String>_authorizerCompany()Company of the authorizer. final JsonField<String>_authorizerIpAddress()IP address of the authorizer. final Map<String, JsonValue>_additionalProperties()final ProofOfAuthorizationRequestSubmissionCreateParams.Bodyvalidate()final ProofOfAuthorizationRequestSubmissionCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builderbuilder()-
-
Method Detail
-
authorizationTerms
final String authorizationTerms()
Terms of authorization.
-
authorizedAt
final OffsetDateTime authorizedAt()
Time of authorization.
-
authorizerEmail
final String authorizerEmail()
Email of the authorizer.
-
authorizerName
final String authorizerName()
Name of the authorizer.
-
customerHasBeenOffboarded
final Boolean customerHasBeenOffboarded()
Whether the customer has been offboarded or suspended.
-
proofOfAuthorizationRequestId
final String proofOfAuthorizationRequestId()
ID of the proof of authorization request.
-
validatedAccountOwnershipViaCredential
final Boolean validatedAccountOwnershipViaCredential()
Whether the account ownership was validated via credential (e.g. Plaid).
-
validatedAccountOwnershipWithAccountStatement
final Boolean validatedAccountOwnershipWithAccountStatement()
Whether the account ownership was validated with an account statement.
-
validatedAccountOwnershipWithMicrodeposit
final Boolean validatedAccountOwnershipWithMicrodeposit()
Whether the account ownership was validated with a microdeposit.
-
authorizerCompany
final Optional<String> authorizerCompany()
Company of the authorizer.
-
authorizerIpAddress
final Optional<String> authorizerIpAddress()
IP address of the authorizer.
-
_authorizationTerms
final JsonField<String> _authorizationTerms()
Terms of authorization.
-
_authorizedAt
final JsonField<OffsetDateTime> _authorizedAt()
Time of authorization.
-
_authorizerEmail
final JsonField<String> _authorizerEmail()
Email of the authorizer.
-
_authorizerName
final JsonField<String> _authorizerName()
Name of the authorizer.
-
_customerHasBeenOffboarded
final JsonField<Boolean> _customerHasBeenOffboarded()
Whether the customer has been offboarded or suspended.
-
_proofOfAuthorizationRequestId
final JsonField<String> _proofOfAuthorizationRequestId()
ID of the proof of authorization request.
-
_validatedAccountOwnershipViaCredential
final JsonField<Boolean> _validatedAccountOwnershipViaCredential()
Whether the account ownership was validated via credential (e.g. Plaid).
-
_validatedAccountOwnershipWithAccountStatement
final JsonField<Boolean> _validatedAccountOwnershipWithAccountStatement()
Whether the account ownership was validated with an account statement.
-
_validatedAccountOwnershipWithMicrodeposit
final JsonField<Boolean> _validatedAccountOwnershipWithMicrodeposit()
Whether the account ownership was validated with a microdeposit.
-
_authorizerCompany
final JsonField<String> _authorizerCompany()
Company of the authorizer.
-
_authorizerIpAddress
final JsonField<String> _authorizerIpAddress()
IP address of the authorizer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ProofOfAuthorizationRequestSubmissionCreateParams.Body validate()
-
toBuilder
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder toBuilder()
-
builder
final static ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder builder()
-
-
-
-