Class RealTimeDecision
-
- All Implemented Interfaces:
public final class RealTimeDecisionReal Time Decisions are created when your application needs to take action in real-time to some event such as a card authorization. For more information, see our Real-Time Decisions guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.BuilderA builder for RealTimeDecision.
public final classRealTimeDecision.CardAuthenticationFields related to a 3DS authentication attempt.
public final classRealTimeDecision.CardAuthenticationChallengeFields related to a 3DS authentication attempt.
public final classRealTimeDecision.CardAuthorizationFields related to a card authorization.
public final classRealTimeDecision.CategoryThe category of the Real-Time Decision.
public final classRealTimeDecision.DigitalWalletAuthenticationFields related to a digital wallet authentication attempt.
public final classRealTimeDecision.DigitalWalletTokenFields related to a digital wallet token provisioning attempt.
public final classRealTimeDecision.StatusThe status of the Real-Time Decision.
public final classRealTimeDecision.TypeA constant representing the object's type. For this resource it will always be
real_time_decision.
-
Method Summary
Modifier and Type Method Description final Stringid()The Real-Time Decision identifier. final Optional<RealTimeDecision.CardAuthentication>cardAuthentication()Fields related to a 3DS authentication attempt. final Optional<RealTimeDecision.CardAuthenticationChallenge>cardAuthenticationChallenge()Fields related to a 3DS authentication attempt. final Optional<RealTimeDecision.CardAuthorization>cardAuthorization()Fields related to a card authorization. final RealTimeDecision.Categorycategory()The category of the Real-Time Decision. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Real-Time Decision was created. final Optional<RealTimeDecision.DigitalWalletAuthentication>digitalWalletAuthentication()Fields related to a digital wallet authentication attempt. final Optional<RealTimeDecision.DigitalWalletToken>digitalWalletToken()Fields related to a digital wallet token provisioning attempt. final RealTimeDecision.Statusstatus()The status of the Real-Time Decision. final OffsetDateTimetimeoutAt()The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision. final RealTimeDecision.Typetype()A constant representing the object's type. final JsonField<String>_id()The Real-Time Decision identifier. final JsonField<RealTimeDecision.CardAuthentication>_cardAuthentication()Fields related to a 3DS authentication attempt. final JsonField<RealTimeDecision.CardAuthenticationChallenge>_cardAuthenticationChallenge()Fields related to a 3DS authentication attempt. final JsonField<RealTimeDecision.CardAuthorization>_cardAuthorization()Fields related to a card authorization. final JsonField<RealTimeDecision.Category>_category()The category of the Real-Time Decision. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the Real-Time Decision was created. final JsonField<RealTimeDecision.DigitalWalletAuthentication>_digitalWalletAuthentication()Fields related to a digital wallet authentication attempt. final JsonField<RealTimeDecision.DigitalWalletToken>_digitalWalletToken()Fields related to a digital wallet token provisioning attempt. final JsonField<RealTimeDecision.Status>_status()The status of the Real-Time Decision. final JsonField<OffsetDateTime>_timeoutAt()The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision. final JsonField<RealTimeDecision.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final RealTimeDecisionvalidate()final RealTimeDecision.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.Builderbuilder()-
-
Method Detail
-
cardAuthentication
final Optional<RealTimeDecision.CardAuthentication> cardAuthentication()
Fields related to a 3DS authentication attempt.
-
cardAuthenticationChallenge
final Optional<RealTimeDecision.CardAuthenticationChallenge> cardAuthenticationChallenge()
Fields related to a 3DS authentication attempt.
-
cardAuthorization
final Optional<RealTimeDecision.CardAuthorization> cardAuthorization()
Fields related to a card authorization.
-
category
final RealTimeDecision.Category category()
The category of the Real-Time Decision.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Real-Time Decision was created.
-
digitalWalletAuthentication
final Optional<RealTimeDecision.DigitalWalletAuthentication> digitalWalletAuthentication()
Fields related to a digital wallet authentication attempt.
-
digitalWalletToken
final Optional<RealTimeDecision.DigitalWalletToken> digitalWalletToken()
Fields related to a digital wallet token provisioning attempt.
-
status
final RealTimeDecision.Status status()
The status of the Real-Time Decision.
-
timeoutAt
final OffsetDateTime timeoutAt()
The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision.
-
type
final RealTimeDecision.Type type()
A constant representing the object's type. For this resource it will always be
real_time_decision.
-
_cardAuthentication
final JsonField<RealTimeDecision.CardAuthentication> _cardAuthentication()
Fields related to a 3DS authentication attempt.
-
_cardAuthenticationChallenge
final JsonField<RealTimeDecision.CardAuthenticationChallenge> _cardAuthenticationChallenge()
Fields related to a 3DS authentication attempt.
-
_cardAuthorization
final JsonField<RealTimeDecision.CardAuthorization> _cardAuthorization()
Fields related to a card authorization.
-
_category
final JsonField<RealTimeDecision.Category> _category()
The category of the Real-Time Decision.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the Real-Time Decision was created.
-
_digitalWalletAuthentication
final JsonField<RealTimeDecision.DigitalWalletAuthentication> _digitalWalletAuthentication()
Fields related to a digital wallet authentication attempt.
-
_digitalWalletToken
final JsonField<RealTimeDecision.DigitalWalletToken> _digitalWalletToken()
Fields related to a digital wallet token provisioning attempt.
-
_status
final JsonField<RealTimeDecision.Status> _status()
The status of the Real-Time Decision.
-
_timeoutAt
final JsonField<OffsetDateTime> _timeoutAt()
The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision.
-
_type
final JsonField<RealTimeDecision.Type> _type()
A constant representing the object's type. For this resource it will always be
real_time_decision.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision validate()
-
toBuilder
final RealTimeDecision.Builder toBuilder()
-
builder
final static RealTimeDecision.Builder builder()
-
-
-
-