Class RealTimeDecision.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.BuilderA builder for RealTimeDecision.
-
-
Method Summary
-
-
Method Detail
-
id
final RealTimeDecision.Builder id(String id)
The Real-Time Decision identifier.
-
id
final RealTimeDecision.Builder id(JsonField<String> id)
The Real-Time Decision identifier.
-
cardAuthentication
final RealTimeDecision.Builder cardAuthentication(RealTimeDecision.CardAuthentication cardAuthentication)
Fields related to a 3DS authentication attempt.
-
cardAuthentication
final RealTimeDecision.Builder cardAuthentication(Optional<RealTimeDecision.CardAuthentication> cardAuthentication)
Fields related to a 3DS authentication attempt.
-
cardAuthentication
final RealTimeDecision.Builder cardAuthentication(JsonField<RealTimeDecision.CardAuthentication> cardAuthentication)
Fields related to a 3DS authentication attempt.
-
cardAuthenticationChallenge
final RealTimeDecision.Builder cardAuthenticationChallenge(RealTimeDecision.CardAuthenticationChallenge cardAuthenticationChallenge)
Fields related to a 3DS authentication attempt.
-
cardAuthenticationChallenge
final RealTimeDecision.Builder cardAuthenticationChallenge(Optional<RealTimeDecision.CardAuthenticationChallenge> cardAuthenticationChallenge)
Fields related to a 3DS authentication attempt.
-
cardAuthenticationChallenge
final RealTimeDecision.Builder cardAuthenticationChallenge(JsonField<RealTimeDecision.CardAuthenticationChallenge> cardAuthenticationChallenge)
Fields related to a 3DS authentication attempt.
-
cardAuthorization
final RealTimeDecision.Builder cardAuthorization(RealTimeDecision.CardAuthorization cardAuthorization)
Fields related to a card authorization.
-
cardAuthorization
final RealTimeDecision.Builder cardAuthorization(Optional<RealTimeDecision.CardAuthorization> cardAuthorization)
Fields related to a card authorization.
-
cardAuthorization
final RealTimeDecision.Builder cardAuthorization(JsonField<RealTimeDecision.CardAuthorization> cardAuthorization)
Fields related to a card authorization.
-
category
final RealTimeDecision.Builder category(RealTimeDecision.Category category)
The category of the Real-Time Decision.
-
category
final RealTimeDecision.Builder category(JsonField<RealTimeDecision.Category> category)
The category of the Real-Time Decision.
-
createdAt
final RealTimeDecision.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Real-Time Decision was created.
-
createdAt
final RealTimeDecision.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the Real-Time Decision was created.
-
digitalWalletAuthentication
final RealTimeDecision.Builder digitalWalletAuthentication(RealTimeDecision.DigitalWalletAuthentication digitalWalletAuthentication)
Fields related to a digital wallet authentication attempt.
-
digitalWalletAuthentication
final RealTimeDecision.Builder digitalWalletAuthentication(Optional<RealTimeDecision.DigitalWalletAuthentication> digitalWalletAuthentication)
Fields related to a digital wallet authentication attempt.
-
digitalWalletAuthentication
final RealTimeDecision.Builder digitalWalletAuthentication(JsonField<RealTimeDecision.DigitalWalletAuthentication> digitalWalletAuthentication)
Fields related to a digital wallet authentication attempt.
-
digitalWalletToken
final RealTimeDecision.Builder digitalWalletToken(RealTimeDecision.DigitalWalletToken digitalWalletToken)
Fields related to a digital wallet token provisioning attempt.
-
digitalWalletToken
final RealTimeDecision.Builder digitalWalletToken(Optional<RealTimeDecision.DigitalWalletToken> digitalWalletToken)
Fields related to a digital wallet token provisioning attempt.
-
digitalWalletToken
final RealTimeDecision.Builder digitalWalletToken(JsonField<RealTimeDecision.DigitalWalletToken> digitalWalletToken)
Fields related to a digital wallet token provisioning attempt.
-
status
final RealTimeDecision.Builder status(RealTimeDecision.Status status)
The status of the Real-Time Decision.
-
status
final RealTimeDecision.Builder status(JsonField<RealTimeDecision.Status> status)
The status of the Real-Time Decision.
-
timeoutAt
final RealTimeDecision.Builder timeoutAt(OffsetDateTime timeoutAt)
The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision.
-
timeoutAt
final RealTimeDecision.Builder timeoutAt(JsonField<OffsetDateTime> timeoutAt)
The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision.
-
type
final RealTimeDecision.Builder type(RealTimeDecision.Type type)
A constant representing the object's type. For this resource it will always be
real_time_decision.
-
type
final RealTimeDecision.Builder type(JsonField<RealTimeDecision.Type> type)
A constant representing the object's type. For this resource it will always be
real_time_decision.
-
additionalProperties
final RealTimeDecision.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision build()
-
-
-
-