Package com.increase.api.models
Class RealTimeDecision.CardAuthentication
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthenticationFields related to a 3DS authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthentication.BuilderA builder for CardAuthentication.
public final classRealTimeDecision.CardAuthentication.DecisionWhether or not the authentication attempt was approved.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the card belongs to. final StringcardId()The identifier of the Card that is being tokenized. final Optional<RealTimeDecision.CardAuthentication.Decision>decision()Whether or not the authentication attempt was approved. final StringupcomingCardPaymentId()The identifier of the Card Payment this authentication attempt will belong to. final JsonField<String>_accountId()The identifier of the Account the card belongs to. final JsonField<String>_cardId()The identifier of the Card that is being tokenized. final JsonField<RealTimeDecision.CardAuthentication.Decision>_decision()Whether or not the authentication attempt was approved. final JsonField<String>_upcomingCardPaymentId()The identifier of the Card Payment this authentication attempt will belong to. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthenticationvalidate()final RealTimeDecision.CardAuthentication.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthentication.Builderbuilder()-
-
Method Detail
-
decision
final Optional<RealTimeDecision.CardAuthentication.Decision> decision()
Whether or not the authentication attempt was approved.
-
upcomingCardPaymentId
final String upcomingCardPaymentId()
The identifier of the Card Payment this authentication attempt will belong to. Available in the API once the card authentication has completed.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account the card belongs to.
-
_decision
final JsonField<RealTimeDecision.CardAuthentication.Decision> _decision()
Whether or not the authentication attempt was approved.
-
_upcomingCardPaymentId
final JsonField<String> _upcomingCardPaymentId()
The identifier of the Card Payment this authentication attempt will belong to. Available in the API once the card authentication has completed.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision.CardAuthentication validate()
-
toBuilder
final RealTimeDecision.CardAuthentication.Builder toBuilder()
-
builder
final static RealTimeDecision.CardAuthentication.Builder builder()
-
-
-
-