Package com.increase.api.models
Class RealTimeDecision.CardAuthenticationChallenge
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthenticationChallengeFields related to a 3DS authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthenticationChallenge.BuilderA builder for CardAuthenticationChallenge.
public final classRealTimeDecision.CardAuthenticationChallenge.ResultWhether or not the challenge was delivered to the cardholder.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the card belongs to. final StringcardId()The identifier of the Card that is being tokenized. final StringcardPaymentId()The identifier of the Card Payment this authentication challenge attempt belongs to. final StringoneTimeCode()The one-time code delivered to the cardholder. final Optional<RealTimeDecision.CardAuthenticationChallenge.Result>result()Whether or not the challenge was delivered to the cardholder. final JsonField<String>_accountId()The identifier of the Account the card belongs to. final JsonField<String>_cardId()The identifier of the Card that is being tokenized. final JsonField<String>_cardPaymentId()The identifier of the Card Payment this authentication challenge attempt belongs to. final JsonField<String>_oneTimeCode()The one-time code delivered to the cardholder. final JsonField<RealTimeDecision.CardAuthenticationChallenge.Result>_result()Whether or not the challenge was delivered to the cardholder. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthenticationChallengevalidate()final RealTimeDecision.CardAuthenticationChallenge.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthenticationChallenge.Builderbuilder()-
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment this authentication challenge attempt belongs to.
-
oneTimeCode
final String oneTimeCode()
The one-time code delivered to the cardholder.
-
result
final Optional<RealTimeDecision.CardAuthenticationChallenge.Result> result()
Whether or not the challenge was delivered to the cardholder.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account the card belongs to.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The identifier of the Card Payment this authentication challenge attempt belongs to.
-
_oneTimeCode
final JsonField<String> _oneTimeCode()
The one-time code delivered to the cardholder.
-
_result
final JsonField<RealTimeDecision.CardAuthenticationChallenge.Result> _result()
Whether or not the challenge was delivered to the cardholder.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision.CardAuthenticationChallenge validate()
-
toBuilder
final RealTimeDecision.CardAuthenticationChallenge.Builder toBuilder()
-
builder
final static RealTimeDecision.CardAuthenticationChallenge.Builder builder()
-
-
-
-