Package com.increase.api.models
Class RealTimeDecision.CardAuthenticationChallenge.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthenticationChallenge.BuilderA builder for CardAuthenticationChallenge.
-
-
Method Summary
-
-
Method Detail
-
accountId
final RealTimeDecision.CardAuthenticationChallenge.Builder accountId(String accountId)
The identifier of the Account the card belongs to.
-
accountId
final RealTimeDecision.CardAuthenticationChallenge.Builder accountId(JsonField<String> accountId)
The identifier of the Account the card belongs to.
-
cardId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardId(JsonField<String> cardId)
The identifier of the Card that is being tokenized.
-
cardPaymentId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardPaymentId(String cardPaymentId)
The identifier of the Card Payment this authentication challenge attempt belongs to.
-
cardPaymentId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardPaymentId(JsonField<String> cardPaymentId)
The identifier of the Card Payment this authentication challenge attempt belongs to.
-
oneTimeCode
final RealTimeDecision.CardAuthenticationChallenge.Builder oneTimeCode(String oneTimeCode)
The one-time code delivered to the cardholder.
-
oneTimeCode
final RealTimeDecision.CardAuthenticationChallenge.Builder oneTimeCode(JsonField<String> oneTimeCode)
The one-time code delivered to the cardholder.
-
result
final RealTimeDecision.CardAuthenticationChallenge.Builder result(RealTimeDecision.CardAuthenticationChallenge.Result result)
Whether or not the challenge was delivered to the cardholder.
-
result
final RealTimeDecision.CardAuthenticationChallenge.Builder result(Optional<RealTimeDecision.CardAuthenticationChallenge.Result> result)
Whether or not the challenge was delivered to the cardholder.
-
result
final RealTimeDecision.CardAuthenticationChallenge.Builder result(JsonField<RealTimeDecision.CardAuthenticationChallenge.Result> result)
Whether or not the challenge was delivered to the cardholder.
-
additionalProperties
final RealTimeDecision.CardAuthenticationChallenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.CardAuthenticationChallenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.CardAuthenticationChallenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.CardAuthenticationChallenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.CardAuthenticationChallenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.CardAuthenticationChallenge build()
-
-
-
-