Class RealTimeDecision.CardAuthorization
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthorizationFields related to a card authorization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthorization.BuilderA builder for CardAuthorization.
public final classRealTimeDecision.CardAuthorization.DecisionWhether or not the authorization was approved.
public final classRealTimeDecision.CardAuthorization.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classRealTimeDecision.CardAuthorization.NetworkDetailsFields specific to the
network.public final classRealTimeDecision.CardAuthorization.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classRealTimeDecision.CardAuthorization.ProcessingCategoryThe processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
public final classRealTimeDecision.CardAuthorization.RequestDetailsFields specific to the type of request, such as an incremental authorization.
public final classRealTimeDecision.CardAuthorization.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the authorization will debit. final StringcardId()The identifier of the Card that is being authorized. final Optional<RealTimeDecision.CardAuthorization.Decision>decision()Whether or not the authorization was approved. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final RealTimeDecision.CardAuthorization.Directiondirection()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final RealTimeDecision.CardAuthorization.NetworkDetailsnetworkDetails()Fields specific to the network.final RealTimeDecision.CardAuthorization.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final LongpresentmentAmount()The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. final StringpresentmentCurrency()The ISO 4217 code for the currency the user sees at the time of purchase. final RealTimeDecision.CardAuthorization.ProcessingCategoryprocessingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final RealTimeDecision.CardAuthorization.RequestDetailsrequestDetails()Fields specific to the type of request, such as an incremental authorization. final LongsettlementAmount()The amount of the attempted authorization in the currency it will be settled in. final StringsettlementCurrency()The ISO 4217 code for the currency the transaction will be settled in. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final StringupcomingCardPaymentId()The identifier of the Card Payment this authorization will belong to. final RealTimeDecision.CardAuthorization.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_accountId()The identifier of the Account the authorization will debit. final JsonField<String>_cardId()The identifier of the Card that is being authorized. final JsonField<RealTimeDecision.CardAuthorization.Decision>_decision()Whether or not the authorization was approved. final JsonField<String>_digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final JsonField<RealTimeDecision.CardAuthorization.Direction>_direction()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final JsonField<String>_merchantPostalCode()The merchant's postal code. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails>_networkDetails()Fields specific to the network.final JsonField<RealTimeDecision.CardAuthorization.NetworkIdentifiers>_networkIdentifiers()Network-specific identifiers for a specific request or transaction. final JsonField<Long>_networkRiskScore()The risk score generated by the card network. final JsonField<String>_physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final JsonField<Long>_presentmentAmount()The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. final JsonField<String>_presentmentCurrency()The ISO 4217 code for the currency the user sees at the time of purchase. final JsonField<RealTimeDecision.CardAuthorization.ProcessingCategory>_processingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final JsonField<RealTimeDecision.CardAuthorization.RequestDetails>_requestDetails()Fields specific to the type of request, such as an incremental authorization. final JsonField<Long>_settlementAmount()The amount of the attempted authorization in the currency it will be settled in. final JsonField<String>_settlementCurrency()The ISO 4217 code for the currency the transaction will be settled in. final JsonField<String>_terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<String>_upcomingCardPaymentId()The identifier of the Card Payment this authorization will belong to. final JsonField<RealTimeDecision.CardAuthorization.Verification>_verification()Fields related to verification of cardholder-provided values. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthorizationvalidate()final RealTimeDecision.CardAuthorization.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthorization.Builderbuilder()-
-
Method Detail
-
decision
final Optional<RealTimeDecision.CardAuthorization.Decision> decision()
Whether or not the authorization was approved.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final RealTimeDecision.CardAuthorization.Direction direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final RealTimeDecision.CardAuthorization.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final RealTimeDecision.CardAuthorization.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final Long presentmentAmount()
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the currency the user sees at the time of purchase.
-
processingCategory
final RealTimeDecision.CardAuthorization.ProcessingCategory processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
requestDetails
final RealTimeDecision.CardAuthorization.RequestDetails requestDetails()
Fields specific to the type of request, such as an incremental authorization.
-
settlementAmount
final Long settlementAmount()
The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.
-
settlementCurrency
final String settlementCurrency()
The ISO 4217 code for the currency the transaction will be settled in.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
upcomingCardPaymentId
final String upcomingCardPaymentId()
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
-
verification
final RealTimeDecision.CardAuthorization.Verification verification()
Fields related to verification of cardholder-provided values.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account the authorization will debit.
-
_decision
final JsonField<RealTimeDecision.CardAuthorization.Decision> _decision()
Whether or not the authorization was approved.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
_direction
final JsonField<RealTimeDecision.CardAuthorization.Direction> _direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_networkDetails
final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails> _networkDetails()
Fields specific to the
network.
-
_networkIdentifiers
final JsonField<RealTimeDecision.CardAuthorization.NetworkIdentifiers> _networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
_physicalCardId
final JsonField<String> _physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
The ISO 4217 code for the currency the user sees at the time of purchase.
-
_processingCategory
final JsonField<RealTimeDecision.CardAuthorization.ProcessingCategory> _processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
_requestDetails
final JsonField<RealTimeDecision.CardAuthorization.RequestDetails> _requestDetails()
Fields specific to the type of request, such as an incremental authorization.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.
-
_settlementCurrency
final JsonField<String> _settlementCurrency()
The ISO 4217 code for the currency the transaction will be settled in.
-
_terminalId
final JsonField<String> _terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_upcomingCardPaymentId
final JsonField<String> _upcomingCardPaymentId()
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
-
_verification
final JsonField<RealTimeDecision.CardAuthorization.Verification> _verification()
Fields related to verification of cardholder-provided values.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision.CardAuthorization validate()
-
toBuilder
final RealTimeDecision.CardAuthorization.Builder toBuilder()
-
builder
final static RealTimeDecision.CardAuthorization.Builder builder()
-
-
-
-