Class RealTimeDecision.CardAuthorization.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthorization.BuilderA builder for CardAuthorization.
-
-
Method Summary
Modifier and Type Method Description final RealTimeDecision.CardAuthorization.BuilderaccountId(String accountId)The identifier of the Account the authorization will debit. final RealTimeDecision.CardAuthorization.BuilderaccountId(JsonField<String> accountId)The identifier of the Account the authorization will debit. final RealTimeDecision.CardAuthorization.BuildercardId(String cardId)The identifier of the Card that is being authorized. final RealTimeDecision.CardAuthorization.BuildercardId(JsonField<String> cardId)The identifier of the Card that is being authorized. final RealTimeDecision.CardAuthorization.Builderdecision(RealTimeDecision.CardAuthorization.Decision decision)Whether or not the authorization was approved. final RealTimeDecision.CardAuthorization.Builderdecision(Optional<RealTimeDecision.CardAuthorization.Decision> decision)Whether or not the authorization was approved. final RealTimeDecision.CardAuthorization.Builderdecision(JsonField<RealTimeDecision.CardAuthorization.Decision> decision)Whether or not the authorization was approved. final RealTimeDecision.CardAuthorization.BuilderdigitalWalletTokenId(String digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final RealTimeDecision.CardAuthorization.BuilderdigitalWalletTokenId(Optional<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final RealTimeDecision.CardAuthorization.BuilderdigitalWalletTokenId(JsonField<String> digitalWalletTokenId)If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final RealTimeDecision.CardAuthorization.Builderdirection(RealTimeDecision.CardAuthorization.Direction direction)The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final RealTimeDecision.CardAuthorization.Builderdirection(JsonField<RealTimeDecision.CardAuthorization.Direction> direction)The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final RealTimeDecision.CardAuthorization.BuildermerchantAcceptorId(String merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final RealTimeDecision.CardAuthorization.BuildermerchantAcceptorId(JsonField<String> merchantAcceptorId)The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final RealTimeDecision.CardAuthorization.BuildermerchantCategoryCode(String merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final RealTimeDecision.CardAuthorization.BuildermerchantCategoryCode(JsonField<String> merchantCategoryCode)The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final RealTimeDecision.CardAuthorization.BuildermerchantCity(String merchantCity)The city the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantCity(Optional<String> merchantCity)The city the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantCity(JsonField<String> merchantCity)The city the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantCountry(String merchantCountry)The country the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantCountry(JsonField<String> merchantCountry)The country the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantDescriptor(String merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final RealTimeDecision.CardAuthorization.BuildermerchantDescriptor(JsonField<String> merchantDescriptor)The merchant descriptor of the merchant the card is transacting with. final RealTimeDecision.CardAuthorization.BuildermerchantPostalCode(String merchantPostalCode)The merchant's postal code. final RealTimeDecision.CardAuthorization.BuildermerchantPostalCode(Optional<String> merchantPostalCode)The merchant's postal code. final RealTimeDecision.CardAuthorization.BuildermerchantPostalCode(JsonField<String> merchantPostalCode)The merchant's postal code. final RealTimeDecision.CardAuthorization.BuildermerchantState(String merchantState)The state the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantState(Optional<String> merchantState)The state the merchant resides in. final RealTimeDecision.CardAuthorization.BuildermerchantState(JsonField<String> merchantState)The state the merchant resides in. final RealTimeDecision.CardAuthorization.BuildernetworkDetails(RealTimeDecision.CardAuthorization.NetworkDetails networkDetails)Fields specific to the network.final RealTimeDecision.CardAuthorization.BuildernetworkDetails(JsonField<RealTimeDecision.CardAuthorization.NetworkDetails> networkDetails)Fields specific to the network.final RealTimeDecision.CardAuthorization.BuildernetworkIdentifiers(RealTimeDecision.CardAuthorization.NetworkIdentifiers networkIdentifiers)Network-specific identifiers for a specific request or transaction. final RealTimeDecision.CardAuthorization.BuildernetworkIdentifiers(JsonField<RealTimeDecision.CardAuthorization.NetworkIdentifiers> networkIdentifiers)Network-specific identifiers for a specific request or transaction. final RealTimeDecision.CardAuthorization.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final RealTimeDecision.CardAuthorization.BuildernetworkRiskScore(Long networkRiskScore)The risk score generated by the card network. final RealTimeDecision.CardAuthorization.BuildernetworkRiskScore(Optional<Long> networkRiskScore)The risk score generated by the card network. final RealTimeDecision.CardAuthorization.BuildernetworkRiskScore(JsonField<Long> networkRiskScore)The risk score generated by the card network. final RealTimeDecision.CardAuthorization.BuilderphysicalCardId(String physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final RealTimeDecision.CardAuthorization.BuilderphysicalCardId(Optional<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final RealTimeDecision.CardAuthorization.BuilderphysicalCardId(JsonField<String> physicalCardId)If the authorization was made in-person with a physical card, the Physical Card that was used. final RealTimeDecision.CardAuthorization.BuilderpresentmentAmount(Long presentmentAmount)The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. final RealTimeDecision.CardAuthorization.BuilderpresentmentAmount(JsonField<Long> presentmentAmount)The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. final RealTimeDecision.CardAuthorization.BuilderpresentmentCurrency(String presentmentCurrency)The ISO 4217 code for the currency the user sees at the time of purchase. final RealTimeDecision.CardAuthorization.BuilderpresentmentCurrency(JsonField<String> presentmentCurrency)The ISO 4217 code for the currency the user sees at the time of purchase. final RealTimeDecision.CardAuthorization.BuilderprocessingCategory(RealTimeDecision.CardAuthorization.ProcessingCategory processingCategory)The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final RealTimeDecision.CardAuthorization.BuilderprocessingCategory(JsonField<RealTimeDecision.CardAuthorization.ProcessingCategory> processingCategory)The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final RealTimeDecision.CardAuthorization.BuilderrequestDetails(RealTimeDecision.CardAuthorization.RequestDetails requestDetails)Fields specific to the type of request, such as an incremental authorization. final RealTimeDecision.CardAuthorization.BuilderrequestDetails(JsonField<RealTimeDecision.CardAuthorization.RequestDetails> requestDetails)Fields specific to the type of request, such as an incremental authorization. final RealTimeDecision.CardAuthorization.BuildersettlementAmount(Long settlementAmount)The amount of the attempted authorization in the currency it will be settled in. final RealTimeDecision.CardAuthorization.BuildersettlementAmount(JsonField<Long> settlementAmount)The amount of the attempted authorization in the currency it will be settled in. final RealTimeDecision.CardAuthorization.BuildersettlementCurrency(String settlementCurrency)The ISO 4217 code for the currency the transaction will be settled in. final RealTimeDecision.CardAuthorization.BuildersettlementCurrency(JsonField<String> settlementCurrency)The ISO 4217 code for the currency the transaction will be settled in. final RealTimeDecision.CardAuthorization.BuilderterminalId(String terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final RealTimeDecision.CardAuthorization.BuilderterminalId(Optional<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final RealTimeDecision.CardAuthorization.BuilderterminalId(JsonField<String> terminalId)The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final RealTimeDecision.CardAuthorization.BuilderupcomingCardPaymentId(String upcomingCardPaymentId)The identifier of the Card Payment this authorization will belong to. final RealTimeDecision.CardAuthorization.BuilderupcomingCardPaymentId(JsonField<String> upcomingCardPaymentId)The identifier of the Card Payment this authorization will belong to. final RealTimeDecision.CardAuthorization.Builderverification(RealTimeDecision.CardAuthorization.Verification verification)Fields related to verification of cardholder-provided values. final RealTimeDecision.CardAuthorization.Builderverification(JsonField<RealTimeDecision.CardAuthorization.Verification> verification)Fields related to verification of cardholder-provided values. final RealTimeDecision.CardAuthorization.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RealTimeDecision.CardAuthorization.BuilderputAdditionalProperty(String key, JsonValue value)final RealTimeDecision.CardAuthorization.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RealTimeDecision.CardAuthorization.BuilderremoveAdditionalProperty(String key)final RealTimeDecision.CardAuthorization.BuilderremoveAllAdditionalProperties(Set<String> keys)final RealTimeDecision.CardAuthorizationbuild()-
-
Method Detail
-
accountId
final RealTimeDecision.CardAuthorization.Builder accountId(String accountId)
The identifier of the Account the authorization will debit.
-
accountId
final RealTimeDecision.CardAuthorization.Builder accountId(JsonField<String> accountId)
The identifier of the Account the authorization will debit.
-
cardId
final RealTimeDecision.CardAuthorization.Builder cardId(String cardId)
The identifier of the Card that is being authorized.
-
cardId
final RealTimeDecision.CardAuthorization.Builder cardId(JsonField<String> cardId)
The identifier of the Card that is being authorized.
-
decision
final RealTimeDecision.CardAuthorization.Builder decision(RealTimeDecision.CardAuthorization.Decision decision)
Whether or not the authorization was approved.
-
decision
final RealTimeDecision.CardAuthorization.Builder decision(Optional<RealTimeDecision.CardAuthorization.Decision> decision)
Whether or not the authorization was approved.
-
decision
final RealTimeDecision.CardAuthorization.Builder decision(JsonField<RealTimeDecision.CardAuthorization.Decision> decision)
Whether or not the authorization was approved.
-
digitalWalletTokenId
final RealTimeDecision.CardAuthorization.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final RealTimeDecision.CardAuthorization.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final RealTimeDecision.CardAuthorization.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final RealTimeDecision.CardAuthorization.Builder direction(RealTimeDecision.CardAuthorization.Direction direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
direction
final RealTimeDecision.CardAuthorization.Builder direction(JsonField<RealTimeDecision.CardAuthorization.Direction> direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
merchantAcceptorId
final RealTimeDecision.CardAuthorization.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final RealTimeDecision.CardAuthorization.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final RealTimeDecision.CardAuthorization.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final RealTimeDecision.CardAuthorization.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final RealTimeDecision.CardAuthorization.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final RealTimeDecision.CardAuthorization.Builder merchantCity(Optional<String> merchantCity)
The city the merchant resides in.
-
merchantCity
final RealTimeDecision.CardAuthorization.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final RealTimeDecision.CardAuthorization.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final RealTimeDecision.CardAuthorization.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantDescriptor
final RealTimeDecision.CardAuthorization.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final RealTimeDecision.CardAuthorization.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final RealTimeDecision.CardAuthorization.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final RealTimeDecision.CardAuthorization.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final RealTimeDecision.CardAuthorization.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final RealTimeDecision.CardAuthorization.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final RealTimeDecision.CardAuthorization.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final RealTimeDecision.CardAuthorization.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkDetails
final RealTimeDecision.CardAuthorization.Builder networkDetails(RealTimeDecision.CardAuthorization.NetworkDetails networkDetails)
Fields specific to the
network.
-
networkDetails
final RealTimeDecision.CardAuthorization.Builder networkDetails(JsonField<RealTimeDecision.CardAuthorization.NetworkDetails> networkDetails)
Fields specific to the
network.
-
networkIdentifiers
final RealTimeDecision.CardAuthorization.Builder networkIdentifiers(RealTimeDecision.CardAuthorization.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final RealTimeDecision.CardAuthorization.Builder networkIdentifiers(JsonField<RealTimeDecision.CardAuthorization.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final RealTimeDecision.CardAuthorization.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final RealTimeDecision.CardAuthorization.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final RealTimeDecision.CardAuthorization.Builder networkRiskScore(Optional<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final RealTimeDecision.CardAuthorization.Builder networkRiskScore(JsonField<Long> networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final RealTimeDecision.CardAuthorization.Builder physicalCardId(String physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final RealTimeDecision.CardAuthorization.Builder physicalCardId(Optional<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final RealTimeDecision.CardAuthorization.Builder physicalCardId(JsonField<String> physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final RealTimeDecision.CardAuthorization.Builder presentmentAmount(Long presentmentAmount)
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.
-
presentmentAmount
final RealTimeDecision.CardAuthorization.Builder presentmentAmount(JsonField<Long> presentmentAmount)
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.
-
presentmentCurrency
final RealTimeDecision.CardAuthorization.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the currency the user sees at the time of purchase.
-
presentmentCurrency
final RealTimeDecision.CardAuthorization.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
The ISO 4217 code for the currency the user sees at the time of purchase.
-
processingCategory
final RealTimeDecision.CardAuthorization.Builder processingCategory(RealTimeDecision.CardAuthorization.ProcessingCategory processingCategory)
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
processingCategory
final RealTimeDecision.CardAuthorization.Builder processingCategory(JsonField<RealTimeDecision.CardAuthorization.ProcessingCategory> processingCategory)
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
requestDetails
final RealTimeDecision.CardAuthorization.Builder requestDetails(RealTimeDecision.CardAuthorization.RequestDetails requestDetails)
Fields specific to the type of request, such as an incremental authorization.
-
requestDetails
final RealTimeDecision.CardAuthorization.Builder requestDetails(JsonField<RealTimeDecision.CardAuthorization.RequestDetails> requestDetails)
Fields specific to the type of request, such as an incremental authorization.
-
settlementAmount
final RealTimeDecision.CardAuthorization.Builder settlementAmount(Long settlementAmount)
The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.
-
settlementAmount
final RealTimeDecision.CardAuthorization.Builder settlementAmount(JsonField<Long> settlementAmount)
The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.
-
settlementCurrency
final RealTimeDecision.CardAuthorization.Builder settlementCurrency(String settlementCurrency)
The ISO 4217 code for the currency the transaction will be settled in.
-
settlementCurrency
final RealTimeDecision.CardAuthorization.Builder settlementCurrency(JsonField<String> settlementCurrency)
The ISO 4217 code for the currency the transaction will be settled in.
-
terminalId
final RealTimeDecision.CardAuthorization.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final RealTimeDecision.CardAuthorization.Builder terminalId(Optional<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final RealTimeDecision.CardAuthorization.Builder terminalId(JsonField<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
upcomingCardPaymentId
final RealTimeDecision.CardAuthorization.Builder upcomingCardPaymentId(String upcomingCardPaymentId)
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
-
upcomingCardPaymentId
final RealTimeDecision.CardAuthorization.Builder upcomingCardPaymentId(JsonField<String> upcomingCardPaymentId)
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
-
verification
final RealTimeDecision.CardAuthorization.Builder verification(RealTimeDecision.CardAuthorization.Verification verification)
Fields related to verification of cardholder-provided values.
-
verification
final RealTimeDecision.CardAuthorization.Builder verification(JsonField<RealTimeDecision.CardAuthorization.Verification> verification)
Fields related to verification of cardholder-provided values.
-
additionalProperties
final RealTimeDecision.CardAuthorization.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.CardAuthorization.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.CardAuthorization.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.CardAuthorization.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.CardAuthorization.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.CardAuthorization build()
-
-
-
-