Class RealTimeDecision.CardAuthorization.NetworkDetails.Visa
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthorization.NetworkDetails.VisaFields specific to the
visanetwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthorization.NetworkDetails.Visa.BuilderA builder for Visa.
public final classRealTimeDecision.CardAuthorization.NetworkDetails.Visa.ElectronicCommerceIndicatorFor electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
public final classRealTimeDecision.CardAuthorization.NetworkDetails.Visa.PointOfServiceEntryModeThe method used to enter the cardholder's primary account number and card expiration date.
public final classRealTimeDecision.CardAuthorization.NetworkDetails.Visa.StandInProcessingReasonOnly present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.
-
Method Summary
-
-
Method Detail
-
electronicCommerceIndicator
final Optional<RealTimeDecision.CardAuthorization.NetworkDetails.Visa.ElectronicCommerceIndicator> electronicCommerceIndicator()
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
-
pointOfServiceEntryMode
final Optional<RealTimeDecision.CardAuthorization.NetworkDetails.Visa.PointOfServiceEntryMode> pointOfServiceEntryMode()
The method used to enter the cardholder's primary account number and card expiration date.
-
standInProcessingReason
final Optional<RealTimeDecision.CardAuthorization.NetworkDetails.Visa.StandInProcessingReason> standInProcessingReason()
Only present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.
-
_electronicCommerceIndicator
final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails.Visa.ElectronicCommerceIndicator> _electronicCommerceIndicator()
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
-
_pointOfServiceEntryMode
final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails.Visa.PointOfServiceEntryMode> _pointOfServiceEntryMode()
The method used to enter the cardholder's primary account number and card expiration date.
-
_standInProcessingReason
final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails.Visa.StandInProcessingReason> _standInProcessingReason()
Only present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision.CardAuthorization.NetworkDetails.Visa validate()
-
toBuilder
final RealTimeDecision.CardAuthorization.NetworkDetails.Visa.Builder toBuilder()
-
builder
final static RealTimeDecision.CardAuthorization.NetworkDetails.Visa.Builder builder()
-
-
-
-