Package com.increase.api.models
Enum RealTimeDecision.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum RealTimeDecision.Category.Known extends Enum<RealTimeDecision.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<RealTimeDecision.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARD_AUTHORIZATION_REQUESTEDA card is being authorized.
CARD_AUTHENTICATION_REQUESTED3DS authentication is requested.
CARD_AUTHENTICATION_CHALLENGE_REQUESTED3DS authentication challenge requires cardholder involvement.
DIGITAL_WALLET_TOKEN_REQUESTEDA card is being loaded into a digital wallet.
DIGITAL_WALLET_AUTHENTICATION_REQUESTEDA card is being loaded into a digital wallet and requires cardholder authentication.
-
Method Summary
Modifier and Type Method Description final RealTimeDecision.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<RealTimeDecision.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<RealTimeDecision.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final RealTimeDecision.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<RealTimeDecision.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<RealTimeDecision.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-