Class RealTimeDecision.DigitalWalletAuthentication
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletAuthenticationFields related to a digital wallet authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.DigitalWalletAuthentication.BuilderA builder for DigitalWalletAuthentication.
public final classRealTimeDecision.DigitalWalletAuthentication.ChannelThe channel to send the card user their one-time passcode.
public final classRealTimeDecision.DigitalWalletAuthentication.DigitalWalletThe digital wallet app being used.
public final classRealTimeDecision.DigitalWalletAuthentication.ResultWhether your application successfully delivered the one-time passcode.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card that is being tokenized. final RealTimeDecision.DigitalWalletAuthentication.Channelchannel()The channel to send the card user their one-time passcode. final RealTimeDecision.DigitalWalletAuthentication.DigitalWalletdigitalWallet()The digital wallet app being used. final Optional<String>email()The email to send the one-time passcode to if channelis equal toemail.final StringoneTimePasscode()The one-time passcode to send the card user. final Optional<String>phone()The phone number to send the one-time passcode to if channelis equal tosms.final Optional<RealTimeDecision.DigitalWalletAuthentication.Result>result()Whether your application successfully delivered the one-time passcode. final JsonField<String>_cardId()The identifier of the Card that is being tokenized. final JsonField<RealTimeDecision.DigitalWalletAuthentication.Channel>_channel()The channel to send the card user their one-time passcode. final JsonField<RealTimeDecision.DigitalWalletAuthentication.DigitalWallet>_digitalWallet()The digital wallet app being used. final JsonField<String>_email()The email to send the one-time passcode to if channelis equal toemail.final JsonField<String>_oneTimePasscode()The one-time passcode to send the card user. final JsonField<String>_phone()The phone number to send the one-time passcode to if channelis equal tosms.final JsonField<RealTimeDecision.DigitalWalletAuthentication.Result>_result()Whether your application successfully delivered the one-time passcode. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.DigitalWalletAuthenticationvalidate()final RealTimeDecision.DigitalWalletAuthentication.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.DigitalWalletAuthentication.Builderbuilder()-
-
Method Detail
-
channel
final RealTimeDecision.DigitalWalletAuthentication.Channel channel()
The channel to send the card user their one-time passcode.
-
digitalWallet
final RealTimeDecision.DigitalWalletAuthentication.DigitalWallet digitalWallet()
The digital wallet app being used.
-
email
final Optional<String> email()
The email to send the one-time passcode to if
channelis equal toemail.
-
oneTimePasscode
final String oneTimePasscode()
The one-time passcode to send the card user.
-
phone
final Optional<String> phone()
The phone number to send the one-time passcode to if
channelis equal tosms.
-
result
final Optional<RealTimeDecision.DigitalWalletAuthentication.Result> result()
Whether your application successfully delivered the one-time passcode.
-
_channel
final JsonField<RealTimeDecision.DigitalWalletAuthentication.Channel> _channel()
The channel to send the card user their one-time passcode.
-
_digitalWallet
final JsonField<RealTimeDecision.DigitalWalletAuthentication.DigitalWallet> _digitalWallet()
The digital wallet app being used.
-
_email
final JsonField<String> _email()
The email to send the one-time passcode to if
channelis equal toemail.
-
_oneTimePasscode
final JsonField<String> _oneTimePasscode()
The one-time passcode to send the card user.
-
_phone
final JsonField<String> _phone()
The phone number to send the one-time passcode to if
channelis equal tosms.
-
_result
final JsonField<RealTimeDecision.DigitalWalletAuthentication.Result> _result()
Whether your application successfully delivered the one-time passcode.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision.DigitalWalletAuthentication validate()
-
toBuilder
final RealTimeDecision.DigitalWalletAuthentication.Builder toBuilder()
-
builder
final static RealTimeDecision.DigitalWalletAuthentication.Builder builder()
-
-
-
-