Class RealTimeDecision.DigitalWalletAuthentication.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletAuthentication.BuilderA builder for DigitalWalletAuthentication.
-
-
Method Summary
-
-
Method Detail
-
cardId
final RealTimeDecision.DigitalWalletAuthentication.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.DigitalWalletAuthentication.Builder cardId(JsonField<String> cardId)
The identifier of the Card that is being tokenized.
-
channel
final RealTimeDecision.DigitalWalletAuthentication.Builder channel(RealTimeDecision.DigitalWalletAuthentication.Channel channel)
The channel to send the card user their one-time passcode.
-
channel
final RealTimeDecision.DigitalWalletAuthentication.Builder channel(JsonField<RealTimeDecision.DigitalWalletAuthentication.Channel> channel)
The channel to send the card user their one-time passcode.
-
digitalWallet
final RealTimeDecision.DigitalWalletAuthentication.Builder digitalWallet(RealTimeDecision.DigitalWalletAuthentication.DigitalWallet digitalWallet)
The digital wallet app being used.
-
digitalWallet
final RealTimeDecision.DigitalWalletAuthentication.Builder digitalWallet(JsonField<RealTimeDecision.DigitalWalletAuthentication.DigitalWallet> digitalWallet)
The digital wallet app being used.
-
email
final RealTimeDecision.DigitalWalletAuthentication.Builder email(String email)
The email to send the one-time passcode to if
channelis equal toemail.
-
email
final RealTimeDecision.DigitalWalletAuthentication.Builder email(Optional<String> email)
The email to send the one-time passcode to if
channelis equal toemail.
-
email
final RealTimeDecision.DigitalWalletAuthentication.Builder email(JsonField<String> email)
The email to send the one-time passcode to if
channelis equal toemail.
-
oneTimePasscode
final RealTimeDecision.DigitalWalletAuthentication.Builder oneTimePasscode(String oneTimePasscode)
The one-time passcode to send the card user.
-
oneTimePasscode
final RealTimeDecision.DigitalWalletAuthentication.Builder oneTimePasscode(JsonField<String> oneTimePasscode)
The one-time passcode to send the card user.
-
phone
final RealTimeDecision.DigitalWalletAuthentication.Builder phone(String phone)
The phone number to send the one-time passcode to if
channelis equal tosms.
-
phone
final RealTimeDecision.DigitalWalletAuthentication.Builder phone(Optional<String> phone)
The phone number to send the one-time passcode to if
channelis equal tosms.
-
phone
final RealTimeDecision.DigitalWalletAuthentication.Builder phone(JsonField<String> phone)
The phone number to send the one-time passcode to if
channelis equal tosms.
-
result
final RealTimeDecision.DigitalWalletAuthentication.Builder result(RealTimeDecision.DigitalWalletAuthentication.Result result)
Whether your application successfully delivered the one-time passcode.
-
result
final RealTimeDecision.DigitalWalletAuthentication.Builder result(Optional<RealTimeDecision.DigitalWalletAuthentication.Result> result)
Whether your application successfully delivered the one-time passcode.
-
result
final RealTimeDecision.DigitalWalletAuthentication.Builder result(JsonField<RealTimeDecision.DigitalWalletAuthentication.Result> result)
Whether your application successfully delivered the one-time passcode.
-
additionalProperties
final RealTimeDecision.DigitalWalletAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.DigitalWalletAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.DigitalWalletAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.DigitalWalletAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.DigitalWalletAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.DigitalWalletAuthentication build()
-
-
-
-