Class RealTimeDecision.DigitalWalletToken
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletTokenFields related to a digital wallet token provisioning attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.DigitalWalletToken.BuilderA builder for DigitalWalletToken.
public final classRealTimeDecision.DigitalWalletToken.DecisionWhether or not the provisioning request was approved. This will be null until the real time decision is responded to.
public final classRealTimeDecision.DigitalWalletToken.DigitalWalletThe digital wallet app being used.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card that is being tokenized. final Optional<String>cardProfileId()The identifier of the Card Profile that was set via the real time decision. final Optional<RealTimeDecision.DigitalWalletToken.Decision>decision()Whether or not the provisioning request was approved. final RealTimeDecision.DigitalWalletToken.DigitalWalletdigitalWallet()The digital wallet app being used. final JsonField<String>_cardId()The identifier of the Card that is being tokenized. final JsonField<String>_cardProfileId()The identifier of the Card Profile that was set via the real time decision. final JsonField<RealTimeDecision.DigitalWalletToken.Decision>_decision()Whether or not the provisioning request was approved. final JsonField<RealTimeDecision.DigitalWalletToken.DigitalWallet>_digitalWallet()The digital wallet app being used. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.DigitalWalletTokenvalidate()final RealTimeDecision.DigitalWalletToken.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.DigitalWalletToken.Builderbuilder()-
-
Method Detail
-
cardProfileId
final Optional<String> cardProfileId()
The identifier of the Card Profile that was set via the real time decision. This will be null until the real time decision is responded to or if the real time decision did not set a card profile.
-
decision
final Optional<RealTimeDecision.DigitalWalletToken.Decision> decision()
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
digitalWallet
final RealTimeDecision.DigitalWalletToken.DigitalWallet digitalWallet()
The digital wallet app being used.
-
_cardProfileId
final JsonField<String> _cardProfileId()
The identifier of the Card Profile that was set via the real time decision. This will be null until the real time decision is responded to or if the real time decision did not set a card profile.
-
_decision
final JsonField<RealTimeDecision.DigitalWalletToken.Decision> _decision()
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
_digitalWallet
final JsonField<RealTimeDecision.DigitalWalletToken.DigitalWallet> _digitalWallet()
The digital wallet app being used.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecision.DigitalWalletToken validate()
-
toBuilder
final RealTimeDecision.DigitalWalletToken.Builder toBuilder()
-
builder
final static RealTimeDecision.DigitalWalletToken.Builder builder()
-
-
-
-