Class RealTimeDecision.DigitalWalletToken.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletToken.BuilderA builder for DigitalWalletToken.
-
-
Method Summary
-
-
Method Detail
-
cardId
final RealTimeDecision.DigitalWalletToken.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.DigitalWalletToken.Builder cardId(JsonField<String> cardId)
The identifier of the Card that is being tokenized.
-
cardProfileId
final RealTimeDecision.DigitalWalletToken.Builder cardProfileId(String cardProfileId)
The identifier of the Card Profile that was set via the real time decision. This will be null until the real time decision is responded to or if the real time decision did not set a card profile.
-
cardProfileId
final RealTimeDecision.DigitalWalletToken.Builder cardProfileId(Optional<String> cardProfileId)
The identifier of the Card Profile that was set via the real time decision. This will be null until the real time decision is responded to or if the real time decision did not set a card profile.
-
cardProfileId
final RealTimeDecision.DigitalWalletToken.Builder cardProfileId(JsonField<String> cardProfileId)
The identifier of the Card Profile that was set via the real time decision. This will be null until the real time decision is responded to or if the real time decision did not set a card profile.
-
decision
final RealTimeDecision.DigitalWalletToken.Builder decision(RealTimeDecision.DigitalWalletToken.Decision decision)
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
decision
final RealTimeDecision.DigitalWalletToken.Builder decision(Optional<RealTimeDecision.DigitalWalletToken.Decision> decision)
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
decision
final RealTimeDecision.DigitalWalletToken.Builder decision(JsonField<RealTimeDecision.DigitalWalletToken.Decision> decision)
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
digitalWallet
final RealTimeDecision.DigitalWalletToken.Builder digitalWallet(RealTimeDecision.DigitalWalletToken.DigitalWallet digitalWallet)
The digital wallet app being used.
-
digitalWallet
final RealTimeDecision.DigitalWalletToken.Builder digitalWallet(JsonField<RealTimeDecision.DigitalWalletToken.DigitalWallet> digitalWallet)
The digital wallet app being used.
-
additionalProperties
final RealTimeDecision.DigitalWalletToken.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.DigitalWalletToken.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.DigitalWalletToken.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.DigitalWalletToken.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.DigitalWalletToken.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.DigitalWalletToken build()
-
-
-
-