Class RealTimeDecisionActionParams.Body
-
- All Implemented Interfaces:
public final class RealTimeDecisionActionParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionActionParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<RealTimeDecisionActionParams.CardAuthentication>cardAuthentication()If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication. final Optional<RealTimeDecisionActionParams.CardAuthenticationChallenge>cardAuthenticationChallenge()If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response. final Optional<RealTimeDecisionActionParams.CardAuthorization>cardAuthorization()If the Real-Time Decision relates to a card authorization attempt, this object contains your response to the authorization. final Optional<RealTimeDecisionActionParams.DigitalWalletAuthentication>digitalWalletAuthentication()If the Real-Time Decision relates to a digital wallet authentication attempt, this object contains your response to the authentication. final Optional<RealTimeDecisionActionParams.DigitalWalletToken>digitalWalletToken()If the Real-Time Decision relates to a digital wallet token provisioning attempt, this object contains your response to the attempt. final JsonField<RealTimeDecisionActionParams.CardAuthentication>_cardAuthentication()If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication. final JsonField<RealTimeDecisionActionParams.CardAuthenticationChallenge>_cardAuthenticationChallenge()If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response. final JsonField<RealTimeDecisionActionParams.CardAuthorization>_cardAuthorization()If the Real-Time Decision relates to a card authorization attempt, this object contains your response to the authorization. final JsonField<RealTimeDecisionActionParams.DigitalWalletAuthentication>_digitalWalletAuthentication()If the Real-Time Decision relates to a digital wallet authentication attempt, this object contains your response to the authentication. final JsonField<RealTimeDecisionActionParams.DigitalWalletToken>_digitalWalletToken()If the Real-Time Decision relates to a digital wallet token provisioning attempt, this object contains your response to the attempt. final Map<String, JsonValue>_additionalProperties()final RealTimeDecisionActionParams.Bodyvalidate()final RealTimeDecisionActionParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecisionActionParams.Body.Builderbuilder()-
-
Method Detail
-
cardAuthentication
final Optional<RealTimeDecisionActionParams.CardAuthentication> cardAuthentication()
If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication.
-
cardAuthenticationChallenge
final Optional<RealTimeDecisionActionParams.CardAuthenticationChallenge> cardAuthenticationChallenge()
If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response.
-
cardAuthorization
final Optional<RealTimeDecisionActionParams.CardAuthorization> cardAuthorization()
If the Real-Time Decision relates to a card authorization attempt, this object contains your response to the authorization.
-
digitalWalletAuthentication
final Optional<RealTimeDecisionActionParams.DigitalWalletAuthentication> digitalWalletAuthentication()
If the Real-Time Decision relates to a digital wallet authentication attempt, this object contains your response to the authentication.
-
digitalWalletToken
final Optional<RealTimeDecisionActionParams.DigitalWalletToken> digitalWalletToken()
If the Real-Time Decision relates to a digital wallet token provisioning attempt, this object contains your response to the attempt.
-
_cardAuthentication
final JsonField<RealTimeDecisionActionParams.CardAuthentication> _cardAuthentication()
If the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication.
-
_cardAuthenticationChallenge
final JsonField<RealTimeDecisionActionParams.CardAuthenticationChallenge> _cardAuthenticationChallenge()
If the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response.
-
_cardAuthorization
final JsonField<RealTimeDecisionActionParams.CardAuthorization> _cardAuthorization()
If the Real-Time Decision relates to a card authorization attempt, this object contains your response to the authorization.
-
_digitalWalletAuthentication
final JsonField<RealTimeDecisionActionParams.DigitalWalletAuthentication> _digitalWalletAuthentication()
If the Real-Time Decision relates to a digital wallet authentication attempt, this object contains your response to the authentication.
-
_digitalWalletToken
final JsonField<RealTimeDecisionActionParams.DigitalWalletToken> _digitalWalletToken()
If the Real-Time Decision relates to a digital wallet token provisioning attempt, this object contains your response to the attempt.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecisionActionParams.Body validate()
-
toBuilder
final RealTimeDecisionActionParams.Body.Builder toBuilder()
-
builder
final static RealTimeDecisionActionParams.Body.Builder builder()
-
-
-
-