Package com.increase.api.models
Class RealTimeDecisionActionParams.CardAuthentication
-
- All Implemented Interfaces:
public final class RealTimeDecisionActionParams.CardAuthenticationIf the Real-Time Decision relates to a 3DS card authentication attempt, this object contains your response to the authentication.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionActionParams.CardAuthentication.BuilderA builder for CardAuthentication.
public final classRealTimeDecisionActionParams.CardAuthentication.DecisionWhether the card authentication attempt should be approved or declined.
-
Method Summary
Modifier and Type Method Description final RealTimeDecisionActionParams.CardAuthentication.Decisiondecision()Whether the card authentication attempt should be approved or declined. final JsonField<RealTimeDecisionActionParams.CardAuthentication.Decision>_decision()Whether the card authentication attempt should be approved or declined. final Map<String, JsonValue>_additionalProperties()final RealTimeDecisionActionParams.CardAuthenticationvalidate()final RealTimeDecisionActionParams.CardAuthentication.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecisionActionParams.CardAuthentication.Builderbuilder()-
-
Method Detail
-
decision
final RealTimeDecisionActionParams.CardAuthentication.Decision decision()
Whether the card authentication attempt should be approved or declined.
-
_decision
final JsonField<RealTimeDecisionActionParams.CardAuthentication.Decision> _decision()
Whether the card authentication attempt should be approved or declined.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecisionActionParams.CardAuthentication validate()
-
toBuilder
final RealTimeDecisionActionParams.CardAuthentication.Builder toBuilder()
-
builder
final static RealTimeDecisionActionParams.CardAuthentication.Builder builder()
-
-
-
-