Package com.increase.api.models
Class RealTimeDecisionActionParams.CardAuthenticationChallenge
-
- All Implemented Interfaces:
public final class RealTimeDecisionActionParams.CardAuthenticationChallengeIf the Real-Time Decision relates to 3DS card authentication challenge delivery, this object contains your response.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionActionParams.CardAuthenticationChallenge.BuilderA builder for CardAuthenticationChallenge.
public final classRealTimeDecisionActionParams.CardAuthenticationChallenge.ResultWhether the card authentication challenge was successfully delivered to the cardholder.
-
Method Summary
Modifier and Type Method Description final RealTimeDecisionActionParams.CardAuthenticationChallenge.Resultresult()Whether the card authentication challenge was successfully delivered to the cardholder. final JsonField<RealTimeDecisionActionParams.CardAuthenticationChallenge.Result>_result()Whether the card authentication challenge was successfully delivered to the cardholder. final Map<String, JsonValue>_additionalProperties()final RealTimeDecisionActionParams.CardAuthenticationChallengevalidate()final RealTimeDecisionActionParams.CardAuthenticationChallenge.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecisionActionParams.CardAuthenticationChallenge.Builderbuilder()-
-
Method Detail
-
result
final RealTimeDecisionActionParams.CardAuthenticationChallenge.Result result()
Whether the card authentication challenge was successfully delivered to the cardholder.
-
_result
final JsonField<RealTimeDecisionActionParams.CardAuthenticationChallenge.Result> _result()
Whether the card authentication challenge was successfully delivered to the cardholder.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecisionActionParams.CardAuthenticationChallenge validate()
-
toBuilder
final RealTimeDecisionActionParams.CardAuthenticationChallenge.Builder toBuilder()
-
builder
final static RealTimeDecisionActionParams.CardAuthenticationChallenge.Builder builder()
-
-
-
-