Package com.increase.api.models
Class RealTimeDecisionActionParams.DigitalWalletToken.Approval
-
- All Implemented Interfaces:
public final class RealTimeDecisionActionParams.DigitalWalletToken.ApprovalIf your application approves the provisioning attempt, this contains metadata about the digital wallet token that will be generated.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionActionParams.DigitalWalletToken.Approval.BuilderA builder for Approval.
-
Method Summary
Modifier and Type Method Description final Optional<String>email()An email address that can be used to verify the cardholder via one-time passcode. final Optional<String>phone()A phone number that can be used to verify the cardholder via one-time passcode over SMS. final JsonField<String>_email()An email address that can be used to verify the cardholder via one-time passcode. final JsonField<String>_phone()A phone number that can be used to verify the cardholder via one-time passcode over SMS. final Map<String, JsonValue>_additionalProperties()final RealTimeDecisionActionParams.DigitalWalletToken.Approvalvalidate()final RealTimeDecisionActionParams.DigitalWalletToken.Approval.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecisionActionParams.DigitalWalletToken.Approval.Builderbuilder()-
-
Method Detail
-
email
final Optional<String> email()
An email address that can be used to verify the cardholder via one-time passcode.
-
phone
final Optional<String> phone()
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
-
_email
final JsonField<String> _email()
An email address that can be used to verify the cardholder via one-time passcode.
-
_phone
final JsonField<String> _phone()
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimeDecisionActionParams.DigitalWalletToken.Approval validate()
-
toBuilder
final RealTimeDecisionActionParams.DigitalWalletToken.Approval.Builder toBuilder()
-
builder
final static RealTimeDecisionActionParams.DigitalWalletToken.Approval.Builder builder()
-
-
-
-