Class RealTimePaymentsTransfer
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransferReal-Time Payments transfers move funds, within seconds, between your Increase account and any other account on the Real-Time Payments network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.BuilderA builder for RealTimePaymentsTransfer.
public final classRealTimePaymentsTransfer.AcknowledgementIf the transfer is acknowledged by the recipient bank, this will contain supplemental details.
public final classRealTimePaymentsTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classRealTimePaymentsTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classRealTimePaymentsTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classRealTimePaymentsTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.public final classRealTimePaymentsTransfer.RejectionIf the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
public final classRealTimePaymentsTransfer.StatusThe lifecycle status of the transfer.
public final classRealTimePaymentsTransfer.SubmissionAfter the transfer is submitted to Real-Time Payments, this will contain supplemental details.
public final classRealTimePaymentsTransfer.TypeA constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Real-Time Payments Transfer's identifier. final StringaccountId()The Account from which the transfer was sent. final Optional<RealTimePaymentsTransfer.Acknowledgement>acknowledgement()If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final Longamount()The transfer amount in USD cents. final Optional<RealTimePaymentsTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<RealTimePaymentsTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<RealTimePaymentsTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final StringcreditorName()The name of the transfer's recipient. final RealTimePaymentsTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final Optional<String>debtorName()The name of the transfer's sender. final StringdestinationAccountNumber()The destination account number. final StringdestinationRoutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<RealTimePaymentsTransfer.Rejection>rejection()If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details. final StringremittanceInformation()Unstructured information that will show on the recipient's bank statement. final StringsourceAccountNumberId()The Account Number the recipient will see as having sent the transfer. final RealTimePaymentsTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<RealTimePaymentsTransfer.Submission>submission()After the transfer is submitted to Real-Time Payments, this will contain supplemental details. final Optional<String>transactionId()The Transaction funding the transfer once it is complete. final RealTimePaymentsTransfer.Typetype()A constant representing the object's type. final Optional<String>ultimateCreditorName()The name of the ultimate recipient of the transfer. final Optional<String>ultimateDebtorName()The name of the ultimate sender of the transfer. final JsonField<String>_id()The Real-Time Payments Transfer's identifier. final JsonField<String>_accountId()The Account from which the transfer was sent. final JsonField<RealTimePaymentsTransfer.Acknowledgement>_acknowledgement()If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<RealTimePaymentsTransfer.Approval>_approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final JsonField<RealTimePaymentsTransfer.Cancellation>_cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<RealTimePaymentsTransfer.CreatedBy>_createdBy()What object created the transfer, either via the API or the dashboard. final JsonField<String>_creditorName()The name of the transfer's recipient. final JsonField<RealTimePaymentsTransfer.Currency>_currency()The ISO 4217 code for the transfer's currency. final JsonField<String>_debtorName()The name of the transfer's sender. final JsonField<String>_destinationAccountNumber()The destination account number. final JsonField<String>_destinationRoutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<String>_externalAccountId()The identifier of the External Account the transfer was made to, if any. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_pendingTransactionId()The ID for the pending transaction representing the transfer. final JsonField<RealTimePaymentsTransfer.Rejection>_rejection()If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details. final JsonField<String>_remittanceInformation()Unstructured information that will show on the recipient's bank statement. final JsonField<String>_sourceAccountNumberId()The Account Number the recipient will see as having sent the transfer. final JsonField<RealTimePaymentsTransfer.Status>_status()The lifecycle status of the transfer. final JsonField<RealTimePaymentsTransfer.Submission>_submission()After the transfer is submitted to Real-Time Payments, this will contain supplemental details. final JsonField<String>_transactionId()The Transaction funding the transfer once it is complete. final JsonField<RealTimePaymentsTransfer.Type>_type()A constant representing the object's type. final JsonField<String>_ultimateCreditorName()The name of the ultimate recipient of the transfer. final JsonField<String>_ultimateDebtorName()The name of the ultimate sender of the transfer. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransfervalidate()final RealTimePaymentsTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransfer.Builderbuilder()-
-
Method Detail
-
acknowledgement
final Optional<RealTimePaymentsTransfer.Acknowledgement> acknowledgement()
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
approval
final Optional<RealTimePaymentsTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final Optional<RealTimePaymentsTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<RealTimePaymentsTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
creditorName
final String creditorName()
The name of the transfer's recipient. This is set by the sender when creating the transfer.
-
currency
final RealTimePaymentsTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.
-
debtorName
final Optional<String> debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
destinationAccountNumber
final String destinationAccountNumber()
The destination account number.
-
destinationRoutingNumber
final String destinationRoutingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
rejection
final Optional<RealTimePaymentsTransfer.Rejection> rejection()
If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
remittanceInformation
final String remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number the recipient will see as having sent the transfer.
-
status
final RealTimePaymentsTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<RealTimePaymentsTransfer.Submission> submission()
After the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
transactionId
final Optional<String> transactionId()
The Transaction funding the transfer once it is complete.
-
type
final RealTimePaymentsTransfer.Type type()
A constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
ultimateCreditorName
final Optional<String> ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final Optional<String> ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
_accountId
final JsonField<String> _accountId()
The Account from which the transfer was sent.
-
_acknowledgement
final JsonField<RealTimePaymentsTransfer.Acknowledgement> _acknowledgement()
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
_approval
final JsonField<RealTimePaymentsTransfer.Approval> _approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
_cancellation
final JsonField<RealTimePaymentsTransfer.Cancellation> _cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_createdBy
final JsonField<RealTimePaymentsTransfer.CreatedBy> _createdBy()
What object created the transfer, either via the API or the dashboard.
-
_creditorName
final JsonField<String> _creditorName()
The name of the transfer's recipient. This is set by the sender when creating the transfer.
-
_currency
final JsonField<RealTimePaymentsTransfer.Currency> _currency()
The ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.
-
_debtorName
final JsonField<String> _debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
_destinationAccountNumber
final JsonField<String> _destinationAccountNumber()
The destination account number.
-
_destinationRoutingNumber
final JsonField<String> _destinationRoutingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_externalAccountId
final JsonField<String> _externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
_rejection
final JsonField<RealTimePaymentsTransfer.Rejection> _rejection()
If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
The Account Number the recipient will see as having sent the transfer.
-
_status
final JsonField<RealTimePaymentsTransfer.Status> _status()
The lifecycle status of the transfer.
-
_submission
final JsonField<RealTimePaymentsTransfer.Submission> _submission()
After the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
_transactionId
final JsonField<String> _transactionId()
The Transaction funding the transfer once it is complete.
-
_type
final JsonField<RealTimePaymentsTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
_ultimateCreditorName
final JsonField<String> _ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
_ultimateDebtorName
final JsonField<String> _ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimePaymentsTransfer validate()
-
toBuilder
final RealTimePaymentsTransfer.Builder toBuilder()
-
builder
final static RealTimePaymentsTransfer.Builder builder()
-
-
-
-