Package com.increase.api.models
Class RealTimePaymentsTransfer.Approval
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.Approval.BuilderA builder for Approval.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeapprovedAt()The ISO 8601 date and time at which the transfer was approved. final Optional<String>approvedBy()If the Transfer was approved by a user in the dashboard, the email address of that user. final JsonField<OffsetDateTime>_approvedAt()The ISO 8601 date and time at which the transfer was approved. final JsonField<String>_approvedBy()If the Transfer was approved by a user in the dashboard, the email address of that user. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransfer.Approvalvalidate()final RealTimePaymentsTransfer.Approval.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransfer.Approval.Builderbuilder()-
-
Method Detail
-
approvedAt
final OffsetDateTime approvedAt()
The ISO 8601 date and time at which the transfer was approved.
-
approvedBy
final Optional<String> approvedBy()
If the Transfer was approved by a user in the dashboard, the email address of that user.
-
_approvedAt
final JsonField<OffsetDateTime> _approvedAt()
The ISO 8601 date and time at which the transfer was approved.
-
_approvedBy
final JsonField<String> _approvedBy()
If the Transfer was approved by a user in the dashboard, the email address of that user.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimePaymentsTransfer.Approval validate()
-
toBuilder
final RealTimePaymentsTransfer.Approval.Builder toBuilder()
-
builder
final static RealTimePaymentsTransfer.Approval.Builder builder()
-
-
-
-