Class RealTimePaymentsTransfer.Builder
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.BuilderA builder for RealTimePaymentsTransfer.
-
-
Method Summary
Modifier and Type Method Description final RealTimePaymentsTransfer.Builderid(String id)The Real-Time Payments Transfer's identifier. final RealTimePaymentsTransfer.Builderid(JsonField<String> id)The Real-Time Payments Transfer's identifier. final RealTimePaymentsTransfer.BuilderaccountId(String accountId)The Account from which the transfer was sent. final RealTimePaymentsTransfer.BuilderaccountId(JsonField<String> accountId)The Account from which the transfer was sent. final RealTimePaymentsTransfer.Builderacknowledgement(RealTimePaymentsTransfer.Acknowledgement acknowledgement)If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final RealTimePaymentsTransfer.Builderacknowledgement(Optional<RealTimePaymentsTransfer.Acknowledgement> acknowledgement)If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final RealTimePaymentsTransfer.Builderacknowledgement(JsonField<RealTimePaymentsTransfer.Acknowledgement> acknowledgement)If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final RealTimePaymentsTransfer.Builderamount(Long amount)The transfer amount in USD cents. final RealTimePaymentsTransfer.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final RealTimePaymentsTransfer.Builderapproval(RealTimePaymentsTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final RealTimePaymentsTransfer.Builderapproval(Optional<RealTimePaymentsTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final RealTimePaymentsTransfer.Builderapproval(JsonField<RealTimePaymentsTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final RealTimePaymentsTransfer.Buildercancellation(RealTimePaymentsTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final RealTimePaymentsTransfer.Buildercancellation(Optional<RealTimePaymentsTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final RealTimePaymentsTransfer.Buildercancellation(JsonField<RealTimePaymentsTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final RealTimePaymentsTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final RealTimePaymentsTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the transfer was created. final RealTimePaymentsTransfer.BuildercreatedBy(RealTimePaymentsTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final RealTimePaymentsTransfer.BuildercreatedBy(Optional<RealTimePaymentsTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final RealTimePaymentsTransfer.BuildercreatedBy(JsonField<RealTimePaymentsTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final RealTimePaymentsTransfer.BuildercreditorName(String creditorName)The name of the transfer's recipient. final RealTimePaymentsTransfer.BuildercreditorName(JsonField<String> creditorName)The name of the transfer's recipient. final RealTimePaymentsTransfer.Buildercurrency(RealTimePaymentsTransfer.Currency currency)The ISO 4217 code for the transfer's currency. final RealTimePaymentsTransfer.Buildercurrency(JsonField<RealTimePaymentsTransfer.Currency> currency)The ISO 4217 code for the transfer's currency. final RealTimePaymentsTransfer.BuilderdebtorName(String debtorName)The name of the transfer's sender. final RealTimePaymentsTransfer.BuilderdebtorName(Optional<String> debtorName)The name of the transfer's sender. final RealTimePaymentsTransfer.BuilderdebtorName(JsonField<String> debtorName)The name of the transfer's sender. final RealTimePaymentsTransfer.BuilderdestinationAccountNumber(String destinationAccountNumber)The destination account number. final RealTimePaymentsTransfer.BuilderdestinationAccountNumber(JsonField<String> destinationAccountNumber)The destination account number. final RealTimePaymentsTransfer.BuilderdestinationRoutingNumber(String destinationRoutingNumber)The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final RealTimePaymentsTransfer.BuilderdestinationRoutingNumber(JsonField<String> destinationRoutingNumber)The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final RealTimePaymentsTransfer.BuilderexternalAccountId(String externalAccountId)The identifier of the External Account the transfer was made to, if any. final RealTimePaymentsTransfer.BuilderexternalAccountId(Optional<String> externalAccountId)The identifier of the External Account the transfer was made to, if any. final RealTimePaymentsTransfer.BuilderexternalAccountId(JsonField<String> externalAccountId)The identifier of the External Account the transfer was made to, if any. final RealTimePaymentsTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final RealTimePaymentsTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final RealTimePaymentsTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final RealTimePaymentsTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final RealTimePaymentsTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final RealTimePaymentsTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final RealTimePaymentsTransfer.Builderrejection(RealTimePaymentsTransfer.Rejection rejection)If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details. final RealTimePaymentsTransfer.Builderrejection(Optional<RealTimePaymentsTransfer.Rejection> rejection)If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details. final RealTimePaymentsTransfer.Builderrejection(JsonField<RealTimePaymentsTransfer.Rejection> rejection)If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details. final RealTimePaymentsTransfer.BuilderremittanceInformation(String remittanceInformation)Unstructured information that will show on the recipient's bank statement. final RealTimePaymentsTransfer.BuilderremittanceInformation(JsonField<String> remittanceInformation)Unstructured information that will show on the recipient's bank statement. final RealTimePaymentsTransfer.BuildersourceAccountNumberId(String sourceAccountNumberId)The Account Number the recipient will see as having sent the transfer. final RealTimePaymentsTransfer.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)The Account Number the recipient will see as having sent the transfer. final RealTimePaymentsTransfer.Builderstatus(RealTimePaymentsTransfer.Status status)The lifecycle status of the transfer. final RealTimePaymentsTransfer.Builderstatus(JsonField<RealTimePaymentsTransfer.Status> status)The lifecycle status of the transfer. final RealTimePaymentsTransfer.Buildersubmission(RealTimePaymentsTransfer.Submission submission)After the transfer is submitted to Real-Time Payments, this will contain supplemental details. final RealTimePaymentsTransfer.Buildersubmission(Optional<RealTimePaymentsTransfer.Submission> submission)After the transfer is submitted to Real-Time Payments, this will contain supplemental details. final RealTimePaymentsTransfer.Buildersubmission(JsonField<RealTimePaymentsTransfer.Submission> submission)After the transfer is submitted to Real-Time Payments, this will contain supplemental details. final RealTimePaymentsTransfer.BuildertransactionId(String transactionId)The Transaction funding the transfer once it is complete. final RealTimePaymentsTransfer.BuildertransactionId(Optional<String> transactionId)The Transaction funding the transfer once it is complete. final RealTimePaymentsTransfer.BuildertransactionId(JsonField<String> transactionId)The Transaction funding the transfer once it is complete. final RealTimePaymentsTransfer.Buildertype(RealTimePaymentsTransfer.Type type)A constant representing the object's type. final RealTimePaymentsTransfer.Buildertype(JsonField<RealTimePaymentsTransfer.Type> type)A constant representing the object's type. final RealTimePaymentsTransfer.BuilderultimateCreditorName(String ultimateCreditorName)The name of the ultimate recipient of the transfer. final RealTimePaymentsTransfer.BuilderultimateCreditorName(Optional<String> ultimateCreditorName)The name of the ultimate recipient of the transfer. final RealTimePaymentsTransfer.BuilderultimateCreditorName(JsonField<String> ultimateCreditorName)The name of the ultimate recipient of the transfer. final RealTimePaymentsTransfer.BuilderultimateDebtorName(String ultimateDebtorName)The name of the ultimate sender of the transfer. final RealTimePaymentsTransfer.BuilderultimateDebtorName(Optional<String> ultimateDebtorName)The name of the ultimate sender of the transfer. final RealTimePaymentsTransfer.BuilderultimateDebtorName(JsonField<String> ultimateDebtorName)The name of the ultimate sender of the transfer. final RealTimePaymentsTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RealTimePaymentsTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final RealTimePaymentsTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RealTimePaymentsTransfer.BuilderremoveAdditionalProperty(String key)final RealTimePaymentsTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final RealTimePaymentsTransferbuild()-
-
Method Detail
-
id
final RealTimePaymentsTransfer.Builder id(String id)
The Real-Time Payments Transfer's identifier.
-
id
final RealTimePaymentsTransfer.Builder id(JsonField<String> id)
The Real-Time Payments Transfer's identifier.
-
accountId
final RealTimePaymentsTransfer.Builder accountId(String accountId)
The Account from which the transfer was sent.
-
accountId
final RealTimePaymentsTransfer.Builder accountId(JsonField<String> accountId)
The Account from which the transfer was sent.
-
acknowledgement
final RealTimePaymentsTransfer.Builder acknowledgement(RealTimePaymentsTransfer.Acknowledgement acknowledgement)
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
acknowledgement
final RealTimePaymentsTransfer.Builder acknowledgement(Optional<RealTimePaymentsTransfer.Acknowledgement> acknowledgement)
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
acknowledgement
final RealTimePaymentsTransfer.Builder acknowledgement(JsonField<RealTimePaymentsTransfer.Acknowledgement> acknowledgement)
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
amount
final RealTimePaymentsTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final RealTimePaymentsTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
approval
final RealTimePaymentsTransfer.Builder approval(RealTimePaymentsTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final RealTimePaymentsTransfer.Builder approval(Optional<RealTimePaymentsTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final RealTimePaymentsTransfer.Builder approval(JsonField<RealTimePaymentsTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final RealTimePaymentsTransfer.Builder cancellation(RealTimePaymentsTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final RealTimePaymentsTransfer.Builder cancellation(Optional<RealTimePaymentsTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final RealTimePaymentsTransfer.Builder cancellation(JsonField<RealTimePaymentsTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final RealTimePaymentsTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final RealTimePaymentsTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final RealTimePaymentsTransfer.Builder createdBy(RealTimePaymentsTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final RealTimePaymentsTransfer.Builder createdBy(Optional<RealTimePaymentsTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final RealTimePaymentsTransfer.Builder createdBy(JsonField<RealTimePaymentsTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
creditorName
final RealTimePaymentsTransfer.Builder creditorName(String creditorName)
The name of the transfer's recipient. This is set by the sender when creating the transfer.
-
creditorName
final RealTimePaymentsTransfer.Builder creditorName(JsonField<String> creditorName)
The name of the transfer's recipient. This is set by the sender when creating the transfer.
-
currency
final RealTimePaymentsTransfer.Builder currency(RealTimePaymentsTransfer.Currency currency)
The ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.
-
currency
final RealTimePaymentsTransfer.Builder currency(JsonField<RealTimePaymentsTransfer.Currency> currency)
The ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.
-
debtorName
final RealTimePaymentsTransfer.Builder debtorName(String debtorName)
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
debtorName
final RealTimePaymentsTransfer.Builder debtorName(Optional<String> debtorName)
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
debtorName
final RealTimePaymentsTransfer.Builder debtorName(JsonField<String> debtorName)
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
destinationAccountNumber
final RealTimePaymentsTransfer.Builder destinationAccountNumber(String destinationAccountNumber)
The destination account number.
-
destinationAccountNumber
final RealTimePaymentsTransfer.Builder destinationAccountNumber(JsonField<String> destinationAccountNumber)
The destination account number.
-
destinationRoutingNumber
final RealTimePaymentsTransfer.Builder destinationRoutingNumber(String destinationRoutingNumber)
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
destinationRoutingNumber
final RealTimePaymentsTransfer.Builder destinationRoutingNumber(JsonField<String> destinationRoutingNumber)
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
externalAccountId
final RealTimePaymentsTransfer.Builder externalAccountId(String externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final RealTimePaymentsTransfer.Builder externalAccountId(Optional<String> externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final RealTimePaymentsTransfer.Builder externalAccountId(JsonField<String> externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final RealTimePaymentsTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final RealTimePaymentsTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final RealTimePaymentsTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
pendingTransactionId
final RealTimePaymentsTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final RealTimePaymentsTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final RealTimePaymentsTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
rejection
final RealTimePaymentsTransfer.Builder rejection(RealTimePaymentsTransfer.Rejection rejection)
If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
rejection
final RealTimePaymentsTransfer.Builder rejection(Optional<RealTimePaymentsTransfer.Rejection> rejection)
If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
rejection
final RealTimePaymentsTransfer.Builder rejection(JsonField<RealTimePaymentsTransfer.Rejection> rejection)
If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
remittanceInformation
final RealTimePaymentsTransfer.Builder remittanceInformation(String remittanceInformation)
Unstructured information that will show on the recipient's bank statement.
-
remittanceInformation
final RealTimePaymentsTransfer.Builder remittanceInformation(JsonField<String> remittanceInformation)
Unstructured information that will show on the recipient's bank statement.
-
sourceAccountNumberId
final RealTimePaymentsTransfer.Builder sourceAccountNumberId(String sourceAccountNumberId)
The Account Number the recipient will see as having sent the transfer.
-
sourceAccountNumberId
final RealTimePaymentsTransfer.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
The Account Number the recipient will see as having sent the transfer.
-
status
final RealTimePaymentsTransfer.Builder status(RealTimePaymentsTransfer.Status status)
The lifecycle status of the transfer.
-
status
final RealTimePaymentsTransfer.Builder status(JsonField<RealTimePaymentsTransfer.Status> status)
The lifecycle status of the transfer.
-
submission
final RealTimePaymentsTransfer.Builder submission(RealTimePaymentsTransfer.Submission submission)
After the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
submission
final RealTimePaymentsTransfer.Builder submission(Optional<RealTimePaymentsTransfer.Submission> submission)
After the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
submission
final RealTimePaymentsTransfer.Builder submission(JsonField<RealTimePaymentsTransfer.Submission> submission)
After the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
transactionId
final RealTimePaymentsTransfer.Builder transactionId(String transactionId)
The Transaction funding the transfer once it is complete.
-
transactionId
final RealTimePaymentsTransfer.Builder transactionId(Optional<String> transactionId)
The Transaction funding the transfer once it is complete.
-
transactionId
final RealTimePaymentsTransfer.Builder transactionId(JsonField<String> transactionId)
The Transaction funding the transfer once it is complete.
-
type
final RealTimePaymentsTransfer.Builder type(RealTimePaymentsTransfer.Type type)
A constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
type
final RealTimePaymentsTransfer.Builder type(JsonField<RealTimePaymentsTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
ultimateCreditorName
final RealTimePaymentsTransfer.Builder ultimateCreditorName(String ultimateCreditorName)
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateCreditorName
final RealTimePaymentsTransfer.Builder ultimateCreditorName(Optional<String> ultimateCreditorName)
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateCreditorName
final RealTimePaymentsTransfer.Builder ultimateCreditorName(JsonField<String> ultimateCreditorName)
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final RealTimePaymentsTransfer.Builder ultimateDebtorName(String ultimateDebtorName)
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
ultimateDebtorName
final RealTimePaymentsTransfer.Builder ultimateDebtorName(Optional<String> ultimateDebtorName)
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
ultimateDebtorName
final RealTimePaymentsTransfer.Builder ultimateDebtorName(JsonField<String> ultimateDebtorName)
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
additionalProperties
final RealTimePaymentsTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimePaymentsTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimePaymentsTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimePaymentsTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimePaymentsTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimePaymentsTransfer build()
-
-
-
-