Package com.increase.api.models
Class RealTimePaymentsTransfer.Cancellation
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.Cancellation.BuilderA builder for Cancellation.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecanceledAt()The ISO 8601 date and time at which the Transfer was canceled. final Optional<String>canceledBy()If the Transfer was canceled by a user in the dashboard, the email address of that user. final JsonField<OffsetDateTime>_canceledAt()The ISO 8601 date and time at which the Transfer was canceled. final JsonField<String>_canceledBy()If the Transfer was canceled by a user in the dashboard, the email address of that user. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransfer.Cancellationvalidate()final RealTimePaymentsTransfer.Cancellation.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransfer.Cancellation.Builderbuilder()-
-
Method Detail
-
canceledAt
final OffsetDateTime canceledAt()
The ISO 8601 date and time at which the Transfer was canceled.
-
canceledBy
final Optional<String> canceledBy()
If the Transfer was canceled by a user in the dashboard, the email address of that user.
-
_canceledAt
final JsonField<OffsetDateTime> _canceledAt()
The ISO 8601 date and time at which the Transfer was canceled.
-
_canceledBy
final JsonField<String> _canceledBy()
If the Transfer was canceled by a user in the dashboard, the email address of that user.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimePaymentsTransfer.Cancellation validate()
-
toBuilder
final RealTimePaymentsTransfer.Cancellation.Builder toBuilder()
-
builder
final static RealTimePaymentsTransfer.Cancellation.Builder builder()
-
-
-
-