Class RealTimePaymentsTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classRealTimePaymentsTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classRealTimePaymentsTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classRealTimePaymentsTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classRealTimePaymentsTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
-
-
Method Detail
-
apiKey
final Optional<RealTimePaymentsTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
category
final RealTimePaymentsTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
oauthApplication
final Optional<RealTimePaymentsTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<RealTimePaymentsTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_apiKey
final JsonField<RealTimePaymentsTransfer.CreatedBy.ApiKey> _apiKey()
If present, details about the API key that created the transfer.
-
_category
final JsonField<RealTimePaymentsTransfer.CreatedBy.Category> _category()
The type of object that created this transfer.
-
_oauthApplication
final JsonField<RealTimePaymentsTransfer.CreatedBy.OAuthApplication> _oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
_user
final JsonField<RealTimePaymentsTransfer.CreatedBy.User> _user()
If present, details about the User that created the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimePaymentsTransfer.CreatedBy validate()
-
toBuilder
final RealTimePaymentsTransfer.CreatedBy.Builder toBuilder()
-
builder
final static RealTimePaymentsTransfer.CreatedBy.Builder builder()
-
-
-
-