Package com.increase.api.models
Class RealTimePaymentsTransfer.CreatedBy.Builder
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.CreatedBy.BuilderA builder for CreatedBy.
-
-
Method Summary
-
-
Method Detail
-
apiKey
final RealTimePaymentsTransfer.CreatedBy.Builder apiKey(RealTimePaymentsTransfer.CreatedBy.ApiKey apiKey)
If present, details about the API key that created the transfer.
-
apiKey
final RealTimePaymentsTransfer.CreatedBy.Builder apiKey(Optional<RealTimePaymentsTransfer.CreatedBy.ApiKey> apiKey)
If present, details about the API key that created the transfer.
-
apiKey
final RealTimePaymentsTransfer.CreatedBy.Builder apiKey(JsonField<RealTimePaymentsTransfer.CreatedBy.ApiKey> apiKey)
If present, details about the API key that created the transfer.
-
category
final RealTimePaymentsTransfer.CreatedBy.Builder category(RealTimePaymentsTransfer.CreatedBy.Category category)
The type of object that created this transfer.
-
category
final RealTimePaymentsTransfer.CreatedBy.Builder category(JsonField<RealTimePaymentsTransfer.CreatedBy.Category> category)
The type of object that created this transfer.
-
oauthApplication
final RealTimePaymentsTransfer.CreatedBy.Builder oauthApplication(RealTimePaymentsTransfer.CreatedBy.OAuthApplication oauthApplication)
If present, details about the OAuth Application that created the transfer.
-
oauthApplication
final RealTimePaymentsTransfer.CreatedBy.Builder oauthApplication(Optional<RealTimePaymentsTransfer.CreatedBy.OAuthApplication> oauthApplication)
If present, details about the OAuth Application that created the transfer.
-
oauthApplication
final RealTimePaymentsTransfer.CreatedBy.Builder oauthApplication(JsonField<RealTimePaymentsTransfer.CreatedBy.OAuthApplication> oauthApplication)
If present, details about the OAuth Application that created the transfer.
-
user
final RealTimePaymentsTransfer.CreatedBy.Builder user(RealTimePaymentsTransfer.CreatedBy.User user)
If present, details about the User that created the transfer.
-
user
final RealTimePaymentsTransfer.CreatedBy.Builder user(Optional<RealTimePaymentsTransfer.CreatedBy.User> user)
If present, details about the User that created the transfer.
-
user
final RealTimePaymentsTransfer.CreatedBy.Builder user(JsonField<RealTimePaymentsTransfer.CreatedBy.User> user)
If present, details about the User that created the transfer.
-
additionalProperties
final RealTimePaymentsTransfer.CreatedBy.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimePaymentsTransfer.CreatedBy.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimePaymentsTransfer.CreatedBy.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimePaymentsTransfer.CreatedBy.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimePaymentsTransfer.CreatedBy.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimePaymentsTransfer.CreatedBy build()
-
-
-
-