Class RealTimePaymentsTransfer.Rejection
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.RejectionIf the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.Rejection.BuilderA builder for Rejection.
public final classRealTimePaymentsTransfer.Rejection.RejectReasonCodeThe reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network.
-
Method Summary
Modifier and Type Method Description final Optional<String>rejectReasonAdditionalInformation()Additional information about the rejection provided by the recipient bank when the reject_reason_codeisNARRATIVE.final RealTimePaymentsTransfer.Rejection.RejectReasonCoderejectReasonCode()The reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network. final Optional<OffsetDateTime>rejectedAt()The ISO 8601 date and time at which the transfer was rejected. final JsonField<String>_rejectReasonAdditionalInformation()Additional information about the rejection provided by the recipient bank when the reject_reason_codeisNARRATIVE.final JsonField<RealTimePaymentsTransfer.Rejection.RejectReasonCode>_rejectReasonCode()The reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network. final JsonField<OffsetDateTime>_rejectedAt()The ISO 8601 date and time at which the transfer was rejected. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransfer.Rejectionvalidate()final RealTimePaymentsTransfer.Rejection.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransfer.Rejection.Builderbuilder()-
-
Method Detail
-
rejectReasonAdditionalInformation
final Optional<String> rejectReasonAdditionalInformation()
Additional information about the rejection provided by the recipient bank when the
reject_reason_codeisNARRATIVE.
-
rejectReasonCode
final RealTimePaymentsTransfer.Rejection.RejectReasonCode rejectReasonCode()
The reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network.
-
rejectedAt
final Optional<OffsetDateTime> rejectedAt()
The ISO 8601 date and time at which the transfer was rejected.
-
_rejectReasonAdditionalInformation
final JsonField<String> _rejectReasonAdditionalInformation()
Additional information about the rejection provided by the recipient bank when the
reject_reason_codeisNARRATIVE.
-
_rejectReasonCode
final JsonField<RealTimePaymentsTransfer.Rejection.RejectReasonCode> _rejectReasonCode()
The reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
The ISO 8601 date and time at which the transfer was rejected.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimePaymentsTransfer.Rejection validate()
-
toBuilder
final RealTimePaymentsTransfer.Rejection.Builder toBuilder()
-
builder
final static RealTimePaymentsTransfer.Rejection.Builder builder()
-
-
-
-