Enum RealTimePaymentsTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum RealTimePaymentsTransfer.Status.Known extends Enum<RealTimePaymentsTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<RealTimePaymentsTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_APPROVALThe transfer is pending approval.
CANCELEDThe transfer has been canceled.
PENDING_REVIEWINGThe transfer is pending review by Increase.
REQUIRES_ATTENTIONThe transfer requires attention from an Increase operator.
REJECTEDThe transfer was rejected by the network or the recipient's bank.
PENDING_SUBMISSIONThe transfer is queued to be submitted to Real-Time Payments.
SUBMITTEDThe transfer has been submitted and is pending a response from Real-Time Payments.
COMPLETEThe transfer has been sent successfully and is complete.
-
Method Summary
Modifier and Type Method Description final RealTimePaymentsTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<RealTimePaymentsTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<RealTimePaymentsTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final RealTimePaymentsTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<RealTimePaymentsTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<RealTimePaymentsTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-