Package com.increase.api.models
Class RealTimePaymentsTransfer.Submission
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.SubmissionAfter the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.Submission.BuilderA builder for Submission.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>submittedAt()The ISO 8601 date and time at which the transfer was submitted to The Clearing House. final StringtransactionIdentification()The Real-Time Payments network identification of the transfer. final JsonField<OffsetDateTime>_submittedAt()The ISO 8601 date and time at which the transfer was submitted to The Clearing House. final JsonField<String>_transactionIdentification()The Real-Time Payments network identification of the transfer. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransfer.Submissionvalidate()final RealTimePaymentsTransfer.Submission.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransfer.Submission.Builderbuilder()-
-
Method Detail
-
submittedAt
final Optional<OffsetDateTime> submittedAt()
The ISO 8601 date and time at which the transfer was submitted to The Clearing House.
-
transactionIdentification
final String transactionIdentification()
The Real-Time Payments network identification of the transfer.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
The ISO 8601 date and time at which the transfer was submitted to The Clearing House.
-
_transactionIdentification
final JsonField<String> _transactionIdentification()
The Real-Time Payments network identification of the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final RealTimePaymentsTransfer.Submission validate()
-
toBuilder
final RealTimePaymentsTransfer.Submission.Builder toBuilder()
-
builder
final static RealTimePaymentsTransfer.Submission.Builder builder()
-
-
-
-