Class RealTimePaymentsTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class RealTimePaymentsTransferCreateParams implements Params
Create a Real-Time Payments Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferCreateParams.Bodypublic final classRealTimePaymentsTransferCreateParams.BuilderA builder for RealTimePaymentsTransferCreateParams.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringcreditorName()The name of the transfer's recipient. final StringremittanceInformation()Unstructured information that will show on the recipient's bank statement. final StringsourceAccountNumberId()The identifier of the Account Number from which to send the transfer. final Optional<String>debtorName()The name of the transfer's sender. final Optional<String>destinationAccountNumber()The destination account number. final Optional<String>destinationRoutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>ultimateCreditorName()The name of the ultimate recipient of the transfer. final Optional<String>ultimateDebtorName()The name of the ultimate sender of the transfer. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<String>_creditorName()The name of the transfer's recipient. final JsonField<String>_remittanceInformation()Unstructured information that will show on the recipient's bank statement. final JsonField<String>_sourceAccountNumberId()The identifier of the Account Number from which to send the transfer. final JsonField<String>_debtorName()The name of the transfer's sender. final JsonField<String>_destinationAccountNumber()The destination account number. final JsonField<String>_destinationRoutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<String>_externalAccountId()The ID of an External Account to initiate a transfer to. final JsonField<Boolean>_requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<String>_ultimateCreditorName()The name of the ultimate recipient of the transfer. final JsonField<String>_ultimateDebtorName()The name of the ultimate sender of the transfer. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final RealTimePaymentsTransferCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransferCreateParams.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
-
creditorName
final String creditorName()
The name of the transfer's recipient.
-
remittanceInformation
final String remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer.
-
debtorName
final Optional<String> debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
destinationAccountNumber
final Optional<String> destinationAccountNumber()
The destination account number.
-
destinationRoutingNumber
final Optional<String> destinationRoutingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
destination_account_numberanddestination_routing_numbermust be absent.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
ultimateCreditorName
final Optional<String> ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final Optional<String> ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
_amount
final JsonField<Long> _amount()
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
-
_creditorName
final JsonField<String> _creditorName()
The name of the transfer's recipient.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer.
-
_debtorName
final JsonField<String> _debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
_destinationAccountNumber
final JsonField<String> _destinationAccountNumber()
The destination account number.
-
_destinationRoutingNumber
final JsonField<String> _destinationRoutingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_externalAccountId
final JsonField<String> _externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
destination_account_numberanddestination_routing_numbermust be absent.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_ultimateCreditorName
final JsonField<String> _ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
_ultimateDebtorName
final JsonField<String> _ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final RealTimePaymentsTransferCreateParams.Builder toBuilder()
-
builder
final static RealTimePaymentsTransferCreateParams.Builder builder()
-
-
-
-