Class RealTimePaymentsTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final RealTimePaymentsTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
-
amount
final RealTimePaymentsTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
-
creditorName
final RealTimePaymentsTransferCreateParams.Body.Builder creditorName(String creditorName)
The name of the transfer's recipient.
-
creditorName
final RealTimePaymentsTransferCreateParams.Body.Builder creditorName(JsonField<String> creditorName)
The name of the transfer's recipient.
-
remittanceInformation
final RealTimePaymentsTransferCreateParams.Body.Builder remittanceInformation(String remittanceInformation)
Unstructured information that will show on the recipient's bank statement.
-
remittanceInformation
final RealTimePaymentsTransferCreateParams.Body.Builder remittanceInformation(JsonField<String> remittanceInformation)
Unstructured information that will show on the recipient's bank statement.
-
sourceAccountNumberId
final RealTimePaymentsTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer.
-
sourceAccountNumberId
final RealTimePaymentsTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer.
-
debtorName
final RealTimePaymentsTransferCreateParams.Body.Builder debtorName(String debtorName)
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
debtorName
final RealTimePaymentsTransferCreateParams.Body.Builder debtorName(JsonField<String> debtorName)
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
destinationAccountNumber
final RealTimePaymentsTransferCreateParams.Body.Builder destinationAccountNumber(String destinationAccountNumber)
The destination account number.
-
destinationAccountNumber
final RealTimePaymentsTransferCreateParams.Body.Builder destinationAccountNumber(JsonField<String> destinationAccountNumber)
The destination account number.
-
destinationRoutingNumber
final RealTimePaymentsTransferCreateParams.Body.Builder destinationRoutingNumber(String destinationRoutingNumber)
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
destinationRoutingNumber
final RealTimePaymentsTransferCreateParams.Body.Builder destinationRoutingNumber(JsonField<String> destinationRoutingNumber)
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
externalAccountId
final RealTimePaymentsTransferCreateParams.Body.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
destination_account_numberanddestination_routing_numbermust be absent.
-
externalAccountId
final RealTimePaymentsTransferCreateParams.Body.Builder externalAccountId(JsonField<String> externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
destination_account_numberanddestination_routing_numbermust be absent.
-
requireApproval
final RealTimePaymentsTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final RealTimePaymentsTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
ultimateCreditorName
final RealTimePaymentsTransferCreateParams.Body.Builder ultimateCreditorName(String ultimateCreditorName)
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateCreditorName
final RealTimePaymentsTransferCreateParams.Body.Builder ultimateCreditorName(JsonField<String> ultimateCreditorName)
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final RealTimePaymentsTransferCreateParams.Body.Builder ultimateDebtorName(String ultimateDebtorName)
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
ultimateDebtorName
final RealTimePaymentsTransferCreateParams.Body.Builder ultimateDebtorName(JsonField<String> ultimateDebtorName)
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
additionalProperties
final RealTimePaymentsTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimePaymentsTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimePaymentsTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimePaymentsTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimePaymentsTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimePaymentsTransferCreateParams.Body build()
-
-
-
-