Class SimulationAccountTransferCompleteParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationAccountTransferCompleteParams
     implements Params
                        

    If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a status of pending_approval.