Class SimulationAchTransferAcknowledgeParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationAchTransferAcknowledgeParams
     implements Params
                        

    Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a status of submitted . In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.