Package com.increase.api.models
Class SimulationAchTransferCreateNotificationOfChangeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationAchTransferCreateNotificationOfChangeParams implements Params
Simulates receiving a Notification of Change for an #ach-transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationAchTransferCreateNotificationOfChangeParams.Bodypublic final classSimulationAchTransferCreateNotificationOfChangeParams.BuilderA builder for SimulationAchTransferCreateNotificationOfChangeParams.
public final classSimulationAchTransferCreateNotificationOfChangeParams.ChangeCodeThe reason for the notification of change.
-
Method Summary
Modifier and Type Method Description final StringachTransferId()The identifier of the ACH Transfer you wish to create a notification of change for. final SimulationAchTransferCreateNotificationOfChangeParams.ChangeCodechangeCode()The reason for the notification of change. final StringcorrectedData()The corrected data for the notification of change (e.g., a new routing number). final JsonField<SimulationAchTransferCreateNotificationOfChangeParams.ChangeCode>_changeCode()The reason for the notification of change. final JsonField<String>_correctedData()The corrected data for the notification of change (e.g., a new routing number). final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationAchTransferCreateNotificationOfChangeParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationAchTransferCreateNotificationOfChangeParams.Builderbuilder()-
-
Method Detail
-
achTransferId
final String achTransferId()
The identifier of the ACH Transfer you wish to create a notification of change for.
-
changeCode
final SimulationAchTransferCreateNotificationOfChangeParams.ChangeCode changeCode()
The reason for the notification of change.
-
correctedData
final String correctedData()
The corrected data for the notification of change (e.g., a new routing number).
-
_changeCode
final JsonField<SimulationAchTransferCreateNotificationOfChangeParams.ChangeCode> _changeCode()
The reason for the notification of change.
-
_correctedData
final JsonField<String> _correctedData()
The corrected data for the notification of change (e.g., a new routing number).
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationAchTransferCreateNotificationOfChangeParams.Builder toBuilder()
-
builder
final static SimulationAchTransferCreateNotificationOfChangeParams.Builder builder()
-
-
-
-