Package com.increase.api.models
Class SimulationAchTransferCreateNotificationOfChangeParams.Body
-
- All Implemented Interfaces:
public final class SimulationAchTransferCreateNotificationOfChangeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationAchTransferCreateNotificationOfChangeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final SimulationAchTransferCreateNotificationOfChangeParams.ChangeCodechangeCode()The reason for the notification of change. final StringcorrectedData()The corrected data for the notification of change (e.g., a new routing number). final JsonField<SimulationAchTransferCreateNotificationOfChangeParams.ChangeCode>_changeCode()The reason for the notification of change. final JsonField<String>_correctedData()The corrected data for the notification of change (e.g., a new routing number). final Map<String, JsonValue>_additionalProperties()final SimulationAchTransferCreateNotificationOfChangeParams.Bodyvalidate()final SimulationAchTransferCreateNotificationOfChangeParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationAchTransferCreateNotificationOfChangeParams.Body.Builderbuilder()-
-
Method Detail
-
changeCode
final SimulationAchTransferCreateNotificationOfChangeParams.ChangeCode changeCode()
The reason for the notification of change.
-
correctedData
final String correctedData()
The corrected data for the notification of change (e.g., a new routing number).
-
_changeCode
final JsonField<SimulationAchTransferCreateNotificationOfChangeParams.ChangeCode> _changeCode()
The reason for the notification of change.
-
_correctedData
final JsonField<String> _correctedData()
The corrected data for the notification of change (e.g., a new routing number).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationAchTransferCreateNotificationOfChangeParams.Body validate()
-
toBuilder
final SimulationAchTransferCreateNotificationOfChangeParams.Body.Builder toBuilder()
-
builder
final static SimulationAchTransferCreateNotificationOfChangeParams.Body.Builder builder()
-
-
-
-