Class SimulationAchTransferReturnParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationAchTransferReturnParams
     implements Params
                        

    Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a status of submitted.