Class SimulationAchTransferSettleParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationAchTransferSettleParams
     implements Params
                        

    Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a status of submitted. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.