Class SimulationAchTransferSubmitParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationAchTransferSubmitParams
     implements Params
                        

    Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a status of pending_approval or pending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status of submitted.