Class SimulationCardAuthorizationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationCardAuthorizationCreateParams implements Params
Simulates a purchase authorization on a #cards. Depending on the balance available to the card and the
amountsubmitted, the authorization activity will result in a #pending-transactions of typecard_authorizationor a #declined-transactions of typecard_decline. You can pass either a Card id or a #digital-wallet-tokens id to simulate the two different ways purchases can be made.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardAuthorizationCreateParams.Bodypublic final classSimulationCardAuthorizationCreateParams.BuilderA builder for SimulationCardAuthorizationCreateParams.
public final classSimulationCardAuthorizationCreateParams.DeclineReasonForces a card decline with a specific reason. No real time decision will be sent.
public final classSimulationCardAuthorizationCreateParams.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classSimulationCardAuthorizationCreateParams.NetworkDetailsFields specific to a given card network.
-
Method Summary
Modifier and Type Method Description final Longamount()The authorization amount in cents. final Optional<String>authenticatedCardPaymentId()The identifier of a Card Payment with a card_authenticationif you want to simulate an authenticated authorization.final Optional<String>cardId()The identifier of the Card to be authorized. final Optional<SimulationCardAuthorizationCreateParams.DeclineReason>declineReason()Forces a card decline with a specific reason. final Optional<String>digitalWalletTokenId()The identifier of the Digital Wallet Token to be authorized. final Optional<SimulationCardAuthorizationCreateParams.Direction>direction()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final Optional<String>eventSubscriptionId()The identifier of the Event Subscription to use. final Optional<String>merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final Optional<String>merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final Optional<String>merchantCountry()The country the merchant resides in. final Optional<String>merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantState()The state the merchant resides in. final Optional<SimulationCardAuthorizationCreateParams.NetworkDetails>networkDetails()Fields specific to a given card network. final Optional<String>physicalCardId()The identifier of the Physical Card to be authorized. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<Long>_amount()The authorization amount in cents. final JsonField<String>_authenticatedCardPaymentId()The identifier of a Card Payment with a card_authenticationif you want to simulate an authenticated authorization.final JsonField<String>_cardId()The identifier of the Card to be authorized. final JsonField<SimulationCardAuthorizationCreateParams.DeclineReason>_declineReason()Forces a card decline with a specific reason. final JsonField<String>_digitalWalletTokenId()The identifier of the Digital Wallet Token to be authorized. final JsonField<SimulationCardAuthorizationCreateParams.Direction>_direction()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final JsonField<String>_eventSubscriptionId()The identifier of the Event Subscription to use. final JsonField<String>_merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final JsonField<String>_merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final JsonField<String>_merchantCity()The city the merchant resides in. final JsonField<String>_merchantCountry()The country the merchant resides in. final JsonField<String>_merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final JsonField<String>_merchantState()The state the merchant resides in. final JsonField<SimulationCardAuthorizationCreateParams.NetworkDetails>_networkDetails()Fields specific to a given card network. final JsonField<String>_physicalCardId()The identifier of the Physical Card to be authorized. final JsonField<String>_terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationCardAuthorizationCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardAuthorizationCreateParams.Builderbuilder()-
-
Method Detail
-
authenticatedCardPaymentId
final Optional<String> authenticatedCardPaymentId()
The identifier of a Card Payment with a
card_authenticationif you want to simulate an authenticated authorization.
-
declineReason
final Optional<SimulationCardAuthorizationCreateParams.DeclineReason> declineReason()
Forces a card decline with a specific reason. No real time decision will be sent.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
The identifier of the Digital Wallet Token to be authorized.
-
direction
final Optional<SimulationCardAuthorizationCreateParams.Direction> direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Optional<String> merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final Optional<String> merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final Optional<SimulationCardAuthorizationCreateParams.NetworkDetails> networkDetails()
Fields specific to a given card network.
-
physicalCardId
final Optional<String> physicalCardId()
The identifier of the Physical Card to be authorized.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_authenticatedCardPaymentId
final JsonField<String> _authenticatedCardPaymentId()
The identifier of a Card Payment with a
card_authenticationif you want to simulate an authenticated authorization.
-
_declineReason
final JsonField<SimulationCardAuthorizationCreateParams.DeclineReason> _declineReason()
Forces a card decline with a specific reason. No real time decision will be sent.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
The identifier of the Digital Wallet Token to be authorized.
-
_direction
final JsonField<SimulationCardAuthorizationCreateParams.Direction> _direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
_eventSubscriptionId
final JsonField<String> _eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
_merchantCity
final JsonField<String> _merchantCity()
The city the merchant resides in.
-
_merchantCountry
final JsonField<String> _merchantCountry()
The country the merchant resides in.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
_merchantState
final JsonField<String> _merchantState()
The state the merchant resides in.
-
_networkDetails
final JsonField<SimulationCardAuthorizationCreateParams.NetworkDetails> _networkDetails()
Fields specific to a given card network.
-
_physicalCardId
final JsonField<String> _physicalCardId()
The identifier of the Physical Card to be authorized.
-
_terminalId
final JsonField<String> _terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationCardAuthorizationCreateParams.Builder toBuilder()
-
builder
final static SimulationCardAuthorizationCreateParams.Builder builder()
-
-
-
-