Class SimulationCardAuthorizationCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SimulationCardAuthorizationCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final SimulationCardAuthorizationCreateParams.Body.Builder amount(Long amount)
The authorization amount in cents.
-
amount
final SimulationCardAuthorizationCreateParams.Body.Builder amount(JsonField<Long> amount)
The authorization amount in cents.
-
authenticatedCardPaymentId
final SimulationCardAuthorizationCreateParams.Body.Builder authenticatedCardPaymentId(String authenticatedCardPaymentId)
The identifier of a Card Payment with a
card_authenticationif you want to simulate an authenticated authorization.
-
authenticatedCardPaymentId
final SimulationCardAuthorizationCreateParams.Body.Builder authenticatedCardPaymentId(JsonField<String> authenticatedCardPaymentId)
The identifier of a Card Payment with a
card_authenticationif you want to simulate an authenticated authorization.
-
cardId
final SimulationCardAuthorizationCreateParams.Body.Builder cardId(String cardId)
The identifier of the Card to be authorized.
-
cardId
final SimulationCardAuthorizationCreateParams.Body.Builder cardId(JsonField<String> cardId)
The identifier of the Card to be authorized.
-
declineReason
final SimulationCardAuthorizationCreateParams.Body.Builder declineReason(SimulationCardAuthorizationCreateParams.DeclineReason declineReason)
Forces a card decline with a specific reason. No real time decision will be sent.
-
declineReason
final SimulationCardAuthorizationCreateParams.Body.Builder declineReason(JsonField<SimulationCardAuthorizationCreateParams.DeclineReason> declineReason)
Forces a card decline with a specific reason. No real time decision will be sent.
-
digitalWalletTokenId
final SimulationCardAuthorizationCreateParams.Body.Builder digitalWalletTokenId(String digitalWalletTokenId)
The identifier of the Digital Wallet Token to be authorized.
-
digitalWalletTokenId
final SimulationCardAuthorizationCreateParams.Body.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
The identifier of the Digital Wallet Token to be authorized.
-
direction
final SimulationCardAuthorizationCreateParams.Body.Builder direction(SimulationCardAuthorizationCreateParams.Direction direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
direction
final SimulationCardAuthorizationCreateParams.Body.Builder direction(JsonField<SimulationCardAuthorizationCreateParams.Direction> direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
eventSubscriptionId
final SimulationCardAuthorizationCreateParams.Body.Builder eventSubscriptionId(String eventSubscriptionId)
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
eventSubscriptionId
final SimulationCardAuthorizationCreateParams.Body.Builder eventSubscriptionId(JsonField<String> eventSubscriptionId)
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
merchantAcceptorId
final SimulationCardAuthorizationCreateParams.Body.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final SimulationCardAuthorizationCreateParams.Body.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final SimulationCardAuthorizationCreateParams.Body.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final SimulationCardAuthorizationCreateParams.Body.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final SimulationCardAuthorizationCreateParams.Body.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final SimulationCardAuthorizationCreateParams.Body.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final SimulationCardAuthorizationCreateParams.Body.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final SimulationCardAuthorizationCreateParams.Body.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantDescriptor
final SimulationCardAuthorizationCreateParams.Body.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final SimulationCardAuthorizationCreateParams.Body.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantState
final SimulationCardAuthorizationCreateParams.Body.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final SimulationCardAuthorizationCreateParams.Body.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkDetails
final SimulationCardAuthorizationCreateParams.Body.Builder networkDetails(SimulationCardAuthorizationCreateParams.NetworkDetails networkDetails)
Fields specific to a given card network.
-
networkDetails
final SimulationCardAuthorizationCreateParams.Body.Builder networkDetails(JsonField<SimulationCardAuthorizationCreateParams.NetworkDetails> networkDetails)
Fields specific to a given card network.
-
physicalCardId
final SimulationCardAuthorizationCreateParams.Body.Builder physicalCardId(String physicalCardId)
The identifier of the Physical Card to be authorized.
-
physicalCardId
final SimulationCardAuthorizationCreateParams.Body.Builder physicalCardId(JsonField<String> physicalCardId)
The identifier of the Physical Card to be authorized.
-
terminalId
final SimulationCardAuthorizationCreateParams.Body.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final SimulationCardAuthorizationCreateParams.Body.Builder terminalId(JsonField<String> terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
additionalProperties
final SimulationCardAuthorizationCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationCardAuthorizationCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationCardAuthorizationCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationCardAuthorizationCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationCardAuthorizationCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SimulationCardAuthorizationCreateParams.Body build()
-
-
-
-