Class SimulationCardAuthorizationCreateResponse
-
- All Implemented Interfaces:
public final class SimulationCardAuthorizationCreateResponseThe results of a Card Authorization simulation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardAuthorizationCreateResponse.BuilderA builder for SimulationCardAuthorizationCreateResponse.
public final classSimulationCardAuthorizationCreateResponse.TypeA constant representing the object's type. For this resource it will always be
inbound_card_authorization_simulation_result.
-
Method Summary
Modifier and Type Method Description final Optional<DeclinedTransaction>declinedTransaction()If the authorization attempt fails, this will contain the resulting #declined-transactions object. final Optional<PendingTransaction>pendingTransaction()If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. final SimulationCardAuthorizationCreateResponse.Typetype()A constant representing the object's type. final JsonField<DeclinedTransaction>_declinedTransaction()If the authorization attempt fails, this will contain the resulting #declined-transactions object. final JsonField<PendingTransaction>_pendingTransaction()If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. final JsonField<SimulationCardAuthorizationCreateResponse.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final SimulationCardAuthorizationCreateResponsevalidate()final SimulationCardAuthorizationCreateResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardAuthorizationCreateResponse.Builderbuilder()-
-
Method Detail
-
declinedTransaction
final Optional<DeclinedTransaction> declinedTransaction()
If the authorization attempt fails, this will contain the resulting #declined-transactions object. The Declined Transaction's
sourcewill be ofcategory: card_decline.
-
pendingTransaction
final Optional<PendingTransaction> pendingTransaction()
If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. The Pending Transaction's
sourcewill be ofcategory: card_authorization.
-
type
final SimulationCardAuthorizationCreateResponse.Type type()
A constant representing the object's type. For this resource it will always be
inbound_card_authorization_simulation_result.
-
_declinedTransaction
final JsonField<DeclinedTransaction> _declinedTransaction()
If the authorization attempt fails, this will contain the resulting #declined-transactions object. The Declined Transaction's
sourcewill be ofcategory: card_decline.
-
_pendingTransaction
final JsonField<PendingTransaction> _pendingTransaction()
If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. The Pending Transaction's
sourcewill be ofcategory: card_authorization.
-
_type
final JsonField<SimulationCardAuthorizationCreateResponse.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_card_authorization_simulation_result.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationCardAuthorizationCreateResponse validate()
-
toBuilder
final SimulationCardAuthorizationCreateResponse.Builder toBuilder()
-
builder
final static SimulationCardAuthorizationCreateResponse.Builder builder()
-
-
-
-