Class SimulationCardFuelConfirmationCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationCardFuelConfirmationCreateParams
     implements Params
                        

    Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.