Class SimulationCardIncrementCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationCardIncrementCreateParams implements Params
Simulates the increment of an authorization by a card acquirer. An authorization can be incremented multiple times.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardIncrementCreateParams.Bodypublic final classSimulationCardIncrementCreateParams.BuilderA builder for SimulationCardIncrementCreateParams.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the increment in minor units in the card authorization's currency. final StringcardPaymentId()The identifier of the Card Payment to create a increment on. final Optional<String>eventSubscriptionId()The identifier of the Event Subscription to use. final JsonField<Long>_amount()The amount of the increment in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()The identifier of the Card Payment to create a increment on. final JsonField<String>_eventSubscriptionId()The identifier of the Event Subscription to use. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationCardIncrementCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardIncrementCreateParams.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount of the increment in minor units in the card authorization's currency.
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a increment on.
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_amount
final JsonField<Long> _amount()
The amount of the increment in minor units in the card authorization's currency.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The identifier of the Card Payment to create a increment on.
-
_eventSubscriptionId
final JsonField<String> _eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationCardIncrementCreateParams.Builder toBuilder()
-
builder
final static SimulationCardIncrementCreateParams.Builder builder()
-
-
-
-