Class SimulationCardIncrementCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationCardIncrementCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardIncrementCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the increment in minor units in the card authorization's currency. final StringcardPaymentId()The identifier of the Card Payment to create a increment on. final Optional<String>eventSubscriptionId()The identifier of the Event Subscription to use. final JsonField<Long>_amount()The amount of the increment in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()The identifier of the Card Payment to create a increment on. final JsonField<String>_eventSubscriptionId()The identifier of the Event Subscription to use. final Map<String, JsonValue>_additionalProperties()final SimulationCardIncrementCreateParams.Bodyvalidate()final SimulationCardIncrementCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardIncrementCreateParams.Body.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount of the increment in minor units in the card authorization's currency.
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a increment on.
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_amount
final JsonField<Long> _amount()
The amount of the increment in minor units in the card authorization's currency.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The identifier of the Card Payment to create a increment on.
-
_eventSubscriptionId
final JsonField<String> _eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationCardIncrementCreateParams.Body validate()
-
toBuilder
final SimulationCardIncrementCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationCardIncrementCreateParams.Body.Builder builder()
-
-
-
-