Class SimulationCardReversalCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationCardReversalCreateParams
     implements Params
                        

    Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.