Package com.increase.api.models
Class SimulationCardReversalCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationCardReversalCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardReversalCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardPaymentId()The identifier of the Card Payment to create a reversal on. final Optional<Long>amount()The amount of the reversal in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()The identifier of the Card Payment to create a reversal on. final JsonField<Long>_amount()The amount of the reversal in minor units in the card authorization's currency. final Map<String, JsonValue>_additionalProperties()final SimulationCardReversalCreateParams.Bodyvalidate()final SimulationCardReversalCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardReversalCreateParams.Body.Builderbuilder()-
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a reversal on.
-
amount
final Optional<Long> amount()
The amount of the reversal in minor units in the card authorization's currency. This defaults to the authorization amount.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The identifier of the Card Payment to create a reversal on.
-
_amount
final JsonField<Long> _amount()
The amount of the reversal in minor units in the card authorization's currency. This defaults to the authorization amount.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationCardReversalCreateParams.Body validate()
-
toBuilder
final SimulationCardReversalCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationCardReversalCreateParams.Body.Builder builder()
-
-
-
-