Class SimulationCardSettlementCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationCardSettlementCreateParams implements Params
Simulates the settlement of an authorization by a card acquirer. After a card authorization is created, the merchant will eventually send a settlement. This simulates that event, which may occur many days after the purchase in production. The amount settled can be different from the amount originally authorized, for example, when adding a tip to a restaurant bill.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardSettlementCreateParams.Bodypublic final classSimulationCardSettlementCreateParams.BuilderA builder for SimulationCardSettlementCreateParams.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to create a settlement on. final StringpendingTransactionId()The identifier of the Pending Transaction for the Card Authorization you wish to settle. final Optional<Long>amount()The amount to be settled. final JsonField<String>_cardId()The identifier of the Card to create a settlement on. final JsonField<String>_pendingTransactionId()The identifier of the Pending Transaction for the Card Authorization you wish to settle. final JsonField<Long>_amount()The amount to be settled. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationCardSettlementCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardSettlementCreateParams.Builderbuilder()-
-
Method Detail
-
pendingTransactionId
final String pendingTransactionId()
The identifier of the Pending Transaction for the Card Authorization you wish to settle.
-
amount
final Optional<Long> amount()
The amount to be settled. This defaults to the amount of the Pending Transaction being settled.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The identifier of the Pending Transaction for the Card Authorization you wish to settle.
-
_amount
final JsonField<Long> _amount()
The amount to be settled. This defaults to the amount of the Pending Transaction being settled.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationCardSettlementCreateParams.Builder toBuilder()
-
builder
final static SimulationCardSettlementCreateParams.Builder builder()
-
-
-
-