Package com.increase.api.models
Class SimulationCardSettlementCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationCardSettlementCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardSettlementCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to create a settlement on. final StringpendingTransactionId()The identifier of the Pending Transaction for the Card Authorization you wish to settle. final Optional<Long>amount()The amount to be settled. final JsonField<String>_cardId()The identifier of the Card to create a settlement on. final JsonField<String>_pendingTransactionId()The identifier of the Pending Transaction for the Card Authorization you wish to settle. final JsonField<Long>_amount()The amount to be settled. final Map<String, JsonValue>_additionalProperties()final SimulationCardSettlementCreateParams.Bodyvalidate()final SimulationCardSettlementCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardSettlementCreateParams.Body.Builderbuilder()-
-
Method Detail
-
pendingTransactionId
final String pendingTransactionId()
The identifier of the Pending Transaction for the Card Authorization you wish to settle.
-
amount
final Optional<Long> amount()
The amount to be settled. This defaults to the amount of the Pending Transaction being settled.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The identifier of the Pending Transaction for the Card Authorization you wish to settle.
-
_amount
final JsonField<Long> _amount()
The amount to be settled. This defaults to the amount of the Pending Transaction being settled.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationCardSettlementCreateParams.Body validate()
-
toBuilder
final SimulationCardSettlementCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationCardSettlementCreateParams.Body.Builder builder()
-
-
-
-