Package com.increase.api.models
Class SimulationDigitalWalletTokenRequestCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationDigitalWalletTokenRequestCreateParams implements Params
Simulates a user attempting add a #cards to a digital wallet such as Apple Pay.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationDigitalWalletTokenRequestCreateParams.Bodypublic final classSimulationDigitalWalletTokenRequestCreateParams.BuilderA builder for SimulationDigitalWalletTokenRequestCreateParams.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to be authorized. final JsonField<String>_cardId()The identifier of the Card to be authorized. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationDigitalWalletTokenRequestCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationDigitalWalletTokenRequestCreateParams.Builderbuilder()-
-
Method Detail
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationDigitalWalletTokenRequestCreateParams.Builder toBuilder()
-
builder
final static SimulationDigitalWalletTokenRequestCreateParams.Builder builder()
-
-
-
-