Class SimulationDigitalWalletTokenRequestCreateResponse
-
- All Implemented Interfaces:
public final class SimulationDigitalWalletTokenRequestCreateResponseThe results of a Digital Wallet Token simulation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationDigitalWalletTokenRequestCreateResponse.BuilderA builder for SimulationDigitalWalletTokenRequestCreateResponse.
public final classSimulationDigitalWalletTokenRequestCreateResponse.DeclineReasonIf the simulated tokenization attempt was declined, this field contains details as to why.
public final classSimulationDigitalWalletTokenRequestCreateResponse.TypeA constant representing the object's type. For this resource it will always be
inbound_digital_wallet_token_request_simulation_result.
-
Method Summary
Modifier and Type Method Description final Optional<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason>declineReason()If the simulated tokenization attempt was declined, this field contains details as to why. final Optional<String>digitalWalletTokenId()If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created. final SimulationDigitalWalletTokenRequestCreateResponse.Typetype()A constant representing the object's type. final JsonField<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason>_declineReason()If the simulated tokenization attempt was declined, this field contains details as to why. final JsonField<String>_digitalWalletTokenId()If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created. final JsonField<SimulationDigitalWalletTokenRequestCreateResponse.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final SimulationDigitalWalletTokenRequestCreateResponsevalidate()final SimulationDigitalWalletTokenRequestCreateResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationDigitalWalletTokenRequestCreateResponse.Builderbuilder()-
-
Method Detail
-
declineReason
final Optional<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason> declineReason()
If the simulated tokenization attempt was declined, this field contains details as to why.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created.
-
type
final SimulationDigitalWalletTokenRequestCreateResponse.Type type()
A constant representing the object's type. For this resource it will always be
inbound_digital_wallet_token_request_simulation_result.
-
_declineReason
final JsonField<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason> _declineReason()
If the simulated tokenization attempt was declined, this field contains details as to why.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created.
-
_type
final JsonField<SimulationDigitalWalletTokenRequestCreateResponse.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_digital_wallet_token_request_simulation_result.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationDigitalWalletTokenRequestCreateResponse validate()
-
toBuilder
final SimulationDigitalWalletTokenRequestCreateResponse.Builder toBuilder()
-
builder
final static SimulationDigitalWalletTokenRequestCreateResponse.Builder builder()
-
-
-
-