Package com.increase.api.models
Enum SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known extends Enum<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known>
An enum containing DeclineReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARD_NOT_ACTIVEThe card is not active.
NO_VERIFICATION_METHODThe card does not have a two-factor authentication method.
WEBHOOK_TIMED_OUTYour webhook timed out when evaluating the token provisioning attempt.
WEBHOOK_DECLINEDYour webhook declined the token provisioning attempt.
-
Method Summary
Modifier and Type Method Description final SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known>getEntries()An enum containing DeclineReason's known values. -
-
Method Detail
-
valueOf
final SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Known> getEntries()
An enum containing DeclineReason's known values.
-
-
-
-