Enum SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value extends Enum<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value>
An enum containing DeclineReason's known values, as well as an _UNKNOWN member.
An instance of DeclineReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARD_NOT_ACTIVEThe card is not active.
NO_VERIFICATION_METHODThe card does not have a two-factor authentication method.
WEBHOOK_TIMED_OUTYour webhook timed out when evaluating the token provisioning attempt.
WEBHOOK_DECLINEDYour webhook declined the token provisioning attempt.
_UNKNOWNAn enum member indicating that DeclineReason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value>getEntries()An enum containing DeclineReason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<SimulationDigitalWalletTokenRequestCreateResponse.DeclineReason.Value> getEntries()
An enum containing DeclineReason's known values, as well as an _UNKNOWN member.
An instance of DeclineReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-