Package com.increase.api.models
Class SimulationDocumentCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationDocumentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationDocumentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the tax document is for. final JsonField<String>_accountId()The identifier of the Account the tax document is for. final Map<String, JsonValue>_additionalProperties()final SimulationDocumentCreateParams.Bodyvalidate()final SimulationDocumentCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationDocumentCreateParams.Body.Builderbuilder()-
-
Method Detail
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account the tax document is for.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationDocumentCreateParams.Body validate()
-
toBuilder
final SimulationDocumentCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationDocumentCreateParams.Body.Builder builder()
-
-
-
-