Class SimulationInboundAchTransferCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationInboundAchTransferCreateParams
     implements Params
                        

    Simulates an inbound ACH transfer to your account. This imitates initiating a transfer to an Increase account from a different financial institution. The transfer may be either a credit or a debit depending on if the amount is positive or negative. The result of calling this API will contain the created transfer. You can pass a resolve_at parameter to allow for a window to action on the Inbound ACH Transfer. Alternatively, if you don't pass the resolve_at parameter the result will contain either a #transactions or a #declined-transactions depending on whether or not the transfer is allowed.