Class SimulationInboundAchTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationInboundAchTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundAchTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the inbound ACH Transfer is for. final Longamount()The transfer amount in cents. final Optional<String>companyDescriptiveDate()The description of the date of the transfer. final Optional<String>companyDiscretionaryData()Data associated with the transfer set by the sender. final Optional<String>companyEntryDescription()The description of the transfer set by the sender. final Optional<String>companyId()The sender's company ID. final Optional<String>companyName()The name of the sender. final Optional<String>receiverIdNumber()The ID of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final Optional<OffsetDateTime>resolveAt()The time at which the transfer should be resolved. final Optional<SimulationInboundAchTransferCreateParams.StandardEntryClassCode>standardEntryClassCode()The standard entry class code for the transfer. final JsonField<String>_accountNumberId()The identifier of the Account Number the inbound ACH Transfer is for. final JsonField<Long>_amount()The transfer amount in cents. final JsonField<String>_companyDescriptiveDate()The description of the date of the transfer. final JsonField<String>_companyDiscretionaryData()Data associated with the transfer set by the sender. final JsonField<String>_companyEntryDescription()The description of the transfer set by the sender. final JsonField<String>_companyId()The sender's company ID. final JsonField<String>_companyName()The name of the sender. final JsonField<String>_receiverIdNumber()The ID of the receiver of the transfer. final JsonField<String>_receiverName()The name of the receiver of the transfer. final JsonField<OffsetDateTime>_resolveAt()The time at which the transfer should be resolved. final JsonField<SimulationInboundAchTransferCreateParams.StandardEntryClassCode>_standardEntryClassCode()The standard entry class code for the transfer. final Map<String, JsonValue>_additionalProperties()final SimulationInboundAchTransferCreateParams.Bodyvalidate()final SimulationInboundAchTransferCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundAchTransferCreateParams.Body.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the inbound ACH Transfer is for.
-
amount
final Long amount()
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
Data associated with the transfer set by the sender.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the transfer set by the sender.
-
companyName
final Optional<String> companyName()
The name of the sender.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The ID of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
resolveAt
final Optional<OffsetDateTime> resolveAt()
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
standardEntryClassCode
final Optional<SimulationInboundAchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode()
The standard entry class code for the transfer.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number the inbound ACH Transfer is for.
-
_amount
final JsonField<Long> _amount()
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
The description of the date of the transfer.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Data associated with the transfer set by the sender.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
The description of the transfer set by the sender.
-
_companyId
final JsonField<String> _companyId()
The sender's company ID.
-
_companyName
final JsonField<String> _companyName()
The name of the sender.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
The ID of the receiver of the transfer.
-
_receiverName
final JsonField<String> _receiverName()
The name of the receiver of the transfer.
-
_resolveAt
final JsonField<OffsetDateTime> _resolveAt()
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
_standardEntryClassCode
final JsonField<SimulationInboundAchTransferCreateParams.StandardEntryClassCode> _standardEntryClassCode()
The standard entry class code for the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationInboundAchTransferCreateParams.Body validate()
-
toBuilder
final SimulationInboundAchTransferCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationInboundAchTransferCreateParams.Body.Builder builder()
-
-
-
-