Class SimulationInboundAchTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SimulationInboundAchTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final SimulationInboundAchTransferCreateParams.Body.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number the inbound ACH Transfer is for.
-
accountNumberId
final SimulationInboundAchTransferCreateParams.Body.Builder accountNumberId(JsonField<String> accountNumberId)
The identifier of the Account Number the inbound ACH Transfer is for.
-
amount
final SimulationInboundAchTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
amount
final SimulationInboundAchTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
companyDescriptiveDate
final SimulationInboundAchTransferCreateParams.Body.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the transfer.
-
companyDescriptiveDate
final SimulationInboundAchTransferCreateParams.Body.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
The description of the date of the transfer.
-
companyDiscretionaryData
final SimulationInboundAchTransferCreateParams.Body.Builder companyDiscretionaryData(String companyDiscretionaryData)
Data associated with the transfer set by the sender.
-
companyDiscretionaryData
final SimulationInboundAchTransferCreateParams.Body.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
Data associated with the transfer set by the sender.
-
companyEntryDescription
final SimulationInboundAchTransferCreateParams.Body.Builder companyEntryDescription(String companyEntryDescription)
The description of the transfer set by the sender.
-
companyEntryDescription
final SimulationInboundAchTransferCreateParams.Body.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
The description of the transfer set by the sender.
-
companyId
final SimulationInboundAchTransferCreateParams.Body.Builder companyId(String companyId)
The sender's company ID.
-
companyId
final SimulationInboundAchTransferCreateParams.Body.Builder companyId(JsonField<String> companyId)
The sender's company ID.
-
companyName
final SimulationInboundAchTransferCreateParams.Body.Builder companyName(String companyName)
The name of the sender.
-
companyName
final SimulationInboundAchTransferCreateParams.Body.Builder companyName(JsonField<String> companyName)
The name of the sender.
-
receiverIdNumber
final SimulationInboundAchTransferCreateParams.Body.Builder receiverIdNumber(String receiverIdNumber)
The ID of the receiver of the transfer.
-
receiverIdNumber
final SimulationInboundAchTransferCreateParams.Body.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
The ID of the receiver of the transfer.
-
receiverName
final SimulationInboundAchTransferCreateParams.Body.Builder receiverName(String receiverName)
The name of the receiver of the transfer.
-
receiverName
final SimulationInboundAchTransferCreateParams.Body.Builder receiverName(JsonField<String> receiverName)
The name of the receiver of the transfer.
-
resolveAt
final SimulationInboundAchTransferCreateParams.Body.Builder resolveAt(OffsetDateTime resolveAt)
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
resolveAt
final SimulationInboundAchTransferCreateParams.Body.Builder resolveAt(JsonField<OffsetDateTime> resolveAt)
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
standardEntryClassCode
final SimulationInboundAchTransferCreateParams.Body.Builder standardEntryClassCode(SimulationInboundAchTransferCreateParams.StandardEntryClassCode standardEntryClassCode)
The standard entry class code for the transfer.
-
standardEntryClassCode
final SimulationInboundAchTransferCreateParams.Body.Builder standardEntryClassCode(JsonField<SimulationInboundAchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode)
The standard entry class code for the transfer.
-
additionalProperties
final SimulationInboundAchTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationInboundAchTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationInboundAchTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationInboundAchTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationInboundAchTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SimulationInboundAchTransferCreateParams.Body build()
-
-
-
-