Package com.increase.api.models
Class SimulationInboundCheckDepositCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationInboundCheckDepositCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundCheckDepositCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the Inbound Check Deposit will be against. final Longamount()The check amount in cents. final StringcheckNumber()The check number on the check to be deposited. final JsonField<String>_accountNumberId()The identifier of the Account Number the Inbound Check Deposit will be against. final JsonField<Long>_amount()The check amount in cents. final JsonField<String>_checkNumber()The check number on the check to be deposited. final Map<String, JsonValue>_additionalProperties()final SimulationInboundCheckDepositCreateParams.Bodyvalidate()final SimulationInboundCheckDepositCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundCheckDepositCreateParams.Body.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the Inbound Check Deposit will be against.
-
checkNumber
final String checkNumber()
The check number on the check to be deposited.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number the Inbound Check Deposit will be against.
-
_checkNumber
final JsonField<String> _checkNumber()
The check number on the check to be deposited.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationInboundCheckDepositCreateParams.Body validate()
-
toBuilder
final SimulationInboundCheckDepositCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationInboundCheckDepositCreateParams.Body.Builder builder()
-
-
-
-