Class SimulationInboundFundsHoldReleaseParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationInboundFundsHoldReleaseParams
     implements Params
                        

    This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.