Class SimulationInboundFundsHoldReleaseResponse
-
- All Implemented Interfaces:
public final class SimulationInboundFundsHoldReleaseResponseWe hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundFundsHoldReleaseResponse.BuilderA builder for SimulationInboundFundsHoldReleaseResponse.
public final classSimulationInboundFundsHoldReleaseResponse.CurrencyThe ISO 4217 code for the hold's currency.
public final classSimulationInboundFundsHoldReleaseResponse.StatusThe status of the hold.
public final classSimulationInboundFundsHoldReleaseResponse.TypeA constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
Method Summary
Modifier and Type Method Description final Stringid()The Inbound Funds Hold identifier. final Longamount()The held amount in the minor unit of the account's currency. final OffsetDateTimeautomaticallyReleasesAt()When the hold will be released automatically. final OffsetDateTimecreatedAt()The ISO 8601 time at which the hold was created. final SimulationInboundFundsHoldReleaseResponse.Currencycurrency()The ISO 4217 code for the hold's currency. final Optional<String>heldTransactionId()The ID of the Transaction for which funds were held. final Optional<String>pendingTransactionId()The ID of the Pending Transaction representing the held funds. final Optional<OffsetDateTime>releasedAt()When the hold was released (if it has been released). final SimulationInboundFundsHoldReleaseResponse.Statusstatus()The status of the hold. final SimulationInboundFundsHoldReleaseResponse.Typetype()A constant representing the object's type. final JsonField<String>_id()The Inbound Funds Hold identifier. final JsonField<Long>_amount()The held amount in the minor unit of the account's currency. final JsonField<OffsetDateTime>_automaticallyReleasesAt()When the hold will be released automatically. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 time at which the hold was created. final JsonField<SimulationInboundFundsHoldReleaseResponse.Currency>_currency()The ISO 4217 code for the hold's currency. final JsonField<String>_heldTransactionId()The ID of the Transaction for which funds were held. final JsonField<String>_pendingTransactionId()The ID of the Pending Transaction representing the held funds. final JsonField<OffsetDateTime>_releasedAt()When the hold was released (if it has been released). final JsonField<SimulationInboundFundsHoldReleaseResponse.Status>_status()The status of the hold. final JsonField<SimulationInboundFundsHoldReleaseResponse.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final SimulationInboundFundsHoldReleaseResponsevalidate()final SimulationInboundFundsHoldReleaseResponse.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundFundsHoldReleaseResponse.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final OffsetDateTime automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the hold was created.
-
currency
final SimulationInboundFundsHoldReleaseResponse.Currency currency()
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final Optional<String> heldTransactionId()
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final Optional<OffsetDateTime> releasedAt()
When the hold was released (if it has been released).
-
status
final SimulationInboundFundsHoldReleaseResponse.Status status()
The status of the hold.
-
type
final SimulationInboundFundsHoldReleaseResponse.Type type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_amount
final JsonField<Long> _amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
_automaticallyReleasesAt
final JsonField<OffsetDateTime> _automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 time at which the hold was created.
-
_currency
final JsonField<SimulationInboundFundsHoldReleaseResponse.Currency> _currency()
The ISO 4217 code for the hold's currency.
-
_heldTransactionId
final JsonField<String> _heldTransactionId()
The ID of the Transaction for which funds were held.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
_releasedAt
final JsonField<OffsetDateTime> _releasedAt()
When the hold was released (if it has been released).
-
_status
final JsonField<SimulationInboundFundsHoldReleaseResponse.Status> _status()
The status of the hold.
-
_type
final JsonField<SimulationInboundFundsHoldReleaseResponse.Type> _type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationInboundFundsHoldReleaseResponse validate()
-
toBuilder
final SimulationInboundFundsHoldReleaseResponse.Builder toBuilder()
-
builder
final static SimulationInboundFundsHoldReleaseResponse.Builder builder()
-
-
-
-