Class SimulationInboundFundsHoldReleaseResponse.Builder
-
- All Implemented Interfaces:
public final class SimulationInboundFundsHoldReleaseResponse.BuilderA builder for SimulationInboundFundsHoldReleaseResponse.
-
-
Method Summary
-
-
Method Detail
-
id
final SimulationInboundFundsHoldReleaseResponse.Builder id(String id)
The Inbound Funds Hold identifier.
-
id
final SimulationInboundFundsHoldReleaseResponse.Builder id(JsonField<String> id)
The Inbound Funds Hold identifier.
-
amount
final SimulationInboundFundsHoldReleaseResponse.Builder amount(Long amount)
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
amount
final SimulationInboundFundsHoldReleaseResponse.Builder amount(JsonField<Long> amount)
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final SimulationInboundFundsHoldReleaseResponse.Builder automaticallyReleasesAt(OffsetDateTime automaticallyReleasesAt)
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
automaticallyReleasesAt
final SimulationInboundFundsHoldReleaseResponse.Builder automaticallyReleasesAt(JsonField<OffsetDateTime> automaticallyReleasesAt)
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final SimulationInboundFundsHoldReleaseResponse.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the hold was created.
-
createdAt
final SimulationInboundFundsHoldReleaseResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 time at which the hold was created.
-
currency
final SimulationInboundFundsHoldReleaseResponse.Builder currency(SimulationInboundFundsHoldReleaseResponse.Currency currency)
The ISO 4217 code for the hold's currency.
-
currency
final SimulationInboundFundsHoldReleaseResponse.Builder currency(JsonField<SimulationInboundFundsHoldReleaseResponse.Currency> currency)
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final SimulationInboundFundsHoldReleaseResponse.Builder heldTransactionId(String heldTransactionId)
The ID of the Transaction for which funds were held.
-
heldTransactionId
final SimulationInboundFundsHoldReleaseResponse.Builder heldTransactionId(Optional<String> heldTransactionId)
The ID of the Transaction for which funds were held.
-
heldTransactionId
final SimulationInboundFundsHoldReleaseResponse.Builder heldTransactionId(JsonField<String> heldTransactionId)
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final SimulationInboundFundsHoldReleaseResponse.Builder pendingTransactionId(String pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
pendingTransactionId
final SimulationInboundFundsHoldReleaseResponse.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
pendingTransactionId
final SimulationInboundFundsHoldReleaseResponse.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final SimulationInboundFundsHoldReleaseResponse.Builder releasedAt(OffsetDateTime releasedAt)
When the hold was released (if it has been released).
-
releasedAt
final SimulationInboundFundsHoldReleaseResponse.Builder releasedAt(Optional<OffsetDateTime> releasedAt)
When the hold was released (if it has been released).
-
releasedAt
final SimulationInboundFundsHoldReleaseResponse.Builder releasedAt(JsonField<OffsetDateTime> releasedAt)
When the hold was released (if it has been released).
-
status
final SimulationInboundFundsHoldReleaseResponse.Builder status(SimulationInboundFundsHoldReleaseResponse.Status status)
The status of the hold.
-
status
final SimulationInboundFundsHoldReleaseResponse.Builder status(JsonField<SimulationInboundFundsHoldReleaseResponse.Status> status)
The status of the hold.
-
type
final SimulationInboundFundsHoldReleaseResponse.Builder type(SimulationInboundFundsHoldReleaseResponse.Type type)
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
type
final SimulationInboundFundsHoldReleaseResponse.Builder type(JsonField<SimulationInboundFundsHoldReleaseResponse.Type> type)
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
additionalProperties
final SimulationInboundFundsHoldReleaseResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationInboundFundsHoldReleaseResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationInboundFundsHoldReleaseResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationInboundFundsHoldReleaseResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationInboundFundsHoldReleaseResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SimulationInboundFundsHoldReleaseResponse build()
-
-
-
-