Package com.increase.api.models
Class SimulationInboundMailItemCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationInboundMailItemCreateParams implements Params
Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundMailItemCreateParams.Bodypublic final classSimulationInboundMailItemCreateParams.BuilderA builder for SimulationInboundMailItemCreateParams.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the check to be simulated, in cents. final StringlockboxId()The identifier of the Lockbox to simulate inbound mail to. final Optional<String>contentsFileId()The file containing the PDF contents. final JsonField<Long>_amount()The amount of the check to be simulated, in cents. final JsonField<String>_lockboxId()The identifier of the Lockbox to simulate inbound mail to. final JsonField<String>_contentsFileId()The file containing the PDF contents. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationInboundMailItemCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundMailItemCreateParams.Builderbuilder()-
-
Method Detail
-
contentsFileId
final Optional<String> contentsFileId()
The file containing the PDF contents. If not present, a default check image file will be used.
-
_lockboxId
final JsonField<String> _lockboxId()
The identifier of the Lockbox to simulate inbound mail to.
-
_contentsFileId
final JsonField<String> _contentsFileId()
The file containing the PDF contents. If not present, a default check image file will be used.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationInboundMailItemCreateParams.Builder toBuilder()
-
builder
final static SimulationInboundMailItemCreateParams.Builder builder()
-
-
-
-