Package com.increase.api.models
Class SimulationInboundMailItemCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationInboundMailItemCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundMailItemCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the check to be simulated, in cents. final StringlockboxId()The identifier of the Lockbox to simulate inbound mail to. final Optional<String>contentsFileId()The file containing the PDF contents. final JsonField<Long>_amount()The amount of the check to be simulated, in cents. final JsonField<String>_lockboxId()The identifier of the Lockbox to simulate inbound mail to. final JsonField<String>_contentsFileId()The file containing the PDF contents. final Map<String, JsonValue>_additionalProperties()final SimulationInboundMailItemCreateParams.Bodyvalidate()final SimulationInboundMailItemCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundMailItemCreateParams.Body.Builderbuilder()-
-
Method Detail
-
contentsFileId
final Optional<String> contentsFileId()
The file containing the PDF contents. If not present, a default check image file will be used.
-
_lockboxId
final JsonField<String> _lockboxId()
The identifier of the Lockbox to simulate inbound mail to.
-
_contentsFileId
final JsonField<String> _contentsFileId()
The file containing the PDF contents. If not present, a default check image file will be used.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationInboundMailItemCreateParams.Body validate()
-
toBuilder
final SimulationInboundMailItemCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationInboundMailItemCreateParams.Body.Builder builder()
-
-
-
-