Class SimulationInboundWireDrawdownRequestCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SimulationInboundWireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder amount(JsonField<Long> amount)
The amount being requested in cents.
-
beneficiaryAccountNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAccountNumber(String beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryAccountNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAccountNumber(JsonField<String> beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryRoutingNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryRoutingNumber(String beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
beneficiaryRoutingNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryRoutingNumber(JsonField<String> beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
currency
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder currency(JsonField<String> currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
messageToRecipient
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder messageToRecipient(String messageToRecipient)
A message from the drawdown request's originator.
-
messageToRecipient
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder messageToRecipient(JsonField<String> messageToRecipient)
A message from the drawdown request's originator.
-
originatorAccountNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAccountNumber(String originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorAccountNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAccountNumber(JsonField<String> originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorRoutingNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorRoutingNumber(String originatorRoutingNumber)
The drawdown request's originator's routing number.
-
originatorRoutingNumber
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
The drawdown request's originator's routing number.
-
recipientAccountNumberId
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number to which the recipient of this request is being requested to send funds from.
-
recipientAccountNumberId
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
The Account Number to which the recipient of this request is being requested to send funds from.
-
beneficiaryAddressLine1
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine1
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryName
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryName(String beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryName
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryName(JsonField<String> beneficiaryName)
The drawdown request's beneficiary's name.
-
originatorAddressLine1
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine1
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine2
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine2
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine3
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorAddressLine3
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorName
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorName(String originatorName)
The drawdown request's originator's name.
-
originatorName
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
The drawdown request's originator's name.
-
originatorToBeneficiaryInformationLine1
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine1
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
additionalProperties
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationInboundWireDrawdownRequestCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SimulationInboundWireDrawdownRequestCreateParams.Body build()
-
-
-
-