Class SimulationInboundWireTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationInboundWireTransferCreateParams implements Params
Simulates an #inbound-wire-transfers to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundWireTransferCreateParams.Bodypublic final classSimulationInboundWireTransferCreateParams.BuilderA builder for SimulationInboundWireTransferCreateParams.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the inbound Wire Transfer is for. final Longamount()The transfer amount in cents. final Optional<String>beneficiaryAddressLine1()The sending bank will set beneficiary_address_line1 in production. final Optional<String>beneficiaryAddressLine2()The sending bank will set beneficiary_address_line2 in production. final Optional<String>beneficiaryAddressLine3()The sending bank will set beneficiary_address_line3 in production. final Optional<String>beneficiaryName()The sending bank will set beneficiary_name in production. final Optional<String>beneficiaryReference()The sending bank will set beneficiary_reference in production. final Optional<String>originatorAddressLine1()The sending bank will set originator_address_line1 in production. final Optional<String>originatorAddressLine2()The sending bank will set originator_address_line2 in production. final Optional<String>originatorAddressLine3()The sending bank will set originator_address_line3 in production. final Optional<String>originatorName()The sending bank will set originator_name in production. final Optional<String>originatorRoutingNumber()The sending bank will set originator_routing_number in production. final Optional<String>originatorToBeneficiaryInformationLine1()The sending bank will set originator_to_beneficiary_information_line1 in production. final Optional<String>originatorToBeneficiaryInformationLine2()The sending bank will set originator_to_beneficiary_information_line2 in production. final Optional<String>originatorToBeneficiaryInformationLine3()The sending bank will set originator_to_beneficiary_information_line3 in production. final Optional<String>originatorToBeneficiaryInformationLine4()The sending bank will set originator_to_beneficiary_information_line4 in production. final Optional<String>senderReference()The sending bank will set sender_reference in production. final JsonField<String>_accountNumberId()The identifier of the Account Number the inbound Wire Transfer is for. final JsonField<Long>_amount()The transfer amount in cents. final JsonField<String>_beneficiaryAddressLine1()The sending bank will set beneficiary_address_line1 in production. final JsonField<String>_beneficiaryAddressLine2()The sending bank will set beneficiary_address_line2 in production. final JsonField<String>_beneficiaryAddressLine3()The sending bank will set beneficiary_address_line3 in production. final JsonField<String>_beneficiaryName()The sending bank will set beneficiary_name in production. final JsonField<String>_beneficiaryReference()The sending bank will set beneficiary_reference in production. final JsonField<String>_originatorAddressLine1()The sending bank will set originator_address_line1 in production. final JsonField<String>_originatorAddressLine2()The sending bank will set originator_address_line2 in production. final JsonField<String>_originatorAddressLine3()The sending bank will set originator_address_line3 in production. final JsonField<String>_originatorName()The sending bank will set originator_name in production. final JsonField<String>_originatorRoutingNumber()The sending bank will set originator_routing_number in production. final JsonField<String>_originatorToBeneficiaryInformationLine1()The sending bank will set originator_to_beneficiary_information_line1 in production. final JsonField<String>_originatorToBeneficiaryInformationLine2()The sending bank will set originator_to_beneficiary_information_line2 in production. final JsonField<String>_originatorToBeneficiaryInformationLine3()The sending bank will set originator_to_beneficiary_information_line3 in production. final JsonField<String>_originatorToBeneficiaryInformationLine4()The sending bank will set originator_to_beneficiary_information_line4 in production. final JsonField<String>_senderReference()The sending bank will set sender_reference in production. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationInboundWireTransferCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundWireTransferCreateParams.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the inbound Wire Transfer is for.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
The sending bank will set beneficiary_address_line1 in production. You can simulate any value here.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
The sending bank will set beneficiary_address_line2 in production. You can simulate any value here.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
The sending bank will set beneficiary_address_line3 in production. You can simulate any value here.
-
beneficiaryName
final Optional<String> beneficiaryName()
The sending bank will set beneficiary_name in production. You can simulate any value here.
-
beneficiaryReference
final Optional<String> beneficiaryReference()
The sending bank will set beneficiary_reference in production. You can simulate any value here.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The sending bank will set originator_address_line1 in production. You can simulate any value here.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The sending bank will set originator_address_line2 in production. You can simulate any value here.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The sending bank will set originator_address_line3 in production. You can simulate any value here.
-
originatorName
final Optional<String> originatorName()
The sending bank will set originator_name in production. You can simulate any value here.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The sending bank will set originator_routing_number in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
The sending bank will set originator_to_beneficiary_information_line1 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
The sending bank will set originator_to_beneficiary_information_line2 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
The sending bank will set originator_to_beneficiary_information_line3 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
The sending bank will set originator_to_beneficiary_information_line4 in production. You can simulate any value here.
-
senderReference
final Optional<String> senderReference()
The sending bank will set sender_reference in production. You can simulate any value here.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number the inbound Wire Transfer is for.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
The sending bank will set beneficiary_address_line1 in production. You can simulate any value here.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
The sending bank will set beneficiary_address_line2 in production. You can simulate any value here.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
The sending bank will set beneficiary_address_line3 in production. You can simulate any value here.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
The sending bank will set beneficiary_name in production. You can simulate any value here.
-
_beneficiaryReference
final JsonField<String> _beneficiaryReference()
The sending bank will set beneficiary_reference in production. You can simulate any value here.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
The sending bank will set originator_address_line1 in production. You can simulate any value here.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
The sending bank will set originator_address_line2 in production. You can simulate any value here.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
The sending bank will set originator_address_line3 in production. You can simulate any value here.
-
_originatorName
final JsonField<String> _originatorName()
The sending bank will set originator_name in production. You can simulate any value here.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
The sending bank will set originator_routing_number in production. You can simulate any value here.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
The sending bank will set originator_to_beneficiary_information_line1 in production. You can simulate any value here.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
The sending bank will set originator_to_beneficiary_information_line2 in production. You can simulate any value here.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
The sending bank will set originator_to_beneficiary_information_line3 in production. You can simulate any value here.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
The sending bank will set originator_to_beneficiary_information_line4 in production. You can simulate any value here.
-
_senderReference
final JsonField<String> _senderReference()
The sending bank will set sender_reference in production. You can simulate any value here.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationInboundWireTransferCreateParams.Builder toBuilder()
-
builder
final static SimulationInboundWireTransferCreateParams.Builder builder()
-
-
-
-