Class SimulationInboundWireTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SimulationInboundWireTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final SimulationInboundWireTransferCreateParams.Body.BuilderaccountNumberId(String accountNumberId)The identifier of the Account Number the inbound Wire Transfer is for. final SimulationInboundWireTransferCreateParams.Body.BuilderaccountNumberId(JsonField<String> accountNumberId)The identifier of the Account Number the inbound Wire Transfer is for. final SimulationInboundWireTransferCreateParams.Body.Builderamount(Long amount)The transfer amount in cents. final SimulationInboundWireTransferCreateParams.Body.Builderamount(JsonField<Long> amount)The transfer amount in cents. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)The sending bank will set beneficiary_address_line1 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)The sending bank will set beneficiary_address_line1 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)The sending bank will set beneficiary_address_line2 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)The sending bank will set beneficiary_address_line2 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)The sending bank will set beneficiary_address_line3 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)The sending bank will set beneficiary_address_line3 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryName(String beneficiaryName)The sending bank will set beneficiary_name in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryName(JsonField<String> beneficiaryName)The sending bank will set beneficiary_name in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryReference(String beneficiaryReference)The sending bank will set beneficiary_reference in production. final SimulationInboundWireTransferCreateParams.Body.BuilderbeneficiaryReference(JsonField<String> beneficiaryReference)The sending bank will set beneficiary_reference in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorAddressLine1(String originatorAddressLine1)The sending bank will set originator_address_line1 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)The sending bank will set originator_address_line1 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorAddressLine2(String originatorAddressLine2)The sending bank will set originator_address_line2 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)The sending bank will set originator_address_line2 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorAddressLine3(String originatorAddressLine3)The sending bank will set originator_address_line3 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)The sending bank will set originator_address_line3 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorName(String originatorName)The sending bank will set originator_name in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorName(JsonField<String> originatorName)The sending bank will set originator_name in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorRoutingNumber(String originatorRoutingNumber)The sending bank will set originator_routing_number in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorRoutingNumber(JsonField<String> originatorRoutingNumber)The sending bank will set originator_routing_number in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)The sending bank will set originator_to_beneficiary_information_line1 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)The sending bank will set originator_to_beneficiary_information_line1 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)The sending bank will set originator_to_beneficiary_information_line2 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)The sending bank will set originator_to_beneficiary_information_line2 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)The sending bank will set originator_to_beneficiary_information_line3 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)The sending bank will set originator_to_beneficiary_information_line3 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)The sending bank will set originator_to_beneficiary_information_line4 in production. final SimulationInboundWireTransferCreateParams.Body.BuilderoriginatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)The sending bank will set originator_to_beneficiary_information_line4 in production. final SimulationInboundWireTransferCreateParams.Body.BuildersenderReference(String senderReference)The sending bank will set sender_reference in production. final SimulationInboundWireTransferCreateParams.Body.BuildersenderReference(JsonField<String> senderReference)The sending bank will set sender_reference in production. final SimulationInboundWireTransferCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final SimulationInboundWireTransferCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final SimulationInboundWireTransferCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final SimulationInboundWireTransferCreateParams.Body.BuilderremoveAdditionalProperty(String key)final SimulationInboundWireTransferCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final SimulationInboundWireTransferCreateParams.Bodybuild()-
-
Method Detail
-
accountNumberId
final SimulationInboundWireTransferCreateParams.Body.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number the inbound Wire Transfer is for.
-
accountNumberId
final SimulationInboundWireTransferCreateParams.Body.Builder accountNumberId(JsonField<String> accountNumberId)
The identifier of the Account Number the inbound Wire Transfer is for.
-
amount
final SimulationInboundWireTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in cents. Must be positive.
-
amount
final SimulationInboundWireTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
The transfer amount in cents. Must be positive.
-
beneficiaryAddressLine1
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
The sending bank will set beneficiary_address_line1 in production. You can simulate any value here.
-
beneficiaryAddressLine1
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
The sending bank will set beneficiary_address_line1 in production. You can simulate any value here.
-
beneficiaryAddressLine2
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
The sending bank will set beneficiary_address_line2 in production. You can simulate any value here.
-
beneficiaryAddressLine2
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
The sending bank will set beneficiary_address_line2 in production. You can simulate any value here.
-
beneficiaryAddressLine3
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
The sending bank will set beneficiary_address_line3 in production. You can simulate any value here.
-
beneficiaryAddressLine3
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
The sending bank will set beneficiary_address_line3 in production. You can simulate any value here.
-
beneficiaryName
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryName(String beneficiaryName)
The sending bank will set beneficiary_name in production. You can simulate any value here.
-
beneficiaryName
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryName(JsonField<String> beneficiaryName)
The sending bank will set beneficiary_name in production. You can simulate any value here.
-
beneficiaryReference
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryReference(String beneficiaryReference)
The sending bank will set beneficiary_reference in production. You can simulate any value here.
-
beneficiaryReference
final SimulationInboundWireTransferCreateParams.Body.Builder beneficiaryReference(JsonField<String> beneficiaryReference)
The sending bank will set beneficiary_reference in production. You can simulate any value here.
-
originatorAddressLine1
final SimulationInboundWireTransferCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
The sending bank will set originator_address_line1 in production. You can simulate any value here.
-
originatorAddressLine1
final SimulationInboundWireTransferCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
The sending bank will set originator_address_line1 in production. You can simulate any value here.
-
originatorAddressLine2
final SimulationInboundWireTransferCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
The sending bank will set originator_address_line2 in production. You can simulate any value here.
-
originatorAddressLine2
final SimulationInboundWireTransferCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
The sending bank will set originator_address_line2 in production. You can simulate any value here.
-
originatorAddressLine3
final SimulationInboundWireTransferCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
The sending bank will set originator_address_line3 in production. You can simulate any value here.
-
originatorAddressLine3
final SimulationInboundWireTransferCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
The sending bank will set originator_address_line3 in production. You can simulate any value here.
-
originatorName
final SimulationInboundWireTransferCreateParams.Body.Builder originatorName(String originatorName)
The sending bank will set originator_name in production. You can simulate any value here.
-
originatorName
final SimulationInboundWireTransferCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
The sending bank will set originator_name in production. You can simulate any value here.
-
originatorRoutingNumber
final SimulationInboundWireTransferCreateParams.Body.Builder originatorRoutingNumber(String originatorRoutingNumber)
The sending bank will set originator_routing_number in production. You can simulate any value here.
-
originatorRoutingNumber
final SimulationInboundWireTransferCreateParams.Body.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
The sending bank will set originator_routing_number in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine1
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
The sending bank will set originator_to_beneficiary_information_line1 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine1
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
The sending bank will set originator_to_beneficiary_information_line1 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine2
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
The sending bank will set originator_to_beneficiary_information_line2 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine2
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
The sending bank will set originator_to_beneficiary_information_line2 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine3
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
The sending bank will set originator_to_beneficiary_information_line3 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine3
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
The sending bank will set originator_to_beneficiary_information_line3 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine4
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
The sending bank will set originator_to_beneficiary_information_line4 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine4
final SimulationInboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
The sending bank will set originator_to_beneficiary_information_line4 in production. You can simulate any value here.
-
senderReference
final SimulationInboundWireTransferCreateParams.Body.Builder senderReference(String senderReference)
The sending bank will set sender_reference in production. You can simulate any value here.
-
senderReference
final SimulationInboundWireTransferCreateParams.Body.Builder senderReference(JsonField<String> senderReference)
The sending bank will set sender_reference in production. You can simulate any value here.
-
additionalProperties
final SimulationInboundWireTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationInboundWireTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationInboundWireTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationInboundWireTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationInboundWireTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SimulationInboundWireTransferCreateParams.Body build()
-
-
-
-