Class SimulationInterestPaymentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationInterestPaymentCreateParams implements Params
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInterestPaymentCreateParams.Bodypublic final classSimulationInterestPaymentCreateParams.BuilderA builder for SimulationInterestPaymentCreateParams.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account Number the Interest Payment is for. final Longamount()The interest amount in cents. final Optional<OffsetDateTime>periodEnd()The end of the interest period. final Optional<OffsetDateTime>periodStart()The start of the interest period. final JsonField<String>_accountId()The identifier of the Account Number the Interest Payment is for. final JsonField<Long>_amount()The interest amount in cents. final JsonField<OffsetDateTime>_periodEnd()The end of the interest period. final JsonField<OffsetDateTime>_periodStart()The start of the interest period. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationInterestPaymentCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInterestPaymentCreateParams.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier of the Account Number the Interest Payment is for.
-
periodEnd
final Optional<OffsetDateTime> periodEnd()
The end of the interest period. If not provided, defaults to the current time.
-
periodStart
final Optional<OffsetDateTime> periodStart()
The start of the interest period. If not provided, defaults to the current time.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account Number the Interest Payment is for.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
The end of the interest period. If not provided, defaults to the current time.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
The start of the interest period. If not provided, defaults to the current time.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationInterestPaymentCreateParams.Builder toBuilder()
-
builder
final static SimulationInterestPaymentCreateParams.Builder builder()
-
-
-
-