Package com.increase.api.models
Class SimulationInterestPaymentCreateParams.Body
-
- All Implemented Interfaces:
public final class SimulationInterestPaymentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInterestPaymentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account Number the Interest Payment is for. final Longamount()The interest amount in cents. final Optional<OffsetDateTime>periodEnd()The end of the interest period. final Optional<OffsetDateTime>periodStart()The start of the interest period. final JsonField<String>_accountId()The identifier of the Account Number the Interest Payment is for. final JsonField<Long>_amount()The interest amount in cents. final JsonField<OffsetDateTime>_periodEnd()The end of the interest period. final JsonField<OffsetDateTime>_periodStart()The start of the interest period. final Map<String, JsonValue>_additionalProperties()final SimulationInterestPaymentCreateParams.Bodyvalidate()final SimulationInterestPaymentCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInterestPaymentCreateParams.Body.Builderbuilder()-
-
Method Detail
-
accountId
final String accountId()
The identifier of the Account Number the Interest Payment is for.
-
periodEnd
final Optional<OffsetDateTime> periodEnd()
The end of the interest period. If not provided, defaults to the current time.
-
periodStart
final Optional<OffsetDateTime> periodStart()
The start of the interest period. If not provided, defaults to the current time.
-
_accountId
final JsonField<String> _accountId()
The identifier of the Account Number the Interest Payment is for.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
The end of the interest period. If not provided, defaults to the current time.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
The start of the interest period. If not provided, defaults to the current time.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationInterestPaymentCreateParams.Body validate()
-
toBuilder
final SimulationInterestPaymentCreateParams.Body.Builder toBuilder()
-
builder
final static SimulationInterestPaymentCreateParams.Body.Builder builder()
-
-
-
-