Package com.increase.api.models
Class SimulationInterestPaymentCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SimulationInterestPaymentCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final SimulationInterestPaymentCreateParams.Body.Builder accountId(String accountId)
The identifier of the Account Number the Interest Payment is for.
-
accountId
final SimulationInterestPaymentCreateParams.Body.Builder accountId(JsonField<String> accountId)
The identifier of the Account Number the Interest Payment is for.
-
amount
final SimulationInterestPaymentCreateParams.Body.Builder amount(Long amount)
The interest amount in cents. Must be positive.
-
amount
final SimulationInterestPaymentCreateParams.Body.Builder amount(JsonField<Long> amount)
The interest amount in cents. Must be positive.
-
periodEnd
final SimulationInterestPaymentCreateParams.Body.Builder periodEnd(OffsetDateTime periodEnd)
The end of the interest period. If not provided, defaults to the current time.
-
periodEnd
final SimulationInterestPaymentCreateParams.Body.Builder periodEnd(JsonField<OffsetDateTime> periodEnd)
The end of the interest period. If not provided, defaults to the current time.
-
periodStart
final SimulationInterestPaymentCreateParams.Body.Builder periodStart(OffsetDateTime periodStart)
The start of the interest period. If not provided, defaults to the current time.
-
periodStart
final SimulationInterestPaymentCreateParams.Body.Builder periodStart(JsonField<OffsetDateTime> periodStart)
The start of the interest period. If not provided, defaults to the current time.
-
additionalProperties
final SimulationInterestPaymentCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationInterestPaymentCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationInterestPaymentCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationInterestPaymentCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationInterestPaymentCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SimulationInterestPaymentCreateParams.Body build()
-
-
-
-