Class SimulationPhysicalCardAdvanceShipmentParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationPhysicalCardAdvanceShipmentParams
     implements Params
                        

    This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery.