Enum SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known extends Enum<SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known>
An enum containing ShipmentStatus's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDINGThe physical card has not yet been shipped.
CANCELEDThe physical card shipment was canceled prior to submission.
SUBMITTEDThe physical card shipment has been submitted to the card fulfillment provider.
ACKNOWLEDGEDThe physical card shipment has been acknowledged by the card fulfillment provider and will be processed in their next batch.
REJECTEDThe physical card shipment was rejected by the card printer due to an error.
SHIPPEDThe physical card has been shipped.
RETURNEDThe physical card shipment was returned to the sender and destroyed by the production facility.
-
Method Summary
Modifier and Type Method Description final SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known>getEntries()An enum containing ShipmentStatus's known values. -
-
Method Detail
-
valueOf
final SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<SimulationPhysicalCardAdvanceShipmentParams.ShipmentStatus.Known> getEntries()
An enum containing ShipmentStatus's known values.
-
-
-
-