Class SimulationRealTimePaymentsTransferCompleteParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationRealTimePaymentsTransferCompleteParams
     implements Params
                        

    Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. This transfer must first have a status of pending_submission.