Package com.increase.api.models
Class SimulationRealTimePaymentsTransferCompleteParams.Rejection
-
- All Implemented Interfaces:
public final class SimulationRealTimePaymentsTransferCompleteParams.RejectionIf set, the simulation will reject the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationRealTimePaymentsTransferCompleteParams.Rejection.BuilderA builder for Rejection.
public final classSimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCodeThe reason code that the simulated rejection will have.
-
Method Summary
Modifier and Type Method Description final SimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCoderejectReasonCode()The reason code that the simulated rejection will have. final JsonField<SimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCode>_rejectReasonCode()The reason code that the simulated rejection will have. final Map<String, JsonValue>_additionalProperties()final SimulationRealTimePaymentsTransferCompleteParams.Rejectionvalidate()final SimulationRealTimePaymentsTransferCompleteParams.Rejection.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builderbuilder()-
-
Method Detail
-
rejectReasonCode
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCode rejectReasonCode()
The reason code that the simulated rejection will have.
-
_rejectReasonCode
final JsonField<SimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCode> _rejectReasonCode()
The reason code that the simulated rejection will have.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SimulationRealTimePaymentsTransferCompleteParams.Rejection validate()
-
toBuilder
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder toBuilder()
-
builder
final static SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder builder()
-
-
-
-