Package com.increase.api.models
Class SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder
-
- All Implemented Interfaces:
public final class SimulationRealTimePaymentsTransferCompleteParams.Rejection.BuilderA builder for Rejection.
-
-
Method Summary
-
-
Method Detail
-
rejectReasonCode
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder rejectReasonCode(SimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCode rejectReasonCode)
The reason code that the simulated rejection will have.
-
rejectReasonCode
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder rejectReasonCode(JsonField<SimulationRealTimePaymentsTransferCompleteParams.Rejection.RejectReasonCode> rejectReasonCode)
The reason code that the simulated rejection will have.
-
additionalProperties
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SimulationRealTimePaymentsTransferCompleteParams.Rejection.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-