Class SimulationWireTransferReverseParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class SimulationWireTransferReverseParams
     implements Params
                        

    Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a status of complete.