Package com.increase.api.models
Class SupplementalDocumentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SupplementalDocumentCreateParams implements Params
Create a supplemental document for an Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentCreateParams.Bodypublic final classSupplementalDocumentCreateParams.BuilderA builder for SupplementalDocumentCreateParams.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to associate with the supplemental document. final StringfileId()The identifier of the File containing the document. final JsonField<String>_entityId()The identifier of the Entity to associate with the supplemental document. final JsonField<String>_fileId()The identifier of the File containing the document. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SupplementalDocumentCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentCreateParams.Builderbuilder()-
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to associate with the supplemental document.
-
_entityId
final JsonField<String> _entityId()
The identifier of the Entity to associate with the supplemental document.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SupplementalDocumentCreateParams.Builder toBuilder()
-
builder
final static SupplementalDocumentCreateParams.Builder builder()
-
-
-
-