Package com.increase.api.models
Class SupplementalDocumentCreateParams.Body
-
- All Implemented Interfaces:
public final class SupplementalDocumentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to associate with the supplemental document. final StringfileId()The identifier of the File containing the document. final JsonField<String>_entityId()The identifier of the Entity to associate with the supplemental document. final JsonField<String>_fileId()The identifier of the File containing the document. final Map<String, JsonValue>_additionalProperties()final SupplementalDocumentCreateParams.Bodyvalidate()final SupplementalDocumentCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentCreateParams.Body.Builderbuilder()-
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to associate with the supplemental document.
-
_entityId
final JsonField<String> _entityId()
The identifier of the Entity to associate with the supplemental document.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final SupplementalDocumentCreateParams.Body validate()
-
toBuilder
final SupplementalDocumentCreateParams.Body.Builder toBuilder()
-
builder
final static SupplementalDocumentCreateParams.Body.Builder builder()
-
-
-
-