Package com.increase.api.models
Class SupplementalDocumentListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SupplementalDocumentListParams implements Params
List Entity Supplemental Document Submissions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentListParams.BuilderA builder for SupplementalDocumentListParams.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to list supplemental documents for. final Optional<String>cursor()Return the page of entries after this one. final Optional<String>idempotencyKey()Filter records to the one with the specified idempotency_keyyou chose for that object.final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SupplementalDocumentListParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentListParams.Builderbuilder()-
-
Method Detail
-
idempotencyKey
final Optional<String> idempotencyKey()
Filter records to the one with the specified
idempotency_keyyou chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SupplementalDocumentListParams.Builder toBuilder()
-
builder
final static SupplementalDocumentListParams.Builder builder()
-
-
-
-