Class Transaction.Source.AccountTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.AccountTransferIntentionAn Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.AccountTransferIntention.BuilderA builder for AccountTransferIntention.
public final classTransaction.Source.AccountTransferIntention.CurrencyThe ISO 4217 code for the destination account currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The pending amount in the minor unit of the transaction's currency. final Transaction.Source.AccountTransferIntention.Currencycurrency()The ISO 4217 code for the destination account currency. final Stringdescription()The description you chose to give the transfer. final StringdestinationAccountId()The identifier of the Account to where the Account Transfer was sent. final StringsourceAccountId()The identifier of the Account from where the Account Transfer was sent. final StringtransferId()The identifier of the Account Transfer that led to this Pending Transaction. final JsonField<Long>_amount()The pending amount in the minor unit of the transaction's currency. final JsonField<Transaction.Source.AccountTransferIntention.Currency>_currency()The ISO 4217 code for the destination account currency. final JsonField<String>_description()The description you chose to give the transfer. final JsonField<String>_destinationAccountId()The identifier of the Account to where the Account Transfer was sent. final JsonField<String>_sourceAccountId()The identifier of the Account from where the Account Transfer was sent. final JsonField<String>_transferId()The identifier of the Account Transfer that led to this Pending Transaction. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.AccountTransferIntentionvalidate()final Transaction.Source.AccountTransferIntention.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.AccountTransferIntention.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.AccountTransferIntention.Currency currency()
The ISO 4217 code for the destination account currency.
-
description
final String description()
The description you chose to give the transfer.
-
destinationAccountId
final String destinationAccountId()
The identifier of the Account to where the Account Transfer was sent.
-
sourceAccountId
final String sourceAccountId()
The identifier of the Account from where the Account Transfer was sent.
-
transferId
final String transferId()
The identifier of the Account Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<Transaction.Source.AccountTransferIntention.Currency> _currency()
The ISO 4217 code for the destination account currency.
-
_description
final JsonField<String> _description()
The description you chose to give the transfer.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
The identifier of the Account to where the Account Transfer was sent.
-
_sourceAccountId
final JsonField<String> _sourceAccountId()
The identifier of the Account from where the Account Transfer was sent.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Account Transfer that led to this Pending Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.AccountTransferIntention validate()
-
toBuilder
final Transaction.Source.AccountTransferIntention.Builder toBuilder()
-
builder
final static Transaction.Source.AccountTransferIntention.Builder builder()
-
-
-
-