Class Transaction.Source.AccountTransferIntention.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.AccountTransferIntention.BuilderA builder for AccountTransferIntention.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.AccountTransferIntention.Builder amount(Long amount)
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.AccountTransferIntention.Builder amount(JsonField<Long> amount)
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.AccountTransferIntention.Builder currency(Transaction.Source.AccountTransferIntention.Currency currency)
The ISO 4217 code for the destination account currency.
-
currency
final Transaction.Source.AccountTransferIntention.Builder currency(JsonField<Transaction.Source.AccountTransferIntention.Currency> currency)
The ISO 4217 code for the destination account currency.
-
description
final Transaction.Source.AccountTransferIntention.Builder description(String description)
The description you chose to give the transfer.
-
description
final Transaction.Source.AccountTransferIntention.Builder description(JsonField<String> description)
The description you chose to give the transfer.
-
destinationAccountId
final Transaction.Source.AccountTransferIntention.Builder destinationAccountId(String destinationAccountId)
The identifier of the Account to where the Account Transfer was sent.
-
destinationAccountId
final Transaction.Source.AccountTransferIntention.Builder destinationAccountId(JsonField<String> destinationAccountId)
The identifier of the Account to where the Account Transfer was sent.
-
sourceAccountId
final Transaction.Source.AccountTransferIntention.Builder sourceAccountId(String sourceAccountId)
The identifier of the Account from where the Account Transfer was sent.
-
sourceAccountId
final Transaction.Source.AccountTransferIntention.Builder sourceAccountId(JsonField<String> sourceAccountId)
The identifier of the Account from where the Account Transfer was sent.
-
transferId
final Transaction.Source.AccountTransferIntention.Builder transferId(String transferId)
The identifier of the Account Transfer that led to this Pending Transaction.
-
transferId
final Transaction.Source.AccountTransferIntention.Builder transferId(JsonField<String> transferId)
The identifier of the Account Transfer that led to this Pending Transaction.
-
additionalProperties
final Transaction.Source.AccountTransferIntention.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.AccountTransferIntention.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.AccountTransferIntention.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.AccountTransferIntention.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.AccountTransferIntention.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.AccountTransferIntention build()
-
-
-
-