Class Transaction.Source.AchTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.AchTransferIntentionAn ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.AchTransferIntention.BuilderA builder for AchTransferIntention.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number for the destination account. final Longamount()The amount in the minor unit of the transaction's currency. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final StringstatementDescriptor()A description set when the ACH Transfer was created. final StringtransferId()The identifier of the ACH Transfer that led to this Transaction. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<Long>_amount()The amount in the minor unit of the transaction's currency. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<String>_statementDescriptor()A description set when the ACH Transfer was created. final JsonField<String>_transferId()The identifier of the ACH Transfer that led to this Transaction. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.AchTransferIntentionvalidate()final Transaction.Source.AchTransferIntention.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.AchTransferIntention.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
statementDescriptor
final String statementDescriptor()
A description set when the ACH Transfer was created.
-
transferId
final String transferId()
The identifier of the ACH Transfer that led to this Transaction.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_statementDescriptor
final JsonField<String> _statementDescriptor()
A description set when the ACH Transfer was created.
-
_transferId
final JsonField<String> _transferId()
The identifier of the ACH Transfer that led to this Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.AchTransferIntention validate()
-
toBuilder
final Transaction.Source.AchTransferIntention.Builder toBuilder()
-
builder
final static Transaction.Source.AchTransferIntention.Builder builder()
-
-
-
-