Class Transaction.Source.AchTransferIntention.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.AchTransferIntention.BuilderA builder for AchTransferIntention.
-
-
Method Summary
-
-
Method Detail
-
accountNumber
final Transaction.Source.AchTransferIntention.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final Transaction.Source.AchTransferIntention.Builder accountNumber(JsonField<String> accountNumber)
The account number for the destination account.
-
amount
final Transaction.Source.AchTransferIntention.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.AchTransferIntention.Builder amount(JsonField<Long> amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
routingNumber
final Transaction.Source.AchTransferIntention.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final Transaction.Source.AchTransferIntention.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
statementDescriptor
final Transaction.Source.AchTransferIntention.Builder statementDescriptor(String statementDescriptor)
A description set when the ACH Transfer was created.
-
statementDescriptor
final Transaction.Source.AchTransferIntention.Builder statementDescriptor(JsonField<String> statementDescriptor)
A description set when the ACH Transfer was created.
-
transferId
final Transaction.Source.AchTransferIntention.Builder transferId(String transferId)
The identifier of the ACH Transfer that led to this Transaction.
-
transferId
final Transaction.Source.AchTransferIntention.Builder transferId(JsonField<String> transferId)
The identifier of the ACH Transfer that led to this Transaction.
-
additionalProperties
final Transaction.Source.AchTransferIntention.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.AchTransferIntention.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.AchTransferIntention.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.AchTransferIntention.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.AchTransferIntention.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.AchTransferIntention build()
-
-
-
-