Class Transaction.Source.AchTransferReturn

  • All Implemented Interfaces:

    
    public final class Transaction.Source.AchTransferReturn
    
                        

    An ACH Transfer Return object. This field will be present in the JSON response if and only if category is equal to ach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.