Class Transaction.Source.AchTransferReturn.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.AchTransferReturn.BuilderA builder for AchTransferReturn.
-
-
Method Summary
-
-
Method Detail
-
createdAt
final Transaction.Source.AchTransferReturn.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final Transaction.Source.AchTransferReturn.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
rawReturnReasonCode
final Transaction.Source.AchTransferReturn.Builder rawReturnReasonCode(String rawReturnReasonCode)
The three character ACH return code, in the range R01 to R85.
-
rawReturnReasonCode
final Transaction.Source.AchTransferReturn.Builder rawReturnReasonCode(JsonField<String> rawReturnReasonCode)
The three character ACH return code, in the range R01 to R85.
-
returnReasonCode
final Transaction.Source.AchTransferReturn.Builder returnReasonCode(Transaction.Source.AchTransferReturn.ReturnReasonCode returnReasonCode)
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
returnReasonCode
final Transaction.Source.AchTransferReturn.Builder returnReasonCode(JsonField<Transaction.Source.AchTransferReturn.ReturnReasonCode> returnReasonCode)
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
traceNumber
final Transaction.Source.AchTransferReturn.Builder traceNumber(String traceNumber)
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
traceNumber
final Transaction.Source.AchTransferReturn.Builder traceNumber(JsonField<String> traceNumber)
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
transactionId
final Transaction.Source.AchTransferReturn.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this return.
-
transactionId
final Transaction.Source.AchTransferReturn.Builder transactionId(JsonField<String> transactionId)
The identifier of the Transaction associated with this return.
-
transferId
final Transaction.Source.AchTransferReturn.Builder transferId(String transferId)
The identifier of the ACH Transfer associated with this return.
-
transferId
final Transaction.Source.AchTransferReturn.Builder transferId(JsonField<String> transferId)
The identifier of the ACH Transfer associated with this return.
-
additionalProperties
final Transaction.Source.AchTransferReturn.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.AchTransferReturn.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.AchTransferReturn.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.AchTransferReturn.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.AchTransferReturn.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.AchTransferReturn build()
-
-
-
-