Class Transaction.Source.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.BuilderA builder for Source.
-
-
Method Summary
-
-
Method Detail
-
accountTransferIntention
final Transaction.Source.Builder accountTransferIntention(Transaction.Source.AccountTransferIntention accountTransferIntention)
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
accountTransferIntention
final Transaction.Source.Builder accountTransferIntention(Optional<Transaction.Source.AccountTransferIntention> accountTransferIntention)
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
accountTransferIntention
final Transaction.Source.Builder accountTransferIntention(JsonField<Transaction.Source.AccountTransferIntention> accountTransferIntention)
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
achTransferIntention
final Transaction.Source.Builder achTransferIntention(Transaction.Source.AchTransferIntention achTransferIntention)
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
achTransferIntention
final Transaction.Source.Builder achTransferIntention(Optional<Transaction.Source.AchTransferIntention> achTransferIntention)
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
achTransferIntention
final Transaction.Source.Builder achTransferIntention(JsonField<Transaction.Source.AchTransferIntention> achTransferIntention)
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
achTransferRejection
final Transaction.Source.Builder achTransferRejection(Transaction.Source.AchTransferRejection achTransferRejection)
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
achTransferRejection
final Transaction.Source.Builder achTransferRejection(Optional<Transaction.Source.AchTransferRejection> achTransferRejection)
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
achTransferRejection
final Transaction.Source.Builder achTransferRejection(JsonField<Transaction.Source.AchTransferRejection> achTransferRejection)
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
achTransferReturn
final Transaction.Source.Builder achTransferReturn(Transaction.Source.AchTransferReturn achTransferReturn)
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
achTransferReturn
final Transaction.Source.Builder achTransferReturn(Optional<Transaction.Source.AchTransferReturn> achTransferReturn)
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
achTransferReturn
final Transaction.Source.Builder achTransferReturn(JsonField<Transaction.Source.AchTransferReturn> achTransferReturn)
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
cardDisputeAcceptance
final Transaction.Source.Builder cardDisputeAcceptance(Transaction.Source.CardDisputeAcceptance cardDisputeAcceptance)
A Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
cardDisputeAcceptance
final Transaction.Source.Builder cardDisputeAcceptance(Optional<Transaction.Source.CardDisputeAcceptance> cardDisputeAcceptance)
A Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
cardDisputeAcceptance
final Transaction.Source.Builder cardDisputeAcceptance(JsonField<Transaction.Source.CardDisputeAcceptance> cardDisputeAcceptance)
A Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
cardDisputeLoss
final Transaction.Source.Builder cardDisputeLoss(Transaction.Source.CardDisputeLoss cardDisputeLoss)
A Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
cardDisputeLoss
final Transaction.Source.Builder cardDisputeLoss(Optional<Transaction.Source.CardDisputeLoss> cardDisputeLoss)
A Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
cardDisputeLoss
final Transaction.Source.Builder cardDisputeLoss(JsonField<Transaction.Source.CardDisputeLoss> cardDisputeLoss)
A Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
cardRefund
final Transaction.Source.Builder cardRefund(Transaction.Source.CardRefund cardRefund)
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRefund
final Transaction.Source.Builder cardRefund(Optional<Transaction.Source.CardRefund> cardRefund)
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRefund
final Transaction.Source.Builder cardRefund(JsonField<Transaction.Source.CardRefund> cardRefund)
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRevenuePayment
final Transaction.Source.Builder cardRevenuePayment(Transaction.Source.CardRevenuePayment cardRevenuePayment)
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
cardRevenuePayment
final Transaction.Source.Builder cardRevenuePayment(Optional<Transaction.Source.CardRevenuePayment> cardRevenuePayment)
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
cardRevenuePayment
final Transaction.Source.Builder cardRevenuePayment(JsonField<Transaction.Source.CardRevenuePayment> cardRevenuePayment)
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
cardSettlement
final Transaction.Source.Builder cardSettlement(Transaction.Source.CardSettlement cardSettlement)
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cardSettlement
final Transaction.Source.Builder cardSettlement(Optional<Transaction.Source.CardSettlement> cardSettlement)
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cardSettlement
final Transaction.Source.Builder cardSettlement(JsonField<Transaction.Source.CardSettlement> cardSettlement)
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cashbackPayment
final Transaction.Source.Builder cashbackPayment(Transaction.Source.CashbackPayment cashbackPayment)
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
cashbackPayment
final Transaction.Source.Builder cashbackPayment(Optional<Transaction.Source.CashbackPayment> cashbackPayment)
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
cashbackPayment
final Transaction.Source.Builder cashbackPayment(JsonField<Transaction.Source.CashbackPayment> cashbackPayment)
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
category
final Transaction.Source.Builder category(Transaction.Source.Category category)
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final Transaction.Source.Builder category(JsonField<Transaction.Source.Category> category)
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
checkDepositAcceptance
final Transaction.Source.Builder checkDepositAcceptance(Transaction.Source.CheckDepositAcceptance checkDepositAcceptance)
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
checkDepositAcceptance
final Transaction.Source.Builder checkDepositAcceptance(Optional<Transaction.Source.CheckDepositAcceptance> checkDepositAcceptance)
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
checkDepositAcceptance
final Transaction.Source.Builder checkDepositAcceptance(JsonField<Transaction.Source.CheckDepositAcceptance> checkDepositAcceptance)
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
checkDepositReturn
final Transaction.Source.Builder checkDepositReturn(Transaction.Source.CheckDepositReturn checkDepositReturn)
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
checkDepositReturn
final Transaction.Source.Builder checkDepositReturn(Optional<Transaction.Source.CheckDepositReturn> checkDepositReturn)
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
checkDepositReturn
final Transaction.Source.Builder checkDepositReturn(JsonField<Transaction.Source.CheckDepositReturn> checkDepositReturn)
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
checkTransferDeposit
final Transaction.Source.Builder checkTransferDeposit(Transaction.Source.CheckTransferDeposit checkTransferDeposit)
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
checkTransferDeposit
final Transaction.Source.Builder checkTransferDeposit(Optional<Transaction.Source.CheckTransferDeposit> checkTransferDeposit)
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
checkTransferDeposit
final Transaction.Source.Builder checkTransferDeposit(JsonField<Transaction.Source.CheckTransferDeposit> checkTransferDeposit)
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
feePayment
final Transaction.Source.Builder feePayment(Transaction.Source.FeePayment feePayment)
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
feePayment
final Transaction.Source.Builder feePayment(Optional<Transaction.Source.FeePayment> feePayment)
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
feePayment
final Transaction.Source.Builder feePayment(JsonField<Transaction.Source.FeePayment> feePayment)
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
inboundAchTransfer
final Transaction.Source.Builder inboundAchTransfer(Transaction.Source.InboundAchTransfer inboundAchTransfer)
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
inboundAchTransfer
final Transaction.Source.Builder inboundAchTransfer(Optional<Transaction.Source.InboundAchTransfer> inboundAchTransfer)
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
inboundAchTransfer
final Transaction.Source.Builder inboundAchTransfer(JsonField<Transaction.Source.InboundAchTransfer> inboundAchTransfer)
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
inboundAchTransferReturnIntention
final Transaction.Source.Builder inboundAchTransferReturnIntention(Transaction.Source.InboundAchTransferReturnIntention inboundAchTransferReturnIntention)
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
inboundAchTransferReturnIntention
final Transaction.Source.Builder inboundAchTransferReturnIntention(Optional<Transaction.Source.InboundAchTransferReturnIntention> inboundAchTransferReturnIntention)
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
inboundAchTransferReturnIntention
final Transaction.Source.Builder inboundAchTransferReturnIntention(JsonField<Transaction.Source.InboundAchTransferReturnIntention> inboundAchTransferReturnIntention)
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
inboundCheckAdjustment
final Transaction.Source.Builder inboundCheckAdjustment(Transaction.Source.InboundCheckAdjustment inboundCheckAdjustment)
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
inboundCheckAdjustment
final Transaction.Source.Builder inboundCheckAdjustment(Optional<Transaction.Source.InboundCheckAdjustment> inboundCheckAdjustment)
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
inboundCheckAdjustment
final Transaction.Source.Builder inboundCheckAdjustment(JsonField<Transaction.Source.InboundCheckAdjustment> inboundCheckAdjustment)
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
inboundCheckDepositReturnIntention
final Transaction.Source.Builder inboundCheckDepositReturnIntention(Transaction.Source.InboundCheckDepositReturnIntention inboundCheckDepositReturnIntention)
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
inboundCheckDepositReturnIntention
final Transaction.Source.Builder inboundCheckDepositReturnIntention(Optional<Transaction.Source.InboundCheckDepositReturnIntention> inboundCheckDepositReturnIntention)
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
inboundCheckDepositReturnIntention
final Transaction.Source.Builder inboundCheckDepositReturnIntention(JsonField<Transaction.Source.InboundCheckDepositReturnIntention> inboundCheckDepositReturnIntention)
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
inboundRealTimePaymentsTransferConfirmation
final Transaction.Source.Builder inboundRealTimePaymentsTransferConfirmation(Transaction.Source.InboundRealTimePaymentsTransferConfirmation inboundRealTimePaymentsTransferConfirmation)
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
inboundRealTimePaymentsTransferConfirmation
final Transaction.Source.Builder inboundRealTimePaymentsTransferConfirmation(Optional<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> inboundRealTimePaymentsTransferConfirmation)
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
inboundRealTimePaymentsTransferConfirmation
final Transaction.Source.Builder inboundRealTimePaymentsTransferConfirmation(JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> inboundRealTimePaymentsTransferConfirmation)
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
inboundRealTimePaymentsTransferDecline
final Transaction.Source.Builder inboundRealTimePaymentsTransferDecline(Transaction.Source.InboundRealTimePaymentsTransferDecline inboundRealTimePaymentsTransferDecline)
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
inboundRealTimePaymentsTransferDecline
final Transaction.Source.Builder inboundRealTimePaymentsTransferDecline(Optional<Transaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline)
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
inboundRealTimePaymentsTransferDecline
final Transaction.Source.Builder inboundRealTimePaymentsTransferDecline(JsonField<Transaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline)
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
inboundWireReversal
final Transaction.Source.Builder inboundWireReversal(Transaction.Source.InboundWireReversal inboundWireReversal)
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
inboundWireReversal
final Transaction.Source.Builder inboundWireReversal(Optional<Transaction.Source.InboundWireReversal> inboundWireReversal)
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
inboundWireReversal
final Transaction.Source.Builder inboundWireReversal(JsonField<Transaction.Source.InboundWireReversal> inboundWireReversal)
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
inboundWireTransfer
final Transaction.Source.Builder inboundWireTransfer(Transaction.Source.InboundWireTransfer inboundWireTransfer)
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
inboundWireTransfer
final Transaction.Source.Builder inboundWireTransfer(Optional<Transaction.Source.InboundWireTransfer> inboundWireTransfer)
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
inboundWireTransfer
final Transaction.Source.Builder inboundWireTransfer(JsonField<Transaction.Source.InboundWireTransfer> inboundWireTransfer)
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
inboundWireTransferReversal
final Transaction.Source.Builder inboundWireTransferReversal(Transaction.Source.InboundWireTransferReversal inboundWireTransferReversal)
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
inboundWireTransferReversal
final Transaction.Source.Builder inboundWireTransferReversal(Optional<Transaction.Source.InboundWireTransferReversal> inboundWireTransferReversal)
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
inboundWireTransferReversal
final Transaction.Source.Builder inboundWireTransferReversal(JsonField<Transaction.Source.InboundWireTransferReversal> inboundWireTransferReversal)
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
interestPayment
final Transaction.Source.Builder interestPayment(Transaction.Source.InterestPayment interestPayment)
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
interestPayment
final Transaction.Source.Builder interestPayment(Optional<Transaction.Source.InterestPayment> interestPayment)
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
interestPayment
final Transaction.Source.Builder interestPayment(JsonField<Transaction.Source.InterestPayment> interestPayment)
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
internalSource
final Transaction.Source.Builder internalSource(Transaction.Source.InternalSource internalSource)
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
internalSource
final Transaction.Source.Builder internalSource(Optional<Transaction.Source.InternalSource> internalSource)
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
internalSource
final Transaction.Source.Builder internalSource(JsonField<Transaction.Source.InternalSource> internalSource)
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
other
final Transaction.Source.Builder other(JsonValue other)
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
realTimePaymentsTransferAcknowledgement
final Transaction.Source.Builder realTimePaymentsTransferAcknowledgement(Transaction.Source.RealTimePaymentsTransferAcknowledgement realTimePaymentsTransferAcknowledgement)
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
realTimePaymentsTransferAcknowledgement
final Transaction.Source.Builder realTimePaymentsTransferAcknowledgement(Optional<Transaction.Source.RealTimePaymentsTransferAcknowledgement> realTimePaymentsTransferAcknowledgement)
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
realTimePaymentsTransferAcknowledgement
final Transaction.Source.Builder realTimePaymentsTransferAcknowledgement(JsonField<Transaction.Source.RealTimePaymentsTransferAcknowledgement> realTimePaymentsTransferAcknowledgement)
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
sampleFunds
final Transaction.Source.Builder sampleFunds(Transaction.Source.SampleFunds sampleFunds)
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
sampleFunds
final Transaction.Source.Builder sampleFunds(Optional<Transaction.Source.SampleFunds> sampleFunds)
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
sampleFunds
final Transaction.Source.Builder sampleFunds(JsonField<Transaction.Source.SampleFunds> sampleFunds)
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
wireTransferIntention
final Transaction.Source.Builder wireTransferIntention(Transaction.Source.WireTransferIntention wireTransferIntention)
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
wireTransferIntention
final Transaction.Source.Builder wireTransferIntention(Optional<Transaction.Source.WireTransferIntention> wireTransferIntention)
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
wireTransferIntention
final Transaction.Source.Builder wireTransferIntention(JsonField<Transaction.Source.WireTransferIntention> wireTransferIntention)
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
additionalProperties
final Transaction.Source.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source build()
-
-
-
-