Package com.increase.api.models
Class Transaction.Source.CardDisputeAcceptance
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeAcceptanceA Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardDisputeAcceptance.BuilderA builder for CardDisputeAcceptance.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The ISO 8601 date and time at which the Card Dispute was accepted. final StringcardDisputeId()The identifier of the Card Dispute that was accepted. final StringtransactionId()The identifier of the Transaction that was created to return the disputed funds to your account. final JsonField<OffsetDateTime>_acceptedAt()The ISO 8601 date and time at which the Card Dispute was accepted. final JsonField<String>_cardDisputeId()The identifier of the Card Dispute that was accepted. final JsonField<String>_transactionId()The identifier of the Transaction that was created to return the disputed funds to your account. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardDisputeAcceptancevalidate()final Transaction.Source.CardDisputeAcceptance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardDisputeAcceptance.Builderbuilder()-
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the Card Dispute was accepted.
-
cardDisputeId
final String cardDisputeId()
The identifier of the Card Dispute that was accepted.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to return the disputed funds to your account.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
The ISO 8601 date and time at which the Card Dispute was accepted.
-
_cardDisputeId
final JsonField<String> _cardDisputeId()
The identifier of the Card Dispute that was accepted.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction that was created to return the disputed funds to your account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardDisputeAcceptance validate()
-
toBuilder
final Transaction.Source.CardDisputeAcceptance.Builder toBuilder()
-
builder
final static Transaction.Source.CardDisputeAcceptance.Builder builder()
-
-
-
-