Package com.increase.api.models
Class Transaction.Source.CardDisputeAcceptance.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeAcceptance.BuilderA builder for CardDisputeAcceptance.
-
-
Method Summary
-
-
Method Detail
-
acceptedAt
final Transaction.Source.CardDisputeAcceptance.Builder acceptedAt(OffsetDateTime acceptedAt)
The ISO 8601 date and time at which the Card Dispute was accepted.
-
acceptedAt
final Transaction.Source.CardDisputeAcceptance.Builder acceptedAt(JsonField<OffsetDateTime> acceptedAt)
The ISO 8601 date and time at which the Card Dispute was accepted.
-
cardDisputeId
final Transaction.Source.CardDisputeAcceptance.Builder cardDisputeId(String cardDisputeId)
The identifier of the Card Dispute that was accepted.
-
cardDisputeId
final Transaction.Source.CardDisputeAcceptance.Builder cardDisputeId(JsonField<String> cardDisputeId)
The identifier of the Card Dispute that was accepted.
-
transactionId
final Transaction.Source.CardDisputeAcceptance.Builder transactionId(String transactionId)
The identifier of the Transaction that was created to return the disputed funds to your account.
-
transactionId
final Transaction.Source.CardDisputeAcceptance.Builder transactionId(JsonField<String> transactionId)
The identifier of the Transaction that was created to return the disputed funds to your account.
-
additionalProperties
final Transaction.Source.CardDisputeAcceptance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardDisputeAcceptance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardDisputeAcceptance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardDisputeAcceptance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardDisputeAcceptance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardDisputeAcceptance build()
-
-
-
-