Package com.increase.api.models
Class Transaction.Source.CardDisputeLoss
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeLossA Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardDisputeLoss.BuilderA builder for CardDisputeLoss.
-
Method Summary
Modifier and Type Method Description final StringcardDisputeId()The identifier of the Card Dispute that was lost. final Stringexplanation()Why the Card Dispute was lost. final OffsetDateTimelostAt()The ISO 8601 date and time at which the Card Dispute was lost. final StringtransactionId()The identifier of the Transaction that was created to debit the disputed funds from your account. final JsonField<String>_cardDisputeId()The identifier of the Card Dispute that was lost. final JsonField<String>_explanation()Why the Card Dispute was lost. final JsonField<OffsetDateTime>_lostAt()The ISO 8601 date and time at which the Card Dispute was lost. final JsonField<String>_transactionId()The identifier of the Transaction that was created to debit the disputed funds from your account. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardDisputeLossvalidate()final Transaction.Source.CardDisputeLoss.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardDisputeLoss.Builderbuilder()-
-
Method Detail
-
cardDisputeId
final String cardDisputeId()
The identifier of the Card Dispute that was lost.
-
explanation
final String explanation()
Why the Card Dispute was lost.
-
lostAt
final OffsetDateTime lostAt()
The ISO 8601 date and time at which the Card Dispute was lost.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to debit the disputed funds from your account.
-
_cardDisputeId
final JsonField<String> _cardDisputeId()
The identifier of the Card Dispute that was lost.
-
_explanation
final JsonField<String> _explanation()
Why the Card Dispute was lost.
-
_lostAt
final JsonField<OffsetDateTime> _lostAt()
The ISO 8601 date and time at which the Card Dispute was lost.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction that was created to debit the disputed funds from your account.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardDisputeLoss validate()
-
toBuilder
final Transaction.Source.CardDisputeLoss.Builder toBuilder()
-
builder
final static Transaction.Source.CardDisputeLoss.Builder builder()
-
-
-
-