Class Transaction.Source.CardRefund.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.BuilderA builder for CardRefund.
-
-
Method Summary
-
-
Method Detail
-
id
final Transaction.Source.CardRefund.Builder id(String id)
The Card Refund identifier.
-
id
final Transaction.Source.CardRefund.Builder id(JsonField<String> id)
The Card Refund identifier.
-
amount
final Transaction.Source.CardRefund.Builder amount(Long amount)
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.CardRefund.Builder amount(JsonField<Long> amount)
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
cardPaymentId
final Transaction.Source.CardRefund.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final Transaction.Source.CardRefund.Builder cardPaymentId(JsonField<String> cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cashback
final Transaction.Source.CardRefund.Builder cashback(Transaction.Source.CardRefund.Cashback cashback)
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
cashback
final Transaction.Source.CardRefund.Builder cashback(Optional<Transaction.Source.CardRefund.Cashback> cashback)
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
cashback
final Transaction.Source.CardRefund.Builder cashback(JsonField<Transaction.Source.CardRefund.Cashback> cashback)
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
currency
final Transaction.Source.CardRefund.Builder currency(Transaction.Source.CardRefund.Currency currency)
The ISO 4217 code for the transaction's settlement currency.
-
currency
final Transaction.Source.CardRefund.Builder currency(JsonField<Transaction.Source.CardRefund.Currency> currency)
The ISO 4217 code for the transaction's settlement currency.
-
interchange
final Transaction.Source.CardRefund.Builder interchange(Transaction.Source.CardRefund.Interchange interchange)
Interchange assessed as a part of this transaciton.
-
interchange
final Transaction.Source.CardRefund.Builder interchange(Optional<Transaction.Source.CardRefund.Interchange> interchange)
Interchange assessed as a part of this transaciton.
-
interchange
final Transaction.Source.CardRefund.Builder interchange(JsonField<Transaction.Source.CardRefund.Interchange> interchange)
Interchange assessed as a part of this transaciton.
-
merchantAcceptorId
final Transaction.Source.CardRefund.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final Transaction.Source.CardRefund.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Transaction.Source.CardRefund.Builder merchantCategoryCode(String merchantCategoryCode)
The 4-digit MCC describing the merchant's business.
-
merchantCategoryCode
final Transaction.Source.CardRefund.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
The 4-digit MCC describing the merchant's business.
-
merchantCity
final Transaction.Source.CardRefund.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final Transaction.Source.CardRefund.Builder merchantCity(JsonField<String> merchantCity)
The city the merchant resides in.
-
merchantCountry
final Transaction.Source.CardRefund.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final Transaction.Source.CardRefund.Builder merchantCountry(JsonField<String> merchantCountry)
The country the merchant resides in.
-
merchantName
final Transaction.Source.CardRefund.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final Transaction.Source.CardRefund.Builder merchantName(JsonField<String> merchantName)
The name of the merchant.
-
merchantPostalCode
final Transaction.Source.CardRefund.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantPostalCode
final Transaction.Source.CardRefund.Builder merchantPostalCode(Optional<String> merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantPostalCode
final Transaction.Source.CardRefund.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantState
final Transaction.Source.CardRefund.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final Transaction.Source.CardRefund.Builder merchantState(Optional<String> merchantState)
The state the merchant resides in.
-
merchantState
final Transaction.Source.CardRefund.Builder merchantState(JsonField<String> merchantState)
The state the merchant resides in.
-
networkIdentifiers
final Transaction.Source.CardRefund.Builder networkIdentifiers(Transaction.Source.CardRefund.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for this refund.
-
networkIdentifiers
final Transaction.Source.CardRefund.Builder networkIdentifiers(JsonField<Transaction.Source.CardRefund.NetworkIdentifiers> networkIdentifiers)
Network-specific identifiers for this refund.
-
presentmentAmount
final Transaction.Source.CardRefund.Builder presentmentAmount(Long presentmentAmount)
The amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final Transaction.Source.CardRefund.Builder presentmentAmount(JsonField<Long> presentmentAmount)
The amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final Transaction.Source.CardRefund.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final Transaction.Source.CardRefund.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
purchaseDetails
final Transaction.Source.CardRefund.Builder purchaseDetails(Transaction.Source.CardRefund.PurchaseDetails purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
purchaseDetails
final Transaction.Source.CardRefund.Builder purchaseDetails(Optional<Transaction.Source.CardRefund.PurchaseDetails> purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
purchaseDetails
final Transaction.Source.CardRefund.Builder purchaseDetails(JsonField<Transaction.Source.CardRefund.PurchaseDetails> purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
transactionId
final Transaction.Source.CardRefund.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this Transaction.
-
transactionId
final Transaction.Source.CardRefund.Builder transactionId(JsonField<String> transactionId)
The identifier of the Transaction associated with this Transaction.
-
type
final Transaction.Source.CardRefund.Builder type(Transaction.Source.CardRefund.Type type)
A constant representing the object's type. For this resource it will always be
card_refund.
-
type
final Transaction.Source.CardRefund.Builder type(JsonField<Transaction.Source.CardRefund.Type> type)
A constant representing the object's type. For this resource it will always be
card_refund.
-
additionalProperties
final Transaction.Source.CardRefund.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRefund.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRefund.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRefund.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRefund.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRefund build()
-
-
-
-