Class Transaction.Source.CardRefund.PurchaseDetails.CarRental
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.CarRentalFields specific to car rentals.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.CarRental.BuilderA builder for CarRental.
public final classTransaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraChargesAdditional charges (gas, late fee, etc.) being billed.
public final classTransaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicatorAn indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
-
Method Summary
Modifier and Type Method Description final Optional<String>carClassCode()Code indicating the vehicle's class. final Optional<LocalDate>checkoutDate()Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date. final Optional<Long>dailyRentalRateAmount()Daily rate being charged for the vehicle. final Optional<String>dailyRentalRateCurrency()The ISO 4217 code for the daily rental rate. final Optional<Long>daysRented()Number of days the vehicle was rented. final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraCharges>extraCharges()Additional charges (gas, late fee, etc.) being billed. final Optional<Long>fuelChargesAmount()Fuel charges for the vehicle. final Optional<String>fuelChargesCurrency()The ISO 4217 code for the fuel charges assessed. final Optional<Long>insuranceChargesAmount()Any insurance being charged for the vehicle. final Optional<String>insuranceChargesCurrency()The ISO 4217 code for the insurance charges assessed. final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicator>noShowIndicator()An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge). final Optional<Long>oneWayDropOffChargesAmount()Charges for returning the vehicle at a different location than where it was picked up. final Optional<String>oneWayDropOffChargesCurrency()The ISO 4217 code for the one-way drop-off charges assessed. final Optional<String>renterName()Name of the person renting the vehicle. final Optional<Long>weeklyRentalRateAmount()Weekly rate being charged for the vehicle. final Optional<String>weeklyRentalRateCurrency()The ISO 4217 code for the weekly rental rate. final JsonField<String>_carClassCode()Code indicating the vehicle's class. final JsonField<LocalDate>_checkoutDate()Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date. final JsonField<Long>_dailyRentalRateAmount()Daily rate being charged for the vehicle. final JsonField<String>_dailyRentalRateCurrency()The ISO 4217 code for the daily rental rate. final JsonField<Long>_daysRented()Number of days the vehicle was rented. final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraCharges>_extraCharges()Additional charges (gas, late fee, etc.) being billed. final JsonField<Long>_fuelChargesAmount()Fuel charges for the vehicle. final JsonField<String>_fuelChargesCurrency()The ISO 4217 code for the fuel charges assessed. final JsonField<Long>_insuranceChargesAmount()Any insurance being charged for the vehicle. final JsonField<String>_insuranceChargesCurrency()The ISO 4217 code for the insurance charges assessed. final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicator>_noShowIndicator()An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge). final JsonField<Long>_oneWayDropOffChargesAmount()Charges for returning the vehicle at a different location than where it was picked up. final JsonField<String>_oneWayDropOffChargesCurrency()The ISO 4217 code for the one-way drop-off charges assessed. final JsonField<String>_renterName()Name of the person renting the vehicle. final JsonField<Long>_weeklyRentalRateAmount()Weekly rate being charged for the vehicle. final JsonField<String>_weeklyRentalRateCurrency()The ISO 4217 code for the weekly rental rate. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRefund.PurchaseDetails.CarRentalvalidate()final Transaction.Source.CardRefund.PurchaseDetails.CarRental.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRefund.PurchaseDetails.CarRental.Builderbuilder()-
-
Method Detail
-
carClassCode
final Optional<String> carClassCode()
Code indicating the vehicle's class.
-
checkoutDate
final Optional<LocalDate> checkoutDate()
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
-
dailyRentalRateAmount
final Optional<Long> dailyRentalRateAmount()
Daily rate being charged for the vehicle.
-
dailyRentalRateCurrency
final Optional<String> dailyRentalRateCurrency()
The ISO 4217 code for the daily rental rate.
-
daysRented
final Optional<Long> daysRented()
Number of days the vehicle was rented.
-
extraCharges
final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraCharges> extraCharges()
Additional charges (gas, late fee, etc.) being billed.
-
fuelChargesAmount
final Optional<Long> fuelChargesAmount()
Fuel charges for the vehicle.
-
fuelChargesCurrency
final Optional<String> fuelChargesCurrency()
The ISO 4217 code for the fuel charges assessed.
-
insuranceChargesAmount
final Optional<Long> insuranceChargesAmount()
Any insurance being charged for the vehicle.
-
insuranceChargesCurrency
final Optional<String> insuranceChargesCurrency()
The ISO 4217 code for the insurance charges assessed.
-
noShowIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicator> noShowIndicator()
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
-
oneWayDropOffChargesAmount
final Optional<Long> oneWayDropOffChargesAmount()
Charges for returning the vehicle at a different location than where it was picked up.
-
oneWayDropOffChargesCurrency
final Optional<String> oneWayDropOffChargesCurrency()
The ISO 4217 code for the one-way drop-off charges assessed.
-
renterName
final Optional<String> renterName()
Name of the person renting the vehicle.
-
weeklyRentalRateAmount
final Optional<Long> weeklyRentalRateAmount()
Weekly rate being charged for the vehicle.
-
weeklyRentalRateCurrency
final Optional<String> weeklyRentalRateCurrency()
The ISO 4217 code for the weekly rental rate.
-
_carClassCode
final JsonField<String> _carClassCode()
Code indicating the vehicle's class.
-
_checkoutDate
final JsonField<LocalDate> _checkoutDate()
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
-
_dailyRentalRateAmount
final JsonField<Long> _dailyRentalRateAmount()
Daily rate being charged for the vehicle.
-
_dailyRentalRateCurrency
final JsonField<String> _dailyRentalRateCurrency()
The ISO 4217 code for the daily rental rate.
-
_daysRented
final JsonField<Long> _daysRented()
Number of days the vehicle was rented.
-
_extraCharges
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraCharges> _extraCharges()
Additional charges (gas, late fee, etc.) being billed.
-
_fuelChargesAmount
final JsonField<Long> _fuelChargesAmount()
Fuel charges for the vehicle.
-
_fuelChargesCurrency
final JsonField<String> _fuelChargesCurrency()
The ISO 4217 code for the fuel charges assessed.
-
_insuranceChargesAmount
final JsonField<Long> _insuranceChargesAmount()
Any insurance being charged for the vehicle.
-
_insuranceChargesCurrency
final JsonField<String> _insuranceChargesCurrency()
The ISO 4217 code for the insurance charges assessed.
-
_noShowIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicator> _noShowIndicator()
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
-
_oneWayDropOffChargesAmount
final JsonField<Long> _oneWayDropOffChargesAmount()
Charges for returning the vehicle at a different location than where it was picked up.
-
_oneWayDropOffChargesCurrency
final JsonField<String> _oneWayDropOffChargesCurrency()
The ISO 4217 code for the one-way drop-off charges assessed.
-
_renterName
final JsonField<String> _renterName()
Name of the person renting the vehicle.
-
_weeklyRentalRateAmount
final JsonField<Long> _weeklyRentalRateAmount()
Weekly rate being charged for the vehicle.
-
_weeklyRentalRateCurrency
final JsonField<String> _weeklyRentalRateCurrency()
The ISO 4217 code for the weekly rental rate.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.CarRental validate()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.CarRental.Builder toBuilder()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.CarRental.Builder builder()
-
-
-
-