Class Transaction.Source.CardRefund.PurchaseDetails.Lodging
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.LodgingFields specific to lodging.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.Lodging.BuilderA builder for Lodging.
public final classTransaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraChargesAdditional charges (phone, late check-out, etc.) being billed.
public final classTransaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicatorIndicator that the cardholder is being billed for a reserved room that was not actually used.
-
Method Summary
Modifier and Type Method Description final Optional<LocalDate>checkInDate()Date the customer checked in. final Optional<Long>dailyRoomRateAmount()Daily rate being charged for the room. final Optional<String>dailyRoomRateCurrency()The ISO 4217 code for the daily room rate. final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges>extraCharges()Additional charges (phone, late check-out, etc.) being billed. final Optional<Long>folioCashAdvancesAmount()Folio cash advances for the room. final Optional<String>folioCashAdvancesCurrency()The ISO 4217 code for the folio cash advances. final Optional<Long>foodBeverageChargesAmount()Food and beverage charges for the room. final Optional<String>foodBeverageChargesCurrency()The ISO 4217 code for the food and beverage charges. final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator>noShowIndicator()Indicator that the cardholder is being billed for a reserved room that was not actually used. final Optional<Long>prepaidExpensesAmount()Prepaid expenses being charged for the room. final Optional<String>prepaidExpensesCurrency()The ISO 4217 code for the prepaid expenses. final Optional<Long>roomNights()Number of nights the room was rented. final Optional<Long>totalRoomTaxAmount()Total room tax being charged. final Optional<String>totalRoomTaxCurrency()The ISO 4217 code for the total room tax. final Optional<Long>totalTaxAmount()Total tax being charged for the room. final Optional<String>totalTaxCurrency()The ISO 4217 code for the total tax assessed. final JsonField<LocalDate>_checkInDate()Date the customer checked in. final JsonField<Long>_dailyRoomRateAmount()Daily rate being charged for the room. final JsonField<String>_dailyRoomRateCurrency()The ISO 4217 code for the daily room rate. final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges>_extraCharges()Additional charges (phone, late check-out, etc.) being billed. final JsonField<Long>_folioCashAdvancesAmount()Folio cash advances for the room. final JsonField<String>_folioCashAdvancesCurrency()The ISO 4217 code for the folio cash advances. final JsonField<Long>_foodBeverageChargesAmount()Food and beverage charges for the room. final JsonField<String>_foodBeverageChargesCurrency()The ISO 4217 code for the food and beverage charges. final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator>_noShowIndicator()Indicator that the cardholder is being billed for a reserved room that was not actually used. final JsonField<Long>_prepaidExpensesAmount()Prepaid expenses being charged for the room. final JsonField<String>_prepaidExpensesCurrency()The ISO 4217 code for the prepaid expenses. final JsonField<Long>_roomNights()Number of nights the room was rented. final JsonField<Long>_totalRoomTaxAmount()Total room tax being charged. final JsonField<String>_totalRoomTaxCurrency()The ISO 4217 code for the total room tax. final JsonField<Long>_totalTaxAmount()Total tax being charged for the room. final JsonField<String>_totalTaxCurrency()The ISO 4217 code for the total tax assessed. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRefund.PurchaseDetails.Lodgingvalidate()final Transaction.Source.CardRefund.PurchaseDetails.Lodging.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builderbuilder()-
-
Method Detail
-
checkInDate
final Optional<LocalDate> checkInDate()
Date the customer checked in.
-
dailyRoomRateAmount
final Optional<Long> dailyRoomRateAmount()
Daily rate being charged for the room.
-
dailyRoomRateCurrency
final Optional<String> dailyRoomRateCurrency()
The ISO 4217 code for the daily room rate.
-
extraCharges
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges> extraCharges()
Additional charges (phone, late check-out, etc.) being billed.
-
folioCashAdvancesAmount
final Optional<Long> folioCashAdvancesAmount()
Folio cash advances for the room.
-
folioCashAdvancesCurrency
final Optional<String> folioCashAdvancesCurrency()
The ISO 4217 code for the folio cash advances.
-
foodBeverageChargesAmount
final Optional<Long> foodBeverageChargesAmount()
Food and beverage charges for the room.
-
foodBeverageChargesCurrency
final Optional<String> foodBeverageChargesCurrency()
The ISO 4217 code for the food and beverage charges.
-
noShowIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator> noShowIndicator()
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
prepaidExpensesAmount
final Optional<Long> prepaidExpensesAmount()
Prepaid expenses being charged for the room.
-
prepaidExpensesCurrency
final Optional<String> prepaidExpensesCurrency()
The ISO 4217 code for the prepaid expenses.
-
roomNights
final Optional<Long> roomNights()
Number of nights the room was rented.
-
totalRoomTaxAmount
final Optional<Long> totalRoomTaxAmount()
Total room tax being charged.
-
totalRoomTaxCurrency
final Optional<String> totalRoomTaxCurrency()
The ISO 4217 code for the total room tax.
-
totalTaxAmount
final Optional<Long> totalTaxAmount()
Total tax being charged for the room.
-
totalTaxCurrency
final Optional<String> totalTaxCurrency()
The ISO 4217 code for the total tax assessed.
-
_checkInDate
final JsonField<LocalDate> _checkInDate()
Date the customer checked in.
-
_dailyRoomRateAmount
final JsonField<Long> _dailyRoomRateAmount()
Daily rate being charged for the room.
-
_dailyRoomRateCurrency
final JsonField<String> _dailyRoomRateCurrency()
The ISO 4217 code for the daily room rate.
-
_extraCharges
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges> _extraCharges()
Additional charges (phone, late check-out, etc.) being billed.
-
_folioCashAdvancesAmount
final JsonField<Long> _folioCashAdvancesAmount()
Folio cash advances for the room.
-
_folioCashAdvancesCurrency
final JsonField<String> _folioCashAdvancesCurrency()
The ISO 4217 code for the folio cash advances.
-
_foodBeverageChargesAmount
final JsonField<Long> _foodBeverageChargesAmount()
Food and beverage charges for the room.
-
_foodBeverageChargesCurrency
final JsonField<String> _foodBeverageChargesCurrency()
The ISO 4217 code for the food and beverage charges.
-
_noShowIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator> _noShowIndicator()
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
_prepaidExpensesAmount
final JsonField<Long> _prepaidExpensesAmount()
Prepaid expenses being charged for the room.
-
_prepaidExpensesCurrency
final JsonField<String> _prepaidExpensesCurrency()
The ISO 4217 code for the prepaid expenses.
-
_roomNights
final JsonField<Long> _roomNights()
Number of nights the room was rented.
-
_totalRoomTaxAmount
final JsonField<Long> _totalRoomTaxAmount()
Total room tax being charged.
-
_totalRoomTaxCurrency
final JsonField<String> _totalRoomTaxCurrency()
The ISO 4217 code for the total room tax.
-
_totalTaxAmount
final JsonField<Long> _totalTaxAmount()
Total tax being charged for the room.
-
_totalTaxCurrency
final JsonField<String> _totalTaxCurrency()
The ISO 4217 code for the total tax assessed.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.Lodging validate()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder toBuilder()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder builder()
-
-
-
-