Class Transaction.Source.CardRevenuePayment
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRevenuePaymentA Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRevenuePayment.BuilderA builder for CardRevenuePayment.
public final classTransaction.Source.CardRevenuePayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.CardRevenuePayment.Currencycurrency()The ISO 4217 code for the transaction currency. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid interest. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid interest. final Optional<String>transactedOnAccountId()The account the card belonged to. final JsonField<Long>_amount()The amount in the minor unit of the transaction's currency. final JsonField<Transaction.Source.CardRevenuePayment.Currency>_currency()The ISO 4217 code for the transaction currency. final JsonField<OffsetDateTime>_periodEnd()The end of the period for which this transaction paid interest. final JsonField<OffsetDateTime>_periodStart()The start of the period for which this transaction paid interest. final JsonField<String>_transactedOnAccountId()The account the card belonged to. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRevenuePaymentvalidate()final Transaction.Source.CardRevenuePayment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRevenuePayment.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.CardRevenuePayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid interest.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid interest.
-
transactedOnAccountId
final Optional<String> transactedOnAccountId()
The account the card belonged to.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<Transaction.Source.CardRevenuePayment.Currency> _currency()
The ISO 4217 code for the transaction currency.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
The end of the period for which this transaction paid interest.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
The start of the period for which this transaction paid interest.
-
_transactedOnAccountId
final JsonField<String> _transactedOnAccountId()
The account the card belonged to.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardRevenuePayment validate()
-
toBuilder
final Transaction.Source.CardRevenuePayment.Builder toBuilder()
-
builder
final static Transaction.Source.CardRevenuePayment.Builder builder()
-
-
-
-