Class Transaction.Source.CashbackPayment
-
- All Implemented Interfaces:
public final class Transaction.Source.CashbackPaymentA Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CashbackPayment.BuilderA builder for CashbackPayment.
public final classTransaction.Source.CashbackPayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final Optional<String>accruedOnCardId()The card on which the cashback was accrued. final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.CashbackPayment.Currencycurrency()The ISO 4217 code for the transaction currency. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid cashback. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid cashback. final JsonField<String>_accruedOnCardId()The card on which the cashback was accrued. final JsonField<Long>_amount()The amount in the minor unit of the transaction's currency. final JsonField<Transaction.Source.CashbackPayment.Currency>_currency()The ISO 4217 code for the transaction currency. final JsonField<OffsetDateTime>_periodEnd()The end of the period for which this transaction paid cashback. final JsonField<OffsetDateTime>_periodStart()The start of the period for which this transaction paid cashback. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CashbackPaymentvalidate()final Transaction.Source.CashbackPayment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CashbackPayment.Builderbuilder()-
-
Method Detail
-
accruedOnCardId
final Optional<String> accruedOnCardId()
The card on which the cashback was accrued.
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.CashbackPayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid cashback.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid cashback.
-
_accruedOnCardId
final JsonField<String> _accruedOnCardId()
The card on which the cashback was accrued.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<Transaction.Source.CashbackPayment.Currency> _currency()
The ISO 4217 code for the transaction currency.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
The end of the period for which this transaction paid cashback.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
The start of the period for which this transaction paid cashback.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CashbackPayment validate()
-
toBuilder
final Transaction.Source.CashbackPayment.Builder toBuilder()
-
builder
final static Transaction.Source.CashbackPayment.Builder builder()
-
-
-
-