Class Transaction.Source.CheckDepositAcceptance
-
- All Implemented Interfaces:
public final class Transaction.Source.CheckDepositAcceptanceA Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CheckDepositAcceptance.BuilderA builder for CheckDepositAcceptance.
public final classTransaction.Source.CheckDepositAcceptance.CurrencyThe ISO 4217 code for the transaction's currency.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number printed on the check. final Longamount()The amount to be deposited in the minor unit of the transaction's currency. final Optional<String>auxiliaryOnUs()An additional line of metadata printed on the check. final StringcheckDepositId()The ID of the Check Deposit that was accepted. final Transaction.Source.CheckDepositAcceptance.Currencycurrency()The ISO 4217 code for the transaction's currency. final StringroutingNumber()The routing number printed on the check. final Optional<String>serialNumber()The check serial number, if present, for consumer checks. final JsonField<String>_accountNumber()The account number printed on the check. final JsonField<Long>_amount()The amount to be deposited in the minor unit of the transaction's currency. final JsonField<String>_auxiliaryOnUs()An additional line of metadata printed on the check. final JsonField<String>_checkDepositId()The ID of the Check Deposit that was accepted. final JsonField<Transaction.Source.CheckDepositAcceptance.Currency>_currency()The ISO 4217 code for the transaction's currency. final JsonField<String>_routingNumber()The routing number printed on the check. final JsonField<String>_serialNumber()The check serial number, if present, for consumer checks. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CheckDepositAcceptancevalidate()final Transaction.Source.CheckDepositAcceptance.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CheckDepositAcceptance.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The account number printed on the check.
-
amount
final Long amount()
The amount to be deposited in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
An additional line of metadata printed on the check. This typically includes the check number for business checks.
-
checkDepositId
final String checkDepositId()
The ID of the Check Deposit that was accepted.
-
currency
final Transaction.Source.CheckDepositAcceptance.Currency currency()
The ISO 4217 code for the transaction's currency.
-
routingNumber
final String routingNumber()
The routing number printed on the check.
-
serialNumber
final Optional<String> serialNumber()
The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the
auxiliary_on_usfield.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number printed on the check.
-
_amount
final JsonField<Long> _amount()
The amount to be deposited in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
An additional line of metadata printed on the check. This typically includes the check number for business checks.
-
_checkDepositId
final JsonField<String> _checkDepositId()
The ID of the Check Deposit that was accepted.
-
_currency
final JsonField<Transaction.Source.CheckDepositAcceptance.Currency> _currency()
The ISO 4217 code for the transaction's currency.
-
_routingNumber
final JsonField<String> _routingNumber()
The routing number printed on the check.
-
_serialNumber
final JsonField<String> _serialNumber()
The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the
auxiliary_on_usfield.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CheckDepositAcceptance validate()
-
toBuilder
final Transaction.Source.CheckDepositAcceptance.Builder toBuilder()
-
builder
final static Transaction.Source.CheckDepositAcceptance.Builder builder()
-
-
-
-