Class Transaction.Source.CheckDepositReturn
-
- All Implemented Interfaces:
public final class Transaction.Source.CheckDepositReturnA Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CheckDepositReturn.BuilderA builder for CheckDepositReturn.
public final classTransaction.Source.CheckDepositReturn.CurrencyThe ISO 4217 code for the transaction's currency.
public final classTransaction.Source.CheckDepositReturn.ReturnReasonWhy this check was returned by the bank holding the account it was drawn against.
-
Method Summary
Modifier and Type Method Description final Longamount()The returned amount in USD cents. final StringcheckDepositId()The identifier of the Check Deposit that was returned. final Transaction.Source.CheckDepositReturn.Currencycurrency()The ISO 4217 code for the transaction's currency. final Transaction.Source.CheckDepositReturn.ReturnReasonreturnReason()Why this check was returned by the bank holding the account it was drawn against. final OffsetDateTimereturnedAt()The ISO 8601 date and time at which the check deposit was returned. final StringtransactionId()The identifier of the transaction that reversed the original check deposit transaction. final JsonField<Long>_amount()The returned amount in USD cents. final JsonField<String>_checkDepositId()The identifier of the Check Deposit that was returned. final JsonField<Transaction.Source.CheckDepositReturn.Currency>_currency()The ISO 4217 code for the transaction's currency. final JsonField<Transaction.Source.CheckDepositReturn.ReturnReason>_returnReason()Why this check was returned by the bank holding the account it was drawn against. final JsonField<OffsetDateTime>_returnedAt()The ISO 8601 date and time at which the check deposit was returned. final JsonField<String>_transactionId()The identifier of the transaction that reversed the original check deposit transaction. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CheckDepositReturnvalidate()final Transaction.Source.CheckDepositReturn.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CheckDepositReturn.Builderbuilder()-
-
Method Detail
-
checkDepositId
final String checkDepositId()
The identifier of the Check Deposit that was returned.
-
currency
final Transaction.Source.CheckDepositReturn.Currency currency()
The ISO 4217 code for the transaction's currency.
-
returnReason
final Transaction.Source.CheckDepositReturn.ReturnReason returnReason()
Why this check was returned by the bank holding the account it was drawn against.
-
returnedAt
final OffsetDateTime returnedAt()
The ISO 8601 date and time at which the check deposit was returned.
-
transactionId
final String transactionId()
The identifier of the transaction that reversed the original check deposit transaction.
-
_checkDepositId
final JsonField<String> _checkDepositId()
The identifier of the Check Deposit that was returned.
-
_currency
final JsonField<Transaction.Source.CheckDepositReturn.Currency> _currency()
The ISO 4217 code for the transaction's currency.
-
_returnReason
final JsonField<Transaction.Source.CheckDepositReturn.ReturnReason> _returnReason()
Why this check was returned by the bank holding the account it was drawn against.
-
_returnedAt
final JsonField<OffsetDateTime> _returnedAt()
The ISO 8601 date and time at which the check deposit was returned.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the transaction that reversed the original check deposit transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CheckDepositReturn validate()
-
toBuilder
final Transaction.Source.CheckDepositReturn.Builder toBuilder()
-
builder
final static Transaction.Source.CheckDepositReturn.Builder builder()
-
-
-
-