Enum Transaction.Source.CheckDepositReturn.ReturnReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.CheckDepositReturn.ReturnReason.Known extends Enum<Transaction.Source.CheckDepositReturn.ReturnReason.Known>
An enum containing ReturnReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.CheckDepositReturn.ReturnReason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACH_CONVERSION_NOT_SUPPORTEDThe check doesn't allow ACH conversion.
CLOSED_ACCOUNTThe account is closed.
DUPLICATE_SUBMISSIONThe check has already been deposited.
INSUFFICIENT_FUNDSInsufficient funds
NO_ACCOUNTNo account was found matching the check details.
NOT_AUTHORIZEDThe check was not authorized.
STALE_DATEDThe check is too old.
STOP_PAYMENTThe payment has been stopped by the account holder.
UNKNOWN_REASONThe reason for the return is unknown.
UNMATCHED_DETAILSThe image doesn't match the details submitted.
UNREADABLE_IMAGEThe image could not be read.
ENDORSEMENT_IRREGULARThe check endorsement was irregular.
ALTERED_OR_FICTITIOUS_ITEMThe check present was either altered or fake.
FROZEN_OR_BLOCKED_ACCOUNTThe account this check is drawn on is frozen.
POST_DATEDThe check is post dated.
ENDORSEMENT_MISSINGThe endorsement was missing.
SIGNATURE_MISSINGThe check signature was missing.
STOP_PAYMENT_SUSPECTThe bank suspects a stop payment will be placed.
UNUSABLE_IMAGEThe bank cannot read the image.
IMAGE_FAILS_SECURITY_CHECKThe check image fails the bank's security check.
CANNOT_DETERMINE_AMOUNTThe bank cannot determine the amount.
SIGNATURE_IRREGULARThe signature is inconsistent with prior signatures.
NON_CASH_ITEMThe check is a non-cash item and cannot be drawn against the account.
UNABLE_TO_PROCESSThe bank is unable to process this check.
ITEM_EXCEEDS_DOLLAR_LIMITThe check exceeds the bank or customer's limit.
BRANCH_OR_ACCOUNT_SOLDThe bank sold this account and no longer services this customer.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CheckDepositReturn.ReturnReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.CheckDepositReturn.ReturnReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.CheckDepositReturn.ReturnReason.Known>getEntries()An enum containing ReturnReason's known values. -
-
Method Detail
-
valueOf
final Transaction.Source.CheckDepositReturn.ReturnReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.CheckDepositReturn.ReturnReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.CheckDepositReturn.ReturnReason.Known> getEntries()
An enum containing ReturnReason's known values.
-
-
-
-