Class Transaction.Source.CheckTransferDeposit
-
- All Implemented Interfaces:
public final class Transaction.Source.CheckTransferDepositA Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CheckTransferDeposit.BuilderA builder for CheckTransferDeposit.
public final classTransaction.Source.CheckTransferDeposit.TypeA constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
Method Summary
Modifier and Type Method Description final Optional<String>backImageFileId()The identifier of the API File object containing an image of the back of the deposited check. final Optional<String>bankOfFirstDepositRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final OffsetDateTimedepositedAt()When the check was deposited. final Optional<String>frontImageFileId()The identifier of the API File object containing an image of the front of the deposited check. final Optional<String>inboundCheckDepositId()The identifier of the Inbound Check Deposit object associated with this transaction. final Optional<String>transactionId()The identifier of the Transaction object created when the check was deposited. final Optional<String>transferId()The identifier of the Check Transfer object that was deposited. final Transaction.Source.CheckTransferDeposit.Typetype()A constant representing the object's type. final JsonField<String>_backImageFileId()The identifier of the API File object containing an image of the back of the deposited check. final JsonField<String>_bankOfFirstDepositRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final JsonField<OffsetDateTime>_depositedAt()When the check was deposited. final JsonField<String>_frontImageFileId()The identifier of the API File object containing an image of the front of the deposited check. final JsonField<String>_inboundCheckDepositId()The identifier of the Inbound Check Deposit object associated with this transaction. final JsonField<String>_transactionId()The identifier of the Transaction object created when the check was deposited. final JsonField<String>_transferId()The identifier of the Check Transfer object that was deposited. final JsonField<Transaction.Source.CheckTransferDeposit.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CheckTransferDepositvalidate()final Transaction.Source.CheckTransferDeposit.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CheckTransferDeposit.Builderbuilder()-
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the API File object containing an image of the back of the deposited check.
-
bankOfFirstDepositRoutingNumber
final Optional<String> bankOfFirstDepositRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
depositedAt
final OffsetDateTime depositedAt()
When the check was deposited.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the API File object containing an image of the front of the deposited check.
-
inboundCheckDepositId
final Optional<String> inboundCheckDepositId()
The identifier of the Inbound Check Deposit object associated with this transaction.
-
transactionId
final Optional<String> transactionId()
The identifier of the Transaction object created when the check was deposited.
-
transferId
final Optional<String> transferId()
The identifier of the Check Transfer object that was deposited.
-
type
final Transaction.Source.CheckTransferDeposit.Type type()
A constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
_backImageFileId
final JsonField<String> _backImageFileId()
The identifier of the API File object containing an image of the back of the deposited check.
-
_bankOfFirstDepositRoutingNumber
final JsonField<String> _bankOfFirstDepositRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
_depositedAt
final JsonField<OffsetDateTime> _depositedAt()
When the check was deposited.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
The identifier of the API File object containing an image of the front of the deposited check.
-
_inboundCheckDepositId
final JsonField<String> _inboundCheckDepositId()
The identifier of the Inbound Check Deposit object associated with this transaction.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction object created when the check was deposited.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Check Transfer object that was deposited.
-
_type
final JsonField<Transaction.Source.CheckTransferDeposit.Type> _type()
A constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CheckTransferDeposit validate()
-
toBuilder
final Transaction.Source.CheckTransferDeposit.Builder toBuilder()
-
builder
final static Transaction.Source.CheckTransferDeposit.Builder builder()
-
-
-
-