Class Transaction.Source.CheckTransferDeposit.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CheckTransferDeposit.BuilderA builder for CheckTransferDeposit.
-
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CheckTransferDeposit.BuilderbackImageFileId(String backImageFileId)The identifier of the API File object containing an image of the back of the deposited check. final Transaction.Source.CheckTransferDeposit.BuilderbackImageFileId(Optional<String> backImageFileId)The identifier of the API File object containing an image of the back of the deposited check. final Transaction.Source.CheckTransferDeposit.BuilderbackImageFileId(JsonField<String> backImageFileId)The identifier of the API File object containing an image of the back of the deposited check. final Transaction.Source.CheckTransferDeposit.BuilderbankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final Transaction.Source.CheckTransferDeposit.BuilderbankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final Transaction.Source.CheckTransferDeposit.BuilderbankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final Transaction.Source.CheckTransferDeposit.BuilderdepositedAt(OffsetDateTime depositedAt)When the check was deposited. final Transaction.Source.CheckTransferDeposit.BuilderdepositedAt(JsonField<OffsetDateTime> depositedAt)When the check was deposited. final Transaction.Source.CheckTransferDeposit.BuilderfrontImageFileId(String frontImageFileId)The identifier of the API File object containing an image of the front of the deposited check. final Transaction.Source.CheckTransferDeposit.BuilderfrontImageFileId(Optional<String> frontImageFileId)The identifier of the API File object containing an image of the front of the deposited check. final Transaction.Source.CheckTransferDeposit.BuilderfrontImageFileId(JsonField<String> frontImageFileId)The identifier of the API File object containing an image of the front of the deposited check. final Transaction.Source.CheckTransferDeposit.BuilderinboundCheckDepositId(String inboundCheckDepositId)The identifier of the Inbound Check Deposit object associated with this transaction. final Transaction.Source.CheckTransferDeposit.BuilderinboundCheckDepositId(Optional<String> inboundCheckDepositId)The identifier of the Inbound Check Deposit object associated with this transaction. final Transaction.Source.CheckTransferDeposit.BuilderinboundCheckDepositId(JsonField<String> inboundCheckDepositId)The identifier of the Inbound Check Deposit object associated with this transaction. final Transaction.Source.CheckTransferDeposit.BuildertransactionId(String transactionId)The identifier of the Transaction object created when the check was deposited. final Transaction.Source.CheckTransferDeposit.BuildertransactionId(Optional<String> transactionId)The identifier of the Transaction object created when the check was deposited. final Transaction.Source.CheckTransferDeposit.BuildertransactionId(JsonField<String> transactionId)The identifier of the Transaction object created when the check was deposited. final Transaction.Source.CheckTransferDeposit.BuildertransferId(String transferId)The identifier of the Check Transfer object that was deposited. final Transaction.Source.CheckTransferDeposit.BuildertransferId(Optional<String> transferId)The identifier of the Check Transfer object that was deposited. final Transaction.Source.CheckTransferDeposit.BuildertransferId(JsonField<String> transferId)The identifier of the Check Transfer object that was deposited. final Transaction.Source.CheckTransferDeposit.Buildertype(Transaction.Source.CheckTransferDeposit.Type type)A constant representing the object's type. final Transaction.Source.CheckTransferDeposit.Buildertype(JsonField<Transaction.Source.CheckTransferDeposit.Type> type)A constant representing the object's type. final Transaction.Source.CheckTransferDeposit.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.Source.CheckTransferDeposit.BuilderputAdditionalProperty(String key, JsonValue value)final Transaction.Source.CheckTransferDeposit.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.Source.CheckTransferDeposit.BuilderremoveAdditionalProperty(String key)final Transaction.Source.CheckTransferDeposit.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transaction.Source.CheckTransferDepositbuild()-
-
Method Detail
-
backImageFileId
final Transaction.Source.CheckTransferDeposit.Builder backImageFileId(String backImageFileId)
The identifier of the API File object containing an image of the back of the deposited check.
-
backImageFileId
final Transaction.Source.CheckTransferDeposit.Builder backImageFileId(Optional<String> backImageFileId)
The identifier of the API File object containing an image of the back of the deposited check.
-
backImageFileId
final Transaction.Source.CheckTransferDeposit.Builder backImageFileId(JsonField<String> backImageFileId)
The identifier of the API File object containing an image of the back of the deposited check.
-
bankOfFirstDepositRoutingNumber
final Transaction.Source.CheckTransferDeposit.Builder bankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
bankOfFirstDepositRoutingNumber
final Transaction.Source.CheckTransferDeposit.Builder bankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
bankOfFirstDepositRoutingNumber
final Transaction.Source.CheckTransferDeposit.Builder bankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
depositedAt
final Transaction.Source.CheckTransferDeposit.Builder depositedAt(OffsetDateTime depositedAt)
When the check was deposited.
-
depositedAt
final Transaction.Source.CheckTransferDeposit.Builder depositedAt(JsonField<OffsetDateTime> depositedAt)
When the check was deposited.
-
frontImageFileId
final Transaction.Source.CheckTransferDeposit.Builder frontImageFileId(String frontImageFileId)
The identifier of the API File object containing an image of the front of the deposited check.
-
frontImageFileId
final Transaction.Source.CheckTransferDeposit.Builder frontImageFileId(Optional<String> frontImageFileId)
The identifier of the API File object containing an image of the front of the deposited check.
-
frontImageFileId
final Transaction.Source.CheckTransferDeposit.Builder frontImageFileId(JsonField<String> frontImageFileId)
The identifier of the API File object containing an image of the front of the deposited check.
-
inboundCheckDepositId
final Transaction.Source.CheckTransferDeposit.Builder inboundCheckDepositId(String inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this transaction.
-
inboundCheckDepositId
final Transaction.Source.CheckTransferDeposit.Builder inboundCheckDepositId(Optional<String> inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this transaction.
-
inboundCheckDepositId
final Transaction.Source.CheckTransferDeposit.Builder inboundCheckDepositId(JsonField<String> inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this transaction.
-
transactionId
final Transaction.Source.CheckTransferDeposit.Builder transactionId(String transactionId)
The identifier of the Transaction object created when the check was deposited.
-
transactionId
final Transaction.Source.CheckTransferDeposit.Builder transactionId(Optional<String> transactionId)
The identifier of the Transaction object created when the check was deposited.
-
transactionId
final Transaction.Source.CheckTransferDeposit.Builder transactionId(JsonField<String> transactionId)
The identifier of the Transaction object created when the check was deposited.
-
transferId
final Transaction.Source.CheckTransferDeposit.Builder transferId(String transferId)
The identifier of the Check Transfer object that was deposited.
-
transferId
final Transaction.Source.CheckTransferDeposit.Builder transferId(Optional<String> transferId)
The identifier of the Check Transfer object that was deposited.
-
transferId
final Transaction.Source.CheckTransferDeposit.Builder transferId(JsonField<String> transferId)
The identifier of the Check Transfer object that was deposited.
-
type
final Transaction.Source.CheckTransferDeposit.Builder type(Transaction.Source.CheckTransferDeposit.Type type)
A constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
type
final Transaction.Source.CheckTransferDeposit.Builder type(JsonField<Transaction.Source.CheckTransferDeposit.Type> type)
A constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
additionalProperties
final Transaction.Source.CheckTransferDeposit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CheckTransferDeposit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CheckTransferDeposit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CheckTransferDeposit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CheckTransferDeposit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CheckTransferDeposit build()
-
-
-
-