Package com.increase.api.models
Class Transaction.Source.FeePayment
-
- All Implemented Interfaces:
public final class Transaction.Source.FeePaymentA Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.FeePayment.BuilderA builder for FeePayment.
public final classTransaction.Source.FeePayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.FeePayment.Currencycurrency()The ISO 4217 code for the transaction currency. final LocalDatefeePeriodStart()The start of this payment's fee period, usually the first day of a month. final Optional<String>programId()The Program for which this fee was incurred. final JsonField<Long>_amount()The amount in the minor unit of the transaction's currency. final JsonField<Transaction.Source.FeePayment.Currency>_currency()The ISO 4217 code for the transaction currency. final JsonField<LocalDate>_feePeriodStart()The start of this payment's fee period, usually the first day of a month. final JsonField<String>_programId()The Program for which this fee was incurred. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.FeePaymentvalidate()final Transaction.Source.FeePayment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.FeePayment.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.FeePayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
feePeriodStart
final LocalDate feePeriodStart()
The start of this payment's fee period, usually the first day of a month.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<Transaction.Source.FeePayment.Currency> _currency()
The ISO 4217 code for the transaction currency.
-
_feePeriodStart
final JsonField<LocalDate> _feePeriodStart()
The start of this payment's fee period, usually the first day of a month.
-
_programId
final JsonField<String> _programId()
The Program for which this fee was incurred.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.FeePayment validate()
-
toBuilder
final Transaction.Source.FeePayment.Builder toBuilder()
-
builder
final static Transaction.Source.FeePayment.Builder builder()
-
-
-
-