Package com.increase.api.models
Class Transaction.Source.FeePayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.FeePayment.BuilderA builder for FeePayment.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.FeePayment.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.FeePayment.Builder amount(JsonField<Long> amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.FeePayment.Builder currency(Transaction.Source.FeePayment.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.FeePayment.Builder currency(JsonField<Transaction.Source.FeePayment.Currency> currency)
The ISO 4217 code for the transaction currency.
-
feePeriodStart
final Transaction.Source.FeePayment.Builder feePeriodStart(LocalDate feePeriodStart)
The start of this payment's fee period, usually the first day of a month.
-
feePeriodStart
final Transaction.Source.FeePayment.Builder feePeriodStart(JsonField<LocalDate> feePeriodStart)
The start of this payment's fee period, usually the first day of a month.
-
programId
final Transaction.Source.FeePayment.Builder programId(String programId)
The Program for which this fee was incurred.
-
programId
final Transaction.Source.FeePayment.Builder programId(Optional<String> programId)
The Program for which this fee was incurred.
-
programId
final Transaction.Source.FeePayment.Builder programId(JsonField<String> programId)
The Program for which this fee was incurred.
-
additionalProperties
final Transaction.Source.FeePayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.FeePayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.FeePayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.FeePayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.FeePayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.FeePayment build()
-
-
-
-