Class Transaction.Source.InboundAchTransfer
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransferAn Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundAchTransfer.BuilderA builder for InboundAchTransfer.
public final classTransaction.Source.InboundAchTransfer.AddendaAdditional information sent from the originator.
-
Method Summary
Modifier and Type Method Description final Optional<Transaction.Source.InboundAchTransfer.Addenda>addenda()Additional information sent from the originator. final Longamount()The transfer amount in USD cents. final Optional<String>originatorCompanyDescriptiveDate()The description of the date of the transfer, usually in the format YYMMDD.final Optional<String>originatorCompanyDiscretionaryData()Data set by the originator. final StringoriginatorCompanyEntryDescription()An informational description of the transfer. final StringoriginatorCompanyId()An identifier for the originating company. final StringoriginatorCompanyName()A name set by the originator to identify themselves. final Optional<String>receiverIdNumber()The originator's identifier for the transfer recipient. final Optional<String>receiverName()The name of the transfer recipient. final StringtraceNumber()A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. final StringtransferId()The Inbound ACH Transfer's identifier. final JsonField<Transaction.Source.InboundAchTransfer.Addenda>_addenda()Additional information sent from the originator. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<String>_originatorCompanyDescriptiveDate()The description of the date of the transfer, usually in the format YYMMDD.final JsonField<String>_originatorCompanyDiscretionaryData()Data set by the originator. final JsonField<String>_originatorCompanyEntryDescription()An informational description of the transfer. final JsonField<String>_originatorCompanyId()An identifier for the originating company. final JsonField<String>_originatorCompanyName()A name set by the originator to identify themselves. final JsonField<String>_receiverIdNumber()The originator's identifier for the transfer recipient. final JsonField<String>_receiverName()The name of the transfer recipient. final JsonField<String>_traceNumber()A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. final JsonField<String>_transferId()The Inbound ACH Transfer's identifier. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundAchTransfervalidate()final Transaction.Source.InboundAchTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundAchTransfer.Builderbuilder()-
-
Method Detail
-
addenda
final Optional<Transaction.Source.InboundAchTransfer.Addenda> addenda()
Additional information sent from the originator.
-
originatorCompanyDescriptiveDate
final Optional<String> originatorCompanyDescriptiveDate()
The description of the date of the transfer, usually in the format
YYMMDD.
-
originatorCompanyDiscretionaryData
final Optional<String> originatorCompanyDiscretionaryData()
Data set by the originator.
-
originatorCompanyEntryDescription
final String originatorCompanyEntryDescription()
An informational description of the transfer.
-
originatorCompanyId
final String originatorCompanyId()
An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.
-
originatorCompanyName
final String originatorCompanyName()
A name set by the originator to identify themselves.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The originator's identifier for the transfer recipient.
-
receiverName
final Optional<String> receiverName()
The name of the transfer recipient. This value is informational and not verified by Increase.
-
traceNumber
final String traceNumber()
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are used to correlate returns.
-
transferId
final String transferId()
The Inbound ACH Transfer's identifier.
-
_addenda
final JsonField<Transaction.Source.InboundAchTransfer.Addenda> _addenda()
Additional information sent from the originator.
-
_originatorCompanyDescriptiveDate
final JsonField<String> _originatorCompanyDescriptiveDate()
The description of the date of the transfer, usually in the format
YYMMDD.
-
_originatorCompanyDiscretionaryData
final JsonField<String> _originatorCompanyDiscretionaryData()
Data set by the originator.
-
_originatorCompanyEntryDescription
final JsonField<String> _originatorCompanyEntryDescription()
An informational description of the transfer.
-
_originatorCompanyId
final JsonField<String> _originatorCompanyId()
An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.
-
_originatorCompanyName
final JsonField<String> _originatorCompanyName()
A name set by the originator to identify themselves.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
The originator's identifier for the transfer recipient.
-
_receiverName
final JsonField<String> _receiverName()
The name of the transfer recipient. This value is informational and not verified by Increase.
-
_traceNumber
final JsonField<String> _traceNumber()
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are used to correlate returns.
-
_transferId
final JsonField<String> _transferId()
The Inbound ACH Transfer's identifier.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundAchTransfer validate()
-
toBuilder
final Transaction.Source.InboundAchTransfer.Builder toBuilder()
-
builder
final static Transaction.Source.InboundAchTransfer.Builder builder()
-
-
-
-