Class Transaction.Source.InboundAchTransfer.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.BuilderA builder for InboundAchTransfer.
-
-
Method Summary
-
-
Method Detail
-
addenda
final Transaction.Source.InboundAchTransfer.Builder addenda(Transaction.Source.InboundAchTransfer.Addenda addenda)
Additional information sent from the originator.
-
addenda
final Transaction.Source.InboundAchTransfer.Builder addenda(Optional<Transaction.Source.InboundAchTransfer.Addenda> addenda)
Additional information sent from the originator.
-
addenda
final Transaction.Source.InboundAchTransfer.Builder addenda(JsonField<Transaction.Source.InboundAchTransfer.Addenda> addenda)
Additional information sent from the originator.
-
amount
final Transaction.Source.InboundAchTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final Transaction.Source.InboundAchTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
originatorCompanyDescriptiveDate
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD.
-
originatorCompanyDescriptiveDate
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD.
-
originatorCompanyDescriptiveDate
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD.
-
originatorCompanyDiscretionaryData
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)
Data set by the originator.
-
originatorCompanyDiscretionaryData
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)
Data set by the originator.
-
originatorCompanyDiscretionaryData
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)
Data set by the originator.
-
originatorCompanyEntryDescription
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyEntryDescription(String originatorCompanyEntryDescription)
An informational description of the transfer.
-
originatorCompanyEntryDescription
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyEntryDescription(JsonField<String> originatorCompanyEntryDescription)
An informational description of the transfer.
-
originatorCompanyId
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyId(String originatorCompanyId)
An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.
-
originatorCompanyId
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyId(JsonField<String> originatorCompanyId)
An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.
-
originatorCompanyName
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyName(String originatorCompanyName)
A name set by the originator to identify themselves.
-
originatorCompanyName
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyName(JsonField<String> originatorCompanyName)
A name set by the originator to identify themselves.
-
receiverIdNumber
final Transaction.Source.InboundAchTransfer.Builder receiverIdNumber(String receiverIdNumber)
The originator's identifier for the transfer recipient.
-
receiverIdNumber
final Transaction.Source.InboundAchTransfer.Builder receiverIdNumber(Optional<String> receiverIdNumber)
The originator's identifier for the transfer recipient.
-
receiverIdNumber
final Transaction.Source.InboundAchTransfer.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
The originator's identifier for the transfer recipient.
-
receiverName
final Transaction.Source.InboundAchTransfer.Builder receiverName(String receiverName)
The name of the transfer recipient. This value is informational and not verified by Increase.
-
receiverName
final Transaction.Source.InboundAchTransfer.Builder receiverName(Optional<String> receiverName)
The name of the transfer recipient. This value is informational and not verified by Increase.
-
receiverName
final Transaction.Source.InboundAchTransfer.Builder receiverName(JsonField<String> receiverName)
The name of the transfer recipient. This value is informational and not verified by Increase.
-
traceNumber
final Transaction.Source.InboundAchTransfer.Builder traceNumber(String traceNumber)
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are used to correlate returns.
-
traceNumber
final Transaction.Source.InboundAchTransfer.Builder traceNumber(JsonField<String> traceNumber)
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are used to correlate returns.
-
transferId
final Transaction.Source.InboundAchTransfer.Builder transferId(String transferId)
The Inbound ACH Transfer's identifier.
-
transferId
final Transaction.Source.InboundAchTransfer.Builder transferId(JsonField<String> transferId)
The Inbound ACH Transfer's identifier.
-
additionalProperties
final Transaction.Source.InboundAchTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundAchTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundAchTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundAchTransfer build()
-
-
-
-