Package com.increase.api.models
Class Transaction.Source.InboundAchTransferReturnIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransferReturnIntentionAn Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundAchTransferReturnIntention.BuilderA builder for InboundAchTransferReturnIntention.
-
Method Summary
Modifier and Type Method Description final StringinboundAchTransferId()The ID of the Inbound ACH Transfer that is being returned. final JsonField<String>_inboundAchTransferId()The ID of the Inbound ACH Transfer that is being returned. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundAchTransferReturnIntentionvalidate()final Transaction.Source.InboundAchTransferReturnIntention.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundAchTransferReturnIntention.Builderbuilder()-
-
Method Detail
-
inboundAchTransferId
final String inboundAchTransferId()
The ID of the Inbound ACH Transfer that is being returned.
-
_inboundAchTransferId
final JsonField<String> _inboundAchTransferId()
The ID of the Inbound ACH Transfer that is being returned.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundAchTransferReturnIntention validate()
-
toBuilder
final Transaction.Source.InboundAchTransferReturnIntention.Builder toBuilder()
-
builder
final static Transaction.Source.InboundAchTransferReturnIntention.Builder builder()
-
-
-
-