Package com.increase.api.models
Class Transaction.Source.InboundCheckAdjustment
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundCheckAdjustmentAn Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundCheckAdjustment.BuilderA builder for InboundCheckAdjustment.
public final classTransaction.Source.InboundCheckAdjustment.ReasonThe reason for the adjustment.
-
Method Summary
Modifier and Type Method Description final StringadjustedTransactionId()The ID of the transaction that was adjusted. final Longamount()The amount of the check adjustment. final Transaction.Source.InboundCheckAdjustment.Reasonreason()The reason for the adjustment. final JsonField<String>_adjustedTransactionId()The ID of the transaction that was adjusted. final JsonField<Long>_amount()The amount of the check adjustment. final JsonField<Transaction.Source.InboundCheckAdjustment.Reason>_reason()The reason for the adjustment. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundCheckAdjustmentvalidate()final Transaction.Source.InboundCheckAdjustment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundCheckAdjustment.Builderbuilder()-
-
Method Detail
-
adjustedTransactionId
final String adjustedTransactionId()
The ID of the transaction that was adjusted.
-
reason
final Transaction.Source.InboundCheckAdjustment.Reason reason()
The reason for the adjustment.
-
_adjustedTransactionId
final JsonField<String> _adjustedTransactionId()
The ID of the transaction that was adjusted.
-
_reason
final JsonField<Transaction.Source.InboundCheckAdjustment.Reason> _reason()
The reason for the adjustment.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundCheckAdjustment validate()
-
toBuilder
final Transaction.Source.InboundCheckAdjustment.Builder toBuilder()
-
builder
final static Transaction.Source.InboundCheckAdjustment.Builder builder()
-
-
-
-