Class Transaction.Source.InboundCheckDepositReturnIntention

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InboundCheckDepositReturnIntention
    
                        

    An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if category is equal to inbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.