Class Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundRealTimePaymentsTransferConfirmation.BuilderA builder for InboundRealTimePaymentsTransferConfirmation.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder amount(Long amount)
The amount in the minor unit of the transfer's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder amount(JsonField<Long> amount)
The amount in the minor unit of the transfer's currency. For dollars, for example, this is cents.
-
creditorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder creditorName(String creditorName)
The name the sender of the transfer specified as the recipient of the transfer.
-
creditorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder creditorName(JsonField<String> creditorName)
The name the sender of the transfer specified as the recipient of the transfer.
-
currency
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder currency(Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency currency)
The ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
currency
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder currency(JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency> currency)
The ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
debtorAccountNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorAccountNumber(String debtorAccountNumber)
The account number of the account that sent the transfer.
-
debtorAccountNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorAccountNumber(JsonField<String> debtorAccountNumber)
The account number of the account that sent the transfer.
-
debtorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorName(String debtorName)
The name provided by the sender of the transfer.
-
debtorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorName(JsonField<String> debtorName)
The name provided by the sender of the transfer.
-
debtorRoutingNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorRoutingNumber(String debtorRoutingNumber)
The routing number of the account that sent the transfer.
-
debtorRoutingNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
The routing number of the account that sent the transfer.
-
remittanceInformation
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder remittanceInformation(String remittanceInformation)
Additional information included with the transfer.
-
remittanceInformation
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder remittanceInformation(Optional<String> remittanceInformation)
Additional information included with the transfer.
-
remittanceInformation
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder remittanceInformation(JsonField<String> remittanceInformation)
Additional information included with the transfer.
-
transactionIdentification
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transactionIdentification(String transactionIdentification)
The Real-Time Payments network identification of the transfer.
-
transactionIdentification
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transactionIdentification(JsonField<String> transactionIdentification)
The Real-Time Payments network identification of the transfer.
-
transferId
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transferId(String transferId)
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
transferId
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transferId(JsonField<String> transferId)
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
additionalProperties
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-