Class Transaction.Source.InboundWireReversal
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireReversalAn Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundWireReversal.BuilderA builder for InboundWireReversal.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount that was reversed in USD cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the reversal was created. final Stringdescription()The description on the reversal message from Fedwire, set by the reversing bank. final Optional<String>financialInstitutionToFinancialInstitutionInformation()Additional financial institution information included in the wire reversal. final LocalDateinputCycleDate()The Fedwire cycle date for the wire reversal. final StringinputMessageAccountabilityData()The Fedwire transaction identifier. final StringinputSequenceNumber()The Fedwire sequence number. final StringinputSource()The Fedwire input source identifier. final Optional<String>originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final LocalDatepreviousMessageInputCycleDate()The Fedwire cycle date for the wire transfer that is being reversed by this message. final StringpreviousMessageInputMessageAccountabilityData()The Fedwire transaction identifier for the wire transfer that was reversed. final StringpreviousMessageInputSequenceNumber()The Fedwire sequence number for the wire transfer that was reversed. final StringpreviousMessageInputSource()The Fedwire input source identifier for the wire transfer that was reversed. final Optional<String>receiverFinancialInstitutionInformation()Information included in the wire reversal for the receiving financial institution. final Optional<String>senderReference()The sending bank's reference number for the wire reversal. final StringtransactionId()The ID for the Transaction associated with the transfer reversal. final StringwireTransferId()The ID for the Wire Transfer that is being reversed. final JsonField<Long>_amount()The amount that was reversed in USD cents. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the reversal was created. final JsonField<String>_description()The description on the reversal message from Fedwire, set by the reversing bank. final JsonField<String>_financialInstitutionToFinancialInstitutionInformation()Additional financial institution information included in the wire reversal. final JsonField<LocalDate>_inputCycleDate()The Fedwire cycle date for the wire reversal. final JsonField<String>_inputMessageAccountabilityData()The Fedwire transaction identifier. final JsonField<String>_inputSequenceNumber()The Fedwire sequence number. final JsonField<String>_inputSource()The Fedwire input source identifier. final JsonField<String>_originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final JsonField<LocalDate>_previousMessageInputCycleDate()The Fedwire cycle date for the wire transfer that is being reversed by this message. final JsonField<String>_previousMessageInputMessageAccountabilityData()The Fedwire transaction identifier for the wire transfer that was reversed. final JsonField<String>_previousMessageInputSequenceNumber()The Fedwire sequence number for the wire transfer that was reversed. final JsonField<String>_previousMessageInputSource()The Fedwire input source identifier for the wire transfer that was reversed. final JsonField<String>_receiverFinancialInstitutionInformation()Information included in the wire reversal for the receiving financial institution. final JsonField<String>_senderReference()The sending bank's reference number for the wire reversal. final JsonField<String>_transactionId()The ID for the Transaction associated with the transfer reversal. final JsonField<String>_wireTransferId()The ID for the Wire Transfer that is being reversed. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundWireReversalvalidate()final Transaction.Source.InboundWireReversal.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundWireReversal.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the reversal was created.
-
description
final String description()
The description on the reversal message from Fedwire, set by the reversing bank.
-
financialInstitutionToFinancialInstitutionInformation
final Optional<String> financialInstitutionToFinancialInstitutionInformation()
Additional financial institution information included in the wire reversal.
-
inputCycleDate
final LocalDate inputCycleDate()
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00 PM Eastern Time on the evening before the
cycle date.
-
inputMessageAccountabilityData
final String inputMessageAccountabilityData()
The Fedwire transaction identifier.
-
inputSequenceNumber
final String inputSequenceNumber()
The Fedwire sequence number.
-
inputSource
final String inputSource()
The Fedwire input source identifier.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
previousMessageInputCycleDate
final LocalDate previousMessageInputCycleDate()
The Fedwire cycle date for the wire transfer that is being reversed by this message.
-
previousMessageInputMessageAccountabilityData
final String previousMessageInputMessageAccountabilityData()
The Fedwire transaction identifier for the wire transfer that was reversed.
-
previousMessageInputSequenceNumber
final String previousMessageInputSequenceNumber()
The Fedwire sequence number for the wire transfer that was reversed.
-
previousMessageInputSource
final String previousMessageInputSource()
The Fedwire input source identifier for the wire transfer that was reversed.
-
receiverFinancialInstitutionInformation
final Optional<String> receiverFinancialInstitutionInformation()
Information included in the wire reversal for the receiving financial institution.
-
senderReference
final Optional<String> senderReference()
The sending bank's reference number for the wire reversal.
-
transactionId
final String transactionId()
The ID for the Transaction associated with the transfer reversal.
-
wireTransferId
final String wireTransferId()
The ID for the Wire Transfer that is being reversed.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the reversal was created.
-
_description
final JsonField<String> _description()
The description on the reversal message from Fedwire, set by the reversing bank.
-
_financialInstitutionToFinancialInstitutionInformation
final JsonField<String> _financialInstitutionToFinancialInstitutionInformation()
Additional financial institution information included in the wire reversal.
-
_inputCycleDate
final JsonField<LocalDate> _inputCycleDate()
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00 PM Eastern Time on the evening before the
cycle date.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
The Fedwire transaction identifier.
-
_inputSequenceNumber
final JsonField<String> _inputSequenceNumber()
The Fedwire sequence number.
-
_inputSource
final JsonField<String> _inputSource()
The Fedwire input source identifier.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
_previousMessageInputCycleDate
final JsonField<LocalDate> _previousMessageInputCycleDate()
The Fedwire cycle date for the wire transfer that is being reversed by this message.
-
_previousMessageInputMessageAccountabilityData
final JsonField<String> _previousMessageInputMessageAccountabilityData()
The Fedwire transaction identifier for the wire transfer that was reversed.
-
_previousMessageInputSequenceNumber
final JsonField<String> _previousMessageInputSequenceNumber()
The Fedwire sequence number for the wire transfer that was reversed.
-
_previousMessageInputSource
final JsonField<String> _previousMessageInputSource()
The Fedwire input source identifier for the wire transfer that was reversed.
-
_receiverFinancialInstitutionInformation
final JsonField<String> _receiverFinancialInstitutionInformation()
Information included in the wire reversal for the receiving financial institution.
-
_senderReference
final JsonField<String> _senderReference()
The sending bank's reference number for the wire reversal.
-
_transactionId
final JsonField<String> _transactionId()
The ID for the Transaction associated with the transfer reversal.
-
_wireTransferId
final JsonField<String> _wireTransferId()
The ID for the Wire Transfer that is being reversed.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundWireReversal validate()
-
toBuilder
final Transaction.Source.InboundWireReversal.Builder toBuilder()
-
builder
final static Transaction.Source.InboundWireReversal.Builder builder()
-
-
-
-