Class Transaction.Source.InboundWireTransfer
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireTransferAn Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in USD cents. final Optional<String>beneficiaryAddressLine1()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine2()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine3()A free-form address field set by the sender. final Optional<String>beneficiaryName()A name set by the sender. final Optional<String>beneficiaryReference()A free-form reference string set by the sender, to help identify the transfer. final Stringdescription()An Increase-constructed description of the transfer. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>originatorAddressLine1()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine2()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine3()The address of the wire originator, set by the sending bank. final Optional<String>originatorName()The originator of the wire, set by the sending bank. final Optional<String>originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>originatorToBeneficiaryInformation()An Increase-created concatenation of the Originator-to-Beneficiary lines. final Optional<String>originatorToBeneficiaryInformationLine1()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine2()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine3()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine4()A free-form message set by the wire originator. final StringtransferId()The ID of the Inbound Wire Transfer object that resulted in this Transaction. final JsonField<Long>_amount()The amount in USD cents. final JsonField<String>_beneficiaryAddressLine1()A free-form address field set by the sender. final JsonField<String>_beneficiaryAddressLine2()A free-form address field set by the sender. final JsonField<String>_beneficiaryAddressLine3()A free-form address field set by the sender. final JsonField<String>_beneficiaryName()A name set by the sender. final JsonField<String>_beneficiaryReference()A free-form reference string set by the sender, to help identify the transfer. final JsonField<String>_description()An Increase-constructed description of the transfer. final JsonField<String>_inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final JsonField<String>_originatorAddressLine1()The address of the wire originator, set by the sending bank. final JsonField<String>_originatorAddressLine2()The address of the wire originator, set by the sending bank. final JsonField<String>_originatorAddressLine3()The address of the wire originator, set by the sending bank. final JsonField<String>_originatorName()The originator of the wire, set by the sending bank. final JsonField<String>_originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final JsonField<String>_originatorToBeneficiaryInformation()An Increase-created concatenation of the Originator-to-Beneficiary lines. final JsonField<String>_originatorToBeneficiaryInformationLine1()A free-form message set by the wire originator. final JsonField<String>_originatorToBeneficiaryInformationLine2()A free-form message set by the wire originator. final JsonField<String>_originatorToBeneficiaryInformationLine3()A free-form message set by the wire originator. final JsonField<String>_originatorToBeneficiaryInformationLine4()A free-form message set by the wire originator. final JsonField<String>_transferId()The ID of the Inbound Wire Transfer object that resulted in this Transaction. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundWireTransfervalidate()final Transaction.Source.InboundWireTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundWireTransfer.Builderbuilder()-
-
Method Detail
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
A free-form address field set by the sender.
-
beneficiaryName
final Optional<String> beneficiaryName()
A name set by the sender.
-
beneficiaryReference
final Optional<String> beneficiaryReference()
A free-form reference string set by the sender, to help identify the transfer.
-
description
final String description()
An Increase-constructed description of the transfer.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The address of the wire originator, set by the sending bank.
-
originatorName
final Optional<String> originatorName()
The originator of the wire, set by the sending bank.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final Optional<String> originatorToBeneficiaryInformation()
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
A free-form message set by the wire originator.
-
transferId
final String transferId()
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
A free-form address field set by the sender.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
A free-form address field set by the sender.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
A free-form address field set by the sender.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
A name set by the sender.
-
_beneficiaryReference
final JsonField<String> _beneficiaryReference()
A free-form reference string set by the sender, to help identify the transfer.
-
_description
final JsonField<String> _description()
An Increase-constructed description of the transfer.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
The address of the wire originator, set by the sending bank.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
The address of the wire originator, set by the sending bank.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
The address of the wire originator, set by the sending bank.
-
_originatorName
final JsonField<String> _originatorName()
The originator of the wire, set by the sending bank.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
_originatorToBeneficiaryInformation
final JsonField<String> _originatorToBeneficiaryInformation()
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
A free-form message set by the wire originator.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
A free-form message set by the wire originator.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
A free-form message set by the wire originator.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
A free-form message set by the wire originator.
-
_transferId
final JsonField<String> _transferId()
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundWireTransfer validate()
-
toBuilder
final Transaction.Source.InboundWireTransfer.Builder toBuilder()
-
builder
final static Transaction.Source.InboundWireTransfer.Builder builder()
-
-
-
-