Class Transaction.Source.InboundWireTransfer.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
-
Method Summary
Modifier and Type Method Description final Transaction.Source.InboundWireTransfer.Builderamount(Long amount)The amount in USD cents. final Transaction.Source.InboundWireTransfer.Builderamount(JsonField<Long> amount)The amount in USD cents. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)A free-form address field set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryName(String beneficiaryName)A name set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryName(Optional<String> beneficiaryName)A name set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryName(JsonField<String> beneficiaryName)A name set by the sender. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryReference(String beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryReference(Optional<String> beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final Transaction.Source.InboundWireTransfer.BuilderbeneficiaryReference(JsonField<String> beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final Transaction.Source.InboundWireTransfer.Builderdescription(String description)An Increase-constructed description of the transfer. final Transaction.Source.InboundWireTransfer.Builderdescription(JsonField<String> description)An Increase-constructed description of the transfer. final Transaction.Source.InboundWireTransfer.BuilderinputMessageAccountabilityData(String inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Transaction.Source.InboundWireTransfer.BuilderinputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Transaction.Source.InboundWireTransfer.BuilderinputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine1(String originatorAddressLine1)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine1(Optional<String> originatorAddressLine1)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine2(String originatorAddressLine2)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine2(Optional<String> originatorAddressLine2)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine3(String originatorAddressLine3)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine3(Optional<String> originatorAddressLine3)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)The address of the wire originator, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorName(String originatorName)The originator of the wire, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorName(Optional<String> originatorName)The originator of the wire, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorName(JsonField<String> originatorName)The originator of the wire, set by the sending bank. final Transaction.Source.InboundWireTransfer.BuilderoriginatorRoutingNumber(String originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final Transaction.Source.InboundWireTransfer.BuilderoriginatorRoutingNumber(Optional<String> originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final Transaction.Source.InboundWireTransfer.BuilderoriginatorRoutingNumber(JsonField<String> originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final Transaction.Source.InboundWireTransfer.BuildertransferId(String transferId)The ID of the Inbound Wire Transfer object that resulted in this Transaction. final Transaction.Source.InboundWireTransfer.BuildertransferId(JsonField<String> transferId)The ID of the Inbound Wire Transfer object that resulted in this Transaction. final Transaction.Source.InboundWireTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.Source.InboundWireTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final Transaction.Source.InboundWireTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.Source.InboundWireTransfer.BuilderremoveAdditionalProperty(String key)final Transaction.Source.InboundWireTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transaction.Source.InboundWireTransferbuild()-
-
Method Detail
-
amount
final Transaction.Source.InboundWireTransfer.Builder amount(Long amount)
The amount in USD cents.
-
amount
final Transaction.Source.InboundWireTransfer.Builder amount(JsonField<Long> amount)
The amount in USD cents.
-
beneficiaryAddressLine1
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine1
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine1
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryName
final Transaction.Source.InboundWireTransfer.Builder beneficiaryName(String beneficiaryName)
A name set by the sender.
-
beneficiaryName
final Transaction.Source.InboundWireTransfer.Builder beneficiaryName(Optional<String> beneficiaryName)
A name set by the sender.
-
beneficiaryName
final Transaction.Source.InboundWireTransfer.Builder beneficiaryName(JsonField<String> beneficiaryName)
A name set by the sender.
-
beneficiaryReference
final Transaction.Source.InboundWireTransfer.Builder beneficiaryReference(String beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
beneficiaryReference
final Transaction.Source.InboundWireTransfer.Builder beneficiaryReference(Optional<String> beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
beneficiaryReference
final Transaction.Source.InboundWireTransfer.Builder beneficiaryReference(JsonField<String> beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
description
final Transaction.Source.InboundWireTransfer.Builder description(String description)
An Increase-constructed description of the transfer.
-
description
final Transaction.Source.InboundWireTransfer.Builder description(JsonField<String> description)
An Increase-constructed description of the transfer.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireTransfer.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireTransfer.Builder inputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireTransfer.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
originatorAddressLine1
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine1(String originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine1
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine1
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine2(String originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine3(String originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorName
final Transaction.Source.InboundWireTransfer.Builder originatorName(String originatorName)
The originator of the wire, set by the sending bank.
-
originatorName
final Transaction.Source.InboundWireTransfer.Builder originatorName(Optional<String> originatorName)
The originator of the wire, set by the sending bank.
-
originatorName
final Transaction.Source.InboundWireTransfer.Builder originatorName(JsonField<String> originatorName)
The originator of the wire, set by the sending bank.
-
originatorRoutingNumber
final Transaction.Source.InboundWireTransfer.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final Transaction.Source.InboundWireTransfer.Builder originatorRoutingNumber(Optional<String> originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final Transaction.Source.InboundWireTransfer.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformationLine1
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine1
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine1
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
transferId
final Transaction.Source.InboundWireTransfer.Builder transferId(String transferId)
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
transferId
final Transaction.Source.InboundWireTransfer.Builder transferId(JsonField<String> transferId)
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
additionalProperties
final Transaction.Source.InboundWireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundWireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundWireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundWireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundWireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundWireTransfer build()
-
-
-
-