Class Transaction.Source.InterestPayment
-
- All Implemented Interfaces:
public final class Transaction.Source.InterestPaymentAn Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InterestPayment.BuilderA builder for InterestPayment.
public final classTransaction.Source.InterestPayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final StringaccruedOnAccountId()The account on which the interest was accrued. final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.InterestPayment.Currencycurrency()The ISO 4217 code for the transaction currency. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid interest. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid interest. final JsonField<String>_accruedOnAccountId()The account on which the interest was accrued. final JsonField<Long>_amount()The amount in the minor unit of the transaction's currency. final JsonField<Transaction.Source.InterestPayment.Currency>_currency()The ISO 4217 code for the transaction currency. final JsonField<OffsetDateTime>_periodEnd()The end of the period for which this transaction paid interest. final JsonField<OffsetDateTime>_periodStart()The start of the period for which this transaction paid interest. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InterestPaymentvalidate()final Transaction.Source.InterestPayment.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InterestPayment.Builderbuilder()-
-
Method Detail
-
accruedOnAccountId
final String accruedOnAccountId()
The account on which the interest was accrued.
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.InterestPayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid interest.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid interest.
-
_accruedOnAccountId
final JsonField<String> _accruedOnAccountId()
The account on which the interest was accrued.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<Transaction.Source.InterestPayment.Currency> _currency()
The ISO 4217 code for the transaction currency.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
The end of the period for which this transaction paid interest.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
The start of the period for which this transaction paid interest.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InterestPayment validate()
-
toBuilder
final Transaction.Source.InterestPayment.Builder toBuilder()
-
builder
final static Transaction.Source.InterestPayment.Builder builder()
-
-
-
-