Package com.increase.api.models
Class Transaction.Source.InterestPayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InterestPayment.BuilderA builder for InterestPayment.
-
-
Method Summary
-
-
Method Detail
-
accruedOnAccountId
final Transaction.Source.InterestPayment.Builder accruedOnAccountId(String accruedOnAccountId)
The account on which the interest was accrued.
-
accruedOnAccountId
final Transaction.Source.InterestPayment.Builder accruedOnAccountId(JsonField<String> accruedOnAccountId)
The account on which the interest was accrued.
-
amount
final Transaction.Source.InterestPayment.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.InterestPayment.Builder amount(JsonField<Long> amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.InterestPayment.Builder currency(Transaction.Source.InterestPayment.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.InterestPayment.Builder currency(JsonField<Transaction.Source.InterestPayment.Currency> currency)
The ISO 4217 code for the transaction currency.
-
periodEnd
final Transaction.Source.InterestPayment.Builder periodEnd(OffsetDateTime periodEnd)
The end of the period for which this transaction paid interest.
-
periodEnd
final Transaction.Source.InterestPayment.Builder periodEnd(JsonField<OffsetDateTime> periodEnd)
The end of the period for which this transaction paid interest.
-
periodStart
final Transaction.Source.InterestPayment.Builder periodStart(OffsetDateTime periodStart)
The start of the period for which this transaction paid interest.
-
periodStart
final Transaction.Source.InterestPayment.Builder periodStart(JsonField<OffsetDateTime> periodStart)
The start of the period for which this transaction paid interest.
-
additionalProperties
final Transaction.Source.InterestPayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InterestPayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InterestPayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InterestPayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InterestPayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InterestPayment build()
-
-
-
-