Class Transaction.Source.InternalSource
-
- All Implemented Interfaces:
public final class Transaction.Source.InternalSourceAn Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InternalSource.BuilderA builder for InternalSource.
public final classTransaction.Source.InternalSource.CurrencyThe ISO 4217 code for the transaction currency.
public final classTransaction.Source.InternalSource.ReasonAn Internal Source is a transaction between you and Increase. This describes the reason for the transaction.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.InternalSource.Currencycurrency()The ISO 4217 code for the transaction currency. final Transaction.Source.InternalSource.Reasonreason()An Internal Source is a transaction between you and Increase. final JsonField<Long>_amount()The amount in the minor unit of the transaction's currency. final JsonField<Transaction.Source.InternalSource.Currency>_currency()The ISO 4217 code for the transaction currency. final JsonField<Transaction.Source.InternalSource.Reason>_reason()An Internal Source is a transaction between you and Increase. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InternalSourcevalidate()final Transaction.Source.InternalSource.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InternalSource.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.InternalSource.Currency currency()
The ISO 4217 code for the transaction currency.
-
reason
final Transaction.Source.InternalSource.Reason reason()
An Internal Source is a transaction between you and Increase. This describes the reason for the transaction.
-
_amount
final JsonField<Long> _amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_currency
final JsonField<Transaction.Source.InternalSource.Currency> _currency()
The ISO 4217 code for the transaction currency.
-
_reason
final JsonField<Transaction.Source.InternalSource.Reason> _reason()
An Internal Source is a transaction between you and Increase. This describes the reason for the transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InternalSource validate()
-
toBuilder
final Transaction.Source.InternalSource.Builder toBuilder()
-
builder
final static Transaction.Source.InternalSource.Builder builder()
-
-
-
-