Package com.increase.api.models
Class Transaction.Source.WireTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.WireTransferIntentionA Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.WireTransferIntention.BuilderA builder for WireTransferIntention.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The destination account number. final Longamount()The transfer amount in USD cents. final StringmessageToRecipient()The message that will show on the recipient's bank statement. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final StringtransferId()The identifier of the Wire Transfer that led to this Transaction. final JsonField<String>_accountNumber()The destination account number. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<String>_messageToRecipient()The message that will show on the recipient's bank statement. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<String>_transferId()The identifier of the Wire Transfer that led to this Transaction. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.WireTransferIntentionvalidate()final Transaction.Source.WireTransferIntention.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.WireTransferIntention.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
messageToRecipient
final String messageToRecipient()
The message that will show on the recipient's bank statement.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
transferId
final String transferId()
The identifier of the Wire Transfer that led to this Transaction.
-
_accountNumber
final JsonField<String> _accountNumber()
The destination account number.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
The message that will show on the recipient's bank statement.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_transferId
final JsonField<String> _transferId()
The identifier of the Wire Transfer that led to this Transaction.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.WireTransferIntention validate()
-
toBuilder
final Transaction.Source.WireTransferIntention.Builder toBuilder()
-
builder
final static Transaction.Source.WireTransferIntention.Builder builder()
-
-
-
-