Class WireDrawdownRequest
-
- All Implemented Interfaces:
public final class WireDrawdownRequestWire drawdown requests enable you to request that someone else send you a wire. This feature is in beta; reach out to [email protected] to learn more.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequest.BuilderA builder for WireDrawdownRequest.
public final classWireDrawdownRequest.StatusThe lifecycle status of the drawdown request.
public final classWireDrawdownRequest.SubmissionAfter the drawdown request is submitted to Fedwire, this will contain supplemental details.
public final classWireDrawdownRequest.TypeA constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Wire drawdown request identifier. final StringaccountNumberId()The Account Number to which the recipient of this request is being requested to send funds. final Longamount()The amount being requested in cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the wire drawdown request was created. final Stringcurrency()The ISO 4217 code for the amount being requested. final Optional<String>fulfillmentInboundWireTransferId()If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringmessageToRecipient()The message the recipient will see as part of the drawdown request. final Optional<String>originatorAddressLine1()The originator's address line 1. final Optional<String>originatorAddressLine2()The originator's address line 2. final Optional<String>originatorAddressLine3()The originator's address line 3. final Optional<String>originatorName()The originator's name. final StringrecipientAccountNumber()The drawdown request's recipient's account number. final Optional<String>recipientAddressLine1()Line 1 of the drawdown request's recipient's address. final Optional<String>recipientAddressLine2()Line 2 of the drawdown request's recipient's address. final Optional<String>recipientAddressLine3()Line 3 of the drawdown request's recipient's address. final Optional<String>recipientName()The drawdown request's recipient's name. final StringrecipientRoutingNumber()The drawdown request's recipient's routing number. final WireDrawdownRequest.Statusstatus()The lifecycle status of the drawdown request. final Optional<WireDrawdownRequest.Submission>submission()After the drawdown request is submitted to Fedwire, this will contain supplemental details. final WireDrawdownRequest.Typetype()A constant representing the object's type. final JsonField<String>_id()The Wire drawdown request identifier. final JsonField<String>_accountNumberId()The Account Number to which the recipient of this request is being requested to send funds. final JsonField<Long>_amount()The amount being requested in cents. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the wire drawdown request was created. final JsonField<String>_currency()The ISO 4217 code for the amount being requested. final JsonField<String>_fulfillmentInboundWireTransferId()If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_messageToRecipient()The message the recipient will see as part of the drawdown request. final JsonField<String>_originatorAddressLine1()The originator's address line 1. final JsonField<String>_originatorAddressLine2()The originator's address line 2. final JsonField<String>_originatorAddressLine3()The originator's address line 3. final JsonField<String>_originatorName()The originator's name. final JsonField<String>_recipientAccountNumber()The drawdown request's recipient's account number. final JsonField<String>_recipientAddressLine1()Line 1 of the drawdown request's recipient's address. final JsonField<String>_recipientAddressLine2()Line 2 of the drawdown request's recipient's address. final JsonField<String>_recipientAddressLine3()Line 3 of the drawdown request's recipient's address. final JsonField<String>_recipientName()The drawdown request's recipient's name. final JsonField<String>_recipientRoutingNumber()The drawdown request's recipient's routing number. final JsonField<WireDrawdownRequest.Status>_status()The lifecycle status of the drawdown request. final JsonField<WireDrawdownRequest.Submission>_submission()After the drawdown request is submitted to Fedwire, this will contain supplemental details. final JsonField<WireDrawdownRequest.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final WireDrawdownRequestvalidate()final WireDrawdownRequest.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequest.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to which the recipient of this request is being requested to send funds.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the wire drawdown request was created.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
fulfillmentInboundWireTransferId
final Optional<String> fulfillmentInboundWireTransferId()
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
messageToRecipient
final String messageToRecipient()
The message the recipient will see as part of the drawdown request.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The originator's address line 1.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The originator's address line 2.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The originator's address line 3.
-
originatorName
final Optional<String> originatorName()
The originator's name.
-
recipientAccountNumber
final String recipientAccountNumber()
The drawdown request's recipient's account number.
-
recipientAddressLine1
final Optional<String> recipientAddressLine1()
Line 1 of the drawdown request's recipient's address.
-
recipientAddressLine2
final Optional<String> recipientAddressLine2()
Line 2 of the drawdown request's recipient's address.
-
recipientAddressLine3
final Optional<String> recipientAddressLine3()
Line 3 of the drawdown request's recipient's address.
-
recipientName
final Optional<String> recipientName()
The drawdown request's recipient's name.
-
recipientRoutingNumber
final String recipientRoutingNumber()
The drawdown request's recipient's routing number.
-
status
final WireDrawdownRequest.Status status()
The lifecycle status of the drawdown request.
-
submission
final Optional<WireDrawdownRequest.Submission> submission()
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
type
final WireDrawdownRequest.Type type()
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The Account Number to which the recipient of this request is being requested to send funds.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the wire drawdown request was created.
-
_currency
final JsonField<String> _currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
_fulfillmentInboundWireTransferId
final JsonField<String> _fulfillmentInboundWireTransferId()
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
The message the recipient will see as part of the drawdown request.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
The originator's address line 1.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
The originator's address line 2.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
The originator's address line 3.
-
_originatorName
final JsonField<String> _originatorName()
The originator's name.
-
_recipientAccountNumber
final JsonField<String> _recipientAccountNumber()
The drawdown request's recipient's account number.
-
_recipientAddressLine1
final JsonField<String> _recipientAddressLine1()
Line 1 of the drawdown request's recipient's address.
-
_recipientAddressLine2
final JsonField<String> _recipientAddressLine2()
Line 2 of the drawdown request's recipient's address.
-
_recipientAddressLine3
final JsonField<String> _recipientAddressLine3()
Line 3 of the drawdown request's recipient's address.
-
_recipientName
final JsonField<String> _recipientName()
The drawdown request's recipient's name.
-
_recipientRoutingNumber
final JsonField<String> _recipientRoutingNumber()
The drawdown request's recipient's routing number.
-
_status
final JsonField<WireDrawdownRequest.Status> _status()
The lifecycle status of the drawdown request.
-
_submission
final JsonField<WireDrawdownRequest.Submission> _submission()
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
_type
final JsonField<WireDrawdownRequest.Type> _type()
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final WireDrawdownRequest validate()
-
toBuilder
final WireDrawdownRequest.Builder toBuilder()
-
builder
final static WireDrawdownRequest.Builder builder()
-
-
-
-