Class WireTransfer
-
- All Implemented Interfaces:
public final class WireTransferWire transfers move funds between your Increase account and any other account accessible by Fedwire.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.BuilderA builder for WireTransfer.
public final classWireTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classWireTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classWireTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classWireTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.public final classWireTransfer.NetworkThe transfer's network.
public final classWireTransfer.ReversalIf your transfer is reversed, this will contain details of the reversal.
public final classWireTransfer.StatusThe lifecycle status of the transfer.
public final classWireTransfer.SubmissionAfter the transfer is submitted to Fedwire, this will contain supplemental details.
public final classWireTransfer.TypeA constant representing the object's type. For this resource it will always be
wire_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The wire transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumber()The destination account number. final Longamount()The transfer amount in USD cents. final Optional<WireTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<String>beneficiaryAddressLine1()The beneficiary's address line 1. final Optional<String>beneficiaryAddressLine2()The beneficiary's address line 2. final Optional<String>beneficiaryAddressLine3()The beneficiary's address line 3. final Optional<String>beneficiaryName()The beneficiary's name. final Optional<WireTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<WireTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final WireTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>messageToRecipient()The message that will show on the recipient's bank statement. final WireTransfer.Networknetwork()The transfer's network. final Optional<String>originatorAddressLine1()The originator's address line 1. final Optional<String>originatorAddressLine2()The originator's address line 2. final Optional<String>originatorAddressLine3()The originator's address line 3. final Optional<String>originatorName()The originator's name. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<WireTransfer.Reversal>reversal()If your transfer is reversed, this will contain details of the reversal. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<String>sourceAccountNumberId()The Account Number that was passed to the wire's recipient. final WireTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<WireTransfer.Submission>submission()After the transfer is submitted to Fedwire, this will contain supplemental details. final Optional<String>transactionId()The ID for the transaction funding the transfer. final WireTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()The wire transfer's identifier. final JsonField<String>_accountId()The Account to which the transfer belongs. final JsonField<String>_accountNumber()The destination account number. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<WireTransfer.Approval>_approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final JsonField<String>_beneficiaryAddressLine1()The beneficiary's address line 1. final JsonField<String>_beneficiaryAddressLine2()The beneficiary's address line 2. final JsonField<String>_beneficiaryAddressLine3()The beneficiary's address line 3. final JsonField<String>_beneficiaryName()The beneficiary's name. final JsonField<WireTransfer.Cancellation>_cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<WireTransfer.CreatedBy>_createdBy()What object created the transfer, either via the API or the dashboard. final JsonField<WireTransfer.Currency>_currency()The ISO 4217 code for the transfer's currency. final JsonField<String>_externalAccountId()The identifier of the External Account the transfer was made to, if any. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<String>_messageToRecipient()The message that will show on the recipient's bank statement. final JsonField<WireTransfer.Network>_network()The transfer's network. final JsonField<String>_originatorAddressLine1()The originator's address line 1. final JsonField<String>_originatorAddressLine2()The originator's address line 2. final JsonField<String>_originatorAddressLine3()The originator's address line 3. final JsonField<String>_originatorName()The originator's name. final JsonField<String>_pendingTransactionId()The ID for the pending transaction representing the transfer. final JsonField<WireTransfer.Reversal>_reversal()If your transfer is reversed, this will contain details of the reversal. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final JsonField<String>_sourceAccountNumberId()The Account Number that was passed to the wire's recipient. final JsonField<WireTransfer.Status>_status()The lifecycle status of the transfer. final JsonField<WireTransfer.Submission>_submission()After the transfer is submitted to Fedwire, this will contain supplemental details. final JsonField<String>_transactionId()The ID for the transaction funding the transfer. final JsonField<WireTransfer.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final WireTransfervalidate()final WireTransfer.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Builderbuilder()-
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
approval
final Optional<WireTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
The beneficiary's address line 1.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
The beneficiary's address line 2.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
The beneficiary's address line 3.
-
beneficiaryName
final Optional<String> beneficiaryName()
The beneficiary's name.
-
cancellation
final Optional<WireTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<WireTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final WireTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
messageToRecipient
final Optional<String> messageToRecipient()
The message that will show on the recipient's bank statement.
-
network
final WireTransfer.Network network()
The transfer's network.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The originator's address line 1.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The originator's address line 2.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The originator's address line 3.
-
originatorName
final Optional<String> originatorName()
The originator's name.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
reversal
final Optional<WireTransfer.Reversal> reversal()
If your transfer is reversed, this will contain details of the reversal.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The Account Number that was passed to the wire's recipient.
-
status
final WireTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<WireTransfer.Submission> submission()
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
transactionId
final Optional<String> transactionId()
The ID for the transaction funding the transfer.
-
type
final WireTransfer.Type type()
A constant representing the object's type. For this resource it will always be
wire_transfer.
-
_accountId
final JsonField<String> _accountId()
The Account to which the transfer belongs.
-
_accountNumber
final JsonField<String> _accountNumber()
The destination account number.
-
_approval
final JsonField<WireTransfer.Approval> _approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
The beneficiary's address line 1.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
The beneficiary's address line 2.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
The beneficiary's address line 3.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
The beneficiary's name.
-
_cancellation
final JsonField<WireTransfer.Cancellation> _cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_createdBy
final JsonField<WireTransfer.CreatedBy> _createdBy()
What object created the transfer, either via the API or the dashboard.
-
_currency
final JsonField<WireTransfer.Currency> _currency()
The ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.
-
_externalAccountId
final JsonField<String> _externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
The message that will show on the recipient's bank statement.
-
_network
final JsonField<WireTransfer.Network> _network()
The transfer's network.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
The originator's address line 1.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
The originator's address line 2.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
The originator's address line 3.
-
_originatorName
final JsonField<String> _originatorName()
The originator's name.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
_reversal
final JsonField<WireTransfer.Reversal> _reversal()
If your transfer is reversed, this will contain details of the reversal.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
The Account Number that was passed to the wire's recipient.
-
_status
final JsonField<WireTransfer.Status> _status()
The lifecycle status of the transfer.
-
_submission
final JsonField<WireTransfer.Submission> _submission()
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
_transactionId
final JsonField<String> _transactionId()
The ID for the transaction funding the transfer.
-
_type
final JsonField<WireTransfer.Type> _type()
A constant representing the object's type. For this resource it will always be
wire_transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final WireTransfer validate()
-
toBuilder
final WireTransfer.Builder toBuilder()
-
builder
final static WireTransfer.Builder builder()
-
-
-
-