Package com.increase.api.models
Class WireTransfer.Approval.Builder
-
- All Implemented Interfaces:
public final class WireTransfer.Approval.BuilderA builder for Approval.
-
-
Method Summary
Modifier and Type Method Description final WireTransfer.Approval.BuilderapprovedAt(OffsetDateTime approvedAt)The ISO 8601 date and time at which the transfer was approved. final WireTransfer.Approval.BuilderapprovedAt(JsonField<OffsetDateTime> approvedAt)The ISO 8601 date and time at which the transfer was approved. final WireTransfer.Approval.BuilderapprovedBy(String approvedBy)If the Transfer was approved by a user in the dashboard, the email address of that user. final WireTransfer.Approval.BuilderapprovedBy(Optional<String> approvedBy)If the Transfer was approved by a user in the dashboard, the email address of that user. final WireTransfer.Approval.BuilderapprovedBy(JsonField<String> approvedBy)If the Transfer was approved by a user in the dashboard, the email address of that user. final WireTransfer.Approval.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransfer.Approval.BuilderputAdditionalProperty(String key, JsonValue value)final WireTransfer.Approval.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransfer.Approval.BuilderremoveAdditionalProperty(String key)final WireTransfer.Approval.BuilderremoveAllAdditionalProperties(Set<String> keys)final WireTransfer.Approvalbuild()-
-
Method Detail
-
approvedAt
final WireTransfer.Approval.Builder approvedAt(OffsetDateTime approvedAt)
The ISO 8601 date and time at which the transfer was approved.
-
approvedAt
final WireTransfer.Approval.Builder approvedAt(JsonField<OffsetDateTime> approvedAt)
The ISO 8601 date and time at which the transfer was approved.
-
approvedBy
final WireTransfer.Approval.Builder approvedBy(String approvedBy)
If the Transfer was approved by a user in the dashboard, the email address of that user.
-
approvedBy
final WireTransfer.Approval.Builder approvedBy(Optional<String> approvedBy)
If the Transfer was approved by a user in the dashboard, the email address of that user.
-
approvedBy
final WireTransfer.Approval.Builder approvedBy(JsonField<String> approvedBy)
If the Transfer was approved by a user in the dashboard, the email address of that user.
-
additionalProperties
final WireTransfer.Approval.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransfer.Approval.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransfer.Approval.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransfer.Approval.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransfer.Approval.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransfer.Approval build()
-
-
-
-