Class WireTransfer.Builder
-
- All Implemented Interfaces:
public final class WireTransfer.BuilderA builder for WireTransfer.
-
-
Method Summary
Modifier and Type Method Description final WireTransfer.Builderid(String id)The wire transfer's identifier. final WireTransfer.Builderid(JsonField<String> id)The wire transfer's identifier. final WireTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final WireTransfer.BuilderaccountId(JsonField<String> accountId)The Account to which the transfer belongs. final WireTransfer.BuilderaccountNumber(String accountNumber)The destination account number. final WireTransfer.BuilderaccountNumber(JsonField<String> accountNumber)The destination account number. final WireTransfer.Builderamount(Long amount)The transfer amount in USD cents. final WireTransfer.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final WireTransfer.Builderapproval(WireTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final WireTransfer.Builderapproval(Optional<WireTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final WireTransfer.Builderapproval(JsonField<WireTransfer.Approval> approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final WireTransfer.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)The beneficiary's address line 1. final WireTransfer.BuilderbeneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)The beneficiary's address line 1. final WireTransfer.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)The beneficiary's address line 1. final WireTransfer.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)The beneficiary's address line 2. final WireTransfer.BuilderbeneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)The beneficiary's address line 2. final WireTransfer.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)The beneficiary's address line 2. final WireTransfer.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)The beneficiary's address line 3. final WireTransfer.BuilderbeneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)The beneficiary's address line 3. final WireTransfer.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)The beneficiary's address line 3. final WireTransfer.BuilderbeneficiaryName(String beneficiaryName)The beneficiary's name. final WireTransfer.BuilderbeneficiaryName(Optional<String> beneficiaryName)The beneficiary's name. final WireTransfer.BuilderbeneficiaryName(JsonField<String> beneficiaryName)The beneficiary's name. final WireTransfer.Buildercancellation(WireTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final WireTransfer.Buildercancellation(Optional<WireTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final WireTransfer.Buildercancellation(JsonField<WireTransfer.Cancellation> cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final WireTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final WireTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)The ISO 8601 date and time at which the transfer was created. final WireTransfer.BuildercreatedBy(WireTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final WireTransfer.BuildercreatedBy(Optional<WireTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final WireTransfer.BuildercreatedBy(JsonField<WireTransfer.CreatedBy> createdBy)What object created the transfer, either via the API or the dashboard. final WireTransfer.Buildercurrency(WireTransfer.Currency currency)The ISO 4217 code for the transfer's currency. final WireTransfer.Buildercurrency(JsonField<WireTransfer.Currency> currency)The ISO 4217 code for the transfer's currency. final WireTransfer.BuilderexternalAccountId(String externalAccountId)The identifier of the External Account the transfer was made to, if any. final WireTransfer.BuilderexternalAccountId(Optional<String> externalAccountId)The identifier of the External Account the transfer was made to, if any. final WireTransfer.BuilderexternalAccountId(JsonField<String> externalAccountId)The identifier of the External Account the transfer was made to, if any. final WireTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final WireTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)The idempotency key you chose for this object. final WireTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)The idempotency key you chose for this object. final WireTransfer.BuildermessageToRecipient(String messageToRecipient)The message that will show on the recipient's bank statement. final WireTransfer.BuildermessageToRecipient(Optional<String> messageToRecipient)The message that will show on the recipient's bank statement. final WireTransfer.BuildermessageToRecipient(JsonField<String> messageToRecipient)The message that will show on the recipient's bank statement. final WireTransfer.Buildernetwork(WireTransfer.Network network)The transfer's network. final WireTransfer.Buildernetwork(JsonField<WireTransfer.Network> network)The transfer's network. final WireTransfer.BuilderoriginatorAddressLine1(String originatorAddressLine1)The originator's address line 1. final WireTransfer.BuilderoriginatorAddressLine1(Optional<String> originatorAddressLine1)The originator's address line 1. final WireTransfer.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)The originator's address line 1. final WireTransfer.BuilderoriginatorAddressLine2(String originatorAddressLine2)The originator's address line 2. final WireTransfer.BuilderoriginatorAddressLine2(Optional<String> originatorAddressLine2)The originator's address line 2. final WireTransfer.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)The originator's address line 2. final WireTransfer.BuilderoriginatorAddressLine3(String originatorAddressLine3)The originator's address line 3. final WireTransfer.BuilderoriginatorAddressLine3(Optional<String> originatorAddressLine3)The originator's address line 3. final WireTransfer.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)The originator's address line 3. final WireTransfer.BuilderoriginatorName(String originatorName)The originator's name. final WireTransfer.BuilderoriginatorName(Optional<String> originatorName)The originator's name. final WireTransfer.BuilderoriginatorName(JsonField<String> originatorName)The originator's name. final WireTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final WireTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final WireTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)The ID for the pending transaction representing the transfer. final WireTransfer.Builderreversal(WireTransfer.Reversal reversal)If your transfer is reversed, this will contain details of the reversal. final WireTransfer.Builderreversal(Optional<WireTransfer.Reversal> reversal)If your transfer is reversed, this will contain details of the reversal. final WireTransfer.Builderreversal(JsonField<WireTransfer.Reversal> reversal)If your transfer is reversed, this will contain details of the reversal. final WireTransfer.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final WireTransfer.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final WireTransfer.BuildersourceAccountNumberId(String sourceAccountNumberId)The Account Number that was passed to the wire's recipient. final WireTransfer.BuildersourceAccountNumberId(Optional<String> sourceAccountNumberId)The Account Number that was passed to the wire's recipient. final WireTransfer.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)The Account Number that was passed to the wire's recipient. final WireTransfer.Builderstatus(WireTransfer.Status status)The lifecycle status of the transfer. final WireTransfer.Builderstatus(JsonField<WireTransfer.Status> status)The lifecycle status of the transfer. final WireTransfer.Buildersubmission(WireTransfer.Submission submission)After the transfer is submitted to Fedwire, this will contain supplemental details. final WireTransfer.Buildersubmission(Optional<WireTransfer.Submission> submission)After the transfer is submitted to Fedwire, this will contain supplemental details. final WireTransfer.Buildersubmission(JsonField<WireTransfer.Submission> submission)After the transfer is submitted to Fedwire, this will contain supplemental details. final WireTransfer.BuildertransactionId(String transactionId)The ID for the transaction funding the transfer. final WireTransfer.BuildertransactionId(Optional<String> transactionId)The ID for the transaction funding the transfer. final WireTransfer.BuildertransactionId(JsonField<String> transactionId)The ID for the transaction funding the transfer. final WireTransfer.Buildertype(WireTransfer.Type type)A constant representing the object's type. final WireTransfer.Buildertype(JsonField<WireTransfer.Type> type)A constant representing the object's type. final WireTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final WireTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransfer.BuilderremoveAdditionalProperty(String key)final WireTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final WireTransferbuild()-
-
Method Detail
-
id
final WireTransfer.Builder id(String id)
The wire transfer's identifier.
-
id
final WireTransfer.Builder id(JsonField<String> id)
The wire transfer's identifier.
-
accountId
final WireTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final WireTransfer.Builder accountId(JsonField<String> accountId)
The Account to which the transfer belongs.
-
accountNumber
final WireTransfer.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final WireTransfer.Builder accountNumber(JsonField<String> accountNumber)
The destination account number.
-
amount
final WireTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final WireTransfer.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
approval
final WireTransfer.Builder approval(WireTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final WireTransfer.Builder approval(Optional<WireTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final WireTransfer.Builder approval(JsonField<WireTransfer.Approval> approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
beneficiaryAddressLine1
final WireTransfer.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine1
final WireTransfer.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine1
final WireTransfer.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine2
final WireTransfer.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine2
final WireTransfer.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine2
final WireTransfer.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine3
final WireTransfer.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
The beneficiary's address line 3.
-
beneficiaryAddressLine3
final WireTransfer.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
The beneficiary's address line 3.
-
beneficiaryAddressLine3
final WireTransfer.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
The beneficiary's address line 3.
-
beneficiaryName
final WireTransfer.Builder beneficiaryName(String beneficiaryName)
The beneficiary's name.
-
beneficiaryName
final WireTransfer.Builder beneficiaryName(Optional<String> beneficiaryName)
The beneficiary's name.
-
beneficiaryName
final WireTransfer.Builder beneficiaryName(JsonField<String> beneficiaryName)
The beneficiary's name.
-
cancellation
final WireTransfer.Builder cancellation(WireTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final WireTransfer.Builder cancellation(Optional<WireTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final WireTransfer.Builder cancellation(JsonField<WireTransfer.Cancellation> cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final WireTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final WireTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final WireTransfer.Builder createdBy(WireTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final WireTransfer.Builder createdBy(Optional<WireTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final WireTransfer.Builder createdBy(JsonField<WireTransfer.CreatedBy> createdBy)
What object created the transfer, either via the API or the dashboard.
-
currency
final WireTransfer.Builder currency(WireTransfer.Currency currency)
The ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.
-
currency
final WireTransfer.Builder currency(JsonField<WireTransfer.Currency> currency)
The ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.
-
externalAccountId
final WireTransfer.Builder externalAccountId(String externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final WireTransfer.Builder externalAccountId(Optional<String> externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final WireTransfer.Builder externalAccountId(JsonField<String> externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final WireTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final WireTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final WireTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
messageToRecipient
final WireTransfer.Builder messageToRecipient(String messageToRecipient)
The message that will show on the recipient's bank statement.
-
messageToRecipient
final WireTransfer.Builder messageToRecipient(Optional<String> messageToRecipient)
The message that will show on the recipient's bank statement.
-
messageToRecipient
final WireTransfer.Builder messageToRecipient(JsonField<String> messageToRecipient)
The message that will show on the recipient's bank statement.
-
network
final WireTransfer.Builder network(WireTransfer.Network network)
The transfer's network.
-
network
final WireTransfer.Builder network(JsonField<WireTransfer.Network> network)
The transfer's network.
-
originatorAddressLine1
final WireTransfer.Builder originatorAddressLine1(String originatorAddressLine1)
The originator's address line 1.
-
originatorAddressLine1
final WireTransfer.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
The originator's address line 1.
-
originatorAddressLine1
final WireTransfer.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
The originator's address line 1.
-
originatorAddressLine2
final WireTransfer.Builder originatorAddressLine2(String originatorAddressLine2)
The originator's address line 2.
-
originatorAddressLine2
final WireTransfer.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
The originator's address line 2.
-
originatorAddressLine2
final WireTransfer.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
The originator's address line 2.
-
originatorAddressLine3
final WireTransfer.Builder originatorAddressLine3(String originatorAddressLine3)
The originator's address line 3.
-
originatorAddressLine3
final WireTransfer.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
The originator's address line 3.
-
originatorAddressLine3
final WireTransfer.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
The originator's address line 3.
-
originatorName
final WireTransfer.Builder originatorName(String originatorName)
The originator's name.
-
originatorName
final WireTransfer.Builder originatorName(Optional<String> originatorName)
The originator's name.
-
originatorName
final WireTransfer.Builder originatorName(JsonField<String> originatorName)
The originator's name.
-
pendingTransactionId
final WireTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final WireTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final WireTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
reversal
final WireTransfer.Builder reversal(WireTransfer.Reversal reversal)
If your transfer is reversed, this will contain details of the reversal.
-
reversal
final WireTransfer.Builder reversal(Optional<WireTransfer.Reversal> reversal)
If your transfer is reversed, this will contain details of the reversal.
-
reversal
final WireTransfer.Builder reversal(JsonField<WireTransfer.Reversal> reversal)
If your transfer is reversed, this will contain details of the reversal.
-
routingNumber
final WireTransfer.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final WireTransfer.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
sourceAccountNumberId
final WireTransfer.Builder sourceAccountNumberId(String sourceAccountNumberId)
The Account Number that was passed to the wire's recipient.
-
sourceAccountNumberId
final WireTransfer.Builder sourceAccountNumberId(Optional<String> sourceAccountNumberId)
The Account Number that was passed to the wire's recipient.
-
sourceAccountNumberId
final WireTransfer.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
The Account Number that was passed to the wire's recipient.
-
status
final WireTransfer.Builder status(WireTransfer.Status status)
The lifecycle status of the transfer.
-
status
final WireTransfer.Builder status(JsonField<WireTransfer.Status> status)
The lifecycle status of the transfer.
-
submission
final WireTransfer.Builder submission(WireTransfer.Submission submission)
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
submission
final WireTransfer.Builder submission(Optional<WireTransfer.Submission> submission)
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
submission
final WireTransfer.Builder submission(JsonField<WireTransfer.Submission> submission)
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
transactionId
final WireTransfer.Builder transactionId(String transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final WireTransfer.Builder transactionId(Optional<String> transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final WireTransfer.Builder transactionId(JsonField<String> transactionId)
The ID for the transaction funding the transfer.
-
type
final WireTransfer.Builder type(WireTransfer.Type type)
A constant representing the object's type. For this resource it will always be
wire_transfer.
-
type
final WireTransfer.Builder type(JsonField<WireTransfer.Type> type)
A constant representing the object's type. For this resource it will always be
wire_transfer.
-
additionalProperties
final WireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransfer build()
-
-
-
-