Class WireTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class WireTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classWireTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classWireTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classWireTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classWireTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final Optional<WireTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final WireTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<WireTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<WireTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<WireTransfer.CreatedBy.ApiKey>_apiKey()If present, details about the API key that created the transfer. final JsonField<WireTransfer.CreatedBy.Category>_category()The type of object that created this transfer. final JsonField<WireTransfer.CreatedBy.OAuthApplication>_oauthApplication()If present, details about the OAuth Application that created the transfer. final JsonField<WireTransfer.CreatedBy.User>_user()If present, details about the User that created the transfer. final Map<String, JsonValue>_additionalProperties()final WireTransfer.CreatedByvalidate()final WireTransfer.CreatedBy.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.CreatedBy.Builderbuilder()-
-
Method Detail
-
apiKey
final Optional<WireTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
category
final WireTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
oauthApplication
final Optional<WireTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<WireTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_apiKey
final JsonField<WireTransfer.CreatedBy.ApiKey> _apiKey()
If present, details about the API key that created the transfer.
-
_category
final JsonField<WireTransfer.CreatedBy.Category> _category()
The type of object that created this transfer.
-
_oauthApplication
final JsonField<WireTransfer.CreatedBy.OAuthApplication> _oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
_user
final JsonField<WireTransfer.CreatedBy.User> _user()
If present, details about the User that created the transfer.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final WireTransfer.CreatedBy validate()
-
toBuilder
final WireTransfer.CreatedBy.Builder toBuilder()
-
builder
final static WireTransfer.CreatedBy.Builder builder()
-
-
-
-