Class WireTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final StringbeneficiaryName()The beneficiary's name. final StringmessageToRecipient()The message that will show on the recipient's bank statement. final Optional<String>accountNumber()The account number for the destination account. final Optional<String>beneficiaryAddressLine1()The beneficiary's address line 1. final Optional<String>beneficiaryAddressLine2()The beneficiary's address line 2. final Optional<String>beneficiaryAddressLine3()The beneficiary's address line 3. final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<String>originatorAddressLine1()The originator's address line 1. final Optional<String>originatorAddressLine2()The originator's address line 2. final Optional<String>originatorAddressLine3()The originator's address line 3. final Optional<String>originatorName()The originator's name. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<String>sourceAccountNumberId()The ID of an Account Number that will be passed to the wire's recipient final JsonField<String>_accountId()The identifier for the account that will send the transfer. final JsonField<Long>_amount()The transfer amount in USD cents. final JsonField<String>_beneficiaryName()The beneficiary's name. final JsonField<String>_messageToRecipient()The message that will show on the recipient's bank statement. final JsonField<String>_accountNumber()The account number for the destination account. final JsonField<String>_beneficiaryAddressLine1()The beneficiary's address line 1. final JsonField<String>_beneficiaryAddressLine2()The beneficiary's address line 2. final JsonField<String>_beneficiaryAddressLine3()The beneficiary's address line 3. final JsonField<String>_externalAccountId()The ID of an External Account to initiate a transfer to. final JsonField<String>_originatorAddressLine1()The originator's address line 1. final JsonField<String>_originatorAddressLine2()The originator's address line 2. final JsonField<String>_originatorAddressLine3()The originator's address line 3. final JsonField<String>_originatorName()The originator's name. final JsonField<Boolean>_requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<String>_routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final JsonField<String>_sourceAccountNumberId()The ID of an Account Number that will be passed to the wire's recipient final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Bodyvalidate()final WireTransferCreateParams.Body.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Body.Builderbuilder()-
-
Method Detail
-
beneficiaryName
final String beneficiaryName()
The beneficiary's name.
-
messageToRecipient
final String messageToRecipient()
The message that will show on the recipient's bank statement.
-
accountNumber
final Optional<String> accountNumber()
The account number for the destination account.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
The beneficiary's address line 1.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
The beneficiary's address line 2.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
The beneficiary's address line 3.
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final Optional<String> originatorName()
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The ID of an Account Number that will be passed to the wire's recipient
-
_accountId
final JsonField<String> _accountId()
The identifier for the account that will send the transfer.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
The beneficiary's name.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
The message that will show on the recipient's bank statement.
-
_accountNumber
final JsonField<String> _accountNumber()
The account number for the destination account.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
The beneficiary's address line 1.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
The beneficiary's address line 2.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
The beneficiary's address line 3.
-
_externalAccountId
final JsonField<String> _externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
_originatorName
final JsonField<String> _originatorName()
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_routingNumber
final JsonField<String> _routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
The ID of an Account Number that will be passed to the wire's recipient
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final WireTransferCreateParams.Body validate()
-
toBuilder
final WireTransferCreateParams.Body.Builder toBuilder()
-
builder
final static WireTransferCreateParams.Body.Builder builder()
-
-
-
-