Class WireTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final WireTransferCreateParams.Body.BuilderaccountId(String accountId)The identifier for the account that will send the transfer. final WireTransferCreateParams.Body.BuilderaccountId(JsonField<String> accountId)The identifier for the account that will send the transfer. final WireTransferCreateParams.Body.Builderamount(Long amount)The transfer amount in USD cents. final WireTransferCreateParams.Body.Builderamount(JsonField<Long> amount)The transfer amount in USD cents. final WireTransferCreateParams.Body.BuilderbeneficiaryName(String beneficiaryName)The beneficiary's name. final WireTransferCreateParams.Body.BuilderbeneficiaryName(JsonField<String> beneficiaryName)The beneficiary's name. final WireTransferCreateParams.Body.BuildermessageToRecipient(String messageToRecipient)The message that will show on the recipient's bank statement. final WireTransferCreateParams.Body.BuildermessageToRecipient(JsonField<String> messageToRecipient)The message that will show on the recipient's bank statement. final WireTransferCreateParams.Body.BuilderaccountNumber(String accountNumber)The account number for the destination account. final WireTransferCreateParams.Body.BuilderaccountNumber(JsonField<String> accountNumber)The account number for the destination account. final WireTransferCreateParams.Body.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)The beneficiary's address line 1. final WireTransferCreateParams.Body.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)The beneficiary's address line 1. final WireTransferCreateParams.Body.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)The beneficiary's address line 2. final WireTransferCreateParams.Body.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)The beneficiary's address line 2. final WireTransferCreateParams.Body.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)The beneficiary's address line 3. final WireTransferCreateParams.Body.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)The beneficiary's address line 3. final WireTransferCreateParams.Body.BuilderexternalAccountId(String externalAccountId)The ID of an External Account to initiate a transfer to. final WireTransferCreateParams.Body.BuilderexternalAccountId(JsonField<String> externalAccountId)The ID of an External Account to initiate a transfer to. final WireTransferCreateParams.Body.BuilderoriginatorAddressLine1(String originatorAddressLine1)The originator's address line 1. final WireTransferCreateParams.Body.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)The originator's address line 1. final WireTransferCreateParams.Body.BuilderoriginatorAddressLine2(String originatorAddressLine2)The originator's address line 2. final WireTransferCreateParams.Body.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)The originator's address line 2. final WireTransferCreateParams.Body.BuilderoriginatorAddressLine3(String originatorAddressLine3)The originator's address line 3. final WireTransferCreateParams.Body.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)The originator's address line 3. final WireTransferCreateParams.Body.BuilderoriginatorName(String originatorName)The originator's name. final WireTransferCreateParams.Body.BuilderoriginatorName(JsonField<String> originatorName)The originator's name. final WireTransferCreateParams.Body.BuilderrequireApproval(Boolean requireApproval)Whether the transfer requires explicit approval via the dashboard or API. final WireTransferCreateParams.Body.BuilderrequireApproval(JsonField<Boolean> requireApproval)Whether the transfer requires explicit approval via the dashboard or API. final WireTransferCreateParams.Body.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final WireTransferCreateParams.Body.BuilderroutingNumber(JsonField<String> routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final WireTransferCreateParams.Body.BuildersourceAccountNumberId(String sourceAccountNumberId)The ID of an Account Number that will be passed to the wire's recipient final WireTransferCreateParams.Body.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)The ID of an Account Number that will be passed to the wire's recipient final WireTransferCreateParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransferCreateParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final WireTransferCreateParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransferCreateParams.Body.BuilderremoveAdditionalProperty(String key)final WireTransferCreateParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final WireTransferCreateParams.Bodybuild()-
-
Method Detail
-
accountId
final WireTransferCreateParams.Body.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final WireTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
The identifier for the account that will send the transfer.
-
amount
final WireTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final WireTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
The transfer amount in USD cents.
-
beneficiaryName
final WireTransferCreateParams.Body.Builder beneficiaryName(String beneficiaryName)
The beneficiary's name.
-
beneficiaryName
final WireTransferCreateParams.Body.Builder beneficiaryName(JsonField<String> beneficiaryName)
The beneficiary's name.
-
messageToRecipient
final WireTransferCreateParams.Body.Builder messageToRecipient(String messageToRecipient)
The message that will show on the recipient's bank statement.
-
messageToRecipient
final WireTransferCreateParams.Body.Builder messageToRecipient(JsonField<String> messageToRecipient)
The message that will show on the recipient's bank statement.
-
accountNumber
final WireTransferCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final WireTransferCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
The account number for the destination account.
-
beneficiaryAddressLine1
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine1
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine2
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine2
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine3
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
The beneficiary's address line 3.
-
beneficiaryAddressLine3
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
The beneficiary's address line 3.
-
externalAccountId
final WireTransferCreateParams.Body.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
externalAccountId
final WireTransferCreateParams.Body.Builder externalAccountId(JsonField<String> externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
originatorAddressLine1
final WireTransferCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine1
final WireTransferCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final WireTransferCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final WireTransferCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final WireTransferCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final WireTransferCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final WireTransferCreateParams.Body.Builder originatorName(String originatorName)
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final WireTransferCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
requireApproval
final WireTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final WireTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final WireTransferCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final WireTransferCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
sourceAccountNumberId
final WireTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The ID of an Account Number that will be passed to the wire's recipient
-
sourceAccountNumberId
final WireTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
The ID of an Account Number that will be passed to the wire's recipient
-
additionalProperties
final WireTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransferCreateParams.Body build()
-
-
-
-