Class AccountNumber
-
- All Implemented Interfaces:
public final class AccountNumberEach account can have multiple account and routing numbers. We recommend that you use a set per vendor. This is similar to how you use different passwords for different websites. Account numbers can also be used to seamlessly reconcile inbound payments. Generating a unique account number per vendor ensures you always know the originator of an incoming payment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumber.BuilderA builder for AccountNumber.
public final classAccountNumber.InboundAchProperties related to how this Account Number handles inbound ACH transfers.
public final classAccountNumber.InboundChecksProperties related to how this Account Number should handle inbound check withdrawals.
public final classAccountNumber.StatusThis indicates if payments can be made to the Account Number.
public final classAccountNumber.TypeA constant representing the object's type. For this resource it will always be
account_number.
-
Method Summary
Modifier and Type Method Description final Stringid()The Account Number identifier. final StringaccountId()The identifier for the account this Account Number belongs to. final StringaccountNumber()The account number. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Account Number was created. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final AccountNumber.InboundAchinboundAch()Properties related to how this Account Number handles inbound ACH transfers. final AccountNumber.InboundChecksinboundChecks()Properties related to how this Account Number should handle inbound check withdrawals. final Stringname()The name you choose for the Account Number. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final AccountNumber.Statusstatus()This indicates if payments can be made to the Account Number. final AccountNumber.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<AccountNumber.InboundAch>_inboundAch()Returns the raw JSON value of inboundAch. final JsonField<AccountNumber.InboundChecks>_inboundChecks()Returns the raw JSON value of inboundChecks. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<AccountNumber.Status>_status()Returns the raw JSON value of status. final JsonField<AccountNumber.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AccountNumber.BuildertoBuilder()final AccountNumbervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumber.Builderbuilder()Returns a mutable builder for constructing an instance of AccountNumber. -
-
Method Detail
-
accountNumber
final String accountNumber()
The account number.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Account Number was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundAch
final AccountNumber.InboundAch inboundAch()
Properties related to how this Account Number handles inbound ACH transfers.
-
inboundChecks
final AccountNumber.InboundChecks inboundChecks()
Properties related to how this Account Number should handle inbound check withdrawals.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final AccountNumber.Status status()
This indicates if payments can be made to the Account Number.
-
type
final AccountNumber.Type type()
A constant representing the object's type. For this resource it will always be
account_number.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundAch
final JsonField<AccountNumber.InboundAch> _inboundAch()
Returns the raw JSON value of inboundAch.
Unlike inboundAch, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundChecks
final JsonField<AccountNumber.InboundChecks> _inboundChecks()
Returns the raw JSON value of inboundChecks.
Unlike inboundChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountNumber.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AccountNumber.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumber.Builder toBuilder()
-
validate
final AccountNumber validate()
-
builder
final static AccountNumber.Builder builder()
Returns a mutable builder for constructing an instance of AccountNumber.
The following fields are required:
.id() .accountId() .accountNumber() .createdAt() .idempotencyKey() .inboundAch() .inboundChecks() .name() .routingNumber() .status() .type()
-
-
-
-