Class AccountNumber.Builder
-
- All Implemented Interfaces:
public final class AccountNumber.BuilderA builder for AccountNumber.
-
-
Method Summary
Modifier and Type Method Description final AccountNumber.Builderid(String id)The Account Number identifier. final AccountNumber.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final AccountNumber.BuilderaccountId(String accountId)The identifier for the account this Account Number belongs to. final AccountNumber.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final AccountNumber.BuilderaccountNumber(String accountNumber)The account number. final AccountNumber.BuilderaccountNumber(JsonField<String> accountNumber)Sets Builder.accountNumber to an arbitrary JSON value. final AccountNumber.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Account Number was created. final AccountNumber.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final AccountNumber.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AccountNumber.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final AccountNumber.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final AccountNumber.BuilderinboundAch(AccountNumber.InboundAch inboundAch)Properties related to how this Account Number handles inbound ACH transfers. final AccountNumber.BuilderinboundAch(JsonField<AccountNumber.InboundAch> inboundAch)Sets Builder.inboundAch to an arbitrary JSON value. final AccountNumber.BuilderinboundChecks(AccountNumber.InboundChecks inboundChecks)Properties related to how this Account Number should handle inbound check withdrawals. final AccountNumber.BuilderinboundChecks(JsonField<AccountNumber.InboundChecks> inboundChecks)Sets Builder.inboundChecks to an arbitrary JSON value. final AccountNumber.Buildername(String name)The name you choose for the Account Number. final AccountNumber.Buildername(JsonField<String> name)Sets Builder.name to an arbitrary JSON value. final AccountNumber.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AccountNumber.BuilderroutingNumber(JsonField<String> routingNumber)Sets Builder.routingNumber to an arbitrary JSON value. final AccountNumber.Builderstatus(AccountNumber.Status status)This indicates if payments can be made to the Account Number. final AccountNumber.Builderstatus(JsonField<AccountNumber.Status> status)Sets Builder.status to an arbitrary JSON value. final AccountNumber.Buildertype(AccountNumber.Type type)A constant representing the object's type. final AccountNumber.Buildertype(JsonField<AccountNumber.Type> type)Sets Builder.type to an arbitrary JSON value. final AccountNumber.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.BuilderputAdditionalProperty(String key, JsonValue value)final AccountNumber.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.BuilderremoveAdditionalProperty(String key)final AccountNumber.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountNumberbuild()Returns an immutable instance of AccountNumber. -
-
Method Detail
-
id
final AccountNumber.Builder id(String id)
The Account Number identifier.
-
id
final AccountNumber.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final AccountNumber.Builder accountId(String accountId)
The identifier for the account this Account Number belongs to.
-
accountId
final AccountNumber.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final AccountNumber.Builder accountNumber(String accountNumber)
The account number.
-
accountNumber
final AccountNumber.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AccountNumber.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Account Number was created.
-
createdAt
final AccountNumber.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final AccountNumber.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AccountNumber.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final AccountNumber.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundAch
final AccountNumber.Builder inboundAch(AccountNumber.InboundAch inboundAch)
Properties related to how this Account Number handles inbound ACH transfers.
-
inboundAch
final AccountNumber.Builder inboundAch(JsonField<AccountNumber.InboundAch> inboundAch)
Sets Builder.inboundAch to an arbitrary JSON value.
You should usually call Builder.inboundAch with a well-typed InboundAch value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundChecks
final AccountNumber.Builder inboundChecks(AccountNumber.InboundChecks inboundChecks)
Properties related to how this Account Number should handle inbound check withdrawals.
-
inboundChecks
final AccountNumber.Builder inboundChecks(JsonField<AccountNumber.InboundChecks> inboundChecks)
Sets Builder.inboundChecks to an arbitrary JSON value.
You should usually call Builder.inboundChecks with a well-typed InboundChecks value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AccountNumber.Builder name(String name)
The name you choose for the Account Number.
-
name
final AccountNumber.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final AccountNumber.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final AccountNumber.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AccountNumber.Builder status(AccountNumber.Status status)
This indicates if payments can be made to the Account Number.
-
status
final AccountNumber.Builder status(JsonField<AccountNumber.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountNumber.Builder type(AccountNumber.Type type)
A constant representing the object's type. For this resource it will always be
account_number.
-
type
final AccountNumber.Builder type(JsonField<AccountNumber.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumber.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumber.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumber.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumber.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumber.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumber build()
Returns an immutable instance of AccountNumber.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .accountNumber() .createdAt() .idempotencyKey() .inboundAch() .inboundChecks() .name() .routingNumber() .status() .type()
-
-
-
-