Class AccountNumber.InboundAch
-
- All Implemented Interfaces:
public final class AccountNumber.InboundAchProperties related to how this Account Number handles inbound ACH transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumber.InboundAch.BuilderA builder for InboundAch.
public final classAccountNumber.InboundAch.DebitStatusWhether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundAch.DebitStatusdebitStatus()Whether ACH debits are allowed against this Account Number. final JsonField<AccountNumber.InboundAch.DebitStatus>_debitStatus()Returns the raw JSON value of debitStatus. final Map<String, JsonValue>_additionalProperties()final AccountNumber.InboundAch.BuildertoBuilder()final AccountNumber.InboundAchvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumber.InboundAch.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAch. -
-
Method Detail
-
debitStatus
final AccountNumber.InboundAch.DebitStatus debitStatus()
Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
_debitStatus
final JsonField<AccountNumber.InboundAch.DebitStatus> _debitStatus()
Returns the raw JSON value of debitStatus.
Unlike debitStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumber.InboundAch.Builder toBuilder()
-
validate
final AccountNumber.InboundAch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountNumber.InboundAch.Builder builder()
Returns a mutable builder for constructing an instance of InboundAch.
The following fields are required:
.debitStatus()
-
-
-
-