Class AccountNumber.InboundAch.Builder
-
- All Implemented Interfaces:
public final class AccountNumber.InboundAch.BuilderA builder for InboundAch.
-
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundAch.BuilderdebitStatus(AccountNumber.InboundAch.DebitStatus debitStatus)Whether ACH debits are allowed against this Account Number. final AccountNumber.InboundAch.BuilderdebitStatus(JsonField<AccountNumber.InboundAch.DebitStatus> debitStatus)Sets Builder.debitStatus to an arbitrary JSON value. final AccountNumber.InboundAch.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.InboundAch.BuilderputAdditionalProperty(String key, JsonValue value)final AccountNumber.InboundAch.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.InboundAch.BuilderremoveAdditionalProperty(String key)final AccountNumber.InboundAch.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountNumber.InboundAchbuild()Returns an immutable instance of InboundAch. -
-
Method Detail
-
debitStatus
final AccountNumber.InboundAch.Builder debitStatus(AccountNumber.InboundAch.DebitStatus debitStatus)
Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is
allowedif the Account Number is not active.
-
debitStatus
final AccountNumber.InboundAch.Builder debitStatus(JsonField<AccountNumber.InboundAch.DebitStatus> debitStatus)
Sets Builder.debitStatus to an arbitrary JSON value.
You should usually call Builder.debitStatus with a well-typed DebitStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumber.InboundAch.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumber.InboundAch.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumber.InboundAch.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumber.InboundAch.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumber.InboundAch.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumber.InboundAch build()
Returns an immutable instance of InboundAch.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.debitStatus()
-
-
-
-