Class AccountNumber.InboundAch.DebitStatus

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class AccountNumber.InboundAch.DebitStatus
     implements Enum
                        

    Whether ACH debits are allowed against this Account Number. Note that they will still be declined if this is allowed if the Account Number is not active.