Class AccountNumber.InboundChecks
-
- All Implemented Interfaces:
public final class AccountNumber.InboundChecksProperties related to how this Account Number should handle inbound check withdrawals.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumber.InboundChecks.BuilderA builder for InboundChecks.
public final classAccountNumber.InboundChecks.StatusHow Increase should process checks with this account number printed on them.
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundChecks.Statusstatus()How Increase should process checks with this account number printed on them. final JsonField<AccountNumber.InboundChecks.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final AccountNumber.InboundChecks.BuildertoBuilder()final AccountNumber.InboundChecksvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumber.InboundChecks.Builderbuilder()Returns a mutable builder for constructing an instance of InboundChecks. -
-
Method Detail
-
status
final AccountNumber.InboundChecks.Status status()
How Increase should process checks with this account number printed on them.
-
_status
final JsonField<AccountNumber.InboundChecks.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumber.InboundChecks.Builder toBuilder()
-
validate
final AccountNumber.InboundChecks validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountNumber.InboundChecks.Builder builder()
Returns a mutable builder for constructing an instance of InboundChecks.
The following fields are required:
.status()
-
-
-
-