Class AccountNumber.InboundChecks.Builder
-
- All Implemented Interfaces:
public final class AccountNumber.InboundChecks.BuilderA builder for InboundChecks.
-
-
Method Summary
Modifier and Type Method Description final AccountNumber.InboundChecks.Builderstatus(AccountNumber.InboundChecks.Status status)How Increase should process checks with this account number printed on them. final AccountNumber.InboundChecks.Builderstatus(JsonField<AccountNumber.InboundChecks.Status> status)Sets Builder.status to an arbitrary JSON value. final AccountNumber.InboundChecks.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.InboundChecks.BuilderputAdditionalProperty(String key, JsonValue value)final AccountNumber.InboundChecks.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountNumber.InboundChecks.BuilderremoveAdditionalProperty(String key)final AccountNumber.InboundChecks.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountNumber.InboundChecksbuild()Returns an immutable instance of InboundChecks. -
-
Method Detail
-
status
final AccountNumber.InboundChecks.Builder status(AccountNumber.InboundChecks.Status status)
How Increase should process checks with this account number printed on them.
-
status
final AccountNumber.InboundChecks.Builder status(JsonField<AccountNumber.InboundChecks.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumber.InboundChecks.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumber.InboundChecks.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumber.InboundChecks.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumber.InboundChecks.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumber.InboundChecks.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumber.InboundChecks build()
Returns an immutable instance of InboundChecks.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.status()
-
-
-
-