Class AccountNumberCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountNumberCreateParams implements Params
Create an Account Number
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.BuilderA builder for AccountNumberCreateParams.
public final classAccountNumberCreateParams.Bodypublic final classAccountNumberCreateParams.InboundAchOptions related to how this Account Number should handle inbound ACH transfers.
public final classAccountNumberCreateParams.InboundChecksOptions related to how this Account Number should handle inbound check withdrawals.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the Account Number should belong to. final Stringname()The name you choose for the Account Number. final Optional<AccountNumberCreateParams.InboundAch>inboundAch()Options related to how this Account Number should handle inbound ACH transfers. final Optional<AccountNumberCreateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AccountNumberCreateParams.InboundAch>_inboundAch()Returns the raw JSON value of inboundAch. final JsonField<AccountNumberCreateParams.InboundChecks>_inboundChecks()Returns the raw JSON value of inboundChecks. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountNumberCreateParams.BuildertoBuilder()final AccountNumberCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountNumberCreateParams. -
-
Method Detail
-
inboundAch
final Optional<AccountNumberCreateParams.InboundAch> inboundAch()
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberCreateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundAch
final JsonField<AccountNumberCreateParams.InboundAch> _inboundAch()
Returns the raw JSON value of inboundAch.
Unlike inboundAch, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundChecks
final JsonField<AccountNumberCreateParams.InboundChecks> _inboundChecks()
Returns the raw JSON value of inboundChecks.
Unlike inboundChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountNumberCreateParams.Builder toBuilder()
-
_body
final AccountNumberCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountNumberCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountNumberCreateParams.
The following fields are required:
.accountId() .name()
-
-
-
-