Class AccountNumberCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final AccountNumberCreateParams.Body.Builder accountId(String accountId)
The Account the Account Number should belong to.
-
accountId
final AccountNumberCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AccountNumberCreateParams.Body.Builder name(String name)
The name you choose for the Account Number.
-
name
final AccountNumberCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundAch
final AccountNumberCreateParams.Body.Builder inboundAch(AccountNumberCreateParams.InboundAch inboundAch)
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundAch
final AccountNumberCreateParams.Body.Builder inboundAch(JsonField<AccountNumberCreateParams.InboundAch> inboundAch)
Sets Builder.inboundAch to an arbitrary JSON value.
You should usually call Builder.inboundAch with a well-typed InboundAch value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundChecks
final AccountNumberCreateParams.Body.Builder inboundChecks(AccountNumberCreateParams.InboundChecks inboundChecks)
Options related to how this Account Number should handle inbound check withdrawals.
-
inboundChecks
final AccountNumberCreateParams.Body.Builder inboundChecks(JsonField<AccountNumberCreateParams.InboundChecks> inboundChecks)
Sets Builder.inboundChecks to an arbitrary JSON value.
You should usually call Builder.inboundChecks with a well-typed InboundChecks value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumberCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .name()
-
-
-
-