Class AccountNumberCreateParams.InboundAch
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.InboundAchOptions related to how this Account Number should handle inbound ACH transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.InboundAch.BuilderA builder for InboundAch.
public final classAccountNumberCreateParams.InboundAch.DebitStatusWhether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active. If you do not specify this field, the default isallowed.
-
Method Summary
Modifier and Type Method Description final AccountNumberCreateParams.InboundAch.DebitStatusdebitStatus()Whether ACH debits are allowed against this Account Number. final JsonField<AccountNumberCreateParams.InboundAch.DebitStatus>_debitStatus()Returns the raw JSON value of debitStatus. final Map<String, JsonValue>_additionalProperties()final AccountNumberCreateParams.InboundAch.BuildertoBuilder()final AccountNumberCreateParams.InboundAchvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.InboundAch.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAch. -
-
Method Detail
-
debitStatus
final AccountNumberCreateParams.InboundAch.DebitStatus debitStatus()
Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active. If you do not specify this field, the default isallowed.
-
_debitStatus
final JsonField<AccountNumberCreateParams.InboundAch.DebitStatus> _debitStatus()
Returns the raw JSON value of debitStatus.
Unlike debitStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumberCreateParams.InboundAch.Builder toBuilder()
-
validate
final AccountNumberCreateParams.InboundAch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountNumberCreateParams.InboundAch.Builder builder()
Returns a mutable builder for constructing an instance of InboundAch.
The following fields are required:
.debitStatus()
-
-
-
-