Class AccountNumberCreateParams.InboundAch.Builder
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.InboundAch.BuilderA builder for InboundAch.
-
-
Method Summary
-
-
Method Detail
-
debitStatus
final AccountNumberCreateParams.InboundAch.Builder debitStatus(AccountNumberCreateParams.InboundAch.DebitStatus debitStatus)
Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active. If you do not specify this field, the default isallowed.
-
debitStatus
final AccountNumberCreateParams.InboundAch.Builder debitStatus(JsonField<AccountNumberCreateParams.InboundAch.DebitStatus> debitStatus)
Sets Builder.debitStatus to an arbitrary JSON value.
You should usually call Builder.debitStatus with a well-typed DebitStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumberCreateParams.InboundAch.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberCreateParams.InboundAch.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberCreateParams.InboundAch.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberCreateParams.InboundAch.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberCreateParams.InboundAch.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberCreateParams.InboundAch build()
Returns an immutable instance of InboundAch.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.debitStatus()
-
-
-
-