Class AccountNumberCreateParams.InboundAch.DebitStatus

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class AccountNumberCreateParams.InboundAch.DebitStatus
     implements Enum
                        

    Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is allowed but the Account Number is not active. If you do not specify this field, the default is allowed.