Class AccountNumberCreateParams.InboundChecks.Builder
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.InboundChecks.BuilderA builder for InboundChecks.
-
-
Method Summary
-
-
Method Detail
-
status
final AccountNumberCreateParams.InboundChecks.Builder status(AccountNumberCreateParams.InboundChecks.Status status)
How Increase should process checks with this account number printed on them. If you do not specify this field, the default is
check_transfers_only.
-
status
final AccountNumberCreateParams.InboundChecks.Builder status(JsonField<AccountNumberCreateParams.InboundChecks.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumberCreateParams.InboundChecks.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberCreateParams.InboundChecks.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberCreateParams.InboundChecks.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberCreateParams.InboundChecks.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberCreateParams.InboundChecks.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberCreateParams.InboundChecks build()
Returns an immutable instance of InboundChecks.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.status()
-
-
-
-