Class AccountNumberCreateParams.InboundChecks.Status

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class AccountNumberCreateParams.InboundChecks.Status
     implements Enum
                        

    How Increase should process checks with this account number printed on them. If you do not specify this field, the default is check_transfers_only.