Enum AccountNumberCreateParams.InboundChecks.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AccountNumberCreateParams.InboundChecks.Status.Known extends Enum<AccountNumberCreateParams.InboundChecks.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AccountNumberCreateParams.InboundChecks.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ALLOWEDChecks with this Account Number will be processed even if they are not associated with a Check Transfer.
CHECK_TRANSFERS_ONLYChecks with this Account Number will be processed only if they can be matched to an existing Check Transfer.
-
Method Summary
Modifier and Type Method Description final AccountNumberCreateParams.InboundChecks.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AccountNumberCreateParams.InboundChecks.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AccountNumberCreateParams.InboundChecks.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final AccountNumberCreateParams.InboundChecks.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AccountNumberCreateParams.InboundChecks.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AccountNumberCreateParams.InboundChecks.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-