Class AccountNumberListPage
-
- All Implemented Interfaces:
public final class AccountNumberListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberListPage.BuilderA builder for AccountNumberListPage.
public final classAccountNumberListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AccountNumber>data()Delegates to AccountNumberListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AccountNumberListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AccountNumberListParams>getNextPageParams()final Optional<AccountNumberListPage>getNextPage()final AccountNumberListPage.AutoPagerautoPager()final AccountNumberListParamsparams()The parameters that were used to request this page. final AccountNumberListPageResponseresponse()The response that this page was parsed from. final AccountNumberListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberListPage.Builderbuilder()Returns a mutable builder for constructing an instance of AccountNumberListPage. -
-
Method Detail
-
data
final List<AccountNumber> data()
Delegates to AccountNumberListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AccountNumberListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AccountNumberListParams> getNextPageParams()
-
getNextPage
final Optional<AccountNumberListPage> getNextPage()
-
autoPager
final AccountNumberListPage.AutoPager autoPager()
-
params
final AccountNumberListParams params()
The parameters that were used to request this page.
-
response
final AccountNumberListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountNumberListPage.Builder toBuilder()
-
builder
final static AccountNumberListPage.Builder builder()
Returns a mutable builder for constructing an instance of AccountNumberListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-