Class AccountNumberListPage.Builder
-
- All Implemented Interfaces:
public final class AccountNumberListPage.BuilderA builder for AccountNumberListPage.
-
-
Method Summary
Modifier and Type Method Description final AccountNumberListPage.Builderservice(AccountNumberService service)final AccountNumberListPage.Builderparams(AccountNumberListParams params)The parameters that were used to request this page. final AccountNumberListPage.Builderresponse(AccountNumberListPageResponse response)The response that this page was parsed from. final AccountNumberListPagebuild()Returns an immutable instance of AccountNumberListPage. -
-
Method Detail
-
service
final AccountNumberListPage.Builder service(AccountNumberService service)
-
params
final AccountNumberListPage.Builder params(AccountNumberListParams params)
The parameters that were used to request this page.
-
response
final AccountNumberListPage.Builder response(AccountNumberListPageResponse response)
The response that this page was parsed from.
-
build
final AccountNumberListPage build()
Returns an immutable instance of AccountNumberListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-