Class AccountNumberListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class AccountNumberListPageAsync implements PageAsync<AccountNumber>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberListPageAsync.BuilderA builder for AccountNumberListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<AccountNumber>data()Delegates to AccountNumberListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AccountNumberListPageResponse, but gracefully handles missing data. List<AccountNumber>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AccountNumberListParamsnextPageParams()CompletableFuture<AccountNumberListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<AccountNumber>autoPager()final AccountNumberListParamsparams()The parameters that were used to request this page. final AccountNumberListPageResponseresponse()The response that this page was parsed from. final AccountNumberListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountNumberListPageAsync. -
-
Method Detail
-
data
final List<AccountNumber> data()
Delegates to AccountNumberListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AccountNumberListPageResponse, but gracefully handles missing data.
-
items
List<AccountNumber> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AccountNumberListParams nextPageParams()
-
nextPage
CompletableFuture<AccountNumberListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<AccountNumber> autoPager()
-
params
final AccountNumberListParams params()
The parameters that were used to request this page.
-
response
final AccountNumberListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountNumberListPageAsync.Builder toBuilder()
-
builder
final static AccountNumberListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountNumberListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-