Class AccountNumberListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AccountNumberListPageAsync.BuilderA builder for AccountNumberListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AccountNumberListPageAsync.Builderservice(AccountNumberServiceAsync service)final AccountNumberListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AccountNumberListPageAsync.Builderparams(AccountNumberListParams params)The parameters that were used to request this page. final AccountNumberListPageAsync.Builderresponse(AccountNumberListPageResponse response)The response that this page was parsed from. final AccountNumberListPageAsyncbuild()Returns an immutable instance of AccountNumberListPageAsync. -
-
Method Detail
-
service
final AccountNumberListPageAsync.Builder service(AccountNumberServiceAsync service)
-
streamHandlerExecutor
final AccountNumberListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AccountNumberListPageAsync.Builder params(AccountNumberListParams params)
The parameters that were used to request this page.
-
response
final AccountNumberListPageAsync.Builder response(AccountNumberListPageResponse response)
The response that this page was parsed from.
-
build
final AccountNumberListPageAsync build()
Returns an immutable instance of AccountNumberListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-