Class AccountNumberUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountNumberUpdateParams implements Params
Update an Account Number
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberUpdateParams.BuilderA builder for AccountNumberUpdateParams.
public final classAccountNumberUpdateParams.Bodypublic final classAccountNumberUpdateParams.InboundAchOptions related to how this Account Number handles inbound ACH transfers.
public final classAccountNumberUpdateParams.InboundChecksOptions related to how this Account Number should handle inbound check withdrawals.
public final classAccountNumberUpdateParams.StatusThis indicates if transfers can be made to the Account Number.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountNumberId()The identifier of the Account Number. final Optional<AccountNumberUpdateParams.InboundAch>inboundAch()Options related to how this Account Number handles inbound ACH transfers. final Optional<AccountNumberUpdateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final Optional<String>name()The name you choose for the Account Number. final Optional<AccountNumberUpdateParams.Status>status()This indicates if transfers can be made to the Account Number. final JsonField<AccountNumberUpdateParams.InboundAch>_inboundAch()Returns the raw JSON value of inboundAch. final JsonField<AccountNumberUpdateParams.InboundChecks>_inboundChecks()Returns the raw JSON value of inboundChecks. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AccountNumberUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountNumberUpdateParams.BuildertoBuilder()final AccountNumberUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberUpdateParamsnone()final static AccountNumberUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountNumberUpdateParams. -
-
Method Detail
-
accountNumberId
final Optional<String> accountNumberId()
The identifier of the Account Number.
-
inboundAch
final Optional<AccountNumberUpdateParams.InboundAch> inboundAch()
Options related to how this Account Number handles inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberUpdateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
status
final Optional<AccountNumberUpdateParams.Status> status()
This indicates if transfers can be made to the Account Number.
-
_inboundAch
final JsonField<AccountNumberUpdateParams.InboundAch> _inboundAch()
Returns the raw JSON value of inboundAch.
Unlike inboundAch, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundChecks
final JsonField<AccountNumberUpdateParams.InboundChecks> _inboundChecks()
Returns the raw JSON value of inboundChecks.
Unlike inboundChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountNumberUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountNumberUpdateParams.Builder toBuilder()
-
_body
final AccountNumberUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountNumberUpdateParams none()
-
builder
final static AccountNumberUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountNumberUpdateParams.
-
-
-
-