Class AccountNumberUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountNumberUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
inboundAch
final AccountNumberUpdateParams.Body.Builder inboundAch(AccountNumberUpdateParams.InboundAch inboundAch)
Options related to how this Account Number handles inbound ACH transfers.
-
inboundAch
final AccountNumberUpdateParams.Body.Builder inboundAch(JsonField<AccountNumberUpdateParams.InboundAch> inboundAch)
Sets Builder.inboundAch to an arbitrary JSON value.
You should usually call Builder.inboundAch with a well-typed InboundAch value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundChecks
final AccountNumberUpdateParams.Body.Builder inboundChecks(AccountNumberUpdateParams.InboundChecks inboundChecks)
Options related to how this Account Number should handle inbound check withdrawals.
-
inboundChecks
final AccountNumberUpdateParams.Body.Builder inboundChecks(JsonField<AccountNumberUpdateParams.InboundChecks> inboundChecks)
Sets Builder.inboundChecks to an arbitrary JSON value.
You should usually call Builder.inboundChecks with a well-typed InboundChecks value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AccountNumberUpdateParams.Body.Builder name(String name)
The name you choose for the Account Number.
-
name
final AccountNumberUpdateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AccountNumberUpdateParams.Body.Builder status(AccountNumberUpdateParams.Status status)
This indicates if transfers can be made to the Account Number.
-
status
final AccountNumberUpdateParams.Body.Builder status(JsonField<AccountNumberUpdateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumberUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-