Class AccountNumberUpdateParams.InboundAch
-
- All Implemented Interfaces:
public final class AccountNumberUpdateParams.InboundAchOptions related to how this Account Number handles inbound ACH transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberUpdateParams.InboundAch.BuilderA builder for InboundAch.
public final classAccountNumberUpdateParams.InboundAch.DebitStatusWhether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active.
-
Method Summary
Modifier and Type Method Description final Optional<AccountNumberUpdateParams.InboundAch.DebitStatus>debitStatus()Whether ACH debits are allowed against this Account Number. final JsonField<AccountNumberUpdateParams.InboundAch.DebitStatus>_debitStatus()Returns the raw JSON value of debitStatus. final Map<String, JsonValue>_additionalProperties()final AccountNumberUpdateParams.InboundAch.BuildertoBuilder()final AccountNumberUpdateParams.InboundAchvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberUpdateParams.InboundAch.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAch. -
-
Method Detail
-
debitStatus
final Optional<AccountNumberUpdateParams.InboundAch.DebitStatus> debitStatus()
Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active.
-
_debitStatus
final JsonField<AccountNumberUpdateParams.InboundAch.DebitStatus> _debitStatus()
Returns the raw JSON value of debitStatus.
Unlike debitStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumberUpdateParams.InboundAch.Builder toBuilder()
-
validate
final AccountNumberUpdateParams.InboundAch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountNumberUpdateParams.InboundAch.Builder builder()
Returns a mutable builder for constructing an instance of InboundAch.
-
-
-
-