Class AccountNumberUpdateParams.InboundAch.Builder
-
- All Implemented Interfaces:
public final class AccountNumberUpdateParams.InboundAch.BuilderA builder for InboundAch.
-
-
Method Summary
-
-
Method Detail
-
debitStatus
final AccountNumberUpdateParams.InboundAch.Builder debitStatus(AccountNumberUpdateParams.InboundAch.DebitStatus debitStatus)
Whether ACH debits are allowed against this Account Number. Note that ACH debits will be declined if this is
allowedbut the Account Number is not active.
-
debitStatus
final AccountNumberUpdateParams.InboundAch.Builder debitStatus(JsonField<AccountNumberUpdateParams.InboundAch.DebitStatus> debitStatus)
Sets Builder.debitStatus to an arbitrary JSON value.
You should usually call Builder.debitStatus with a well-typed DebitStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumberUpdateParams.InboundAch.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberUpdateParams.InboundAch.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberUpdateParams.InboundAch.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberUpdateParams.InboundAch.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberUpdateParams.InboundAch.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberUpdateParams.InboundAch build()
Returns an immutable instance of InboundAch.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-