Class AccountNumberUpdateParams.InboundChecks.Builder
-
- All Implemented Interfaces:
public final class AccountNumberUpdateParams.InboundChecks.BuilderA builder for InboundChecks.
-
-
Method Summary
-
-
Method Detail
-
status
final AccountNumberUpdateParams.InboundChecks.Builder status(AccountNumberUpdateParams.InboundChecks.Status status)
How Increase should process checks with this account number printed on them.
-
status
final AccountNumberUpdateParams.InboundChecks.Builder status(JsonField<AccountNumberUpdateParams.InboundChecks.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountNumberUpdateParams.InboundChecks.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountNumberUpdateParams.InboundChecks.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountNumberUpdateParams.InboundChecks.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountNumberUpdateParams.InboundChecks.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountNumberUpdateParams.InboundChecks.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountNumberUpdateParams.InboundChecks build()
Returns an immutable instance of InboundChecks.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.status()
-
-
-
-