Class Account
-
- All Implemented Interfaces:
public final class AccountAccounts are your bank accounts with Increase. They store money, receive transfers, and send payments. They earn interest and have depository insurance.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.BuilderA builder for Account.
public final classAccount.BankThe bank the Account is with.
public final classAccount.CurrencyThe ISO 4217 code for the Account currency.
public final classAccount.FundingWhether the Account is funded by a loan or by deposits.
public final classAccount.LoanThe Account's loan-related information, if the Account is a loan account.
public final classAccount.StatusThe status of the Account.
public final classAccount.TypeA constant representing the object's type. For this resource it will always be
account.
-
Method Summary
Modifier and Type Method Description final Stringid()The Account identifier. final Optional<String>accountRevenueRate()The account revenue rate currently being earned on the account, as a string containing a decimal number. final Account.Bankbank()The bank the Account is with. final Optional<OffsetDateTime>closedAt()The ISO 8601 time at which the Account was closed. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Account was created. final Account.Currencycurrency()The ISO 4217 code for the Account currency. final StringentityId()The identifier for the Entity the Account belongs to. final Account.Fundingfunding()Whether the Account is funded by a loan or by deposits. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final StringinterestRate()The interest rate currently being earned on the account, as a string containing a decimal number. final Optional<Account.Loan>loan()The Account's loan-related information, if the Account is a loan account. final Stringname()The name you choose for the Account. final StringprogramId()The identifier of the Program determining the compliance and commercial terms of this Account. final Account.Statusstatus()The status of the Account. final Account.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountRevenueRate()Returns the raw JSON value of accountRevenueRate. final JsonField<Account.Bank>_bank()Returns the raw JSON value of bank. final JsonField<OffsetDateTime>_closedAt()Returns the raw JSON value of closedAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Account.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<Account.Funding>_funding()Returns the raw JSON value of funding. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_informationalEntityId()Returns the raw JSON value of informationalEntityId. final JsonField<String>_interestRate()Returns the raw JSON value of interestRate. final JsonField<Account.Loan>_loan()Returns the raw JSON value of loan. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_programId()Returns the raw JSON value of programId. final JsonField<Account.Status>_status()Returns the raw JSON value of status. final JsonField<Account.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Account.BuildertoBuilder()final Accountvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.Builderbuilder()Returns a mutable builder for constructing an instance of Account. -
-
Method Detail
-
accountRevenueRate
final Optional<String> accountRevenueRate()
The account revenue rate currently being earned on the account, as a string containing a decimal number. For example, a 1% account revenue rate would be represented as "0.01". Account revenue is a type of non-interest income accrued on the account.
-
bank
final Account.Bank bank()
The bank the Account is with.
-
closedAt
final Optional<OffsetDateTime> closedAt()
The ISO 8601 time at which the Account was closed.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Account was created.
-
currency
final Account.Currency currency()
The ISO 4217 code for the Account currency.
-
funding
final Account.Funding funding()
Whether the Account is funded by a loan or by deposits.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
informationalEntityId
final Optional<String> informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
interestRate
final String interestRate()
The interest rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
loan
final Optional<Account.Loan> loan()
The Account's loan-related information, if the Account is a loan account.
-
programId
final String programId()
The identifier of the Program determining the compliance and commercial terms of this Account.
-
status
final Account.Status status()
The status of the Account.
-
type
final Account.Type type()
A constant representing the object's type. For this resource it will always be
account.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountRevenueRate
final JsonField<String> _accountRevenueRate()
Returns the raw JSON value of accountRevenueRate.
Unlike accountRevenueRate, this method doesn't throw if the JSON field has an unexpected type.
-
_bank
final JsonField<Account.Bank> _bank()
Returns the raw JSON value of bank.
Unlike bank, this method doesn't throw if the JSON field has an unexpected type.
-
_closedAt
final JsonField<OffsetDateTime> _closedAt()
Returns the raw JSON value of closedAt.
Unlike closedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Account.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<Account.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_informationalEntityId
final JsonField<String> _informationalEntityId()
Returns the raw JSON value of informationalEntityId.
Unlike informationalEntityId, this method doesn't throw if the JSON field has an unexpected type.
-
_interestRate
final JsonField<String> _interestRate()
Returns the raw JSON value of interestRate.
Unlike interestRate, this method doesn't throw if the JSON field has an unexpected type.
-
_loan
final JsonField<Account.Loan> _loan()
Returns the raw JSON value of loan.
Unlike loan, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Account.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Account.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Account.Builder toBuilder()
-
validate
final Account validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Account.Builder builder()
Returns a mutable builder for constructing an instance of Account.
The following fields are required:
.id() .accountRevenueRate() .bank() .closedAt() .createdAt() .currency() .entityId() .funding() .idempotencyKey() .informationalEntityId() .interestRate() .loan() .name() .programId() .status() .type()
-
-
-
-