Class Account.Builder
-
- All Implemented Interfaces:
public final class Account.BuilderA builder for Account.
-
-
Method Summary
Modifier and Type Method Description final Account.Builderid(String id)The Account identifier. final Account.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Account.BuilderaccountRevenueRate(String accountRevenueRate)The account revenue rate currently being earned on the account, as a string containing a decimal number. final Account.BuilderaccountRevenueRate(Optional<String> accountRevenueRate)Alias for calling Builder.accountRevenueRate with accountRevenueRate.orElse(null).final Account.BuilderaccountRevenueRate(JsonField<String> accountRevenueRate)Sets Builder.accountRevenueRate to an arbitrary JSON value. final Account.Builderbank(Account.Bank bank)The bank the Account is with. final Account.Builderbank(JsonField<Account.Bank> bank)Sets Builder.bank to an arbitrary JSON value. final Account.BuilderclosedAt(OffsetDateTime closedAt)The ISO 8601 time at which the Account was closed. final Account.BuilderclosedAt(Optional<OffsetDateTime> closedAt)Alias for calling Builder.closedAt with closedAt.orElse(null).final Account.BuilderclosedAt(JsonField<OffsetDateTime> closedAt)Sets Builder.closedAt to an arbitrary JSON value. final Account.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Account was created. final Account.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Account.Buildercurrency(Account.Currency currency)The ISO 4217 code for the Account currency. final Account.Buildercurrency(JsonField<Account.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final Account.BuilderentityId(String entityId)The identifier for the Entity the Account belongs to. final Account.BuilderentityId(JsonField<String> entityId)Sets Builder.entityId to an arbitrary JSON value. final Account.Builderfunding(Account.Funding funding)Whether the Account is funded by a loan or by deposits. final Account.Builderfunding(JsonField<Account.Funding> funding)Sets Builder.funding to an arbitrary JSON value. final Account.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Account.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final Account.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final Account.BuilderinformationalEntityId(String informationalEntityId)The identifier of an Entity that, while not owning the Account, is associated with its activity. final Account.BuilderinformationalEntityId(Optional<String> informationalEntityId)Alias for calling Builder.informationalEntityId with informationalEntityId.orElse(null).final Account.BuilderinformationalEntityId(JsonField<String> informationalEntityId)Sets Builder.informationalEntityId to an arbitrary JSON value. final Account.BuilderinterestRate(String interestRate)The interest rate currently being earned on the account, as a string containing a decimal number. final Account.BuilderinterestRate(JsonField<String> interestRate)Sets Builder.interestRate to an arbitrary JSON value. final Account.Builderloan(Account.Loan loan)The Account's loan-related information, if the Account is a loan account. final Account.Builderloan(Optional<Account.Loan> loan)Alias for calling Builder.loan with loan.orElse(null).final Account.Builderloan(JsonField<Account.Loan> loan)Sets Builder.loan to an arbitrary JSON value. final Account.Buildername(String name)The name you choose for the Account. final Account.Buildername(JsonField<String> name)Sets Builder.name to an arbitrary JSON value. final Account.BuilderprogramId(String programId)The identifier of the Program determining the compliance and commercial terms of this Account. final Account.BuilderprogramId(JsonField<String> programId)Sets Builder.programId to an arbitrary JSON value. final Account.Builderstatus(Account.Status status)The status of the Account. final Account.Builderstatus(JsonField<Account.Status> status)Sets Builder.status to an arbitrary JSON value. final Account.Buildertype(Account.Type type)A constant representing the object's type. final Account.Buildertype(JsonField<Account.Type> type)Sets Builder.type to an arbitrary JSON value. final Account.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Account.BuilderputAdditionalProperty(String key, JsonValue value)final Account.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Account.BuilderremoveAdditionalProperty(String key)final Account.BuilderremoveAllAdditionalProperties(Set<String> keys)final Accountbuild()Returns an immutable instance of Account. -
-
Method Detail
-
id
final Account.Builder id(String id)
The Account identifier.
-
id
final Account.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountRevenueRate
final Account.Builder accountRevenueRate(String accountRevenueRate)
The account revenue rate currently being earned on the account, as a string containing a decimal number. For example, a 1% account revenue rate would be represented as "0.01". Account revenue is a type of non-interest income accrued on the account.
-
accountRevenueRate
final Account.Builder accountRevenueRate(Optional<String> accountRevenueRate)
Alias for calling Builder.accountRevenueRate with
accountRevenueRate.orElse(null).
-
accountRevenueRate
final Account.Builder accountRevenueRate(JsonField<String> accountRevenueRate)
Sets Builder.accountRevenueRate to an arbitrary JSON value.
You should usually call Builder.accountRevenueRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bank
final Account.Builder bank(Account.Bank bank)
The bank the Account is with.
-
bank
final Account.Builder bank(JsonField<Account.Bank> bank)
Sets Builder.bank to an arbitrary JSON value.
You should usually call Builder.bank with a well-typed Bank value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
closedAt
final Account.Builder closedAt(OffsetDateTime closedAt)
The ISO 8601 time at which the Account was closed.
-
closedAt
final Account.Builder closedAt(Optional<OffsetDateTime> closedAt)
Alias for calling Builder.closedAt with
closedAt.orElse(null).
-
closedAt
final Account.Builder closedAt(JsonField<OffsetDateTime> closedAt)
Sets Builder.closedAt to an arbitrary JSON value.
You should usually call Builder.closedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Account.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Account was created.
-
createdAt
final Account.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Account.Builder currency(Account.Currency currency)
The ISO 4217 code for the Account currency.
-
currency
final Account.Builder currency(JsonField<Account.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final Account.Builder entityId(String entityId)
The identifier for the Entity the Account belongs to.
-
entityId
final Account.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final Account.Builder funding(Account.Funding funding)
Whether the Account is funded by a loan or by deposits.
-
funding
final Account.Builder funding(JsonField<Account.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final Account.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Account.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final Account.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
informationalEntityId
final Account.Builder informationalEntityId(String informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity.
-
informationalEntityId
final Account.Builder informationalEntityId(Optional<String> informationalEntityId)
Alias for calling Builder.informationalEntityId with
informationalEntityId.orElse(null).
-
informationalEntityId
final Account.Builder informationalEntityId(JsonField<String> informationalEntityId)
Sets Builder.informationalEntityId to an arbitrary JSON value.
You should usually call Builder.informationalEntityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestRate
final Account.Builder interestRate(String interestRate)
The interest rate currently being earned on the account, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
interestRate
final Account.Builder interestRate(JsonField<String> interestRate)
Sets Builder.interestRate to an arbitrary JSON value.
You should usually call Builder.interestRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
loan
final Account.Builder loan(Account.Loan loan)
The Account's loan-related information, if the Account is a loan account.
-
loan
final Account.Builder loan(Optional<Account.Loan> loan)
Alias for calling Builder.loan with
loan.orElse(null).
-
loan
final Account.Builder loan(JsonField<Account.Loan> loan)
Sets Builder.loan to an arbitrary JSON value.
You should usually call Builder.loan with a well-typed Loan value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Account.Builder name(String name)
The name you choose for the Account.
-
name
final Account.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final Account.Builder programId(String programId)
The identifier of the Program determining the compliance and commercial terms of this Account.
-
programId
final Account.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Account.Builder status(Account.Status status)
The status of the Account.
-
status
final Account.Builder status(JsonField<Account.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Account.Builder type(Account.Type type)
A constant representing the object's type. For this resource it will always be
account.
-
type
final Account.Builder type(JsonField<Account.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Account.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Account.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Account.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Account.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Account.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Account build()
Returns an immutable instance of Account.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountRevenueRate() .bank() .closedAt() .createdAt() .currency() .entityId() .funding() .idempotencyKey() .informationalEntityId() .interestRate() .loan() .name() .programId() .status() .type()
-
-
-
-