Enum Account.Funding.Known

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      LOAN

      An account funded by a loan. Before opening a loan account, contact [email protected] to set up a loan program.

      DEPOSITS

      An account funded by deposits.

    • Method Summary

      Modifier and Type Method Description
      final Account.Funding.Known valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<Account.Funding.Known> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<Account.Funding.Known> getEntries() An enum containing Funding's known values.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail