Class Account.Loan
-
- All Implemented Interfaces:
public final class Account.LoanThe Account's loan-related information, if the Account is a loan account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccount.Loan.BuilderA builder for Loan.
public final classAccount.Loan.StatementPaymentTypeThe type of payment for the loan.
-
Method Summary
Modifier and Type Method Description final LongcreditLimit()The maximum amount of money that can be borrowed on the Account. final LonggracePeriodDays()The number of days after the statement date that the Account can be past due before being considered delinquent. final Optional<LocalDate>maturityDate()The date on which the loan matures. final LongstatementDayOfMonth()The day of the month on which the loan statement is generated. final Account.Loan.StatementPaymentTypestatementPaymentType()The type of payment for the loan. final JsonField<Long>_creditLimit()Returns the raw JSON value of creditLimit. final JsonField<Long>_gracePeriodDays()Returns the raw JSON value of gracePeriodDays. final JsonField<LocalDate>_maturityDate()Returns the raw JSON value of maturityDate. final JsonField<Long>_statementDayOfMonth()Returns the raw JSON value of statementDayOfMonth. final JsonField<Account.Loan.StatementPaymentType>_statementPaymentType()Returns the raw JSON value of statementPaymentType. final Map<String, JsonValue>_additionalProperties()final Account.Loan.BuildertoBuilder()final Account.Loanvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Account.Loan.Builderbuilder()Returns a mutable builder for constructing an instance of Loan. -
-
Method Detail
-
creditLimit
final Long creditLimit()
The maximum amount of money that can be borrowed on the Account.
-
gracePeriodDays
final Long gracePeriodDays()
The number of days after the statement date that the Account can be past due before being considered delinquent.
-
maturityDate
final Optional<LocalDate> maturityDate()
The date on which the loan matures.
-
statementDayOfMonth
final Long statementDayOfMonth()
The day of the month on which the loan statement is generated.
-
statementPaymentType
final Account.Loan.StatementPaymentType statementPaymentType()
The type of payment for the loan.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_gracePeriodDays
final JsonField<Long> _gracePeriodDays()
Returns the raw JSON value of gracePeriodDays.
Unlike gracePeriodDays, this method doesn't throw if the JSON field has an unexpected type.
-
_maturityDate
final JsonField<LocalDate> _maturityDate()
Returns the raw JSON value of maturityDate.
Unlike maturityDate, this method doesn't throw if the JSON field has an unexpected type.
-
_statementDayOfMonth
final JsonField<Long> _statementDayOfMonth()
Returns the raw JSON value of statementDayOfMonth.
Unlike statementDayOfMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_statementPaymentType
final JsonField<Account.Loan.StatementPaymentType> _statementPaymentType()
Returns the raw JSON value of statementPaymentType.
Unlike statementPaymentType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Account.Loan.Builder toBuilder()
-
validate
final Account.Loan validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Account.Loan.Builder builder()
Returns a mutable builder for constructing an instance of Loan.
The following fields are required:
.creditLimit() .gracePeriodDays() .maturityDate() .statementDayOfMonth() .statementPaymentType()
-
-
-
-