Package com.increase.api.models.accounts
Class AccountBalanceParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountBalanceParams implements Params
Retrieve the current and available balances for an account in minor units of the account's currency. Learn more about /documentation/balance.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountBalanceParams.BuilderA builder for AccountBalanceParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()The identifier of the Account to retrieve. final Optional<OffsetDateTime>atTime()The moment to query the balance at. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountBalanceParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountBalanceParamsnone()final static AccountBalanceParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountBalanceParams. -
-
Method Detail
-
atTime
final Optional<OffsetDateTime> atTime()
The moment to query the balance at. If not set, returns the current balances.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountBalanceParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountBalanceParams none()
-
builder
final static AccountBalanceParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountBalanceParams.
-
-
-
-