Class AccountCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final AccountCreateParams.Body.Builder name(String name)
The name you choose for the Account.
-
name
final AccountCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final AccountCreateParams.Body.Builder entityId(String entityId)
The identifier for the Entity that will own the Account.
-
entityId
final AccountCreateParams.Body.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final AccountCreateParams.Body.Builder funding(AccountCreateParams.Funding funding)
Whether the Account is funded by a loan or by deposits.
-
funding
final AccountCreateParams.Body.Builder funding(JsonField<AccountCreateParams.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
informationalEntityId
final AccountCreateParams.Body.Builder informationalEntityId(String informationalEntityId)
The identifier of an Entity that, while not owning the Account, is associated with its activity. This is generally the beneficiary of the funds.
-
informationalEntityId
final AccountCreateParams.Body.Builder informationalEntityId(JsonField<String> informationalEntityId)
Sets Builder.informationalEntityId to an arbitrary JSON value.
You should usually call Builder.informationalEntityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
loan
final AccountCreateParams.Body.Builder loan(AccountCreateParams.Loan loan)
The loan details for the account.
-
loan
final AccountCreateParams.Body.Builder loan(JsonField<AccountCreateParams.Loan> loan)
Sets Builder.loan to an arbitrary JSON value.
You should usually call Builder.loan with a well-typed Loan value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final AccountCreateParams.Body.Builder programId(String programId)
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
programId
final AccountCreateParams.Body.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-