Package com.increase.api.models.accounts
Enum AccountCreateParams.Funding.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AccountCreateParams.Funding.Known extends Enum<AccountCreateParams.Funding.Known>
An enum containing Funding's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AccountCreateParams.Funding.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description LOANAn account funded by a loan. Before opening a loan account, contact [email protected] to set up a loan program.
DEPOSITSAn account funded by deposits.
-
Method Summary
Modifier and Type Method Description final AccountCreateParams.Funding.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AccountCreateParams.Funding.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AccountCreateParams.Funding.Known>getEntries()An enum containing Funding's known values. -
-
Method Detail
-
valueOf
final AccountCreateParams.Funding.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AccountCreateParams.Funding.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AccountCreateParams.Funding.Known> getEntries()
An enum containing Funding's known values.
-
-
-
-