Class AccountCreateParams.Loan
-
- All Implemented Interfaces:
public final class AccountCreateParams.LoanThe loan details for the account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountCreateParams.Loan.BuilderA builder for Loan.
public final classAccountCreateParams.Loan.StatementPaymentTypeThe type of statement payment for the account.
-
Method Summary
Modifier and Type Method Description final LongcreditLimit()The maximum amount of money that can be drawn from the Account. final LonggracePeriodDays()The number of days after the statement date that the Account can be past due before being considered delinquent. final LongstatementDayOfMonth()The day of the month on which the loan statement is generated. final AccountCreateParams.Loan.StatementPaymentTypestatementPaymentType()The type of statement payment for the account. final Optional<LocalDate>maturityDate()The date on which the loan matures. final JsonField<Long>_creditLimit()Returns the raw JSON value of creditLimit. final JsonField<Long>_gracePeriodDays()Returns the raw JSON value of gracePeriodDays. final JsonField<Long>_statementDayOfMonth()Returns the raw JSON value of statementDayOfMonth. final JsonField<AccountCreateParams.Loan.StatementPaymentType>_statementPaymentType()Returns the raw JSON value of statementPaymentType. final JsonField<LocalDate>_maturityDate()Returns the raw JSON value of maturityDate. final Map<String, JsonValue>_additionalProperties()final AccountCreateParams.Loan.BuildertoBuilder()final AccountCreateParams.Loanvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountCreateParams.Loan.Builderbuilder()Returns a mutable builder for constructing an instance of Loan. -
-
Method Detail
-
creditLimit
final Long creditLimit()
The maximum amount of money that can be drawn from the Account.
-
gracePeriodDays
final Long gracePeriodDays()
The number of days after the statement date that the Account can be past due before being considered delinquent.
-
statementDayOfMonth
final Long statementDayOfMonth()
The day of the month on which the loan statement is generated.
-
statementPaymentType
final AccountCreateParams.Loan.StatementPaymentType statementPaymentType()
The type of statement payment for the account.
-
maturityDate
final Optional<LocalDate> maturityDate()
The date on which the loan matures.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_gracePeriodDays
final JsonField<Long> _gracePeriodDays()
Returns the raw JSON value of gracePeriodDays.
Unlike gracePeriodDays, this method doesn't throw if the JSON field has an unexpected type.
-
_statementDayOfMonth
final JsonField<Long> _statementDayOfMonth()
Returns the raw JSON value of statementDayOfMonth.
Unlike statementDayOfMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_statementPaymentType
final JsonField<AccountCreateParams.Loan.StatementPaymentType> _statementPaymentType()
Returns the raw JSON value of statementPaymentType.
Unlike statementPaymentType, this method doesn't throw if the JSON field has an unexpected type.
-
_maturityDate
final JsonField<LocalDate> _maturityDate()
Returns the raw JSON value of maturityDate.
Unlike maturityDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountCreateParams.Loan.Builder toBuilder()
-
validate
final AccountCreateParams.Loan validate()
-
builder
final static AccountCreateParams.Loan.Builder builder()
Returns a mutable builder for constructing an instance of Loan.
The following fields are required:
.creditLimit() .gracePeriodDays() .statementDayOfMonth() .statementPaymentType()
-
-
-
-