Package com.increase.api.models.accounts
Class AccountListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AccountListPageAsync.BuilderA builder for AccountListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AccountListPageAsync.Builderservice(AccountServiceAsync service)final AccountListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AccountListPageAsync.Builderparams(AccountListParams params)The parameters that were used to request this page. final AccountListPageAsync.Builderresponse(AccountListPageResponse response)The response that this page was parsed from. final AccountListPageAsyncbuild()Returns an immutable instance of AccountListPageAsync. -
-
Method Detail
-
service
final AccountListPageAsync.Builder service(AccountServiceAsync service)
-
streamHandlerExecutor
final AccountListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AccountListPageAsync.Builder params(AccountListParams params)
The parameters that were used to request this page.
-
response
final AccountListPageAsync.Builder response(AccountListPageResponse response)
The response that this page was parsed from.
-
build
final AccountListPageAsync build()
Returns an immutable instance of AccountListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-