Package com.increase.api.models.accounts
Class AccountListPageAsync.Response
-
- All Implemented Interfaces:
public final class AccountListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountListPageAsync.Response.Builder
-
Method Summary
Modifier and Type Method Description final List<Account>data()final Optional<String>nextCursor()final Optional<JsonField<List<Account>>>_data()final Optional<JsonField<String>>_nextCursor()final Map<String, JsonValue>_additionalProperties()final AccountListPageAsync.Responsevalidate()final BooleanisValid()final AccountListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of AccountListPageAsync. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
-
_nextCursor
final Optional<JsonField<String>> _nextCursor()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final AccountListPageAsync.Response validate()
-
toBuilder
final AccountListPageAsync.Response.Builder toBuilder()
-
builder
final static AccountListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of AccountListPageAsync.
-
-
-
-