Class AccountListPageResponse.Builder
-
- All Implemented Interfaces:
public final class AccountListPageResponse.BuilderA builder for AccountListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final AccountListPageResponse.Builder data(List<Account> data)
The contents of the list.
-
data
final AccountListPageResponse.Builder data(JsonField<List<Account>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Account>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final AccountListPageResponse.Builder addData(Account data)
Adds a single Account to Builder.data.
-
nextCursor
final AccountListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final AccountListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final AccountListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountListPageResponse build()
Returns an immutable instance of AccountListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-