Class BalanceLookup
-
- All Implemented Interfaces:
public final class BalanceLookupRepresents a request to lookup the balance of an Account at a given point in time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBalanceLookup.BuilderA builder for BalanceLookup.
public final classBalanceLookup.LoanThe loan balances for the Account.
public final classBalanceLookup.TypeA constant representing the object's type. For this resource it will always be
balance_lookup.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account for which the balance was queried. final LongavailableBalance()The Account's available balance, representing the current balance less any open Pending Transactions on the Account. final LongcurrentBalance()The Account's current balance, representing the sum of all posted Transactions on the Account. final Optional<BalanceLookup.Loan>loan()The loan balances for the Account. final BalanceLookup.Typetype()A constant representing the object's type. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_availableBalance()Returns the raw JSON value of availableBalance. final JsonField<Long>_currentBalance()Returns the raw JSON value of currentBalance. final JsonField<BalanceLookup.Loan>_loan()Returns the raw JSON value of loan. final JsonField<BalanceLookup.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BalanceLookup.BuildertoBuilder()final BalanceLookupvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BalanceLookup.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceLookup. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the account for which the balance was queried.
-
availableBalance
final Long availableBalance()
The Account's available balance, representing the current balance less any open Pending Transactions on the Account.
-
currentBalance
final Long currentBalance()
The Account's current balance, representing the sum of all posted Transactions on the Account.
-
loan
final Optional<BalanceLookup.Loan> loan()
The loan balances for the Account.
-
type
final BalanceLookup.Type type()
A constant representing the object's type. For this resource it will always be
balance_lookup.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_availableBalance
final JsonField<Long> _availableBalance()
Returns the raw JSON value of availableBalance.
Unlike availableBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_currentBalance
final JsonField<Long> _currentBalance()
Returns the raw JSON value of currentBalance.
Unlike currentBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_loan
final JsonField<BalanceLookup.Loan> _loan()
Returns the raw JSON value of loan.
Unlike loan, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BalanceLookup.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BalanceLookup.Builder toBuilder()
-
validate
final BalanceLookup validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BalanceLookup.Builder builder()
Returns a mutable builder for constructing an instance of BalanceLookup.
The following fields are required:
.accountId() .availableBalance() .currentBalance() .loan() .type()
-
-
-
-