Class BalanceLookup.Builder
-
- All Implemented Interfaces:
public final class BalanceLookup.BuilderA builder for BalanceLookup.
-
-
Method Summary
Modifier and Type Method Description final BalanceLookup.BuilderaccountId(String accountId)The identifier for the account for which the balance was queried. final BalanceLookup.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final BalanceLookup.BuilderavailableBalance(Long availableBalance)The Account's available balance, representing the current balance less any open Pending Transactions on the Account. final BalanceLookup.BuilderavailableBalance(JsonField<Long> availableBalance)Sets Builder.availableBalance to an arbitrary JSON value. final BalanceLookup.BuildercurrentBalance(Long currentBalance)The Account's current balance, representing the sum of all posted Transactions on the Account. final BalanceLookup.BuildercurrentBalance(JsonField<Long> currentBalance)Sets Builder.currentBalance to an arbitrary JSON value. final BalanceLookup.Buildertype(BalanceLookup.Type type)A constant representing the object's type. final BalanceLookup.Buildertype(JsonField<BalanceLookup.Type> type)Sets Builder.type to an arbitrary JSON value. final BalanceLookup.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BalanceLookup.BuilderputAdditionalProperty(String key, JsonValue value)final BalanceLookup.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BalanceLookup.BuilderremoveAdditionalProperty(String key)final BalanceLookup.BuilderremoveAllAdditionalProperties(Set<String> keys)final BalanceLookupbuild()Returns an immutable instance of BalanceLookup. -
-
Method Detail
-
accountId
final BalanceLookup.Builder accountId(String accountId)
The identifier for the account for which the balance was queried.
-
accountId
final BalanceLookup.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
availableBalance
final BalanceLookup.Builder availableBalance(Long availableBalance)
The Account's available balance, representing the current balance less any open Pending Transactions on the Account.
-
availableBalance
final BalanceLookup.Builder availableBalance(JsonField<Long> availableBalance)
Sets Builder.availableBalance to an arbitrary JSON value.
You should usually call Builder.availableBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currentBalance
final BalanceLookup.Builder currentBalance(Long currentBalance)
The Account's current balance, representing the sum of all posted Transactions on the Account.
-
currentBalance
final BalanceLookup.Builder currentBalance(JsonField<Long> currentBalance)
Sets Builder.currentBalance to an arbitrary JSON value.
You should usually call Builder.currentBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BalanceLookup.Builder type(BalanceLookup.Type type)
A constant representing the object's type. For this resource it will always be
balance_lookup.
-
type
final BalanceLookup.Builder type(JsonField<BalanceLookup.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BalanceLookup.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BalanceLookup.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BalanceLookup.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BalanceLookup.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BalanceLookup.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BalanceLookup build()
Returns an immutable instance of BalanceLookup.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .availableBalance() .currentBalance() .type()
-
-
-
-