Class AccountStatement
-
- All Implemented Interfaces:
public final class AccountStatementAccount Statements are generated monthly for every active Account. You can access the statement's data via the API or retrieve a PDF with its details via its associated File.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatement.BuilderA builder for AccountStatement.
public final classAccountStatement.LoanThe loan balances.
public final classAccountStatement.TypeA constant representing the object's type. For this resource it will always be
account_statement.
-
Method Summary
Modifier and Type Method Description final Stringid()The Account Statement identifier. final StringaccountId()The identifier for the Account this Account Statement belongs to. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Account Statement was created. final LongendingBalance()The Account's balance at the end of its statement period. final StringfileId()The identifier of the File containing a PDF of the statement. final Optional<AccountStatement.Loan>loan()The loan balances. final LongstartingBalance()The Account's balance at the start of its statement period. final OffsetDateTimestatementPeriodEnd()The ISO 8601 time representing the end of the period the Account Statement covers. final OffsetDateTimestatementPeriodStart()The ISO 8601 time representing the start of the period the Account Statement covers. final AccountStatement.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Long>_endingBalance()Returns the raw JSON value of endingBalance. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<AccountStatement.Loan>_loan()Returns the raw JSON value of loan. final JsonField<Long>_startingBalance()Returns the raw JSON value of startingBalance. final JsonField<OffsetDateTime>_statementPeriodEnd()Returns the raw JSON value of statementPeriodEnd. final JsonField<OffsetDateTime>_statementPeriodStart()Returns the raw JSON value of statementPeriodStart. final JsonField<AccountStatement.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AccountStatement.BuildertoBuilder()final AccountStatementvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatement.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatement. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account this Account Statement belongs to.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Account Statement was created.
-
endingBalance
final Long endingBalance()
The Account's balance at the end of its statement period.
-
loan
final Optional<AccountStatement.Loan> loan()
The loan balances.
-
startingBalance
final Long startingBalance()
The Account's balance at the start of its statement period.
-
statementPeriodEnd
final OffsetDateTime statementPeriodEnd()
The ISO 8601 time representing the end of the period the Account Statement covers.
-
statementPeriodStart
final OffsetDateTime statementPeriodStart()
The ISO 8601 time representing the start of the period the Account Statement covers.
-
type
final AccountStatement.Type type()
A constant representing the object's type. For this resource it will always be
account_statement.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_endingBalance
final JsonField<Long> _endingBalance()
Returns the raw JSON value of endingBalance.
Unlike endingBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_loan
final JsonField<AccountStatement.Loan> _loan()
Returns the raw JSON value of loan.
Unlike loan, this method doesn't throw if the JSON field has an unexpected type.
-
_startingBalance
final JsonField<Long> _startingBalance()
Returns the raw JSON value of startingBalance.
Unlike startingBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_statementPeriodEnd
final JsonField<OffsetDateTime> _statementPeriodEnd()
Returns the raw JSON value of statementPeriodEnd.
Unlike statementPeriodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_statementPeriodStart
final JsonField<OffsetDateTime> _statementPeriodStart()
Returns the raw JSON value of statementPeriodStart.
Unlike statementPeriodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AccountStatement.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountStatement.Builder toBuilder()
-
validate
final AccountStatement validate()
-
builder
final static AccountStatement.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatement.
The following fields are required:
.id() .accountId() .createdAt() .endingBalance() .fileId() .loan() .startingBalance() .statementPeriodEnd() .statementPeriodStart() .type()
-
-
-
-