Class AccountStatementListPage
-
- All Implemented Interfaces:
public final class AccountStatementListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementListPage.BuilderA builder for AccountStatementListPage.
public final classAccountStatementListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AccountStatement>data()Delegates to AccountStatementListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AccountStatementListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AccountStatementListParams>getNextPageParams()final Optional<AccountStatementListPage>getNextPage()final AccountStatementListPage.AutoPagerautoPager()final AccountStatementListParamsparams()The parameters that were used to request this page. final AccountStatementListPageResponseresponse()The response that this page was parsed from. final AccountStatementListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementListPage.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementListPage. -
-
Method Detail
-
data
final List<AccountStatement> data()
Delegates to AccountStatementListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AccountStatementListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AccountStatementListParams> getNextPageParams()
-
getNextPage
final Optional<AccountStatementListPage> getNextPage()
-
autoPager
final AccountStatementListPage.AutoPager autoPager()
-
params
final AccountStatementListParams params()
The parameters that were used to request this page.
-
response
final AccountStatementListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountStatementListPage.Builder toBuilder()
-
builder
final static AccountStatementListPage.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-