Class AccountStatementListPage.Builder
-
- All Implemented Interfaces:
public final class AccountStatementListPage.BuilderA builder for AccountStatementListPage.
-
-
Method Summary
Modifier and Type Method Description final AccountStatementListPage.Builderservice(AccountStatementService service)final AccountStatementListPage.Builderparams(AccountStatementListParams params)The parameters that were used to request this page. final AccountStatementListPage.Builderresponse(AccountStatementListPageResponse response)The response that this page was parsed from. final AccountStatementListPagebuild()Returns an immutable instance of AccountStatementListPage. -
-
Method Detail
-
service
final AccountStatementListPage.Builder service(AccountStatementService service)
-
params
final AccountStatementListPage.Builder params(AccountStatementListParams params)
The parameters that were used to request this page.
-
response
final AccountStatementListPage.Builder response(AccountStatementListPageResponse response)
The response that this page was parsed from.
-
build
final AccountStatementListPage build()
Returns an immutable instance of AccountStatementListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-