Class AccountStatementListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class AccountStatementListPageAsync implements PageAsync<AccountStatement>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementListPageAsync.BuilderA builder for AccountStatementListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<AccountStatement>data()Delegates to AccountStatementListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AccountStatementListPageResponse, but gracefully handles missing data. List<AccountStatement>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final AccountStatementListParamsnextPageParams()CompletableFuture<AccountStatementListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<AccountStatement>autoPager()final AccountStatementListParamsparams()The parameters that were used to request this page. final AccountStatementListPageResponseresponse()The response that this page was parsed from. final AccountStatementListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementListPageAsync. -
-
Method Detail
-
data
final List<AccountStatement> data()
Delegates to AccountStatementListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AccountStatementListPageResponse, but gracefully handles missing data.
-
items
List<AccountStatement> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final AccountStatementListParams nextPageParams()
-
nextPage
CompletableFuture<AccountStatementListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<AccountStatement> autoPager()
-
params
final AccountStatementListParams params()
The parameters that were used to request this page.
-
response
final AccountStatementListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountStatementListPageAsync.Builder toBuilder()
-
builder
final static AccountStatementListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-