Class AccountStatementListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountStatementListParams implements Params
List Account Statements
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementListParams.BuilderA builder for AccountStatementListParams.
public final classAccountStatementListParams.StatementPeriodStart
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Account Statements to those belonging to the specified Account. final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Optional<AccountStatementListParams.StatementPeriodStart>statementPeriodStart()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountStatementListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementListParamsnone()final static AccountStatementListParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementListParams. -
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Account Statements to those belonging to the specified Account.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
statementPeriodStart
final Optional<AccountStatementListParams.StatementPeriodStart> statementPeriodStart()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountStatementListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountStatementListParams none()
-
builder
final static AccountStatementListParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementListParams.
-
-
-
-