Class AccountStatementListParams.StatementPeriodStart
-
- All Implemented Interfaces:
public final class AccountStatementListParams.StatementPeriodStart
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementListParams.StatementPeriodStart.BuilderA builder for StatementPeriodStart.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>after()Return results after this ISO 8601 timestamp. final Optional<OffsetDateTime>before()Return results before this ISO 8601 timestamp. final Optional<OffsetDateTime>onOrAfter()Return results on or after this ISO 8601 timestamp. final Optional<OffsetDateTime>onOrBefore()Return results on or before this ISO 8601 timestamp. final QueryParams_additionalProperties()Query params to send with the request. final AccountStatementListParams.StatementPeriodStart.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementListParams.StatementPeriodStart.Builderbuilder()Returns a mutable builder for constructing an instance of StatementPeriodStart. -
-
Method Detail
-
after
final Optional<OffsetDateTime> after()
Return results after this ISO 8601 timestamp.
-
before
final Optional<OffsetDateTime> before()
Return results before this ISO 8601 timestamp.
-
onOrAfter
final Optional<OffsetDateTime> onOrAfter()
Return results on or after this ISO 8601 timestamp.
-
onOrBefore
final Optional<OffsetDateTime> onOrBefore()
Return results on or before this ISO 8601 timestamp.
-
_additionalProperties
final QueryParams _additionalProperties()
Query params to send with the request.
-
toBuilder
final AccountStatementListParams.StatementPeriodStart.Builder toBuilder()
-
builder
final static AccountStatementListParams.StatementPeriodStart.Builder builder()
Returns a mutable builder for constructing an instance of StatementPeriodStart.
-
-
-
-