Class AccountStatementRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountStatementRetrieveParams implements Params
Retrieve an Account Statement
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementRetrieveParams.BuilderA builder for AccountStatementRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountStatementId()The identifier of the Account Statement to retrieve. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountStatementRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementRetrieveParamsnone()final static AccountStatementRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementRetrieveParams. -
-
Method Detail
-
accountStatementId
final Optional<String> accountStatementId()
The identifier of the Account Statement to retrieve.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountStatementRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountStatementRetrieveParams none()
-
builder
final static AccountStatementRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementRetrieveParams.
-
-
-
-