Class AccountTransfer.Builder
-
- All Implemented Interfaces:
public final class AccountTransfer.BuilderA builder for AccountTransfer.
-
-
Method Summary
Modifier and Type Method Description final AccountTransfer.Builderid(String id)The Account Transfer's identifier. final AccountTransfer.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final AccountTransfer.BuilderaccountId(String accountId)The Account from which the transfer originated. final AccountTransfer.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final AccountTransfer.Builderamount(Long amount)The transfer amount in cents. final AccountTransfer.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final AccountTransfer.Builderapproval(AccountTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AccountTransfer.Builderapproval(Optional<AccountTransfer.Approval> approval)Alias for calling Builder.approval with approval.orElse(null).final AccountTransfer.Builderapproval(JsonField<AccountTransfer.Approval> approval)Sets Builder.approval to an arbitrary JSON value. final AccountTransfer.Buildercancellation(AccountTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AccountTransfer.Buildercancellation(Optional<AccountTransfer.Cancellation> cancellation)Alias for calling Builder.cancellation with cancellation.orElse(null).final AccountTransfer.Buildercancellation(JsonField<AccountTransfer.Cancellation> cancellation)Sets Builder.cancellation to an arbitrary JSON value. final AccountTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final AccountTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final AccountTransfer.BuildercreatedBy(AccountTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final AccountTransfer.BuildercreatedBy(Optional<AccountTransfer.CreatedBy> createdBy)Alias for calling Builder.createdBy with createdBy.orElse(null).final AccountTransfer.BuildercreatedBy(JsonField<AccountTransfer.CreatedBy> createdBy)Sets Builder.createdBy to an arbitrary JSON value. final AccountTransfer.Buildercurrency(AccountTransfer.Currency currency)The ISO 4217 code for the transfer's currency. final AccountTransfer.Buildercurrency(JsonField<AccountTransfer.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final AccountTransfer.Builderdescription(String description)An internal-facing description for the transfer for display in the API and dashboard. final AccountTransfer.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final AccountTransfer.BuilderdestinationAccountId(String destinationAccountId)The destination Account's identifier. final AccountTransfer.BuilderdestinationAccountId(JsonField<String> destinationAccountId)Sets Builder.destinationAccountId to an arbitrary JSON value. final AccountTransfer.BuilderdestinationTransactionId(String destinationTransactionId)The identifier of the Transaction on the destination Account representing the received funds. final AccountTransfer.BuilderdestinationTransactionId(Optional<String> destinationTransactionId)Alias for calling Builder.destinationTransactionId with destinationTransactionId.orElse(null).final AccountTransfer.BuilderdestinationTransactionId(JsonField<String> destinationTransactionId)Sets Builder.destinationTransactionId to an arbitrary JSON value. final AccountTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AccountTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final AccountTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final AccountTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final AccountTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)Alias for calling Builder.pendingTransactionId with pendingTransactionId.orElse(null).final AccountTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)Sets Builder.pendingTransactionId to an arbitrary JSON value. final AccountTransfer.Builderstatus(AccountTransfer.Status status)The lifecycle status of the transfer. final AccountTransfer.Builderstatus(JsonField<AccountTransfer.Status> status)Sets Builder.status to an arbitrary JSON value. final AccountTransfer.BuildertransactionId(String transactionId)The identifier of the Transaction on the originating account representing the transferred funds. final AccountTransfer.BuildertransactionId(Optional<String> transactionId)Alias for calling Builder.transactionId with transactionId.orElse(null).final AccountTransfer.BuildertransactionId(JsonField<String> transactionId)Sets Builder.transactionId to an arbitrary JSON value. final AccountTransfer.Buildertype(AccountTransfer.Type type)A constant representing the object's type. final AccountTransfer.Buildertype(JsonField<AccountTransfer.Type> type)Sets Builder.type to an arbitrary JSON value. final AccountTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final AccountTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountTransfer.BuilderremoveAdditionalProperty(String key)final AccountTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountTransferbuild()Returns an immutable instance of AccountTransfer. -
-
Method Detail
-
id
final AccountTransfer.Builder id(String id)
The Account Transfer's identifier.
-
id
final AccountTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final AccountTransfer.Builder accountId(String accountId)
The Account from which the transfer originated.
-
accountId
final AccountTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final AccountTransfer.Builder amount(Long amount)
The transfer amount in cents. This will always be positive and indicates the amount of money leaving the originating account.
-
amount
final AccountTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approval
final AccountTransfer.Builder approval(AccountTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final AccountTransfer.Builder approval(Optional<AccountTransfer.Approval> approval)
Alias for calling Builder.approval with
approval.orElse(null).
-
approval
final AccountTransfer.Builder approval(JsonField<AccountTransfer.Approval> approval)
Sets Builder.approval to an arbitrary JSON value.
You should usually call Builder.approval with a well-typed Approval value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cancellation
final AccountTransfer.Builder cancellation(AccountTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final AccountTransfer.Builder cancellation(Optional<AccountTransfer.Cancellation> cancellation)
Alias for calling Builder.cancellation with
cancellation.orElse(null).
-
cancellation
final AccountTransfer.Builder cancellation(JsonField<AccountTransfer.Cancellation> cancellation)
Sets Builder.cancellation to an arbitrary JSON value.
You should usually call Builder.cancellation with a well-typed Cancellation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AccountTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final AccountTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdBy
final AccountTransfer.Builder createdBy(AccountTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final AccountTransfer.Builder createdBy(Optional<AccountTransfer.CreatedBy> createdBy)
Alias for calling Builder.createdBy with
createdBy.orElse(null).
-
createdBy
final AccountTransfer.Builder createdBy(JsonField<AccountTransfer.CreatedBy> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed CreatedBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final AccountTransfer.Builder currency(AccountTransfer.Currency currency)
The ISO 4217 code for the transfer's currency.
-
currency
final AccountTransfer.Builder currency(JsonField<AccountTransfer.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final AccountTransfer.Builder description(String description)
An internal-facing description for the transfer for display in the API and dashboard. This will also show in the description of the created Transactions.
-
description
final AccountTransfer.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationAccountId
final AccountTransfer.Builder destinationAccountId(String destinationAccountId)
The destination Account's identifier.
-
destinationAccountId
final AccountTransfer.Builder destinationAccountId(JsonField<String> destinationAccountId)
Sets Builder.destinationAccountId to an arbitrary JSON value.
You should usually call Builder.destinationAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationTransactionId
final AccountTransfer.Builder destinationTransactionId(String destinationTransactionId)
The identifier of the Transaction on the destination Account representing the received funds.
-
destinationTransactionId
final AccountTransfer.Builder destinationTransactionId(Optional<String> destinationTransactionId)
Alias for calling Builder.destinationTransactionId with
destinationTransactionId.orElse(null).
-
destinationTransactionId
final AccountTransfer.Builder destinationTransactionId(JsonField<String> destinationTransactionId)
Sets Builder.destinationTransactionId to an arbitrary JSON value.
You should usually call Builder.destinationTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final AccountTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AccountTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final AccountTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final AccountTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final AccountTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final AccountTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AccountTransfer.Builder status(AccountTransfer.Status status)
The lifecycle status of the transfer.
-
status
final AccountTransfer.Builder status(JsonField<AccountTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final AccountTransfer.Builder transactionId(String transactionId)
The identifier of the Transaction on the originating account representing the transferred funds.
-
transactionId
final AccountTransfer.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final AccountTransfer.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountTransfer.Builder type(AccountTransfer.Type type)
A constant representing the object's type. For this resource it will always be
account_transfer.
-
type
final AccountTransfer.Builder type(JsonField<AccountTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountTransfer build()
Returns an immutable instance of AccountTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount() .approval() .cancellation() .createdAt() .createdBy() .currency() .description() .destinationAccountId() .destinationTransactionId() .idempotencyKey() .pendingTransactionId() .status() .transactionId() .type()
-
-
-
-