Class AccountTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class AccountTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classAccountTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classAccountTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classAccountTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classAccountTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
-
-
Method Detail
-
apiKey
final Optional<AccountTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
category
final AccountTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
oauthApplication
final Optional<AccountTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<AccountTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_apiKey
final JsonField<AccountTransfer.CreatedBy.ApiKey> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<AccountTransfer.CreatedBy.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthApplication
final JsonField<AccountTransfer.CreatedBy.OAuthApplication> _oauthApplication()
Returns the raw JSON value of oauthApplication.
Unlike oauthApplication, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<AccountTransfer.CreatedBy.User> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountTransfer.CreatedBy.Builder toBuilder()
-
validate
final AccountTransfer.CreatedBy validate()
-
builder
final static AccountTransfer.CreatedBy.Builder builder()
Returns a mutable builder for constructing an instance of CreatedBy.
The following fields are required:
.apiKey() .category() .oauthApplication() .user()
-
-
-
-