Class AccountTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountTransferCreateParams implements Params
Create an Account Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferCreateParams.BuilderA builder for AccountTransferCreateParams.
public final classAccountTransferCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the originating Account that will send the transfer. final Longamount()The transfer amount in the minor unit of the account currency. final Stringdescription()An internal-facing description for the transfer for display in the API and dashboard. final StringdestinationAccountId()The identifier for the destination Account that will receive the transfer. final Optional<Boolean>requireApproval()Whether the transfer should require explicit approval via the dashboard or API. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_destinationAccountId()Returns the raw JSON value of destinationAccountId. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountTransferCreateParams.BuildertoBuilder()final AccountTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountTransferCreateParams. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the originating Account that will send the transfer.
-
amount
final Long amount()
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
description
final String description()
An internal-facing description for the transfer for display in the API and dashboard. This will also show in the description of the created Transactions.
-
destinationAccountId
final String destinationAccountId()
The identifier for the destination Account that will receive the transfer.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer should require explicit approval via the dashboard or API. For more information, see /documentation/transfer-approvals.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
Returns the raw JSON value of destinationAccountId.
Unlike destinationAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountTransferCreateParams.Builder toBuilder()
-
_body
final AccountTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountTransferCreateParams.
The following fields are required:
.accountId() .amount() .description() .destinationAccountId()
-
-
-
-