Class AccountTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class AccountTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the originating Account that will send the transfer. final Longamount()The transfer amount in the minor unit of the account currency. final Stringdescription()An internal-facing description for the transfer for display in the API and dashboard. final StringdestinationAccountId()The identifier for the destination Account that will receive the transfer. final Optional<Boolean>requireApproval()Whether the transfer should require explicit approval via the dashboard or API. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_destinationAccountId()Returns the raw JSON value of destinationAccountId. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final Map<String, JsonValue>_additionalProperties()final AccountTransferCreateParams.Body.BuildertoBuilder()final AccountTransferCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransferCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the originating Account that will send the transfer.
-
amount
final Long amount()
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
description
final String description()
An internal-facing description for the transfer for display in the API and dashboard. This will also show in the description of the created Transactions.
-
destinationAccountId
final String destinationAccountId()
The identifier for the destination Account that will receive the transfer.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer should require explicit approval via the dashboard or API. For more information, see /documentation/transfer-approvals.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
Returns the raw JSON value of destinationAccountId.
Unlike destinationAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountTransferCreateParams.Body.Builder toBuilder()
-
validate
final AccountTransferCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AccountTransferCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount() .description() .destinationAccountId()
-
-
-
-