Class AccountTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final AccountTransferCreateParams.Body.Builder accountId(String accountId)
The identifier for the originating Account that will send the transfer.
-
accountId
final AccountTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final AccountTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in the minor unit of the account currency. For dollars, for example, this is cents.
-
amount
final AccountTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final AccountTransferCreateParams.Body.Builder description(String description)
An internal-facing description for the transfer for display in the API and dashboard. This will also show in the description of the created Transactions.
-
description
final AccountTransferCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationAccountId
final AccountTransferCreateParams.Body.Builder destinationAccountId(String destinationAccountId)
The identifier for the destination Account that will receive the transfer.
-
destinationAccountId
final AccountTransferCreateParams.Body.Builder destinationAccountId(JsonField<String> destinationAccountId)
Sets Builder.destinationAccountId to an arbitrary JSON value.
You should usually call Builder.destinationAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final AccountTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer should require explicit approval via the dashboard or API. For more information, see /documentation/transfer-approvals.
-
requireApproval
final AccountTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .description() .destinationAccountId()
-
-
-
-