Class AccountTransferListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AccountTransferListPageAsync.BuilderA builder for AccountTransferListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AccountTransferListPageAsync.Builderservice(AccountTransferServiceAsync service)final AccountTransferListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AccountTransferListPageAsync.Builderparams(AccountTransferListParams params)The parameters that were used to request this page. final AccountTransferListPageAsync.Builderresponse(AccountTransferListPageResponse response)The response that this page was parsed from. final AccountTransferListPageAsyncbuild()Returns an immutable instance of AccountTransferListPageAsync. -
-
Method Detail
-
service
final AccountTransferListPageAsync.Builder service(AccountTransferServiceAsync service)
-
streamHandlerExecutor
final AccountTransferListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AccountTransferListPageAsync.Builder params(AccountTransferListParams params)
The parameters that were used to request this page.
-
response
final AccountTransferListPageAsync.Builder response(AccountTransferListPageResponse response)
The response that this page was parsed from.
-
build
final AccountTransferListPageAsync build()
Returns an immutable instance of AccountTransferListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-