Class AccountTransferListPageResponse
-
- All Implemented Interfaces:
public final class AccountTransferListPageResponseA list of Account Transfer objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferListPageResponse.BuilderA builder for AccountTransferListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<AccountTransfer>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<AccountTransfer>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final AccountTransferListPageResponse.BuildertoBuilder()final AccountTransferListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountTransferListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of AccountTransferListPageResponse. -
-
Method Detail
-
data
final List<AccountTransfer> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<AccountTransfer>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountTransferListPageResponse.Builder toBuilder()
-
validate
final AccountTransferListPageResponse validate()
-
builder
final static AccountTransferListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of AccountTransferListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-