Package com.increase.api.models.accounttransfers
See: Description
-
Class Summary Class Description Builder A builder for AccountTransfer. Builder A builder for Approval. Approval If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. Builder A builder for Cancellation. Cancellation If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. Builder A builder for CreatedBy. Builder A builder for ApiKey. ApiKey If present, details about the API key that created the transfer. Category The type of object that created this transfer. Builder A builder for OAuthApplication. OAuthApplication If present, details about the OAuth Application that created the transfer. Builder A builder for User. User If present, details about the User that created the transfer. CreatedBy What object created the transfer, either via the API or the dashboard. Currency The ISO 4217 code for the transfer's currency. Status The lifecycle status of the transfer. Type A constant representing the object's type. AccountTransfer Account transfers move funds between your own accounts at Increase (accounting systems often refer to these as Book Transfers). Builder A builder for AccountTransferApproveParams. AccountTransferApproveParams Approves an Account Transfer in status pending_approval.Builder A builder for AccountTransferCancelParams. AccountTransferCancelParams Cancels an Account Transfer in status pending_approval.Builder A builder for AccountTransferCreateParams. Builder A builder for Body. Body AccountTransferCreateParams Create an Account Transfer Builder A builder for AccountTransferListPage. AccountTransferListPage Builder A builder for AccountTransferListPageAsync. AccountTransferListPageAsync Builder A builder for AccountTransferListPageResponse. AccountTransferListPageResponse A list of Account Transfer objects. Builder A builder for AccountTransferListParams. Builder A builder for CreatedAt. CreatedAt AccountTransferListParams List Account Transfers Builder A builder for AccountTransferRetrieveParams. AccountTransferRetrieveParams Retrieve an Account Transfer -
Enum Summary Enum Description Known An enum containing Category's known values. Value An enum containing Category's known values, as well as an _UNKNOWN member. Known An enum containing Currency's known values. Value An enum containing Currency's known values, as well as an _UNKNOWN member. Known An enum containing Status's known values. Value An enum containing Status's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member.