Class AchPrenotification
-
- All Implemented Interfaces:
public final class AchPrenotificationACH Prenotifications are one way you can verify account and routing numbers by Automated Clearing House (ACH).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotification.BuilderA builder for AchPrenotification.
public final classAchPrenotification.CreditDebitIndicatorIf the notification is for a future credit or debit.
public final classAchPrenotification.NotificationsOfChangepublic final classAchPrenotification.PrenotificationReturnIf your prenotification is returned, this will contain details of the return.
public final classAchPrenotification.StandardEntryClassCodeThe Standard Entry Class (SEC) code to use for the ACH Prenotification.
public final classAchPrenotification.StatusThe lifecycle status of the ACH Prenotification.
public final classAchPrenotification.TypeA constant representing the object's type. For this resource it will always be
ach_prenotification.
-
Method Summary
Modifier and Type Method Description final Stringid()The ACH Prenotification's identifier. final Optional<String>accountId()The account that sent the ACH Prenotification. final StringaccountNumber()The destination account number. final Optional<String>addendum()Additional information for the recipient. final Optional<String>companyDescriptiveDate()The description of the date of the notification. final Optional<String>companyDiscretionaryData()Optional data associated with the notification. final Optional<String>companyEntryDescription()The description of the notification. final Optional<String>companyName()The name by which you know the company. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the prenotification was created. final Optional<AchPrenotification.CreditDebitIndicator>creditDebitIndicator()If the notification is for a future credit or debit. final Optional<OffsetDateTime>effectiveDate()The effective date in ISO 8601 format. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>individualId()Your identifier for the recipient. final Optional<String>individualName()The name of the recipient. final List<AchPrenotification.NotificationsOfChange>notificationsOfChange()If the receiving bank notifies that future transfers should use different details, this will contain those details. final Optional<AchPrenotification.PrenotificationReturn>prenotificationReturn()If your prenotification is returned, this will contain details of the return. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<AchPrenotification.StandardEntryClassCode>standardEntryClassCode()The Standard Entry Class (SEC) code to use for the ACH Prenotification. final AchPrenotification.Statusstatus()The lifecycle status of the ACH Prenotification. final AchPrenotification.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_addendum()Returns the raw JSON value of addendum. final JsonField<String>_companyDescriptiveDate()Returns the raw JSON value of companyDescriptiveDate. final JsonField<String>_companyDiscretionaryData()Returns the raw JSON value of companyDiscretionaryData. final JsonField<String>_companyEntryDescription()Returns the raw JSON value of companyEntryDescription. final JsonField<String>_companyName()Returns the raw JSON value of companyName. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<AchPrenotification.CreditDebitIndicator>_creditDebitIndicator()Returns the raw JSON value of creditDebitIndicator. final JsonField<OffsetDateTime>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<String>_individualName()Returns the raw JSON value of individualName. final JsonField<List<AchPrenotification.NotificationsOfChange>>_notificationsOfChange()Returns the raw JSON value of notificationsOfChange. final JsonField<AchPrenotification.PrenotificationReturn>_prenotificationReturn()Returns the raw JSON value of prenotificationReturn. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<AchPrenotification.StandardEntryClassCode>_standardEntryClassCode()Returns the raw JSON value of standardEntryClassCode. final JsonField<AchPrenotification.Status>_status()Returns the raw JSON value of status. final JsonField<AchPrenotification.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AchPrenotification.BuildertoBuilder()final AchPrenotificationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchPrenotification.Builderbuilder()Returns a mutable builder for constructing an instance of AchPrenotification. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the notification.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
Optional data associated with the notification.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the notification.
-
companyName
final Optional<String> companyName()
The name by which you know the company.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the prenotification was created.
-
creditDebitIndicator
final Optional<AchPrenotification.CreditDebitIndicator> creditDebitIndicator()
If the notification is for a future credit or debit.
-
effectiveDate
final Optional<OffsetDateTime> effectiveDate()
The effective date in ISO 8601 format.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
individualId
final Optional<String> individualId()
Your identifier for the recipient.
-
individualName
final Optional<String> individualName()
The name of the recipient. This value is informational and not verified by the recipient's bank.
-
notificationsOfChange
final List<AchPrenotification.NotificationsOfChange> notificationsOfChange()
If the receiving bank notifies that future transfers should use different details, this will contain those details.
-
prenotificationReturn
final Optional<AchPrenotification.PrenotificationReturn> prenotificationReturn()
If your prenotification is returned, this will contain details of the return.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
standardEntryClassCode
final Optional<AchPrenotification.StandardEntryClassCode> standardEntryClassCode()
The Standard Entry Class (SEC) code to use for the ACH Prenotification.
-
status
final AchPrenotification.Status status()
The lifecycle status of the ACH Prenotification.
-
type
final AchPrenotification.Type type()
A constant representing the object's type. For this resource it will always be
ach_prenotification.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_addendum
final JsonField<String> _addendum()
Returns the raw JSON value of addendum.
Unlike addendum, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
Returns the raw JSON value of companyDescriptiveDate.
Unlike companyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Returns the raw JSON value of companyDiscretionaryData.
Unlike companyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
Returns the raw JSON value of companyEntryDescription.
Unlike companyEntryDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_companyName
final JsonField<String> _companyName()
Returns the raw JSON value of companyName.
Unlike companyName, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_creditDebitIndicator
final JsonField<AchPrenotification.CreditDebitIndicator> _creditDebitIndicator()
Returns the raw JSON value of creditDebitIndicator.
Unlike creditDebitIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<OffsetDateTime> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_individualName
final JsonField<String> _individualName()
Returns the raw JSON value of individualName.
Unlike individualName, this method doesn't throw if the JSON field has an unexpected type.
-
_notificationsOfChange
final JsonField<List<AchPrenotification.NotificationsOfChange>> _notificationsOfChange()
Returns the raw JSON value of notificationsOfChange.
Unlike notificationsOfChange, this method doesn't throw if the JSON field has an unexpected type.
-
_prenotificationReturn
final JsonField<AchPrenotification.PrenotificationReturn> _prenotificationReturn()
Returns the raw JSON value of prenotificationReturn.
Unlike prenotificationReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_standardEntryClassCode
final JsonField<AchPrenotification.StandardEntryClassCode> _standardEntryClassCode()
Returns the raw JSON value of standardEntryClassCode.
Unlike standardEntryClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AchPrenotification.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AchPrenotification.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchPrenotification.Builder toBuilder()
-
validate
final AchPrenotification validate()
-
builder
final static AchPrenotification.Builder builder()
Returns a mutable builder for constructing an instance of AchPrenotification.
The following fields are required:
.id() .accountId() .accountNumber() .addendum() .companyDescriptiveDate() .companyDiscretionaryData() .companyEntryDescription() .companyName() .createdAt() .creditDebitIndicator() .effectiveDate() .idempotencyKey() .individualId() .individualName() .notificationsOfChange() .prenotificationReturn() .routingNumber() .standardEntryClassCode() .status() .type()
-
-
-
-