Class AchPrenotificationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchPrenotificationCreateParams implements Params
Create an ACH Prenotification
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotificationCreateParams.BuilderA builder for AchPrenotificationCreateParams.
public final classAchPrenotificationCreateParams.Bodypublic final classAchPrenotificationCreateParams.CreditDebitIndicatorWhether the Prenotification is for a future debit or credit.
public final classAchPrenotificationCreateParams.StandardEntryClassCodeThe /documentation/ach-standard-entry-class-codes to use for the ACH Prenotification.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Increase identifier for the account that will send the ACH Prenotification. final StringaccountNumber()The account number for the destination account. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<String>addendum()Additional information that will be sent to the recipient. final Optional<String>companyDescriptiveDate()The description of the date of the ACH Prenotification. final Optional<String>companyDiscretionaryData()The data you choose to associate with the ACH Prenotification. final Optional<String>companyEntryDescription()The description you wish to be shown to the recipient. final Optional<String>companyName()The name by which the recipient knows you. final Optional<AchPrenotificationCreateParams.CreditDebitIndicator>creditDebitIndicator()Whether the Prenotification is for a future debit or credit. final Optional<LocalDate>effectiveDate()The ACH Prenotification effective date in ISO 8601 format. final Optional<String>individualId()Your identifier for the recipient. final Optional<String>individualName()The name of therecipient. final Optional<AchPrenotificationCreateParams.StandardEntryClassCode>standardEntryClassCode()The /documentation/ach-standard-entry-class-codes to use for the ACH Prenotification. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_addendum()Returns the raw JSON value of addendum. final JsonField<String>_companyDescriptiveDate()Returns the raw JSON value of companyDescriptiveDate. final JsonField<String>_companyDiscretionaryData()Returns the raw JSON value of companyDiscretionaryData. final JsonField<String>_companyEntryDescription()Returns the raw JSON value of companyEntryDescription. final JsonField<String>_companyName()Returns the raw JSON value of companyName. final JsonField<AchPrenotificationCreateParams.CreditDebitIndicator>_creditDebitIndicator()Returns the raw JSON value of creditDebitIndicator. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<String>_individualName()Returns the raw JSON value of individualName. final JsonField<AchPrenotificationCreateParams.StandardEntryClassCode>_standardEntryClassCode()Returns the raw JSON value of standardEntryClassCode. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AchPrenotificationCreateParams.BuildertoBuilder()final AchPrenotificationCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchPrenotificationCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AchPrenotificationCreateParams. -
-
Method Detail
-
accountId
final String accountId()
The Increase identifier for the account that will send the ACH Prenotification.
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
addendum
final Optional<String> addendum()
Additional information that will be sent to the recipient.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the ACH Prenotification.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
The data you choose to associate with the ACH Prenotification.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description you wish to be shown to the recipient.
-
companyName
final Optional<String> companyName()
The name by which the recipient knows you.
-
creditDebitIndicator
final Optional<AchPrenotificationCreateParams.CreditDebitIndicator> creditDebitIndicator()
Whether the Prenotification is for a future debit or credit.
-
effectiveDate
final Optional<LocalDate> effectiveDate()
The ACH Prenotification effective date in ISO 8601 format.
-
individualId
final Optional<String> individualId()
Your identifier for the recipient.
-
individualName
final Optional<String> individualName()
The name of therecipient. This value is informational and not verified by the recipient's bank.
-
standardEntryClassCode
final Optional<AchPrenotificationCreateParams.StandardEntryClassCode> standardEntryClassCode()
The /documentation/ach-standard-entry-class-codes to use for the ACH Prenotification.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_addendum
final JsonField<String> _addendum()
Returns the raw JSON value of addendum.
Unlike addendum, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
Returns the raw JSON value of companyDescriptiveDate.
Unlike companyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Returns the raw JSON value of companyDiscretionaryData.
Unlike companyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
Returns the raw JSON value of companyEntryDescription.
Unlike companyEntryDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_companyName
final JsonField<String> _companyName()
Returns the raw JSON value of companyName.
Unlike companyName, this method doesn't throw if the JSON field has an unexpected type.
-
_creditDebitIndicator
final JsonField<AchPrenotificationCreateParams.CreditDebitIndicator> _creditDebitIndicator()
Returns the raw JSON value of creditDebitIndicator.
Unlike creditDebitIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_individualName
final JsonField<String> _individualName()
Returns the raw JSON value of individualName.
Unlike individualName, this method doesn't throw if the JSON field has an unexpected type.
-
_standardEntryClassCode
final JsonField<AchPrenotificationCreateParams.StandardEntryClassCode> _standardEntryClassCode()
Returns the raw JSON value of standardEntryClassCode.
Unlike standardEntryClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AchPrenotificationCreateParams.Builder toBuilder()
-
_body
final AchPrenotificationCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AchPrenotificationCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AchPrenotificationCreateParams.
The following fields are required:
.accountId() .accountNumber() .routingNumber()
-
-
-
-