Class AchTransfer
-
- All Implemented Interfaces:
public final class AchTransferACH transfers move funds between your Increase account and any other account accessible by the Automated Clearing House (ACH).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.BuilderA builder for AchTransfer.
public final classAchTransfer.AcknowledgementAfter the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
public final classAchTransfer.AddendaAdditional information that will be sent to the recipient.
public final classAchTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classAchTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classAchTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classAchTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.public final classAchTransfer.DestinationAccountHolderThe type of entity that owns the account to which the ACH Transfer is being sent.
public final classAchTransfer.FundingThe type of the account to which the transfer will be sent.
public final classAchTransfer.InboundFundsHoldIncrease will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
public final classAchTransfer.NetworkThe transfer's network.
public final classAchTransfer.NotificationsOfChangepublic final classAchTransfer.PreferredEffectiveDateConfiguration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.public final classAchTransfer.ReturnIf your transfer is returned, this will contain details of the return.
public final classAchTransfer.SettlementA subhash containing information about when and how the transfer settled at the Federal Reserve.
public final classAchTransfer.StandardEntryClassCodeThe /documentation/ach-standard-entry-class-codes to use for the transfer.
public final classAchTransfer.StatusThe lifecycle status of the transfer.
public final classAchTransfer.SubmissionAfter the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
public final classAchTransfer.TypeA constant representing the object's type. For this resource it will always be
ach_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The ACH transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumber()The destination account number. final Optional<AchTransfer.Acknowledgement>acknowledgement()After the transfer is acknowledged by FedACH, this will contain supplemental details. final Optional<AchTransfer.Addenda>addenda()Additional information that will be sent to the recipient. final Longamount()The transfer amount in USD cents. final Optional<AchTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<AchTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final Optional<String>companyDescriptiveDate()The description of the date of the transfer. final Optional<String>companyDiscretionaryData()The data you chose to associate with the transfer. final Optional<String>companyEntryDescription()The description of the transfer you set to be shown to the recipient. final StringcompanyId()The company ID associated with the transfer. final Optional<String>companyName()The name by which the recipient knows you. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<AchTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final AchTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final AchTransfer.DestinationAccountHolderdestinationAccountHolder()The type of entity that owns the account to which the ACH Transfer is being sent. final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final AchTransfer.Fundingfunding()The type of the account to which the transfer will be sent. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<AchTransfer.InboundFundsHold>inboundFundsHold()Increase will sometimes hold the funds for ACH debit transfers. final Optional<String>individualId()Your identifier for the transfer recipient. final Optional<String>individualName()The name of the transfer recipient. final AchTransfer.Networknetwork()The transfer's network. final List<AchTransfer.NotificationsOfChange>notificationsOfChange()If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final AchTransfer.PreferredEffectiveDatepreferredEffectiveDate()Configuration for how the effective date of the transfer will be set. final Optional<AchTransfer.Return>return_()If your transfer is returned, this will contain details of the return. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<AchTransfer.Settlement>settlement()A subhash containing information about when and how the transfer settled at the Federal Reserve. final AchTransfer.StandardEntryClassCodestandardEntryClassCode()The /documentation/ach-standard-entry-class-codes to use for the transfer. final StringstatementDescriptor()The descriptor that will show on the recipient's bank statement. final AchTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<AchTransfer.Submission>submission()After the transfer is submitted to FedACH, this will contain supplemental details. final Optional<String>transactionId()The ID for the transaction funding the transfer. final AchTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<AchTransfer.Acknowledgement>_acknowledgement()Returns the raw JSON value of acknowledgement. final JsonField<AchTransfer.Addenda>_addenda()Returns the raw JSON value of addenda. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<AchTransfer.Approval>_approval()Returns the raw JSON value of approval. final JsonField<AchTransfer.Cancellation>_cancellation()Returns the raw JSON value of cancellation. final JsonField<String>_companyDescriptiveDate()Returns the raw JSON value of companyDescriptiveDate. final JsonField<String>_companyDiscretionaryData()Returns the raw JSON value of companyDiscretionaryData. final JsonField<String>_companyEntryDescription()Returns the raw JSON value of companyEntryDescription. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_companyName()Returns the raw JSON value of companyName. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<AchTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<AchTransfer.Currency>_currency()Returns the raw JSON value of currency. final JsonField<AchTransfer.DestinationAccountHolder>_destinationAccountHolder()Returns the raw JSON value of destinationAccountHolder. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<AchTransfer.Funding>_funding()Returns the raw JSON value of funding. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<AchTransfer.InboundFundsHold>_inboundFundsHold()Returns the raw JSON value of inboundFundsHold. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<String>_individualName()Returns the raw JSON value of individualName. final JsonField<AchTransfer.Network>_network()Returns the raw JSON value of network. final JsonField<List<AchTransfer.NotificationsOfChange>>_notificationsOfChange()Returns the raw JSON value of notificationsOfChange. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<AchTransfer.PreferredEffectiveDate>_preferredEffectiveDate()Returns the raw JSON value of preferredEffectiveDate. final JsonField<AchTransfer.Return>_return_()Returns the raw JSON value of return_. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<AchTransfer.Settlement>_settlement()Returns the raw JSON value of settlement. final JsonField<AchTransfer.StandardEntryClassCode>_standardEntryClassCode()Returns the raw JSON value of standardEntryClassCode. final JsonField<String>_statementDescriptor()Returns the raw JSON value of statementDescriptor. final JsonField<AchTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<AchTransfer.Submission>_submission()Returns the raw JSON value of submission. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<AchTransfer.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final AchTransfer.BuildertoBuilder()final AchTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransfer. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
acknowledgement
final Optional<AchTransfer.Acknowledgement> acknowledgement()
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
addenda
final Optional<AchTransfer.Addenda> addenda()
Additional information that will be sent to the recipient.
-
amount
final Long amount()
The transfer amount in USD cents. A positive amount indicates a credit transfer pushing funds to the receiving account. A negative amount indicates a debit transfer pulling funds from the receiving account.
-
approval
final Optional<AchTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final Optional<AchTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
The data you chose to associate with the transfer.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the transfer you set to be shown to the recipient.
-
companyName
final Optional<String> companyName()
The name by which the recipient knows you.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<AchTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final AchTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.
-
destinationAccountHolder
final AchTransfer.DestinationAccountHolder destinationAccountHolder()
The type of entity that owns the account to which the ACH Transfer is being sent.
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
funding
final AchTransfer.Funding funding()
The type of the account to which the transfer will be sent.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundFundsHold
final Optional<AchTransfer.InboundFundsHold> inboundFundsHold()
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
individualId
final Optional<String> individualId()
Your identifier for the transfer recipient.
-
individualName
final Optional<String> individualName()
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
network
final AchTransfer.Network network()
The transfer's network.
-
notificationsOfChange
final List<AchTransfer.NotificationsOfChange> notificationsOfChange()
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
preferredEffectiveDate
final AchTransfer.PreferredEffectiveDate preferredEffectiveDate()
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
return_
final Optional<AchTransfer.Return> return_()
If your transfer is returned, this will contain details of the return.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
settlement
final Optional<AchTransfer.Settlement> settlement()
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
standardEntryClassCode
final AchTransfer.StandardEntryClassCode standardEntryClassCode()
The /documentation/ach-standard-entry-class-codes to use for the transfer.
-
statementDescriptor
final String statementDescriptor()
The descriptor that will show on the recipient's bank statement.
-
status
final AchTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<AchTransfer.Submission> submission()
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
transactionId
final Optional<String> transactionId()
The ID for the transaction funding the transfer.
-
type
final AchTransfer.Type type()
A constant representing the object's type. For this resource it will always be
ach_transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_acknowledgement
final JsonField<AchTransfer.Acknowledgement> _acknowledgement()
Returns the raw JSON value of acknowledgement.
Unlike acknowledgement, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<AchTransfer.Addenda> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_approval
final JsonField<AchTransfer.Approval> _approval()
Returns the raw JSON value of approval.
Unlike approval, this method doesn't throw if the JSON field has an unexpected type.
-
_cancellation
final JsonField<AchTransfer.Cancellation> _cancellation()
Returns the raw JSON value of cancellation.
Unlike cancellation, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
Returns the raw JSON value of companyDescriptiveDate.
Unlike companyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Returns the raw JSON value of companyDiscretionaryData.
Unlike companyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
Returns the raw JSON value of companyEntryDescription.
Unlike companyEntryDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_companyName
final JsonField<String> _companyName()
Returns the raw JSON value of companyName.
Unlike companyName, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<AchTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<AchTransfer.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountHolder
final JsonField<AchTransfer.DestinationAccountHolder> _destinationAccountHolder()
Returns the raw JSON value of destinationAccountHolder.
Unlike destinationAccountHolder, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<AchTransfer.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundFundsHold
final JsonField<AchTransfer.InboundFundsHold> _inboundFundsHold()
Returns the raw JSON value of inboundFundsHold.
Unlike inboundFundsHold, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_individualName
final JsonField<String> _individualName()
Returns the raw JSON value of individualName.
Unlike individualName, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<AchTransfer.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_notificationsOfChange
final JsonField<List<AchTransfer.NotificationsOfChange>> _notificationsOfChange()
Returns the raw JSON value of notificationsOfChange.
Unlike notificationsOfChange, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredEffectiveDate
final JsonField<AchTransfer.PreferredEffectiveDate> _preferredEffectiveDate()
Returns the raw JSON value of preferredEffectiveDate.
Unlike preferredEffectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_return_
final JsonField<AchTransfer.Return> _return_()
Returns the raw JSON value of return_.
Unlike return_, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_settlement
final JsonField<AchTransfer.Settlement> _settlement()
Returns the raw JSON value of settlement.
Unlike settlement, this method doesn't throw if the JSON field has an unexpected type.
-
_standardEntryClassCode
final JsonField<AchTransfer.StandardEntryClassCode> _standardEntryClassCode()
Returns the raw JSON value of standardEntryClassCode.
Unlike standardEntryClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_statementDescriptor
final JsonField<String> _statementDescriptor()
Returns the raw JSON value of statementDescriptor.
Unlike statementDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AchTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<AchTransfer.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<AchTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransfer.Builder toBuilder()
-
validate
final AchTransfer validate()
-
builder
final static AchTransfer.Builder builder()
Returns a mutable builder for constructing an instance of AchTransfer.
The following fields are required:
.id() .accountId() .accountNumber() .acknowledgement() .addenda() .amount() .approval() .cancellation() .companyDescriptiveDate() .companyDiscretionaryData() .companyEntryDescription() .companyId() .companyName() .createdAt() .createdBy() .currency() .destinationAccountHolder() .externalAccountId() .funding() .idempotencyKey() .inboundFundsHold() .individualId() .individualName() .network() .notificationsOfChange() .pendingTransactionId() .preferredEffectiveDate() .return_() .routingNumber() .settlement() .standardEntryClassCode() .statementDescriptor() .status() .submission() .transactionId() .type()
-
-
-
-