Class AchTransfer.Acknowledgement
-
- All Implemented Interfaces:
public final class AchTransfer.AcknowledgementAfter the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Acknowledgement.BuilderA builder for Acknowledgement.
-
Method Summary
Modifier and Type Method Description final StringacknowledgedAt()When the Federal Reserve acknowledged the submitted file containing this transfer. final JsonField<String>_acknowledgedAt()Returns the raw JSON value of acknowledgedAt. final Map<String, JsonValue>_additionalProperties()final AchTransfer.Acknowledgement.BuildertoBuilder()final AchTransfer.Acknowledgementvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Acknowledgement.Builderbuilder()Returns a mutable builder for constructing an instance of Acknowledgement. -
-
Method Detail
-
acknowledgedAt
final String acknowledgedAt()
When the Federal Reserve acknowledged the submitted file containing this transfer.
-
_acknowledgedAt
final JsonField<String> _acknowledgedAt()
Returns the raw JSON value of acknowledgedAt.
Unlike acknowledgedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransfer.Acknowledgement.Builder toBuilder()
-
validate
final AchTransfer.Acknowledgement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AchTransfer.Acknowledgement.Builder builder()
Returns a mutable builder for constructing an instance of Acknowledgement.
The following fields are required:
.acknowledgedAt()
-
-
-
-