Class AchTransfer.Acknowledgement.Builder
-
- All Implemented Interfaces:
public final class AchTransfer.Acknowledgement.BuilderA builder for Acknowledgement.
-
-
Method Summary
Modifier and Type Method Description final AchTransfer.Acknowledgement.BuilderacknowledgedAt(String acknowledgedAt)When the Federal Reserve acknowledged the submitted file containing this transfer. final AchTransfer.Acknowledgement.BuilderacknowledgedAt(JsonField<String> acknowledgedAt)Sets Builder.acknowledgedAt to an arbitrary JSON value. final AchTransfer.Acknowledgement.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.Acknowledgement.BuilderputAdditionalProperty(String key, JsonValue value)final AchTransfer.Acknowledgement.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.Acknowledgement.BuilderremoveAdditionalProperty(String key)final AchTransfer.Acknowledgement.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchTransfer.Acknowledgementbuild()Returns an immutable instance of Acknowledgement. -
-
Method Detail
-
acknowledgedAt
final AchTransfer.Acknowledgement.Builder acknowledgedAt(String acknowledgedAt)
When the Federal Reserve acknowledged the submitted file containing this transfer.
-
acknowledgedAt
final AchTransfer.Acknowledgement.Builder acknowledgedAt(JsonField<String> acknowledgedAt)
Sets Builder.acknowledgedAt to an arbitrary JSON value.
You should usually call Builder.acknowledgedAt with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AchTransfer.Acknowledgement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransfer.Acknowledgement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransfer.Acknowledgement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransfer.Acknowledgement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransfer.Acknowledgement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransfer.Acknowledgement build()
Returns an immutable instance of Acknowledgement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.acknowledgedAt()
-
-
-
-