Class AchTransfer.Builder
-
- All Implemented Interfaces:
public final class AchTransfer.BuilderA builder for AchTransfer.
-
-
Method Summary
Modifier and Type Method Description final AchTransfer.Builderid(String id)The ACH transfer's identifier. final AchTransfer.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final AchTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final AchTransfer.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final AchTransfer.BuilderaccountNumber(String accountNumber)The destination account number. final AchTransfer.BuilderaccountNumber(JsonField<String> accountNumber)Sets Builder.accountNumber to an arbitrary JSON value. final AchTransfer.Builderacknowledgement(AchTransfer.Acknowledgement acknowledgement)After the transfer is acknowledged by FedACH, this will contain supplemental details. final AchTransfer.Builderacknowledgement(Optional<AchTransfer.Acknowledgement> acknowledgement)Alias for calling Builder.acknowledgement with acknowledgement.orElse(null).final AchTransfer.Builderacknowledgement(JsonField<AchTransfer.Acknowledgement> acknowledgement)Sets Builder.acknowledgement to an arbitrary JSON value. final AchTransfer.Builderaddenda(AchTransfer.Addenda addenda)Additional information that will be sent to the recipient. final AchTransfer.Builderaddenda(Optional<AchTransfer.Addenda> addenda)Alias for calling Builder.addenda with addenda.orElse(null).final AchTransfer.Builderaddenda(JsonField<AchTransfer.Addenda> addenda)Sets Builder.addenda to an arbitrary JSON value. final AchTransfer.Builderamount(Long amount)The transfer amount in USD cents. final AchTransfer.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final AchTransfer.Builderapproval(AchTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final AchTransfer.Builderapproval(Optional<AchTransfer.Approval> approval)Alias for calling Builder.approval with approval.orElse(null).final AchTransfer.Builderapproval(JsonField<AchTransfer.Approval> approval)Sets Builder.approval to an arbitrary JSON value. final AchTransfer.Buildercancellation(AchTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final AchTransfer.Buildercancellation(Optional<AchTransfer.Cancellation> cancellation)Alias for calling Builder.cancellation with cancellation.orElse(null).final AchTransfer.Buildercancellation(JsonField<AchTransfer.Cancellation> cancellation)Sets Builder.cancellation to an arbitrary JSON value. final AchTransfer.BuildercompanyDescriptiveDate(String companyDescriptiveDate)The description of the date of the transfer. final AchTransfer.BuildercompanyDescriptiveDate(Optional<String> companyDescriptiveDate)Alias for calling Builder.companyDescriptiveDate with companyDescriptiveDate.orElse(null).final AchTransfer.BuildercompanyDescriptiveDate(JsonField<String> companyDescriptiveDate)Sets Builder.companyDescriptiveDate to an arbitrary JSON value. final AchTransfer.BuildercompanyDiscretionaryData(String companyDiscretionaryData)The data you chose to associate with the transfer. final AchTransfer.BuildercompanyDiscretionaryData(Optional<String> companyDiscretionaryData)Alias for calling Builder.companyDiscretionaryData with companyDiscretionaryData.orElse(null).final AchTransfer.BuildercompanyDiscretionaryData(JsonField<String> companyDiscretionaryData)Sets Builder.companyDiscretionaryData to an arbitrary JSON value. final AchTransfer.BuildercompanyEntryDescription(String companyEntryDescription)The description of the transfer you set to be shown to the recipient. final AchTransfer.BuildercompanyEntryDescription(Optional<String> companyEntryDescription)Alias for calling Builder.companyEntryDescription with companyEntryDescription.orElse(null).final AchTransfer.BuildercompanyEntryDescription(JsonField<String> companyEntryDescription)Sets Builder.companyEntryDescription to an arbitrary JSON value. final AchTransfer.BuildercompanyId(String companyId)The company ID associated with the transfer. final AchTransfer.BuildercompanyId(JsonField<String> companyId)Sets Builder.companyId to an arbitrary JSON value. final AchTransfer.BuildercompanyName(String companyName)The name by which the recipient knows you. final AchTransfer.BuildercompanyName(Optional<String> companyName)Alias for calling Builder.companyName with companyName.orElse(null).final AchTransfer.BuildercompanyName(JsonField<String> companyName)Sets Builder.companyName to an arbitrary JSON value. final AchTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final AchTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final AchTransfer.BuildercreatedBy(AchTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final AchTransfer.BuildercreatedBy(Optional<AchTransfer.CreatedBy> createdBy)Alias for calling Builder.createdBy with createdBy.orElse(null).final AchTransfer.BuildercreatedBy(JsonField<AchTransfer.CreatedBy> createdBy)Sets Builder.createdBy to an arbitrary JSON value. final AchTransfer.Buildercurrency(AchTransfer.Currency currency)The ISO 4217 code for the transfer's currency. final AchTransfer.Buildercurrency(JsonField<AchTransfer.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final AchTransfer.BuilderdestinationAccountHolder(AchTransfer.DestinationAccountHolder destinationAccountHolder)The type of entity that owns the account to which the ACH Transfer is being sent. final AchTransfer.BuilderdestinationAccountHolder(JsonField<AchTransfer.DestinationAccountHolder> destinationAccountHolder)Sets Builder.destinationAccountHolder to an arbitrary JSON value. final AchTransfer.BuilderexternalAccountId(String externalAccountId)The identifier of the External Account the transfer was made to, if any. final AchTransfer.BuilderexternalAccountId(Optional<String> externalAccountId)Alias for calling Builder.externalAccountId with externalAccountId.orElse(null).final AchTransfer.BuilderexternalAccountId(JsonField<String> externalAccountId)Sets Builder.externalAccountId to an arbitrary JSON value. final AchTransfer.Builderfunding(AchTransfer.Funding funding)The type of the account to which the transfer will be sent. final AchTransfer.Builderfunding(JsonField<AchTransfer.Funding> funding)Sets Builder.funding to an arbitrary JSON value. final AchTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final AchTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final AchTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final AchTransfer.BuilderinboundFundsHold(AchTransfer.InboundFundsHold inboundFundsHold)Increase will sometimes hold the funds for ACH debit transfers. final AchTransfer.BuilderinboundFundsHold(Optional<AchTransfer.InboundFundsHold> inboundFundsHold)Alias for calling Builder.inboundFundsHold with inboundFundsHold.orElse(null).final AchTransfer.BuilderinboundFundsHold(JsonField<AchTransfer.InboundFundsHold> inboundFundsHold)Sets Builder.inboundFundsHold to an arbitrary JSON value. final AchTransfer.BuilderindividualId(String individualId)Your identifier for the transfer recipient. final AchTransfer.BuilderindividualId(Optional<String> individualId)Alias for calling Builder.individualId with individualId.orElse(null).final AchTransfer.BuilderindividualId(JsonField<String> individualId)Sets Builder.individualId to an arbitrary JSON value. final AchTransfer.BuilderindividualName(String individualName)The name of the transfer recipient. final AchTransfer.BuilderindividualName(Optional<String> individualName)Alias for calling Builder.individualName with individualName.orElse(null).final AchTransfer.BuilderindividualName(JsonField<String> individualName)Sets Builder.individualName to an arbitrary JSON value. final AchTransfer.Buildernetwork(AchTransfer.Network network)The transfer's network. final AchTransfer.Buildernetwork(JsonField<AchTransfer.Network> network)Sets Builder.network to an arbitrary JSON value. final AchTransfer.BuildernotificationsOfChange(List<AchTransfer.NotificationsOfChange> notificationsOfChange)If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details. final AchTransfer.BuildernotificationsOfChange(JsonField<List<AchTransfer.NotificationsOfChange>> notificationsOfChange)Sets Builder.notificationsOfChange to an arbitrary JSON value. final AchTransfer.BuilderaddNotificationsOfChange(AchTransfer.NotificationsOfChange notificationsOfChange)Adds a single NotificationsOfChange to Builder.notificationsOfChange. final AchTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final AchTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)Alias for calling Builder.pendingTransactionId with pendingTransactionId.orElse(null).final AchTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)Sets Builder.pendingTransactionId to an arbitrary JSON value. final AchTransfer.BuilderpreferredEffectiveDate(AchTransfer.PreferredEffectiveDate preferredEffectiveDate)Configuration for how the effective date of the transfer will be set. final AchTransfer.BuilderpreferredEffectiveDate(JsonField<AchTransfer.PreferredEffectiveDate> preferredEffectiveDate)Sets Builder.preferredEffectiveDate to an arbitrary JSON value. final AchTransfer.Builderreturn_(AchTransfer.Return return_)If your transfer is returned, this will contain details of the return. final AchTransfer.Builderreturn_(Optional<AchTransfer.Return> return_)Alias for calling Builder.return_ with return_.orElse(null).final AchTransfer.Builderreturn_(JsonField<AchTransfer.Return> return_)Sets Builder.return_ to an arbitrary JSON value. final AchTransfer.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final AchTransfer.BuilderroutingNumber(JsonField<String> routingNumber)Sets Builder.routingNumber to an arbitrary JSON value. final AchTransfer.Buildersettlement(AchTransfer.Settlement settlement)A subhash containing information about when and how the transfer settled at the Federal Reserve. final AchTransfer.Buildersettlement(Optional<AchTransfer.Settlement> settlement)Alias for calling Builder.settlement with settlement.orElse(null).final AchTransfer.Buildersettlement(JsonField<AchTransfer.Settlement> settlement)Sets Builder.settlement to an arbitrary JSON value. final AchTransfer.BuilderstandardEntryClassCode(AchTransfer.StandardEntryClassCode standardEntryClassCode)The Standard Entry Class (SEC) code to use for the transfer. final AchTransfer.BuilderstandardEntryClassCode(JsonField<AchTransfer.StandardEntryClassCode> standardEntryClassCode)Sets Builder.standardEntryClassCode to an arbitrary JSON value. final AchTransfer.BuilderstatementDescriptor(String statementDescriptor)The descriptor that will show on the recipient's bank statement. final AchTransfer.BuilderstatementDescriptor(JsonField<String> statementDescriptor)Sets Builder.statementDescriptor to an arbitrary JSON value. final AchTransfer.Builderstatus(AchTransfer.Status status)The lifecycle status of the transfer. final AchTransfer.Builderstatus(JsonField<AchTransfer.Status> status)Sets Builder.status to an arbitrary JSON value. final AchTransfer.Buildersubmission(AchTransfer.Submission submission)After the transfer is submitted to FedACH, this will contain supplemental details. final AchTransfer.Buildersubmission(Optional<AchTransfer.Submission> submission)Alias for calling Builder.submission with submission.orElse(null).final AchTransfer.Buildersubmission(JsonField<AchTransfer.Submission> submission)Sets Builder.submission to an arbitrary JSON value. final AchTransfer.BuildertransactionId(String transactionId)The ID for the transaction funding the transfer. final AchTransfer.BuildertransactionId(Optional<String> transactionId)Alias for calling Builder.transactionId with transactionId.orElse(null).final AchTransfer.BuildertransactionId(JsonField<String> transactionId)Sets Builder.transactionId to an arbitrary JSON value. final AchTransfer.Buildertype(AchTransfer.Type type)A constant representing the object's type. final AchTransfer.Buildertype(JsonField<AchTransfer.Type> type)Sets Builder.type to an arbitrary JSON value. final AchTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final AchTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AchTransfer.BuilderremoveAdditionalProperty(String key)final AchTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final AchTransferbuild()Returns an immutable instance of AchTransfer. -
-
Method Detail
-
id
final AchTransfer.Builder id(String id)
The ACH transfer's identifier.
-
id
final AchTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final AchTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final AchTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final AchTransfer.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final AchTransfer.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acknowledgement
final AchTransfer.Builder acknowledgement(AchTransfer.Acknowledgement acknowledgement)
After the transfer is acknowledged by FedACH, this will contain supplemental details. The Federal Reserve sends an acknowledgement message for each file that Increase submits.
-
acknowledgement
final AchTransfer.Builder acknowledgement(Optional<AchTransfer.Acknowledgement> acknowledgement)
Alias for calling Builder.acknowledgement with
acknowledgement.orElse(null).
-
acknowledgement
final AchTransfer.Builder acknowledgement(JsonField<AchTransfer.Acknowledgement> acknowledgement)
Sets Builder.acknowledgement to an arbitrary JSON value.
You should usually call Builder.acknowledgement with a well-typed Acknowledgement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addenda
final AchTransfer.Builder addenda(AchTransfer.Addenda addenda)
Additional information that will be sent to the recipient.
-
addenda
final AchTransfer.Builder addenda(Optional<AchTransfer.Addenda> addenda)
Alias for calling Builder.addenda with
addenda.orElse(null).
-
addenda
final AchTransfer.Builder addenda(JsonField<AchTransfer.Addenda> addenda)
Sets Builder.addenda to an arbitrary JSON value.
You should usually call Builder.addenda with a well-typed Addenda value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final AchTransfer.Builder amount(Long amount)
The transfer amount in USD cents. A positive amount indicates a credit transfer pushing funds to the receiving account. A negative amount indicates a debit transfer pulling funds from the receiving account.
-
amount
final AchTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approval
final AchTransfer.Builder approval(AchTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final AchTransfer.Builder approval(Optional<AchTransfer.Approval> approval)
Alias for calling Builder.approval with
approval.orElse(null).
-
approval
final AchTransfer.Builder approval(JsonField<AchTransfer.Approval> approval)
Sets Builder.approval to an arbitrary JSON value.
You should usually call Builder.approval with a well-typed Approval value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cancellation
final AchTransfer.Builder cancellation(AchTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final AchTransfer.Builder cancellation(Optional<AchTransfer.Cancellation> cancellation)
Alias for calling Builder.cancellation with
cancellation.orElse(null).
-
cancellation
final AchTransfer.Builder cancellation(JsonField<AchTransfer.Cancellation> cancellation)
Sets Builder.cancellation to an arbitrary JSON value.
You should usually call Builder.cancellation with a well-typed Cancellation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyDescriptiveDate
final AchTransfer.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the transfer.
-
companyDescriptiveDate
final AchTransfer.Builder companyDescriptiveDate(Optional<String> companyDescriptiveDate)
Alias for calling Builder.companyDescriptiveDate with
companyDescriptiveDate.orElse(null).
-
companyDescriptiveDate
final AchTransfer.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
Sets Builder.companyDescriptiveDate to an arbitrary JSON value.
You should usually call Builder.companyDescriptiveDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyDiscretionaryData
final AchTransfer.Builder companyDiscretionaryData(String companyDiscretionaryData)
The data you chose to associate with the transfer.
-
companyDiscretionaryData
final AchTransfer.Builder companyDiscretionaryData(Optional<String> companyDiscretionaryData)
Alias for calling Builder.companyDiscretionaryData with
companyDiscretionaryData.orElse(null).
-
companyDiscretionaryData
final AchTransfer.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
Sets Builder.companyDiscretionaryData to an arbitrary JSON value.
You should usually call Builder.companyDiscretionaryData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyEntryDescription
final AchTransfer.Builder companyEntryDescription(String companyEntryDescription)
The description of the transfer you set to be shown to the recipient.
-
companyEntryDescription
final AchTransfer.Builder companyEntryDescription(Optional<String> companyEntryDescription)
Alias for calling Builder.companyEntryDescription with
companyEntryDescription.orElse(null).
-
companyEntryDescription
final AchTransfer.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
Sets Builder.companyEntryDescription to an arbitrary JSON value.
You should usually call Builder.companyEntryDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyId
final AchTransfer.Builder companyId(String companyId)
The company ID associated with the transfer.
-
companyId
final AchTransfer.Builder companyId(JsonField<String> companyId)
Sets Builder.companyId to an arbitrary JSON value.
You should usually call Builder.companyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyName
final AchTransfer.Builder companyName(String companyName)
The name by which the recipient knows you.
-
companyName
final AchTransfer.Builder companyName(Optional<String> companyName)
Alias for calling Builder.companyName with
companyName.orElse(null).
-
companyName
final AchTransfer.Builder companyName(JsonField<String> companyName)
Sets Builder.companyName to an arbitrary JSON value.
You should usually call Builder.companyName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AchTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final AchTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdBy
final AchTransfer.Builder createdBy(AchTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final AchTransfer.Builder createdBy(Optional<AchTransfer.CreatedBy> createdBy)
Alias for calling Builder.createdBy with
createdBy.orElse(null).
-
createdBy
final AchTransfer.Builder createdBy(JsonField<AchTransfer.CreatedBy> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed CreatedBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final AchTransfer.Builder currency(AchTransfer.Currency currency)
The ISO 4217 code for the transfer's currency. For ACH transfers this is always equal to
usd.
-
currency
final AchTransfer.Builder currency(JsonField<AchTransfer.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationAccountHolder
final AchTransfer.Builder destinationAccountHolder(AchTransfer.DestinationAccountHolder destinationAccountHolder)
The type of entity that owns the account to which the ACH Transfer is being sent.
-
destinationAccountHolder
final AchTransfer.Builder destinationAccountHolder(JsonField<AchTransfer.DestinationAccountHolder> destinationAccountHolder)
Sets Builder.destinationAccountHolder to an arbitrary JSON value.
You should usually call Builder.destinationAccountHolder with a well-typed DestinationAccountHolder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalAccountId
final AchTransfer.Builder externalAccountId(String externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final AchTransfer.Builder externalAccountId(Optional<String> externalAccountId)
Alias for calling Builder.externalAccountId with
externalAccountId.orElse(null).
-
externalAccountId
final AchTransfer.Builder externalAccountId(JsonField<String> externalAccountId)
Sets Builder.externalAccountId to an arbitrary JSON value.
You should usually call Builder.externalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final AchTransfer.Builder funding(AchTransfer.Funding funding)
The type of the account to which the transfer will be sent.
-
funding
final AchTransfer.Builder funding(JsonField<AchTransfer.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final AchTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final AchTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final AchTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundFundsHold
final AchTransfer.Builder inboundFundsHold(AchTransfer.InboundFundsHold inboundFundsHold)
Increase will sometimes hold the funds for ACH debit transfers. If funds are held, this sub-object will contain details of the hold.
-
inboundFundsHold
final AchTransfer.Builder inboundFundsHold(Optional<AchTransfer.InboundFundsHold> inboundFundsHold)
Alias for calling Builder.inboundFundsHold with
inboundFundsHold.orElse(null).
-
inboundFundsHold
final AchTransfer.Builder inboundFundsHold(JsonField<AchTransfer.InboundFundsHold> inboundFundsHold)
Sets Builder.inboundFundsHold to an arbitrary JSON value.
You should usually call Builder.inboundFundsHold with a well-typed InboundFundsHold value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final AchTransfer.Builder individualId(String individualId)
Your identifier for the transfer recipient.
-
individualId
final AchTransfer.Builder individualId(Optional<String> individualId)
Alias for calling Builder.individualId with
individualId.orElse(null).
-
individualId
final AchTransfer.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualName
final AchTransfer.Builder individualName(String individualName)
The name of the transfer recipient. This value is information and not verified by the recipient's bank.
-
individualName
final AchTransfer.Builder individualName(Optional<String> individualName)
Alias for calling Builder.individualName with
individualName.orElse(null).
-
individualName
final AchTransfer.Builder individualName(JsonField<String> individualName)
Sets Builder.individualName to an arbitrary JSON value.
You should usually call Builder.individualName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final AchTransfer.Builder network(AchTransfer.Network network)
The transfer's network.
-
network
final AchTransfer.Builder network(JsonField<AchTransfer.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
notificationsOfChange
final AchTransfer.Builder notificationsOfChange(List<AchTransfer.NotificationsOfChange> notificationsOfChange)
If the receiving bank accepts the transfer but notifies that future transfers should use different details, this will contain those details.
-
notificationsOfChange
final AchTransfer.Builder notificationsOfChange(JsonField<List<AchTransfer.NotificationsOfChange>> notificationsOfChange)
Sets Builder.notificationsOfChange to an arbitrary JSON value.
You should usually call Builder.notificationsOfChange with a well-typed
List<NotificationsOfChange>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addNotificationsOfChange
final AchTransfer.Builder addNotificationsOfChange(AchTransfer.NotificationsOfChange notificationsOfChange)
Adds a single NotificationsOfChange to Builder.notificationsOfChange.
-
pendingTransactionId
final AchTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final AchTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final AchTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
preferredEffectiveDate
final AchTransfer.Builder preferredEffectiveDate(AchTransfer.PreferredEffectiveDate preferredEffectiveDate)
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
preferredEffectiveDate
final AchTransfer.Builder preferredEffectiveDate(JsonField<AchTransfer.PreferredEffectiveDate> preferredEffectiveDate)
Sets Builder.preferredEffectiveDate to an arbitrary JSON value.
You should usually call Builder.preferredEffectiveDate with a well-typed PreferredEffectiveDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
return_
final AchTransfer.Builder return_(AchTransfer.Return return_)
If your transfer is returned, this will contain details of the return.
-
return_
final AchTransfer.Builder return_(Optional<AchTransfer.Return> return_)
Alias for calling Builder.return_ with
return_.orElse(null).
-
return_
final AchTransfer.Builder return_(JsonField<AchTransfer.Return> return_)
Sets Builder.return_ to an arbitrary JSON value.
You should usually call Builder.return_ with a well-typed Return value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final AchTransfer.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final AchTransfer.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlement
final AchTransfer.Builder settlement(AchTransfer.Settlement settlement)
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
settlement
final AchTransfer.Builder settlement(Optional<AchTransfer.Settlement> settlement)
Alias for calling Builder.settlement with
settlement.orElse(null).
-
settlement
final AchTransfer.Builder settlement(JsonField<AchTransfer.Settlement> settlement)
Sets Builder.settlement to an arbitrary JSON value.
You should usually call Builder.settlement with a well-typed Settlement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
standardEntryClassCode
final AchTransfer.Builder standardEntryClassCode(AchTransfer.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the transfer.
-
standardEntryClassCode
final AchTransfer.Builder standardEntryClassCode(JsonField<AchTransfer.StandardEntryClassCode> standardEntryClassCode)
Sets Builder.standardEntryClassCode to an arbitrary JSON value.
You should usually call Builder.standardEntryClassCode with a well-typed StandardEntryClassCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementDescriptor
final AchTransfer.Builder statementDescriptor(String statementDescriptor)
The descriptor that will show on the recipient's bank statement.
-
statementDescriptor
final AchTransfer.Builder statementDescriptor(JsonField<String> statementDescriptor)
Sets Builder.statementDescriptor to an arbitrary JSON value.
You should usually call Builder.statementDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final AchTransfer.Builder status(AchTransfer.Status status)
The lifecycle status of the transfer.
-
status
final AchTransfer.Builder status(JsonField<AchTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submission
final AchTransfer.Builder submission(AchTransfer.Submission submission)
After the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
submission
final AchTransfer.Builder submission(Optional<AchTransfer.Submission> submission)
Alias for calling Builder.submission with
submission.orElse(null).
-
submission
final AchTransfer.Builder submission(JsonField<AchTransfer.Submission> submission)
Sets Builder.submission to an arbitrary JSON value.
You should usually call Builder.submission with a well-typed Submission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final AchTransfer.Builder transactionId(String transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final AchTransfer.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final AchTransfer.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AchTransfer.Builder type(AchTransfer.Type type)
A constant representing the object's type. For this resource it will always be
ach_transfer.
-
type
final AchTransfer.Builder type(JsonField<AchTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AchTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransfer build()
Returns an immutable instance of AchTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .accountNumber() .acknowledgement() .addenda() .amount() .approval() .cancellation() .companyDescriptiveDate() .companyDiscretionaryData() .companyEntryDescription() .companyId() .companyName() .createdAt() .createdBy() .currency() .destinationAccountHolder() .externalAccountId() .funding() .idempotencyKey() .inboundFundsHold() .individualId() .individualName() .network() .notificationsOfChange() .pendingTransactionId() .preferredEffectiveDate() .return_() .routingNumber() .settlement() .standardEntryClassCode() .statementDescriptor() .status() .submission() .transactionId() .type()
-
-
-
-