Class AchTransfer.NotificationsOfChange
-
- All Implemented Interfaces:
public final class AchTransfer.NotificationsOfChange
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.NotificationsOfChange.BuilderA builder for NotificationsOfChange.
public final classAchTransfer.NotificationsOfChange.ChangeCodeThe required type of change that is being signaled by the receiving financial institution.
public final classAchTransfer.NotificationsOfChange.CorrectedAccountFundingThe corrected account funding type that should be used in future ACHs to this account. This is derived from the corrected transaction code.
-
Method Summary
Modifier and Type Method Description final AchTransfer.NotificationsOfChange.ChangeCodechangeCode()The required type of change that is being signaled by the receiving financial institution. final Optional<AchTransfer.NotificationsOfChange.CorrectedAccountFunding>correctedAccountFunding()The corrected account funding type that should be used in future ACHs to this account. final Optional<String>correctedAccountNumber()The corrected account number that should be used in future ACHs to this account. final Optional<String>correctedIndividualId()The corrected individual identifier that should be used in future ACHs. final Optional<String>correctedRoutingNumber()The corrected routing number that should be used in future ACHs to this account. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the notification occurred. final JsonField<AchTransfer.NotificationsOfChange.ChangeCode>_changeCode()Returns the raw JSON value of changeCode. final JsonField<AchTransfer.NotificationsOfChange.CorrectedAccountFunding>_correctedAccountFunding()Returns the raw JSON value of correctedAccountFunding. final JsonField<String>_correctedAccountNumber()Returns the raw JSON value of correctedAccountNumber. final JsonField<String>_correctedIndividualId()Returns the raw JSON value of correctedIndividualId. final JsonField<String>_correctedRoutingNumber()Returns the raw JSON value of correctedRoutingNumber. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final AchTransfer.NotificationsOfChange.BuildertoBuilder()final AchTransfer.NotificationsOfChangevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.NotificationsOfChange.Builderbuilder()Returns a mutable builder for constructing an instance of NotificationsOfChange. -
-
Method Detail
-
changeCode
final AchTransfer.NotificationsOfChange.ChangeCode changeCode()
The required type of change that is being signaled by the receiving financial institution.
-
correctedAccountFunding
final Optional<AchTransfer.NotificationsOfChange.CorrectedAccountFunding> correctedAccountFunding()
The corrected account funding type that should be used in future ACHs to this account. This is derived from the corrected transaction code.
-
correctedAccountNumber
final Optional<String> correctedAccountNumber()
The corrected account number that should be used in future ACHs to this account.
-
correctedIndividualId
final Optional<String> correctedIndividualId()
The corrected individual identifier that should be used in future ACHs.
-
correctedRoutingNumber
final Optional<String> correctedRoutingNumber()
The corrected routing number that should be used in future ACHs to this account.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the notification occurred.
-
_changeCode
final JsonField<AchTransfer.NotificationsOfChange.ChangeCode> _changeCode()
Returns the raw JSON value of changeCode.
Unlike changeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedAccountFunding
final JsonField<AchTransfer.NotificationsOfChange.CorrectedAccountFunding> _correctedAccountFunding()
Returns the raw JSON value of correctedAccountFunding.
Unlike correctedAccountFunding, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedAccountNumber
final JsonField<String> _correctedAccountNumber()
Returns the raw JSON value of correctedAccountNumber.
Unlike correctedAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedIndividualId
final JsonField<String> _correctedIndividualId()
Returns the raw JSON value of correctedIndividualId.
Unlike correctedIndividualId, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedRoutingNumber
final JsonField<String> _correctedRoutingNumber()
Returns the raw JSON value of correctedRoutingNumber.
Unlike correctedRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransfer.NotificationsOfChange.Builder toBuilder()
-
validate
final AchTransfer.NotificationsOfChange validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AchTransfer.NotificationsOfChange.Builder builder()
Returns a mutable builder for constructing an instance of NotificationsOfChange.
The following fields are required:
.changeCode() .correctedAccountFunding() .correctedAccountNumber() .correctedIndividualId() .correctedRoutingNumber() .createdAt()
-
-
-
-