Enum AchTransfer.NotificationsOfChange.ChangeCode.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AchTransfer.NotificationsOfChange.ChangeCode.Value extends Enum<AchTransfer.NotificationsOfChange.ChangeCode.Value>
An enum containing ChangeCode's known values, as well as an _UNKNOWN member.
An instance of ChangeCode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AchTransfer.NotificationsOfChange.ChangeCode.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description INCORRECT_ACCOUNT_NUMBERThe account number was incorrect.
INCORRECT_ROUTING_NUMBERThe routing number was incorrect.
INCORRECT_ROUTING_NUMBER_AND_ACCOUNT_NUMBERBoth the routing number and the account number were incorrect.
INCORRECT_TRANSACTION_CODEThe transaction code was incorrect. Try changing the
fundingparameter from checking to savings or vice-versa.INCORRECT_ACCOUNT_NUMBER_AND_TRANSACTION_CODEThe account number and the transaction code were incorrect.
INCORRECT_ROUTING_NUMBER_ACCOUNT_NUMBER_AND_TRANSACTION_CODEThe routing number, account number, and transaction code were incorrect.
INCORRECT_RECEIVING_DEPOSITORY_FINANCIAL_INSTITUTION_IDENTIFICATIONThe receiving depository financial institution identification was incorrect.
INCORRECT_INDIVIDUAL_IDENTIFICATION_NUMBERThe individual identification number was incorrect.
ADDENDA_FORMAT_ERRORThe addenda had an incorrect format.
INCORRECT_STANDARD_ENTRY_CLASS_CODE_FOR_OUTBOUND_INTERNATIONAL_PAYMENTThe standard entry class code was incorrect for an outbound international payment.
MISROUTED_NOTIFICATION_OF_CHANGEThe notification of change was misrouted.
INCORRECT_TRACE_NUMBERThe trace number was incorrect.
INCORRECT_COMPANY_IDENTIFICATION_NUMBERThe company identification number was incorrect.
INCORRECT_IDENTIFICATION_NUMBERThe individual identification number or identification number was incorrect.
INCORRECTLY_FORMATTED_CORRECTED_DATAThe corrected data was incorrectly formatted.
INCORRECT_DISCRETIONARY_DATAThe discretionary data was incorrect.
ROUTING_NUMBER_NOT_FROM_ORIGINAL_ENTRY_DETAIL_RECORDThe routing number was not from the original entry detail record.
DEPOSITORY_FINANCIAL_INSTITUTION_ACCOUNT_NUMBER_NOT_FROM_ORIGINAL_ENTRY_DETAIL_RECORDThe depository financial institution account number was not from the original entry detail record.
INCORRECT_TRANSACTION_CODE_BY_ORIGINATING_DEPOSITORY_FINANCIAL_INSTITUTIONThe transaction code was incorrect, initiated by the originating depository financial institution.
_UNKNOWNAn enum member indicating that ChangeCode was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final AchTransfer.NotificationsOfChange.ChangeCode.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AchTransfer.NotificationsOfChange.ChangeCode.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AchTransfer.NotificationsOfChange.ChangeCode.Value>getEntries()An enum containing ChangeCode's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final AchTransfer.NotificationsOfChange.ChangeCode.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AchTransfer.NotificationsOfChange.ChangeCode.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AchTransfer.NotificationsOfChange.ChangeCode.Value> getEntries()
An enum containing ChangeCode's known values, as well as an _UNKNOWN member.
An instance of ChangeCode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-