Class AchTransfer.PreferredEffectiveDate
-
- All Implemented Interfaces:
public final class AchTransfer.PreferredEffectiveDateConfiguration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.PreferredEffectiveDate.BuilderA builder for PreferredEffectiveDate.
public final classAchTransfer.PreferredEffectiveDate.SettlementScheduleA schedule by which Increase will choose an effective date for the transfer.
-
Method Summary
Modifier and Type Method Description final Optional<LocalDate>date()A specific date in ISO 8601 format to use as the effective date when submitting this transfer. final Optional<AchTransfer.PreferredEffectiveDate.SettlementSchedule>settlementSchedule()A schedule by which Increase will choose an effective date for the transfer. final JsonField<LocalDate>_date()Returns the raw JSON value of date. final JsonField<AchTransfer.PreferredEffectiveDate.SettlementSchedule>_settlementSchedule()Returns the raw JSON value of settlementSchedule. final Map<String, JsonValue>_additionalProperties()final AchTransfer.PreferredEffectiveDate.BuildertoBuilder()final AchTransfer.PreferredEffectiveDatevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.PreferredEffectiveDate.Builderbuilder()Returns a mutable builder for constructing an instance of PreferredEffectiveDate. -
-
Method Detail
-
date
final Optional<LocalDate> date()
A specific date in ISO 8601 format to use as the effective date when submitting this transfer.
-
settlementSchedule
final Optional<AchTransfer.PreferredEffectiveDate.SettlementSchedule> settlementSchedule()
A schedule by which Increase will choose an effective date for the transfer.
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementSchedule
final JsonField<AchTransfer.PreferredEffectiveDate.SettlementSchedule> _settlementSchedule()
Returns the raw JSON value of settlementSchedule.
Unlike settlementSchedule, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransfer.PreferredEffectiveDate.Builder toBuilder()
-
validate
final AchTransfer.PreferredEffectiveDate validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AchTransfer.PreferredEffectiveDate.Builder builder()
Returns a mutable builder for constructing an instance of PreferredEffectiveDate.
The following fields are required:
.date() .settlementSchedule()
-
-
-
-