Enum AchTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum AchTransfer.Status.Known extends Enum<AchTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<AchTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_APPROVALThe transfer is pending approval.
PENDING_TRANSFER_SESSION_CONFIRMATIONThe transfer belongs to a Transfer Session that is pending confirmation.
CANCELEDThe transfer has been canceled.
PENDING_SUBMISSIONThe transfer is pending submission to the Federal Reserve.
PENDING_REVIEWINGThe transfer is pending review by Increase.
REQUIRES_ATTENTIONThe transfer requires attention from an Increase operator.
REJECTEDThe transfer has been rejected.
SUBMITTEDThe transfer is complete.
RETURNEDThe transfer has been returned.
-
Method Summary
Modifier and Type Method Description final AchTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<AchTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<AchTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final AchTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<AchTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<AchTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-