Class AchTransfer.Submission
-
- All Implemented Interfaces:
public final class AchTransfer.SubmissionAfter the transfer is submitted to FedACH, this will contain supplemental details. Increase batches transfers and submits a file to the Federal Reserve roughly every 30 minutes. The Federal Reserve processes ACH transfers during weekdays according to their posted schedule.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.Submission.BuilderA builder for Submission.
public final classAchTransfer.Submission.ExpectedSettlementScheduleThe settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeadministrativeReturnsExpectedBy()The timestamp by which any administrative returns are expected to be received by. final LocalDateeffectiveDate()The ACH transfer's effective date as sent to the Federal Reserve. final OffsetDateTimeexpectedFundsSettlementAt()When the transfer is expected to settle in the recipient's account. final AchTransfer.Submission.ExpectedSettlementScheduleexpectedSettlementSchedule()The settlement schedule the transfer is expected to follow. final OffsetDateTimesubmittedAt()When the ACH transfer was sent to FedACH. final StringtraceNumber()A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. final JsonField<OffsetDateTime>_administrativeReturnsExpectedBy()Returns the raw JSON value of administrativeReturnsExpectedBy. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<OffsetDateTime>_expectedFundsSettlementAt()Returns the raw JSON value of expectedFundsSettlementAt. final JsonField<AchTransfer.Submission.ExpectedSettlementSchedule>_expectedSettlementSchedule()Returns the raw JSON value of expectedSettlementSchedule. final JsonField<OffsetDateTime>_submittedAt()Returns the raw JSON value of submittedAt. final JsonField<String>_traceNumber()Returns the raw JSON value of traceNumber. final Map<String, JsonValue>_additionalProperties()final AchTransfer.Submission.BuildertoBuilder()final AchTransfer.Submissionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.Submission.Builderbuilder()Returns a mutable builder for constructing an instance of Submission. -
-
Method Detail
-
administrativeReturnsExpectedBy
final OffsetDateTime administrativeReturnsExpectedBy()
The timestamp by which any administrative returns are expected to be received by. This follows the NACHA guidelines for return windows, which are: "In general, return entries must be received by the RDFI’s ACH Operator by its deposit deadline for the return entry to be made available to the ODFI no later than the opening of business on the second banking day following the Settlement Date of the original entry.".
-
effectiveDate
final LocalDate effectiveDate()
The ACH transfer's effective date as sent to the Federal Reserve. If a specific date was configured using
preferred_effective_date, this will match that value. Otherwise, it will be the date selected (following the specified settlement schedule) at the time the transfer was submitted.
-
expectedFundsSettlementAt
final OffsetDateTime expectedFundsSettlementAt()
When the transfer is expected to settle in the recipient's account. Credits may be available sooner, at the receiving bank's discretion. The FedACH schedule is published here.
-
expectedSettlementSchedule
final AchTransfer.Submission.ExpectedSettlementSchedule expectedSettlementSchedule()
The settlement schedule the transfer is expected to follow. This expectation takes into account the
effective_date,submitted_at, and the amount of the transfer.
-
submittedAt
final OffsetDateTime submittedAt()
When the ACH transfer was sent to FedACH.
-
traceNumber
final String traceNumber()
A 15 digit number recorded in the Nacha file and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at the receiving bank. ACH trace numbers are not unique, but are used to correlate returns.
-
_administrativeReturnsExpectedBy
final JsonField<OffsetDateTime> _administrativeReturnsExpectedBy()
Returns the raw JSON value of administrativeReturnsExpectedBy.
Unlike administrativeReturnsExpectedBy, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_expectedFundsSettlementAt
final JsonField<OffsetDateTime> _expectedFundsSettlementAt()
Returns the raw JSON value of expectedFundsSettlementAt.
Unlike expectedFundsSettlementAt, this method doesn't throw if the JSON field has an unexpected type.
-
_expectedSettlementSchedule
final JsonField<AchTransfer.Submission.ExpectedSettlementSchedule> _expectedSettlementSchedule()
Returns the raw JSON value of expectedSettlementSchedule.
Unlike expectedSettlementSchedule, this method doesn't throw if the JSON field has an unexpected type.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
Returns the raw JSON value of submittedAt.
Unlike submittedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_traceNumber
final JsonField<String> _traceNumber()
Returns the raw JSON value of traceNumber.
Unlike traceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransfer.Submission.Builder toBuilder()
-
validate
final AchTransfer.Submission validate()
-
builder
final static AchTransfer.Submission.Builder builder()
Returns a mutable builder for constructing an instance of Submission.
The following fields are required:
.administrativeReturnsExpectedBy() .effectiveDate() .expectedFundsSettlementAt() .expectedSettlementSchedule() .submittedAt() .traceNumber()
-
-
-
-