Class AchTransferCreateParams.Addenda

  • All Implemented Interfaces:

    
    public final class AchTransferCreateParams.Addenda
    
                        

    Additional information passed through to the receiving bank with the transfer. Most ACH transfers do not need this. Only set this if your recipient has asked for addendum data, typically unstructured remittance information. Corporate Trade Exchange (CTX) flows can carry structured X12 remittance advice instead.