Class AchTransferCreateParams.Addenda.Freeform
-
- All Implemented Interfaces:
public final class AchTransferCreateParams.Addenda.FreeformUnstructured
payment_related_informationpassed through with the transfer. Required if and only ifcategoryisfreeform.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateParams.Addenda.Freeform.BuilderA builder for Freeform.
public final classAchTransferCreateParams.Addenda.Freeform.Entry
-
Method Summary
Modifier and Type Method Description final List<AchTransferCreateParams.Addenda.Freeform.Entry>entries()Each entry represents an addendum sent with the transfer. final JsonField<List<AchTransferCreateParams.Addenda.Freeform.Entry>>_entries()Returns the raw JSON value of entries. final Map<String, JsonValue>_additionalProperties()final AchTransferCreateParams.Addenda.Freeform.BuildertoBuilder()final AchTransferCreateParams.Addenda.Freeformvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferCreateParams.Addenda.Freeform.Builderbuilder()Returns a mutable builder for constructing an instance of Freeform. -
-
Method Detail
-
entries
final List<AchTransferCreateParams.Addenda.Freeform.Entry> entries()
Each entry represents an addendum sent with the transfer. Sending more than one addendum is only supported for transfers with
standard_entry_class_codeofcorporate_trade_exchange(CTX).
-
_entries
final JsonField<List<AchTransferCreateParams.Addenda.Freeform.Entry>> _entries()
Returns the raw JSON value of entries.
Unlike entries, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransferCreateParams.Addenda.Freeform.Builder toBuilder()
-
validate
final AchTransferCreateParams.Addenda.Freeform validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AchTransferCreateParams.Addenda.Freeform.Builder builder()
Returns a mutable builder for constructing an instance of Freeform.
The following fields are required:
.entries()
-
-
-
-