Class AchTransferCreateParams.PreferredEffectiveDate
-
- All Implemented Interfaces:
public final class AchTransferCreateParams.PreferredEffectiveDateConfiguration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateParams.PreferredEffectiveDate.BuilderA builder for PreferredEffectiveDate.
public final classAchTransferCreateParams.PreferredEffectiveDate.SettlementScheduleA schedule by which Increase will choose an effective date for the transfer.
-
Method Summary
-
-
Method Detail
-
date
final Optional<LocalDate> date()
A specific date in ISO 8601 format to use as the effective date when submitting this transfer.
-
settlementSchedule
final Optional<AchTransferCreateParams.PreferredEffectiveDate.SettlementSchedule> settlementSchedule()
A schedule by which Increase will choose an effective date for the transfer.
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementSchedule
final JsonField<AchTransferCreateParams.PreferredEffectiveDate.SettlementSchedule> _settlementSchedule()
Returns the raw JSON value of settlementSchedule.
Unlike settlementSchedule, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransferCreateParams.PreferredEffectiveDate.Builder toBuilder()
-
validate
final AchTransferCreateParams.PreferredEffectiveDate validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AchTransferCreateParams.PreferredEffectiveDate.Builder builder()
Returns a mutable builder for constructing an instance of PreferredEffectiveDate.
-
-
-
-