Class AchTransferListPageAsync
-
- All Implemented Interfaces:
public final class AchTransferListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferListPageAsync.BuilderA builder for AchTransferListPageAsync.
public final classAchTransferListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AchTransfer>data()Delegates to AchTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AchTransferListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AchTransferListParams>getNextPageParams()final CompletableFuture<Optional<AchTransferListPageAsync>>getNextPage()final AchTransferListPageAsync.AutoPagerautoPager()final AchTransferListParamsparams()The parameters that were used to request this page. final AchTransferListPageResponseresponse()The response that this page was parsed from. final AchTransferListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransferListPageAsync. -
-
Method Detail
-
data
final List<AchTransfer> data()
Delegates to AchTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AchTransferListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AchTransferListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<AchTransferListPageAsync>> getNextPage()
-
autoPager
final AchTransferListPageAsync.AutoPager autoPager()
-
params
final AchTransferListParams params()
The parameters that were used to request this page.
-
response
final AchTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AchTransferListPageAsync.Builder toBuilder()
-
builder
final static AchTransferListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AchTransferListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-