Class AchTransferListPageAsync.Builder
-
- All Implemented Interfaces:
public final class AchTransferListPageAsync.BuilderA builder for AchTransferListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final AchTransferListPageAsync.Builderservice(AchTransferServiceAsync service)final AchTransferListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final AchTransferListPageAsync.Builderparams(AchTransferListParams params)The parameters that were used to request this page. final AchTransferListPageAsync.Builderresponse(AchTransferListPageResponse response)The response that this page was parsed from. final AchTransferListPageAsyncbuild()Returns an immutable instance of AchTransferListPageAsync. -
-
Method Detail
-
service
final AchTransferListPageAsync.Builder service(AchTransferServiceAsync service)
-
streamHandlerExecutor
final AchTransferListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final AchTransferListPageAsync.Builder params(AchTransferListParams params)
The parameters that were used to request this page.
-
response
final AchTransferListPageAsync.Builder response(AchTransferListPageResponse response)
The response that this page was parsed from.
-
build
final AchTransferListPageAsync build()
Returns an immutable instance of AchTransferListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-