Class AchTransferRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchTransferRetrieveParams implements Params
Retrieve an ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferRetrieveParams.BuilderA builder for AchTransferRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>achTransferId()The identifier of the ACH Transfer. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AchTransferRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferRetrieveParamsnone()final static AchTransferRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransferRetrieveParams. -
-
Method Detail
-
achTransferId
final Optional<String> achTransferId()
The identifier of the ACH Transfer.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AchTransferRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AchTransferRetrieveParams none()
-
builder
final static AchTransferRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of AchTransferRetrieveParams.
-
-
-
-