Class BookkeepingAccount
-
- All Implemented Interfaces:
public final class BookkeepingAccountAccounts are T-accounts. They can store accounting entries. Your compliance setup might require annotating money movements using this API. Learn more in our guide to Bookkeeping.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccount.BuilderA builder for BookkeepingAccount.
public final classBookkeepingAccount.ComplianceCategoryThe compliance category of the account.
public final classBookkeepingAccount.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
Method Summary
Modifier and Type Method Description final Stringid()The account identifier. final Optional<String>accountId()The API Account associated with this bookkeeping account. final Optional<BookkeepingAccount.ComplianceCategory>complianceCategory()The compliance category of the account. final Optional<String>entityId()The Entity associated with this bookkeeping account. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Stringname()The name you choose for the account. final BookkeepingAccount.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<BookkeepingAccount.ComplianceCategory>_complianceCategory()Returns the raw JSON value of complianceCategory. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<BookkeepingAccount.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BookkeepingAccount.BuildertoBuilder()final BookkeepingAccountvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccount.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingAccount. -
-
Method Detail
-
accountId
final Optional<String> accountId()
The API Account associated with this bookkeeping account.
-
complianceCategory
final Optional<BookkeepingAccount.ComplianceCategory> complianceCategory()
The compliance category of the account.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final BookkeepingAccount.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_complianceCategory
final JsonField<BookkeepingAccount.ComplianceCategory> _complianceCategory()
Returns the raw JSON value of complianceCategory.
Unlike complianceCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BookkeepingAccount.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingAccount.Builder toBuilder()
-
validate
final BookkeepingAccount validate()
-
builder
final static BookkeepingAccount.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingAccount.
The following fields are required:
.id() .accountId() .complianceCategory() .entityId() .idempotencyKey() .name() .type()
-
-
-
-