Class BookkeepingAccount.Builder
-
- All Implemented Interfaces:
public final class BookkeepingAccount.BuilderA builder for BookkeepingAccount.
-
-
Method Summary
-
-
Method Detail
-
id
final BookkeepingAccount.Builder id(String id)
The account identifier.
-
id
final BookkeepingAccount.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final BookkeepingAccount.Builder accountId(String accountId)
The API Account associated with this bookkeeping account.
-
accountId
final BookkeepingAccount.Builder accountId(Optional<String> accountId)
Alias for calling Builder.accountId with
accountId.orElse(null).
-
accountId
final BookkeepingAccount.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
complianceCategory
final BookkeepingAccount.Builder complianceCategory(BookkeepingAccount.ComplianceCategory complianceCategory)
The compliance category of the account.
-
complianceCategory
final BookkeepingAccount.Builder complianceCategory(Optional<BookkeepingAccount.ComplianceCategory> complianceCategory)
Alias for calling Builder.complianceCategory with
complianceCategory.orElse(null).
-
complianceCategory
final BookkeepingAccount.Builder complianceCategory(JsonField<BookkeepingAccount.ComplianceCategory> complianceCategory)
Sets Builder.complianceCategory to an arbitrary JSON value.
You should usually call Builder.complianceCategory with a well-typed ComplianceCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final BookkeepingAccount.Builder entityId(String entityId)
The Entity associated with this bookkeeping account.
-
entityId
final BookkeepingAccount.Builder entityId(Optional<String> entityId)
Alias for calling Builder.entityId with
entityId.orElse(null).
-
entityId
final BookkeepingAccount.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final BookkeepingAccount.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final BookkeepingAccount.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final BookkeepingAccount.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final BookkeepingAccount.Builder name(String name)
The name you choose for the account.
-
name
final BookkeepingAccount.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BookkeepingAccount.Builder type(BookkeepingAccount.Type type)
A constant representing the object's type. For this resource it will always be
bookkeeping_account.
-
type
final BookkeepingAccount.Builder type(JsonField<BookkeepingAccount.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingAccount.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingAccount.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingAccount.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingAccount.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingAccount.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingAccount build()
Returns an immutable instance of BookkeepingAccount.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .complianceCategory() .entityId() .idempotencyKey() .name() .type()
-
-
-
-