Class BookkeepingAccountBalanceParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingAccountBalanceParams implements Params
Retrieve a Bookkeeping Account Balance
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountBalanceParams.BuilderA builder for BookkeepingAccountBalanceParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>bookkeepingAccountId()The identifier of the Bookkeeping Account to retrieve. final Optional<OffsetDateTime>atTime()The moment to query the balance at. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final BookkeepingAccountBalanceParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccountBalanceParamsnone()final static BookkeepingAccountBalanceParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingAccountBalanceParams. -
-
Method Detail
-
bookkeepingAccountId
final Optional<String> bookkeepingAccountId()
The identifier of the Bookkeeping Account to retrieve.
-
atTime
final Optional<OffsetDateTime> atTime()
The moment to query the balance at. If not set, returns the current balances.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final BookkeepingAccountBalanceParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static BookkeepingAccountBalanceParams none()
-
builder
final static BookkeepingAccountBalanceParams.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingAccountBalanceParams.
-
-
-
-