Class BookkeepingAccountCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingAccountCreateParams implements Params
Create a Bookkeeping Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountCreateParams.BuilderA builder for BookkeepingAccountCreateParams.
public final classBookkeepingAccountCreateParams.Bodypublic final classBookkeepingAccountCreateParams.ComplianceCategoryThe account compliance category.
-
Method Summary
Modifier and Type Method Description final Stringname()The name you choose for the account. final Optional<String>accountId()The account, if compliance_categoryiscommingled_cash.final Optional<BookkeepingAccountCreateParams.ComplianceCategory>complianceCategory()The account compliance category. final Optional<String>entityId()The entity, if compliance_categoryiscustomer_balance.final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<BookkeepingAccountCreateParams.ComplianceCategory>_complianceCategory()Returns the raw JSON value of complianceCategory. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final BookkeepingAccountCreateParams.BuildertoBuilder()final BookkeepingAccountCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccountCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingAccountCreateParams. -
-
Method Detail
-
accountId
final Optional<String> accountId()
The account, if
compliance_categoryiscommingled_cash.
-
complianceCategory
final Optional<BookkeepingAccountCreateParams.ComplianceCategory> complianceCategory()
The account compliance category.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_complianceCategory
final JsonField<BookkeepingAccountCreateParams.ComplianceCategory> _complianceCategory()
Returns the raw JSON value of complianceCategory.
Unlike complianceCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final BookkeepingAccountCreateParams.Builder toBuilder()
-
_body
final BookkeepingAccountCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static BookkeepingAccountCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingAccountCreateParams.
The following fields are required:
.name()
-
-
-
-