Class BookkeepingAccountCreateParams.Body
-
- All Implemented Interfaces:
public final class BookkeepingAccountCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()The name you choose for the account. final Optional<String>accountId()The entity, if compliance_categoryiscommingled_cash.final Optional<BookkeepingAccountCreateParams.ComplianceCategory>complianceCategory()The account compliance category. final Optional<String>entityId()The entity, if compliance_categoryiscustomer_balance.final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<BookkeepingAccountCreateParams.ComplianceCategory>_complianceCategory()Returns the raw JSON value of complianceCategory. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalProperties()final BookkeepingAccountCreateParams.Body.BuildertoBuilder()final BookkeepingAccountCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccountCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
complianceCategory
final Optional<BookkeepingAccountCreateParams.ComplianceCategory> complianceCategory()
The account compliance category.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_complianceCategory
final JsonField<BookkeepingAccountCreateParams.ComplianceCategory> _complianceCategory()
Returns the raw JSON value of complianceCategory.
Unlike complianceCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingAccountCreateParams.Body.Builder toBuilder()
-
validate
final BookkeepingAccountCreateParams.Body validate()
-
builder
final static BookkeepingAccountCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-