Class BookkeepingAccountCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class BookkeepingAccountCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final BookkeepingAccountCreateParams.Body.Builder name(String name)
The name you choose for the account.
-
name
final BookkeepingAccountCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final BookkeepingAccountCreateParams.Body.Builder accountId(String accountId)
The account, if
compliance_categoryiscommingled_cash.
-
accountId
final BookkeepingAccountCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
complianceCategory
final BookkeepingAccountCreateParams.Body.Builder complianceCategory(BookkeepingAccountCreateParams.ComplianceCategory complianceCategory)
The account compliance category.
-
complianceCategory
final BookkeepingAccountCreateParams.Body.Builder complianceCategory(JsonField<BookkeepingAccountCreateParams.ComplianceCategory> complianceCategory)
Sets Builder.complianceCategory to an arbitrary JSON value.
You should usually call Builder.complianceCategory with a well-typed ComplianceCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final BookkeepingAccountCreateParams.Body.Builder entityId(String entityId)
The entity, if
compliance_categoryiscustomer_balance.
-
entityId
final BookkeepingAccountCreateParams.Body.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingAccountCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingAccountCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingAccountCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingAccountCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingAccountCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingAccountCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-