Class BookkeepingAccountListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class BookkeepingAccountListPage implements Page<BookkeepingAccount>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountListPage.BuilderA builder for BookkeepingAccountListPage.
-
Method Summary
Modifier and Type Method Description final List<BookkeepingAccount>data()Delegates to BookkeepingAccountListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to BookkeepingAccountListPageResponse, but gracefully handles missing data. List<BookkeepingAccount>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final BookkeepingAccountListParamsnextPageParams()BookkeepingAccountListPagenextPage()Returns the page after this one by making another request. final AutoPager<BookkeepingAccount>autoPager()final BookkeepingAccountListParamsparams()The parameters that were used to request this page. final BookkeepingAccountListPageResponseresponse()The response that this page was parsed from. final BookkeepingAccountListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccountListPage.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingAccountListPage. -
-
Method Detail
-
data
final List<BookkeepingAccount> data()
Delegates to BookkeepingAccountListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to BookkeepingAccountListPageResponse, but gracefully handles missing data.
-
items
List<BookkeepingAccount> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final BookkeepingAccountListParams nextPageParams()
-
nextPage
BookkeepingAccountListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<BookkeepingAccount> autoPager()
-
params
final BookkeepingAccountListParams params()
The parameters that were used to request this page.
-
response
final BookkeepingAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookkeepingAccountListPage.Builder toBuilder()
-
builder
final static BookkeepingAccountListPage.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingAccountListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-