Class BookkeepingAccountUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingAccountUpdateParams implements Params
Update a Bookkeeping Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountUpdateParams.BuilderA builder for BookkeepingAccountUpdateParams.
public final classBookkeepingAccountUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>bookkeepingAccountId()The bookkeeping account you would like to update. final Stringname()The name you choose for the account. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final BookkeepingAccountUpdateParams.BuildertoBuilder()final BookkeepingAccountUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingAccountUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingAccountUpdateParams. -
-
Method Detail
-
bookkeepingAccountId
final Optional<String> bookkeepingAccountId()
The bookkeeping account you would like to update.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final BookkeepingAccountUpdateParams.Builder toBuilder()
-
_body
final BookkeepingAccountUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static BookkeepingAccountUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingAccountUpdateParams.
The following fields are required:
.name()
-
-
-
-