Class BookkeepingBalanceLookup
-
- All Implemented Interfaces:
public final class BookkeepingBalanceLookupRepresents a request to lookup the balance of an Bookkeeping Account at a given point in time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingBalanceLookup.BuilderA builder for BookkeepingBalanceLookup.
public final classBookkeepingBalanceLookup.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
Method Summary
Modifier and Type Method Description final Longbalance()The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account. final StringbookkeepingAccountId()The identifier for the account for which the balance was queried. final BookkeepingBalanceLookup.Typetype()A constant representing the object's type. final JsonField<Long>_balance()Returns the raw JSON value of balance. final JsonField<String>_bookkeepingAccountId()Returns the raw JSON value of bookkeepingAccountId. final JsonField<BookkeepingBalanceLookup.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BookkeepingBalanceLookup.BuildertoBuilder()final BookkeepingBalanceLookupvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingBalanceLookup.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingBalanceLookup. -
-
Method Detail
-
balance
final Long balance()
The Bookkeeping Account's current balance, representing the sum of all Bookkeeping Entries on the Bookkeeping Account.
-
bookkeepingAccountId
final String bookkeepingAccountId()
The identifier for the account for which the balance was queried.
-
type
final BookkeepingBalanceLookup.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_balance_lookup.
-
_balance
final JsonField<Long> _balance()
Returns the raw JSON value of balance.
Unlike balance, this method doesn't throw if the JSON field has an unexpected type.
-
_bookkeepingAccountId
final JsonField<String> _bookkeepingAccountId()
Returns the raw JSON value of bookkeepingAccountId.
Unlike bookkeepingAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BookkeepingBalanceLookup.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingBalanceLookup.Builder toBuilder()
-
validate
final BookkeepingBalanceLookup validate()
-
builder
final static BookkeepingBalanceLookup.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingBalanceLookup.
The following fields are required:
.balance() .bookkeepingAccountId() .type()
-
-
-
-