Class BookkeepingEntry
-
- All Implemented Interfaces:
public final class BookkeepingEntryEntries are T-account entries recording debits and credits. Your compliance setup might require annotating money movements using this API. Learn more in our guide to Bookkeeping.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntry.BuilderA builder for BookkeepingEntry.
public final classBookkeepingEntry.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
Method Summary
Modifier and Type Method Description final Stringid()The entry identifier. final StringaccountId()The identifier for the Account the Entry belongs to. final Longamount()The Entry amount in the minor unit of its currency. final OffsetDateTimecreatedAt()When the entry set was created. final StringentrySetId()The identifier for the Entry Set the Entry belongs to. final BookkeepingEntry.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_entrySetId()Returns the raw JSON value of entrySetId. final JsonField<BookkeepingEntry.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntry.BuildertoBuilder()final BookkeepingEntryvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntry.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntry. -
-
Method Detail
-
amount
final Long amount()
The Entry amount in the minor unit of its currency. For dollars, for example, this is cents.
-
createdAt
final OffsetDateTime createdAt()
When the entry set was created.
-
entrySetId
final String entrySetId()
The identifier for the Entry Set the Entry belongs to.
-
type
final BookkeepingEntry.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_entrySetId
final JsonField<String> _entrySetId()
Returns the raw JSON value of entrySetId.
Unlike entrySetId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BookkeepingEntry.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingEntry.Builder toBuilder()
-
validate
final BookkeepingEntry validate()
-
builder
final static BookkeepingEntry.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntry.
The following fields are required:
.id() .accountId() .amount() .createdAt() .entrySetId() .type()
-
-
-
-