Class BookkeepingEntry.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntry.BuilderA builder for BookkeepingEntry.
-
-
Method Summary
-
-
Method Detail
-
id
final BookkeepingEntry.Builder id(String id)
The entry identifier.
-
id
final BookkeepingEntry.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final BookkeepingEntry.Builder accountId(String accountId)
The identifier for the Account the Entry belongs to.
-
accountId
final BookkeepingEntry.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final BookkeepingEntry.Builder amount(Long amount)
The Entry amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final BookkeepingEntry.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final BookkeepingEntry.Builder createdAt(OffsetDateTime createdAt)
When the entry set was created.
-
createdAt
final BookkeepingEntry.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entrySetId
final BookkeepingEntry.Builder entrySetId(String entrySetId)
The identifier for the Account the Entry belongs to.
-
entrySetId
final BookkeepingEntry.Builder entrySetId(JsonField<String> entrySetId)
Sets Builder.entrySetId to an arbitrary JSON value.
You should usually call Builder.entrySetId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BookkeepingEntry.Builder type(BookkeepingEntry.Type type)
A constant representing the object's type. For this resource it will always be
bookkeeping_entry.
-
type
final BookkeepingEntry.Builder type(JsonField<BookkeepingEntry.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingEntry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingEntry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingEntry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingEntry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingEntry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingEntry build()
Returns an immutable instance of BookkeepingEntry.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount() .createdAt() .entrySetId() .type()
-
-
-
-