Class BookkeepingEntryListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class BookkeepingEntryListPage implements Page<BookkeepingEntry>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntryListPage.BuilderA builder for BookkeepingEntryListPage.
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntry>data()Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data. List<BookkeepingEntry>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final BookkeepingEntryListParamsnextPageParams()BookkeepingEntryListPagenextPage()Returns the page after this one by making another request. final AutoPager<BookkeepingEntry>autoPager()final BookkeepingEntryListParamsparams()The parameters that were used to request this page. final BookkeepingEntryListPageResponseresponse()The response that this page was parsed from. final BookkeepingEntryListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntryListPage.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntryListPage. -
-
Method Detail
-
data
final List<BookkeepingEntry> data()
Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data.
-
items
List<BookkeepingEntry> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final BookkeepingEntryListParams nextPageParams()
-
nextPage
BookkeepingEntryListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<BookkeepingEntry> autoPager()
-
params
final BookkeepingEntryListParams params()
The parameters that were used to request this page.
-
response
final BookkeepingEntryListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookkeepingEntryListPage.Builder toBuilder()
-
builder
final static BookkeepingEntryListPage.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntryListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-