Class BookkeepingEntryListPage.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntryListPage.BuilderA builder for BookkeepingEntryListPage.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingEntryListPage.Builderservice(BookkeepingEntryService service)final BookkeepingEntryListPage.Builderparams(BookkeepingEntryListParams params)The parameters that were used to request this page. final BookkeepingEntryListPage.Builderresponse(BookkeepingEntryListPageResponse response)The response that this page was parsed from. final BookkeepingEntryListPagebuild()Returns an immutable instance of BookkeepingEntryListPage. -
-
Method Detail
-
service
final BookkeepingEntryListPage.Builder service(BookkeepingEntryService service)
-
params
final BookkeepingEntryListPage.Builder params(BookkeepingEntryListParams params)
The parameters that were used to request this page.
-
response
final BookkeepingEntryListPage.Builder response(BookkeepingEntryListPageResponse response)
The response that this page was parsed from.
-
build
final BookkeepingEntryListPage build()
Returns an immutable instance of BookkeepingEntryListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-