Class BookkeepingEntryListPageAsync
-
- All Implemented Interfaces:
public final class BookkeepingEntryListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntryListPageAsync.BuilderA builder for BookkeepingEntryListPageAsync.
public final classBookkeepingEntryListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntry>data()Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BookkeepingEntryListParams>getNextPageParams()final CompletableFuture<Optional<BookkeepingEntryListPageAsync>>getNextPage()final BookkeepingEntryListPageAsync.AutoPagerautoPager()final BookkeepingEntryListParamsparams()The parameters that were used to request this page. final BookkeepingEntryListPageResponseresponse()The response that this page was parsed from. final BookkeepingEntryListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntryListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntryListPageAsync. -
-
Method Detail
-
data
final List<BookkeepingEntry> data()
Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to BookkeepingEntryListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BookkeepingEntryListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<BookkeepingEntryListPageAsync>> getNextPage()
-
autoPager
final BookkeepingEntryListPageAsync.AutoPager autoPager()
-
params
final BookkeepingEntryListParams params()
The parameters that were used to request this page.
-
response
final BookkeepingEntryListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookkeepingEntryListPageAsync.Builder toBuilder()
-
builder
final static BookkeepingEntryListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntryListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-