Class BookkeepingEntryListPageAsync.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntryListPageAsync.BuilderA builder for BookkeepingEntryListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingEntryListPageAsync.Builderservice(BookkeepingEntryServiceAsync service)final BookkeepingEntryListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final BookkeepingEntryListPageAsync.Builderparams(BookkeepingEntryListParams params)The parameters that were used to request this page. final BookkeepingEntryListPageAsync.Builderresponse(BookkeepingEntryListPageResponse response)The response that this page was parsed from. final BookkeepingEntryListPageAsyncbuild()Returns an immutable instance of BookkeepingEntryListPageAsync. -
-
Method Detail
-
service
final BookkeepingEntryListPageAsync.Builder service(BookkeepingEntryServiceAsync service)
-
streamHandlerExecutor
final BookkeepingEntryListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final BookkeepingEntryListPageAsync.Builder params(BookkeepingEntryListParams params)
The parameters that were used to request this page.
-
response
final BookkeepingEntryListPageAsync.Builder response(BookkeepingEntryListPageResponse response)
The response that this page was parsed from.
-
build
final BookkeepingEntryListPageAsync build()
Returns an immutable instance of BookkeepingEntryListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-