Class BookkeepingEntryListPageResponse
-
- All Implemented Interfaces:
public final class BookkeepingEntryListPageResponseA list of Bookkeeping Entry objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntryListPageResponse.BuilderA builder for BookkeepingEntryListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntry>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<BookkeepingEntry>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntryListPageResponse.BuildertoBuilder()final BookkeepingEntryListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntryListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntryListPageResponse. -
-
Method Detail
-
data
final List<BookkeepingEntry> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<BookkeepingEntry>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingEntryListPageResponse.Builder toBuilder()
-
validate
final BookkeepingEntryListPageResponse validate()
-
builder
final static BookkeepingEntryListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntryListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-