Class BookkeepingEntryListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingEntryListParams implements Params
List Bookkeeping Entries
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntryListParams.BuilderA builder for BookkeepingEntryListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()The identifier for the Bookkeeping Account to filter by. final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final BookkeepingEntryListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntryListParamsnone()final static BookkeepingEntryListParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntryListParams. -
-
Method Detail
-
accountId
final Optional<String> accountId()
The identifier for the Bookkeeping Account to filter by.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final BookkeepingEntryListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static BookkeepingEntryListParams none()
-
builder
final static BookkeepingEntryListParams.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntryListParams.
-
-
-
-