Class BookkeepingEntrySet
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetEntry Sets are accounting entries that are transactionally applied. Your compliance setup might require annotating money movements using this API. Learn more in our guide to Bookkeeping.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySet.BuilderA builder for BookkeepingEntrySet.
public final classBookkeepingEntrySet.Entrypublic final classBookkeepingEntrySet.TypeA constant representing the object's type. For this resource it will always be
bookkeeping_entry_set.
-
Method Summary
Modifier and Type Method Description final Stringid()The entry set identifier. final OffsetDateTimecreatedAt()When the entry set was created. final OffsetDateTimedate()The timestamp of the entry set. final List<BookkeepingEntrySet.Entry>entries()The entries. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>transactionId()The transaction identifier, if any. final BookkeepingEntrySet.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<OffsetDateTime>_date()Returns the raw JSON value of date. final JsonField<List<BookkeepingEntrySet.Entry>>_entries()Returns the raw JSON value of entries. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<BookkeepingEntrySet.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySet.BuildertoBuilder()final BookkeepingEntrySetvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySet.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntrySet. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
When the entry set was created.
-
date
final OffsetDateTime date()
The timestamp of the entry set.
-
entries
final List<BookkeepingEntrySet.Entry> entries()
The entries.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
transactionId
final Optional<String> transactionId()
The transaction identifier, if any.
-
type
final BookkeepingEntrySet.Type type()
A constant representing the object's type. For this resource it will always be
bookkeeping_entry_set.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_date
final JsonField<OffsetDateTime> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_entries
final JsonField<List<BookkeepingEntrySet.Entry>> _entries()
Returns the raw JSON value of entries.
Unlike entries, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BookkeepingEntrySet.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingEntrySet.Builder toBuilder()
-
validate
final BookkeepingEntrySet validate()
-
builder
final static BookkeepingEntrySet.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntrySet.
The following fields are required:
.id() .createdAt() .date() .entries() .idempotencyKey() .transactionId() .type()
-
-
-
-