Class BookkeepingEntrySet.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntrySet.BuilderA builder for BookkeepingEntrySet.
-
-
Method Summary
-
-
Method Detail
-
id
final BookkeepingEntrySet.Builder id(String id)
The entry set identifier.
-
id
final BookkeepingEntrySet.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final BookkeepingEntrySet.Builder createdAt(OffsetDateTime createdAt)
When the entry set was created.
-
createdAt
final BookkeepingEntrySet.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
date
final BookkeepingEntrySet.Builder date(OffsetDateTime date)
The timestamp of the entry set.
-
date
final BookkeepingEntrySet.Builder date(JsonField<OffsetDateTime> date)
Sets Builder.date to an arbitrary JSON value.
You should usually call Builder.date with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entries
final BookkeepingEntrySet.Builder entries(List<BookkeepingEntrySet.Entry> entries)
The entries.
-
entries
final BookkeepingEntrySet.Builder entries(JsonField<List<BookkeepingEntrySet.Entry>> entries)
Sets Builder.entries to an arbitrary JSON value.
You should usually call Builder.entries with a well-typed
List<Entry>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEntry
final BookkeepingEntrySet.Builder addEntry(BookkeepingEntrySet.Entry entry)
-
idempotencyKey
final BookkeepingEntrySet.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final BookkeepingEntrySet.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final BookkeepingEntrySet.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final BookkeepingEntrySet.Builder transactionId(String transactionId)
The transaction identifier, if any.
-
transactionId
final BookkeepingEntrySet.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final BookkeepingEntrySet.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BookkeepingEntrySet.Builder type(BookkeepingEntrySet.Type type)
A constant representing the object's type. For this resource it will always be
bookkeeping_entry_set.
-
type
final BookkeepingEntrySet.Builder type(JsonField<BookkeepingEntrySet.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingEntrySet.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingEntrySet.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingEntrySet.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingEntrySet.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingEntrySet.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingEntrySet build()
Returns an immutable instance of BookkeepingEntrySet.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .date() .entries() .idempotencyKey() .transactionId() .type()
-
-
-
-