Class BookkeepingEntrySet.Entry
-
- All Implemented Interfaces:
public final class BookkeepingEntrySet.Entry
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySet.Entry.BuilderA builder for Entry.
-
Method Summary
Modifier and Type Method Description final Stringid()The entry identifier. final StringaccountId()The bookkeeping account impacted by the entry. final Longamount()The amount of the entry in minor units. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySet.Entry.BuildertoBuilder()final BookkeepingEntrySet.Entryvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySet.Entry.Builderbuilder()Returns a mutable builder for constructing an instance of Entry. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingEntrySet.Entry.Builder toBuilder()
-
validate
final BookkeepingEntrySet.Entry validate()
-
builder
final static BookkeepingEntrySet.Entry.Builder builder()
Returns a mutable builder for constructing an instance of Entry.
The following fields are required:
.id() .accountId() .amount()
-
-
-
-