Class BookkeepingEntrySet.Entry.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntrySet.Entry.BuilderA builder for Entry.
-
-
Method Summary
-
-
Method Detail
-
id
final BookkeepingEntrySet.Entry.Builder id(String id)
The entry identifier.
-
id
final BookkeepingEntrySet.Entry.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final BookkeepingEntrySet.Entry.Builder accountId(String accountId)
The bookkeeping account impacted by the entry.
-
accountId
final BookkeepingEntrySet.Entry.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final BookkeepingEntrySet.Entry.Builder amount(Long amount)
The amount of the entry in minor units.
-
amount
final BookkeepingEntrySet.Entry.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingEntrySet.Entry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingEntrySet.Entry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingEntrySet.Entry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingEntrySet.Entry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingEntrySet.Entry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingEntrySet.Entry build()
Returns an immutable instance of Entry.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount()
-
-
-
-