Class BookkeepingEntrySetCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingEntrySetCreateParams implements Params
Create a Bookkeeping Entry Set
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetCreateParams.BuilderA builder for BookkeepingEntrySetCreateParams.
public final classBookkeepingEntrySetCreateParams.Bodypublic final classBookkeepingEntrySetCreateParams.Entry
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntrySetCreateParams.Entry>entries()The bookkeeping entries. final Optional<OffsetDateTime>date()The date of the transaction. final Optional<String>transactionId()The identifier of the Transaction related to this entry set, if any. final JsonField<List<BookkeepingEntrySetCreateParams.Entry>>_entries()Returns the raw JSON value of entries. final JsonField<OffsetDateTime>_date()Returns the raw JSON value of date. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final BookkeepingEntrySetCreateParams.BuildertoBuilder()final BookkeepingEntrySetCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntrySetCreateParams. -
-
Method Detail
-
entries
final List<BookkeepingEntrySetCreateParams.Entry> entries()
The bookkeeping entries.
-
date
final Optional<OffsetDateTime> date()
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
transactionId
final Optional<String> transactionId()
The identifier of the Transaction related to this entry set, if any.
-
_entries
final JsonField<List<BookkeepingEntrySetCreateParams.Entry>> _entries()
Returns the raw JSON value of entries.
Unlike entries, this method doesn't throw if the JSON field has an unexpected type.
-
_date
final JsonField<OffsetDateTime> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final BookkeepingEntrySetCreateParams.Builder toBuilder()
-
_body
final BookkeepingEntrySetCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static BookkeepingEntrySetCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntrySetCreateParams.
The following fields are required:
.entries()
-
-
-
-