Class BookkeepingEntrySetCreateParams.Body
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntrySetCreateParams.Entry>entries()The bookkeeping entries. final Optional<OffsetDateTime>date()The date of the transaction. final Optional<String>transactionId()The identifier of the Transaction related to this entry set, if any. final JsonField<List<BookkeepingEntrySetCreateParams.Entry>>_entries()Returns the raw JSON value of entries. final JsonField<OffsetDateTime>_date()Returns the raw JSON value of date. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySetCreateParams.Body.BuildertoBuilder()final BookkeepingEntrySetCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
entries
final List<BookkeepingEntrySetCreateParams.Entry> entries()
The bookkeeping entries.
-
date
final Optional<OffsetDateTime> date()
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
transactionId
final Optional<String> transactionId()
The identifier of the Transaction related to this entry set, if any.
-
_entries
final JsonField<List<BookkeepingEntrySetCreateParams.Entry>> _entries()
Returns the raw JSON value of entries.
Unlike entries, this method doesn't throw if the JSON field has an unexpected type.
-
_date
final JsonField<OffsetDateTime> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingEntrySetCreateParams.Body.Builder toBuilder()
-
validate
final BookkeepingEntrySetCreateParams.Body validate()
-
builder
final static BookkeepingEntrySetCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.entries()
-
-
-
-