Class BookkeepingEntrySetCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
entries
final BookkeepingEntrySetCreateParams.Body.Builder entries(List<BookkeepingEntrySetCreateParams.Entry> entries)
The bookkeeping entries.
-
entries
final BookkeepingEntrySetCreateParams.Body.Builder entries(JsonField<List<BookkeepingEntrySetCreateParams.Entry>> entries)
Sets Builder.entries to an arbitrary JSON value.
You should usually call Builder.entries with a well-typed
List<Entry>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addEntry
final BookkeepingEntrySetCreateParams.Body.Builder addEntry(BookkeepingEntrySetCreateParams.Entry entry)
-
date
final BookkeepingEntrySetCreateParams.Body.Builder date(OffsetDateTime date)
The date of the transaction. Optional if
transaction_idis provided, in which case we use thedateof that transaction. Required otherwise.
-
date
final BookkeepingEntrySetCreateParams.Body.Builder date(JsonField<OffsetDateTime> date)
Sets Builder.date to an arbitrary JSON value.
You should usually call Builder.date with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final BookkeepingEntrySetCreateParams.Body.Builder transactionId(String transactionId)
The identifier of the Transaction related to this entry set, if any.
-
transactionId
final BookkeepingEntrySetCreateParams.Body.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingEntrySetCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingEntrySetCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingEntrySetCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingEntrySetCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingEntrySetCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingEntrySetCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.entries()
-
-
-
-