Class BookkeepingEntrySetCreateParams.Entry
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetCreateParams.Entry
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetCreateParams.Entry.BuilderA builder for Entry.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the Bookkeeping Account impacted by this entry. final Longamount()The entry amount in the minor unit of the account currency. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalProperties()final BookkeepingEntrySetCreateParams.Entry.BuildertoBuilder()final BookkeepingEntrySetCreateParams.Entryvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetCreateParams.Entry.Builderbuilder()Returns a mutable builder for constructing an instance of Entry. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the Bookkeeping Account impacted by this entry.
-
amount
final Long amount()
The entry amount in the minor unit of the account currency. For dollars, for example, this is cents. Debit entries have positive amounts; credit entries have negative amounts.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BookkeepingEntrySetCreateParams.Entry.Builder toBuilder()
-
validate
final BookkeepingEntrySetCreateParams.Entry validate()
-
builder
final static BookkeepingEntrySetCreateParams.Entry.Builder builder()
Returns a mutable builder for constructing an instance of Entry.
The following fields are required:
.accountId() .amount()
-
-
-
-