Class BookkeepingEntrySetCreateParams.Entry.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetCreateParams.Entry.BuilderA builder for Entry.
-
-
Method Summary
-
-
Method Detail
-
accountId
final BookkeepingEntrySetCreateParams.Entry.Builder accountId(String accountId)
The identifier for the Bookkeeping Account impacted by this entry.
-
accountId
final BookkeepingEntrySetCreateParams.Entry.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final BookkeepingEntrySetCreateParams.Entry.Builder amount(Long amount)
The entry amount in the minor unit of the account currency. For dollars, for example, this is cents. Debit entries have positive amounts; credit entries have negative amounts.
-
amount
final BookkeepingEntrySetCreateParams.Entry.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BookkeepingEntrySetCreateParams.Entry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BookkeepingEntrySetCreateParams.Entry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BookkeepingEntrySetCreateParams.Entry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BookkeepingEntrySetCreateParams.Entry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BookkeepingEntrySetCreateParams.Entry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BookkeepingEntrySetCreateParams.Entry build()
Returns an immutable instance of Entry.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount()
-
-
-
-