Class BookkeepingEntrySetListPage
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetListPage.BuilderA builder for BookkeepingEntrySetListPage.
public final classBookkeepingEntrySetListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntrySet>data()Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BookkeepingEntrySetListParams>getNextPageParams()final Optional<BookkeepingEntrySetListPage>getNextPage()final BookkeepingEntrySetListPage.AutoPagerautoPager()final BookkeepingEntrySetListParamsparams()The parameters that were used to request this page. final BookkeepingEntrySetListPageResponseresponse()The response that this page was parsed from. final BookkeepingEntrySetListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetListPage.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntrySetListPage. -
-
Method Detail
-
data
final List<BookkeepingEntrySet> data()
Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BookkeepingEntrySetListParams> getNextPageParams()
-
getNextPage
final Optional<BookkeepingEntrySetListPage> getNextPage()
-
autoPager
final BookkeepingEntrySetListPage.AutoPager autoPager()
-
params
final BookkeepingEntrySetListParams params()
The parameters that were used to request this page.
-
response
final BookkeepingEntrySetListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookkeepingEntrySetListPage.Builder toBuilder()
-
builder
final static BookkeepingEntrySetListPage.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntrySetListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-