Class BookkeepingEntrySetListPage.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetListPage.BuilderA builder for BookkeepingEntrySetListPage.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingEntrySetListPage.Builderservice(BookkeepingEntrySetService service)final BookkeepingEntrySetListPage.Builderparams(BookkeepingEntrySetListParams params)The parameters that were used to request this page. final BookkeepingEntrySetListPage.Builderresponse(BookkeepingEntrySetListPageResponse response)The response that this page was parsed from. final BookkeepingEntrySetListPagebuild()Returns an immutable instance of BookkeepingEntrySetListPage. -
-
Method Detail
-
service
final BookkeepingEntrySetListPage.Builder service(BookkeepingEntrySetService service)
-
params
final BookkeepingEntrySetListPage.Builder params(BookkeepingEntrySetListParams params)
The parameters that were used to request this page.
-
response
final BookkeepingEntrySetListPage.Builder response(BookkeepingEntrySetListPageResponse response)
The response that this page was parsed from.
-
build
final BookkeepingEntrySetListPage build()
Returns an immutable instance of BookkeepingEntrySetListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-