Class BookkeepingEntrySetListPageAsync
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetListPageAsync.BuilderA builder for BookkeepingEntrySetListPageAsync.
public final classBookkeepingEntrySetListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<BookkeepingEntrySet>data()Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<BookkeepingEntrySetListParams>getNextPageParams()final CompletableFuture<Optional<BookkeepingEntrySetListPageAsync>>getNextPage()final BookkeepingEntrySetListPageAsync.AutoPagerautoPager()final BookkeepingEntrySetListParamsparams()The parameters that were used to request this page. final BookkeepingEntrySetListPageResponseresponse()The response that this page was parsed from. final BookkeepingEntrySetListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntrySetListPageAsync. -
-
Method Detail
-
data
final List<BookkeepingEntrySet> data()
Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to BookkeepingEntrySetListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<BookkeepingEntrySetListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<BookkeepingEntrySetListPageAsync>> getNextPage()
-
autoPager
final BookkeepingEntrySetListPageAsync.AutoPager autoPager()
-
params
final BookkeepingEntrySetListParams params()
The parameters that were used to request this page.
-
response
final BookkeepingEntrySetListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final BookkeepingEntrySetListPageAsync.Builder toBuilder()
-
builder
final static BookkeepingEntrySetListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntrySetListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-