Class BookkeepingEntrySetListPageAsync.Builder
-
- All Implemented Interfaces:
public final class BookkeepingEntrySetListPageAsync.BuilderA builder for BookkeepingEntrySetListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final BookkeepingEntrySetListPageAsync.Builderservice(BookkeepingEntrySetServiceAsync service)final BookkeepingEntrySetListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final BookkeepingEntrySetListPageAsync.Builderparams(BookkeepingEntrySetListParams params)The parameters that were used to request this page. final BookkeepingEntrySetListPageAsync.Builderresponse(BookkeepingEntrySetListPageResponse response)The response that this page was parsed from. final BookkeepingEntrySetListPageAsyncbuild()Returns an immutable instance of BookkeepingEntrySetListPageAsync. -
-
Method Detail
-
service
final BookkeepingEntrySetListPageAsync.Builder service(BookkeepingEntrySetServiceAsync service)
-
streamHandlerExecutor
final BookkeepingEntrySetListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final BookkeepingEntrySetListPageAsync.Builder params(BookkeepingEntrySetListParams params)
The parameters that were used to request this page.
-
response
final BookkeepingEntrySetListPageAsync.Builder response(BookkeepingEntrySetListPageResponse response)
The response that this page was parsed from.
-
build
final BookkeepingEntrySetListPageAsync build()
Returns an immutable instance of BookkeepingEntrySetListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-