Class BookkeepingEntrySetListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class BookkeepingEntrySetListParams implements Params
List Bookkeeping Entry Sets
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetListParams.BuilderA builder for BookkeepingEntrySetListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cursor()Return the page of entries after this one. final Optional<String>idempotencyKey()Filter records to the one with the specified idempotency_keyyou chose for that object.final Optional<Long>limit()Limit the size of the list that is returned. final Optional<String>transactionId()Filter to the Bookkeeping Entry Set that maps to this Transaction. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final BookkeepingEntrySetListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static BookkeepingEntrySetListParamsnone()final static BookkeepingEntrySetListParams.Builderbuilder()Returns a mutable builder for constructing an instance of BookkeepingEntrySetListParams. -
-
Method Detail
-
idempotencyKey
final Optional<String> idempotencyKey()
Filter records to the one with the specified
idempotency_keyyou chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
transactionId
final Optional<String> transactionId()
Filter to the Bookkeeping Entry Set that maps to this Transaction.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final BookkeepingEntrySetListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static BookkeepingEntrySetListParams none()
-
builder
final static BookkeepingEntrySetListParams.Builder builder()
Returns a mutable builder for constructing an instance of BookkeepingEntrySetListParams.
-
-
-
-