Package com.increase.api.models.carddetails
See: Description
-
Class Summary Class Description Builder A builder for CardDetailCreateDetailsIframeParams. Builder A builder for Body. Body CardDetailCreateDetailsIframeParams Create an iframe URL for a Card to display the card details. Builder A builder for CardDetailDetailsParams. CardDetailDetailsParams Sensitive details for a Card include the primary account number, expiry, card verification code, and PIN. Builder A builder for CardDetailUpdateParams. Builder A builder for Body. Body CardDetailUpdateParams Update a Card's PIN Builder A builder for CardDetails. Type A constant representing the object's type. CardDetails An object containing the sensitive details (card number, CVC, PIN, etc) for a Card. Builder A builder for CardIframeUrl. Type A constant representing the object's type. CardIframeUrl An object containing the iframe URL for a Card.