Class CardDisputeCreateParams.AttachmentFile
-
- All Implemented Interfaces:
public final class CardDisputeCreateParams.AttachmentFile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeCreateParams.AttachmentFile.BuilderA builder for AttachmentFile.
-
Method Summary
Modifier and Type Method Description final StringfileId()The ID of the file to be attached. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final CardDisputeCreateParams.AttachmentFile.BuildertoBuilder()final CardDisputeCreateParams.AttachmentFilevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDisputeCreateParams.AttachmentFile.Builderbuilder()Returns a mutable builder for constructing an instance of AttachmentFile. -
-
Method Detail
-
fileId
final String fileId()
The ID of the file to be attached. The file must have a
purposeofcard_dispute_attachment.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardDisputeCreateParams.AttachmentFile.Builder toBuilder()
-
validate
final CardDisputeCreateParams.AttachmentFile validate()
-
builder
final static CardDisputeCreateParams.AttachmentFile.Builder builder()
Returns a mutable builder for constructing an instance of AttachmentFile.
The following fields are required:
.fileId()
-
-
-
-