Class CardDisputeCreateParams.Visa.ProcessingError
-
- All Implemented Interfaces:
public final class CardDisputeCreateParams.Visa.ProcessingErrorProcessing error. Required if and only if
categoryisprocessing_error.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeCreateParams.Visa.ProcessingError.BuilderA builder for ProcessingError.
public final classCardDisputeCreateParams.Visa.ProcessingError.ErrorReasonError reason.
public final classCardDisputeCreateParams.Visa.ProcessingError.MerchantResolutionAttemptedMerchant resolution attempted.
public final classCardDisputeCreateParams.Visa.ProcessingError.DuplicateTransactionDuplicate transaction. Required if and only if
error_reasonisduplicate_transaction.public final classCardDisputeCreateParams.Visa.ProcessingError.IncorrectAmountIncorrect amount. Required if and only if
error_reasonisincorrect_amount.public final classCardDisputeCreateParams.Visa.ProcessingError.PaidByOtherMeansPaid by other means. Required if and only if
error_reasonispaid_by_other_means.
-
Method Summary
-
-
Method Detail
-
errorReason
final CardDisputeCreateParams.Visa.ProcessingError.ErrorReason errorReason()
Error reason.
-
merchantResolutionAttempted
final CardDisputeCreateParams.Visa.ProcessingError.MerchantResolutionAttempted merchantResolutionAttempted()
Merchant resolution attempted.
-
duplicateTransaction
final Optional<CardDisputeCreateParams.Visa.ProcessingError.DuplicateTransaction> duplicateTransaction()
Duplicate transaction. Required if and only if
error_reasonisduplicate_transaction.
-
incorrectAmount
final Optional<CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount> incorrectAmount()
Incorrect amount. Required if and only if
error_reasonisincorrect_amount.
-
paidByOtherMeans
final Optional<CardDisputeCreateParams.Visa.ProcessingError.PaidByOtherMeans> paidByOtherMeans()
Paid by other means. Required if and only if
error_reasonispaid_by_other_means.
-
_errorReason
final JsonField<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason> _errorReason()
Returns the raw JSON value of errorReason.
Unlike errorReason, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantResolutionAttempted
final JsonField<CardDisputeCreateParams.Visa.ProcessingError.MerchantResolutionAttempted> _merchantResolutionAttempted()
Returns the raw JSON value of merchantResolutionAttempted.
Unlike merchantResolutionAttempted, this method doesn't throw if the JSON field has an unexpected type.
-
_duplicateTransaction
final JsonField<CardDisputeCreateParams.Visa.ProcessingError.DuplicateTransaction> _duplicateTransaction()
Returns the raw JSON value of duplicateTransaction.
Unlike duplicateTransaction, this method doesn't throw if the JSON field has an unexpected type.
-
_incorrectAmount
final JsonField<CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount> _incorrectAmount()
Returns the raw JSON value of incorrectAmount.
Unlike incorrectAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_paidByOtherMeans
final JsonField<CardDisputeCreateParams.Visa.ProcessingError.PaidByOtherMeans> _paidByOtherMeans()
Returns the raw JSON value of paidByOtherMeans.
Unlike paidByOtherMeans, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardDisputeCreateParams.Visa.ProcessingError.Builder toBuilder()
-
validate
final CardDisputeCreateParams.Visa.ProcessingError validate()
-
builder
final static CardDisputeCreateParams.Visa.ProcessingError.Builder builder()
Returns a mutable builder for constructing an instance of ProcessingError.
The following fields are required:
.errorReason() .merchantResolutionAttempted()
-
-
-
-