Enum CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known extends Enum<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known>
An enum containing ErrorReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description DUPLICATE_TRANSACTIONDuplicate transaction.
INCORRECT_AMOUNTIncorrect amount.
PAID_BY_OTHER_MEANSPaid by other means.
-
Method Summary
Modifier and Type Method Description final CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known>getEntries()An enum containing ErrorReason's known values. -
-
Method Detail
-
valueOf
final CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardDisputeCreateParams.Visa.ProcessingError.ErrorReason.Known> getEntries()
An enum containing ErrorReason's known values.
-
-
-
-