Class CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount
-
- All Implemented Interfaces:
public final class CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmountIncorrect amount. Required if and only if
error_reasonisincorrect_amount.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount.BuilderA builder for IncorrectAmount.
-
Method Summary
Modifier and Type Method Description final LongexpectedAmount()Expected amount. final JsonField<Long>_expectedAmount()Returns the raw JSON value of expectedAmount. final Map<String, JsonValue>_additionalProperties()final CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount.BuildertoBuilder()final CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmountvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount.Builderbuilder()Returns a mutable builder for constructing an instance of IncorrectAmount. -
-
Method Detail
-
expectedAmount
final Long expectedAmount()
Expected amount.
-
_expectedAmount
final JsonField<Long> _expectedAmount()
Returns the raw JSON value of expectedAmount.
Unlike expectedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount validate()
-
builder
final static CardDisputeCreateParams.Visa.ProcessingError.IncorrectAmount.Builder builder()
Returns a mutable builder for constructing an instance of IncorrectAmount.
The following fields are required:
.expectedAmount()
-
-
-
-