Class CardPayment
-
- All Implemented Interfaces:
public final class CardPaymentCard Payments group together interactions related to a single card payment, such as an authorization and its corresponding settlement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.BuilderA builder for CardPayment.
public final classCardPayment.Elementpublic final classCardPayment.StateThe summarized state of this card payment.
public final classCardPayment.TypeA constant representing the object's type. For this resource it will always be
card_payment.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Payment identifier. final StringaccountId()The identifier for the Account the Transaction belongs to. final StringcardId()The Card identifier for this payment. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Card Payment was created. final Optional<String>digitalWalletTokenId()The Digital Wallet Token identifier for this payment. final List<CardPayment.Element>elements()The interactions related to this card payment. final Optional<String>physicalCardId()The Physical Card identifier for this payment. final CardPayment.Statestate()The summarized state of this card payment. final CardPayment.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<List<CardPayment.Element>>_elements()Returns the raw JSON value of elements. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<CardPayment.State>_state()Returns the raw JSON value of state. final JsonField<CardPayment.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardPayment.BuildertoBuilder()final CardPaymentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Builderbuilder()Returns a mutable builder for constructing an instance of CardPayment. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Payment was created.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
The Digital Wallet Token identifier for this payment.
-
elements
final List<CardPayment.Element> elements()
The interactions related to this card payment.
-
physicalCardId
final Optional<String> physicalCardId()
The Physical Card identifier for this payment.
-
state
final CardPayment.State state()
The summarized state of this card payment.
-
type
final CardPayment.Type type()
A constant representing the object's type. For this resource it will always be
card_payment.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_elements
final JsonField<List<CardPayment.Element>> _elements()
Returns the raw JSON value of elements.
Unlike elements, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<CardPayment.State> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Builder toBuilder()
-
validate
final CardPayment validate()
-
builder
final static CardPayment.Builder builder()
Returns a mutable builder for constructing an instance of CardPayment.
The following fields are required:
.id() .accountId() .cardId() .createdAt() .digitalWalletTokenId() .elements() .physicalCardId() .state() .type()
-
-
-
-