Class CardPayment.Builder
-
- All Implemented Interfaces:
public final class CardPayment.BuilderA builder for CardPayment.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.Builderid(String id)The Card Payment identifier. final CardPayment.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final CardPayment.BuilderaccountId(String accountId)The identifier for the Account the Transaction belongs to. final CardPayment.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final CardPayment.BuildercardId(String cardId)The Card identifier for this payment. final CardPayment.BuildercardId(JsonField<String> cardId)Sets Builder.cardId to an arbitrary JSON value. final CardPayment.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Card Payment was created. final CardPayment.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final CardPayment.BuilderdigitalWalletTokenId(String digitalWalletTokenId)The Digital Wallet Token identifier for this payment. final CardPayment.BuilderdigitalWalletTokenId(Optional<String> digitalWalletTokenId)Alias for calling Builder.digitalWalletTokenId with digitalWalletTokenId.orElse(null).final CardPayment.BuilderdigitalWalletTokenId(JsonField<String> digitalWalletTokenId)Sets Builder.digitalWalletTokenId to an arbitrary JSON value. final CardPayment.Builderelements(List<CardPayment.Element> elements)The interactions related to this card payment. final CardPayment.Builderelements(JsonField<List<CardPayment.Element>> elements)Sets Builder.elements to an arbitrary JSON value. final CardPayment.BuilderaddElement(CardPayment.Element element)Adds a single Element to elements. final CardPayment.BuilderphysicalCardId(String physicalCardId)The Physical Card identifier for this payment. final CardPayment.BuilderphysicalCardId(Optional<String> physicalCardId)Alias for calling Builder.physicalCardId with physicalCardId.orElse(null).final CardPayment.BuilderphysicalCardId(JsonField<String> physicalCardId)Sets Builder.physicalCardId to an arbitrary JSON value. final CardPayment.Builderstate(CardPayment.State state)The summarized state of this card payment. final CardPayment.Builderstate(JsonField<CardPayment.State> state)Sets Builder.state to an arbitrary JSON value. final CardPayment.Buildertype(CardPayment.Type type)A constant representing the object's type. final CardPayment.Buildertype(JsonField<CardPayment.Type> type)Sets Builder.type to an arbitrary JSON value. final CardPayment.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.BuilderremoveAdditionalProperty(String key)final CardPayment.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPaymentbuild()Returns an immutable instance of CardPayment. -
-
Method Detail
-
id
final CardPayment.Builder id(String id)
The Card Payment identifier.
-
id
final CardPayment.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final CardPayment.Builder accountId(String accountId)
The identifier for the Account the Transaction belongs to.
-
accountId
final CardPayment.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final CardPayment.Builder cardId(String cardId)
The Card identifier for this payment.
-
cardId
final CardPayment.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CardPayment.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Card Payment was created.
-
createdAt
final CardPayment.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenId
final CardPayment.Builder digitalWalletTokenId(String digitalWalletTokenId)
The Digital Wallet Token identifier for this payment.
-
digitalWalletTokenId
final CardPayment.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
Alias for calling Builder.digitalWalletTokenId with
digitalWalletTokenId.orElse(null).
-
digitalWalletTokenId
final CardPayment.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
Sets Builder.digitalWalletTokenId to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
elements
final CardPayment.Builder elements(List<CardPayment.Element> elements)
The interactions related to this card payment.
-
elements
final CardPayment.Builder elements(JsonField<List<CardPayment.Element>> elements)
Sets Builder.elements to an arbitrary JSON value.
You should usually call Builder.elements with a well-typed
List<Element>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addElement
final CardPayment.Builder addElement(CardPayment.Element element)
-
physicalCardId
final CardPayment.Builder physicalCardId(String physicalCardId)
The Physical Card identifier for this payment.
-
physicalCardId
final CardPayment.Builder physicalCardId(Optional<String> physicalCardId)
Alias for calling Builder.physicalCardId with
physicalCardId.orElse(null).
-
physicalCardId
final CardPayment.Builder physicalCardId(JsonField<String> physicalCardId)
Sets Builder.physicalCardId to an arbitrary JSON value.
You should usually call Builder.physicalCardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final CardPayment.Builder state(CardPayment.State state)
The summarized state of this card payment.
-
state
final CardPayment.Builder state(JsonField<CardPayment.State> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed State value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPayment.Builder type(CardPayment.Type type)
A constant representing the object's type. For this resource it will always be
card_payment.
-
type
final CardPayment.Builder type(JsonField<CardPayment.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment build()
Returns an immutable instance of CardPayment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .cardId() .createdAt() .digitalWalletTokenId() .elements() .physicalCardId() .state() .type()
-
-
-
-