Class CardPayment.Element
-
- All Implemented Interfaces:
public final class CardPayment.Element
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.BuilderA builder for Element.
public final classCardPayment.Element.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classCardPayment.Element.CardAuthenticationA Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.public final classCardPayment.Element.CardAuthorizationA Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.public final classCardPayment.Element.CardAuthorizationExpirationA Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.public final classCardPayment.Element.CardBalanceInquiryA Card Balance Inquiry object. This field will be present in the JSON response if and only if
categoryis equal tocard_balance_inquiry. Card Balance Inquiries are transactions that allow merchants to check the available balance on a card without placing a hold on funds, commonly used when a customer requests their balance at an ATM.public final classCardPayment.Element.CardDeclineA Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.public final classCardPayment.Element.CardFinancialA Card Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_financial. Card Financials are temporary holds placed on a customer's funds with the intent to later clear a transaction.public final classCardPayment.Element.CardFuelConfirmationA Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.public final classCardPayment.Element.CardIncrementA Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.public final classCardPayment.Element.CardRefundA Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.public final classCardPayment.Element.CardReversalA Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.public final classCardPayment.Element.CardSettlementA Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.public final classCardPayment.Element.CardValidationAn Inbound Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Inbound Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.public final classCardPayment.Element.OtherIf the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
Method Summary
-
-
Method Detail
-
category
final CardPayment.Element.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the card payment element was created.
-
cardAuthentication
final Optional<CardPayment.Element.CardAuthentication> cardAuthentication()
A Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
cardAuthorization
final Optional<CardPayment.Element.CardAuthorization> cardAuthorization()
A Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.
-
cardAuthorizationExpiration
final Optional<CardPayment.Element.CardAuthorizationExpiration> cardAuthorizationExpiration()
A Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.
-
cardBalanceInquiry
final Optional<CardPayment.Element.CardBalanceInquiry> cardBalanceInquiry()
A Card Balance Inquiry object. This field will be present in the JSON response if and only if
categoryis equal tocard_balance_inquiry. Card Balance Inquiries are transactions that allow merchants to check the available balance on a card without placing a hold on funds, commonly used when a customer requests their balance at an ATM.
-
cardDecline
final Optional<CardPayment.Element.CardDecline> cardDecline()
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
cardFinancial
final Optional<CardPayment.Element.CardFinancial> cardFinancial()
A Card Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_financial. Card Financials are temporary holds placed on a customer's funds with the intent to later clear a transaction.
-
cardFuelConfirmation
final Optional<CardPayment.Element.CardFuelConfirmation> cardFuelConfirmation()
A Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.
-
cardIncrement
final Optional<CardPayment.Element.CardIncrement> cardIncrement()
A Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.
-
cardRefund
final Optional<CardPayment.Element.CardRefund> cardRefund()
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.
-
cardReversal
final Optional<CardPayment.Element.CardReversal> cardReversal()
A Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.
-
cardSettlement
final Optional<CardPayment.Element.CardSettlement> cardSettlement()
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cardValidation
final Optional<CardPayment.Element.CardValidation> cardValidation()
An Inbound Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Inbound Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.
-
other
final Optional<CardPayment.Element.Other> other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
_category
final JsonField<CardPayment.Element.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthentication
final JsonField<CardPayment.Element.CardAuthentication> _cardAuthentication()
Returns the raw JSON value of cardAuthentication.
Unlike cardAuthentication, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorization
final JsonField<CardPayment.Element.CardAuthorization> _cardAuthorization()
Returns the raw JSON value of cardAuthorization.
Unlike cardAuthorization, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorizationExpiration
final JsonField<CardPayment.Element.CardAuthorizationExpiration> _cardAuthorizationExpiration()
Returns the raw JSON value of cardAuthorizationExpiration.
Unlike cardAuthorizationExpiration, this method doesn't throw if the JSON field has an unexpected type.
-
_cardBalanceInquiry
final JsonField<CardPayment.Element.CardBalanceInquiry> _cardBalanceInquiry()
Returns the raw JSON value of cardBalanceInquiry.
Unlike cardBalanceInquiry, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDecline
final JsonField<CardPayment.Element.CardDecline> _cardDecline()
Returns the raw JSON value of cardDecline.
Unlike cardDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_cardFinancial
final JsonField<CardPayment.Element.CardFinancial> _cardFinancial()
Returns the raw JSON value of cardFinancial.
Unlike cardFinancial, this method doesn't throw if the JSON field has an unexpected type.
-
_cardFuelConfirmation
final JsonField<CardPayment.Element.CardFuelConfirmation> _cardFuelConfirmation()
Returns the raw JSON value of cardFuelConfirmation.
Unlike cardFuelConfirmation, this method doesn't throw if the JSON field has an unexpected type.
-
_cardIncrement
final JsonField<CardPayment.Element.CardIncrement> _cardIncrement()
Returns the raw JSON value of cardIncrement.
Unlike cardIncrement, this method doesn't throw if the JSON field has an unexpected type.
-
_cardRefund
final JsonField<CardPayment.Element.CardRefund> _cardRefund()
Returns the raw JSON value of cardRefund.
Unlike cardRefund, this method doesn't throw if the JSON field has an unexpected type.
-
_cardReversal
final JsonField<CardPayment.Element.CardReversal> _cardReversal()
Returns the raw JSON value of cardReversal.
Unlike cardReversal, this method doesn't throw if the JSON field has an unexpected type.
-
_cardSettlement
final JsonField<CardPayment.Element.CardSettlement> _cardSettlement()
Returns the raw JSON value of cardSettlement.
Unlike cardSettlement, this method doesn't throw if the JSON field has an unexpected type.
-
_cardValidation
final JsonField<CardPayment.Element.CardValidation> _cardValidation()
Returns the raw JSON value of cardValidation.
Unlike cardValidation, this method doesn't throw if the JSON field has an unexpected type.
-
_other
final JsonField<CardPayment.Element.Other> _other()
Returns the raw JSON value of other.
Unlike other, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.Builder toBuilder()
-
validate
final CardPayment.Element validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.Builder builder()
Returns a mutable builder for constructing an instance of Element.
The following fields are required:
.category() .createdAt()
-
-
-
-