Class CardPayment.Element.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.BuilderA builder for Element.
-
-
Method Summary
-
-
Method Detail
-
cardAuthentication
final CardPayment.Element.Builder cardAuthentication(CardPayment.Element.CardAuthentication cardAuthentication)
A Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
cardAuthentication
final CardPayment.Element.Builder cardAuthentication(Optional<CardPayment.Element.CardAuthentication> cardAuthentication)
Alias for calling Builder.cardAuthentication with
cardAuthentication.orElse(null).
-
cardAuthentication
final CardPayment.Element.Builder cardAuthentication(JsonField<CardPayment.Element.CardAuthentication> cardAuthentication)
Sets Builder.cardAuthentication to an arbitrary JSON value.
You should usually call Builder.cardAuthentication with a well-typed CardAuthentication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorization
final CardPayment.Element.Builder cardAuthorization(CardPayment.Element.CardAuthorization cardAuthorization)
A Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customers funds with the intent to later clear a transaction.
-
cardAuthorization
final CardPayment.Element.Builder cardAuthorization(Optional<CardPayment.Element.CardAuthorization> cardAuthorization)
Alias for calling Builder.cardAuthorization with
cardAuthorization.orElse(null).
-
cardAuthorization
final CardPayment.Element.Builder cardAuthorization(JsonField<CardPayment.Element.CardAuthorization> cardAuthorization)
Sets Builder.cardAuthorization to an arbitrary JSON value.
You should usually call Builder.cardAuthorization with a well-typed CardAuthorization value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorizationExpiration
final CardPayment.Element.Builder cardAuthorizationExpiration(CardPayment.Element.CardAuthorizationExpiration cardAuthorizationExpiration)
A Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.
-
cardAuthorizationExpiration
final CardPayment.Element.Builder cardAuthorizationExpiration(Optional<CardPayment.Element.CardAuthorizationExpiration> cardAuthorizationExpiration)
Alias for calling Builder.cardAuthorizationExpiration with
cardAuthorizationExpiration.orElse(null).
-
cardAuthorizationExpiration
final CardPayment.Element.Builder cardAuthorizationExpiration(JsonField<CardPayment.Element.CardAuthorizationExpiration> cardAuthorizationExpiration)
Sets Builder.cardAuthorizationExpiration to an arbitrary JSON value.
You should usually call Builder.cardAuthorizationExpiration with a well-typed CardAuthorizationExpiration value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDecline
final CardPayment.Element.Builder cardDecline(CardPayment.Element.CardDecline cardDecline)
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
cardDecline
final CardPayment.Element.Builder cardDecline(Optional<CardPayment.Element.CardDecline> cardDecline)
Alias for calling Builder.cardDecline with
cardDecline.orElse(null).
-
cardDecline
final CardPayment.Element.Builder cardDecline(JsonField<CardPayment.Element.CardDecline> cardDecline)
Sets Builder.cardDecline to an arbitrary JSON value.
You should usually call Builder.cardDecline with a well-typed CardDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardFuelConfirmation
final CardPayment.Element.Builder cardFuelConfirmation(CardPayment.Element.CardFuelConfirmation cardFuelConfirmation)
A Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.
-
cardFuelConfirmation
final CardPayment.Element.Builder cardFuelConfirmation(Optional<CardPayment.Element.CardFuelConfirmation> cardFuelConfirmation)
Alias for calling Builder.cardFuelConfirmation with
cardFuelConfirmation.orElse(null).
-
cardFuelConfirmation
final CardPayment.Element.Builder cardFuelConfirmation(JsonField<CardPayment.Element.CardFuelConfirmation> cardFuelConfirmation)
Sets Builder.cardFuelConfirmation to an arbitrary JSON value.
You should usually call Builder.cardFuelConfirmation with a well-typed CardFuelConfirmation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardIncrement
final CardPayment.Element.Builder cardIncrement(CardPayment.Element.CardIncrement cardIncrement)
A Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.
-
cardIncrement
final CardPayment.Element.Builder cardIncrement(Optional<CardPayment.Element.CardIncrement> cardIncrement)
Alias for calling Builder.cardIncrement with
cardIncrement.orElse(null).
-
cardIncrement
final CardPayment.Element.Builder cardIncrement(JsonField<CardPayment.Element.CardIncrement> cardIncrement)
Sets Builder.cardIncrement to an arbitrary JSON value.
You should usually call Builder.cardIncrement with a well-typed CardIncrement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardRefund
final CardPayment.Element.Builder cardRefund(CardPayment.Element.CardRefund cardRefund)
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRefund
final CardPayment.Element.Builder cardRefund(Optional<CardPayment.Element.CardRefund> cardRefund)
Alias for calling Builder.cardRefund with
cardRefund.orElse(null).
-
cardRefund
final CardPayment.Element.Builder cardRefund(JsonField<CardPayment.Element.CardRefund> cardRefund)
Sets Builder.cardRefund to an arbitrary JSON value.
You should usually call Builder.cardRefund with a well-typed CardRefund value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardReversal
final CardPayment.Element.Builder cardReversal(CardPayment.Element.CardReversal cardReversal)
A Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.
-
cardReversal
final CardPayment.Element.Builder cardReversal(Optional<CardPayment.Element.CardReversal> cardReversal)
Alias for calling Builder.cardReversal with
cardReversal.orElse(null).
-
cardReversal
final CardPayment.Element.Builder cardReversal(JsonField<CardPayment.Element.CardReversal> cardReversal)
Sets Builder.cardReversal to an arbitrary JSON value.
You should usually call Builder.cardReversal with a well-typed CardReversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardSettlement
final CardPayment.Element.Builder cardSettlement(CardPayment.Element.CardSettlement cardSettlement)
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cardSettlement
final CardPayment.Element.Builder cardSettlement(Optional<CardPayment.Element.CardSettlement> cardSettlement)
Alias for calling Builder.cardSettlement with
cardSettlement.orElse(null).
-
cardSettlement
final CardPayment.Element.Builder cardSettlement(JsonField<CardPayment.Element.CardSettlement> cardSettlement)
Sets Builder.cardSettlement to an arbitrary JSON value.
You should usually call Builder.cardSettlement with a well-typed CardSettlement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardValidation
final CardPayment.Element.Builder cardValidation(CardPayment.Element.CardValidation cardValidation)
A Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.
-
cardValidation
final CardPayment.Element.Builder cardValidation(Optional<CardPayment.Element.CardValidation> cardValidation)
Alias for calling Builder.cardValidation with
cardValidation.orElse(null).
-
cardValidation
final CardPayment.Element.Builder cardValidation(JsonField<CardPayment.Element.CardValidation> cardValidation)
Sets Builder.cardValidation to an arbitrary JSON value.
You should usually call Builder.cardValidation with a well-typed CardValidation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final CardPayment.Element.Builder category(CardPayment.Element.Category category)
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final CardPayment.Element.Builder category(JsonField<CardPayment.Element.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CardPayment.Element.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the card payment element was created.
-
createdAt
final CardPayment.Element.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
other
final CardPayment.Element.Builder other(JsonValue other)
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
additionalProperties
final CardPayment.Element.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element build()
Returns an immutable instance of Element.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardAuthentication() .cardAuthorization() .cardAuthorizationExpiration() .cardDecline() .cardFuelConfirmation() .cardIncrement() .cardRefund() .cardReversal() .cardSettlement() .cardValidation() .category() .createdAt() .other()
-
-
-
-