Class CardPayment.Element.CardAuthentication

  • All Implemented Interfaces:

    
    public final class CardPayment.Element.CardAuthentication
    
                        

    A Card Authentication object. This field will be present in the JSON response if and only if category is equal to card_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.