Class CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.Challenge.Attempt.BuilderA builder for Attempt.
-
-
Method Summary
-
-
Method Detail
-
createdAt
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time of the Card Authentication Challenge Attempt.
-
createdAt
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outcome
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder outcome(CardPayment.Element.CardAuthentication.Challenge.Attempt.Outcome outcome)
The outcome of the Card Authentication Challenge Attempt.
-
outcome
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder outcome(JsonField<CardPayment.Element.CardAuthentication.Challenge.Attempt.Outcome> outcome)
Sets Builder.outcome to an arbitrary JSON value.
You should usually call Builder.outcome with a well-typed Outcome value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication.Challenge.Attempt build()
Returns an immutable instance of Attempt.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.createdAt() .outcome()
-
-
-
-