Class CardPayment.Element.CardAuthentication.Challenge.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.Challenge.BuilderA builder for Challenge.
-
-
Method Summary
-
-
Method Detail
-
attempts
final CardPayment.Element.CardAuthentication.Challenge.Builder attempts(List<CardPayment.Element.CardAuthentication.Challenge.Attempt> attempts)
Details about the challenge verification attempts, if any happened.
-
attempts
final CardPayment.Element.CardAuthentication.Challenge.Builder attempts(JsonField<List<CardPayment.Element.CardAuthentication.Challenge.Attempt>> attempts)
Sets Builder.attempts to an arbitrary JSON value.
You should usually call Builder.attempts with a well-typed
List<Attempt>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAttempt
final CardPayment.Element.CardAuthentication.Challenge.Builder addAttempt(CardPayment.Element.CardAuthentication.Challenge.Attempt attempt)
-
createdAt
final CardPayment.Element.CardAuthentication.Challenge.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Card Authentication Challenge was started.
-
createdAt
final CardPayment.Element.CardAuthentication.Challenge.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
oneTimeCode
final CardPayment.Element.CardAuthentication.Challenge.Builder oneTimeCode(String oneTimeCode)
The one-time code used for the Card Authentication Challenge.
-
oneTimeCode
final CardPayment.Element.CardAuthentication.Challenge.Builder oneTimeCode(JsonField<String> oneTimeCode)
Sets Builder.oneTimeCode to an arbitrary JSON value.
You should usually call Builder.oneTimeCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verificationMethod
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationMethod(CardPayment.Element.CardAuthentication.Challenge.VerificationMethod verificationMethod)
The method used to verify the Card Authentication Challenge.
-
verificationMethod
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationMethod(JsonField<CardPayment.Element.CardAuthentication.Challenge.VerificationMethod> verificationMethod)
Sets Builder.verificationMethod to an arbitrary JSON value.
You should usually call Builder.verificationMethod with a well-typed VerificationMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verificationValue
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationValue(String verificationValue)
E.g., the email address or phone number used for the Card Authentication Challenge.
-
verificationValue
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationValue(Optional<String> verificationValue)
Alias for calling Builder.verificationValue with
verificationValue.orElse(null).
-
verificationValue
final CardPayment.Element.CardAuthentication.Challenge.Builder verificationValue(JsonField<String> verificationValue)
Sets Builder.verificationValue to an arbitrary JSON value.
You should usually call Builder.verificationValue with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.Challenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.Challenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Challenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication.Challenge build()
Returns an immutable instance of Challenge.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.attempts() .createdAt() .oneTimeCode() .verificationMethod() .verificationValue()
-
-
-
-