Class CardPayment.Element.CardAuthentication.DeviceChannel.Browser
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.DeviceChannel.BrowserFields specific to the browser device channel.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.DeviceChannel.Browser.BuilderA builder for Browser.
public final classCardPayment.Element.CardAuthentication.DeviceChannel.Browser.JavascriptEnabledWhether JavaScript is enabled in the cardholder's browser.
-
Method Summary
Modifier and Type Method Description final Optional<String>acceptHeader()The accept header from the cardholder's browser. final Optional<String>ipAddress()The IP address of the cardholder's browser. final Optional<CardPayment.Element.CardAuthentication.DeviceChannel.Browser.JavascriptEnabled>javascriptEnabled()Whether JavaScript is enabled in the cardholder's browser. final Optional<String>language()The language of the cardholder's browser. final Optional<String>userAgent()The user agent of the cardholder's browser. final JsonField<String>_acceptHeader()Returns the raw JSON value of acceptHeader. final JsonField<String>_ipAddress()Returns the raw JSON value of ipAddress. final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.Browser.JavascriptEnabled>_javascriptEnabled()Returns the raw JSON value of javascriptEnabled. final JsonField<String>_language()Returns the raw JSON value of language. final JsonField<String>_userAgent()Returns the raw JSON value of userAgent. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthentication.DeviceChannel.Browser.BuildertoBuilder()final CardPayment.Element.CardAuthentication.DeviceChannel.Browservalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.DeviceChannel.Browser.Builderbuilder()Returns a mutable builder for constructing an instance of Browser. -
-
Method Detail
-
acceptHeader
final Optional<String> acceptHeader()
The accept header from the cardholder's browser.
-
javascriptEnabled
final Optional<CardPayment.Element.CardAuthentication.DeviceChannel.Browser.JavascriptEnabled> javascriptEnabled()
Whether JavaScript is enabled in the cardholder's browser.
-
_acceptHeader
final JsonField<String> _acceptHeader()
Returns the raw JSON value of acceptHeader.
Unlike acceptHeader, this method doesn't throw if the JSON field has an unexpected type.
-
_ipAddress
final JsonField<String> _ipAddress()
Returns the raw JSON value of ipAddress.
Unlike ipAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_javascriptEnabled
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.Browser.JavascriptEnabled> _javascriptEnabled()
Returns the raw JSON value of javascriptEnabled.
Unlike javascriptEnabled, this method doesn't throw if the JSON field has an unexpected type.
-
_language
final JsonField<String> _language()
Returns the raw JSON value of language.
Unlike language, this method doesn't throw if the JSON field has an unexpected type.
-
_userAgent
final JsonField<String> _userAgent()
Returns the raw JSON value of userAgent.
Unlike userAgent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardAuthentication.DeviceChannel.Browser validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardAuthentication.DeviceChannel.Browser.Builder builder()
Returns a mutable builder for constructing an instance of Browser.
The following fields are required:
.acceptHeader() .ipAddress() .javascriptEnabled() .language() .userAgent()
-
-
-
-