Class CardPayment.Element.CardAuthentication.DeviceChannel.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.DeviceChannel.BuilderA builder for DeviceChannel.
-
-
Method Summary
-
-
Method Detail
-
browser
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder browser(CardPayment.Element.CardAuthentication.DeviceChannel.Browser browser)
Fields specific to the browser device channel.
-
browser
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder browser(Optional<CardPayment.Element.CardAuthentication.DeviceChannel.Browser> browser)
Alias for calling Builder.browser with
browser.orElse(null).
-
browser
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder browser(JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.Browser> browser)
Sets Builder.browser to an arbitrary JSON value.
You should usually call Builder.browser with a well-typed Browser value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder category(CardPayment.Element.CardAuthentication.DeviceChannel.Category category)
The category of the device channel.
-
category
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder category(JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantInitiated
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder merchantInitiated(CardPayment.Element.CardAuthentication.DeviceChannel.MerchantInitiated merchantInitiated)
Fields specific to merchant initiated transactions.
-
merchantInitiated
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder merchantInitiated(Optional<CardPayment.Element.CardAuthentication.DeviceChannel.MerchantInitiated> merchantInitiated)
Alias for calling Builder.merchantInitiated with
merchantInitiated.orElse(null).
-
merchantInitiated
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder merchantInitiated(JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.MerchantInitiated> merchantInitiated)
Sets Builder.merchantInitiated to an arbitrary JSON value.
You should usually call Builder.merchantInitiated with a well-typed MerchantInitiated value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication.DeviceChannel build()
Returns an immutable instance of DeviceChannel.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.browser() .category() .merchantInitiated()
-
-
-
-