Class CardPayment.Element.CardAuthentication.MessageCategory
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.MessageCategoryThe message category of the card authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.MessageCategory.BuilderA builder for MessageCategory.
public final classCardPayment.Element.CardAuthentication.MessageCategory.CategoryThe category of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.MessageCategory.NonPaymentFields specific to non-payment authentication attempts.
public final classCardPayment.Element.CardAuthentication.MessageCategory.PaymentFields specific to payment authentication attempts.
-
Method Summary
-
-
Method Detail
-
category
final CardPayment.Element.CardAuthentication.MessageCategory.Category category()
The category of the card authentication attempt.
-
nonPayment
final Optional<CardPayment.Element.CardAuthentication.MessageCategory.NonPayment> nonPayment()
Fields specific to non-payment authentication attempts.
-
payment
final Optional<CardPayment.Element.CardAuthentication.MessageCategory.Payment> payment()
Fields specific to payment authentication attempts.
-
_category
final JsonField<CardPayment.Element.CardAuthentication.MessageCategory.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_nonPayment
final JsonField<CardPayment.Element.CardAuthentication.MessageCategory.NonPayment> _nonPayment()
Returns the raw JSON value of nonPayment.
Unlike nonPayment, this method doesn't throw if the JSON field has an unexpected type.
-
_payment
final JsonField<CardPayment.Element.CardAuthentication.MessageCategory.Payment> _payment()
Returns the raw JSON value of payment.
Unlike payment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthentication.MessageCategory.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthentication.MessageCategory validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardAuthentication.MessageCategory.Builder builder()
Returns a mutable builder for constructing an instance of MessageCategory.
The following fields are required:
.category() .nonPayment() .payment()
-
-
-
-