Class CardPayment.Element.CardAuthentication.MessageCategory.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.MessageCategory.BuilderA builder for MessageCategory.
-
-
Method Summary
-
-
Method Detail
-
category
final CardPayment.Element.CardAuthentication.MessageCategory.Builder category(CardPayment.Element.CardAuthentication.MessageCategory.Category category)
The category of the card authentication attempt.
-
category
final CardPayment.Element.CardAuthentication.MessageCategory.Builder category(JsonField<CardPayment.Element.CardAuthentication.MessageCategory.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nonPayment
final CardPayment.Element.CardAuthentication.MessageCategory.Builder nonPayment(CardPayment.Element.CardAuthentication.MessageCategory.NonPayment nonPayment)
Fields specific to non-payment authentication attempts.
-
nonPayment
final CardPayment.Element.CardAuthentication.MessageCategory.Builder nonPayment(Optional<CardPayment.Element.CardAuthentication.MessageCategory.NonPayment> nonPayment)
Alias for calling Builder.nonPayment with
nonPayment.orElse(null).
-
nonPayment
final CardPayment.Element.CardAuthentication.MessageCategory.Builder nonPayment(JsonField<CardPayment.Element.CardAuthentication.MessageCategory.NonPayment> nonPayment)
Sets Builder.nonPayment to an arbitrary JSON value.
You should usually call Builder.nonPayment with a well-typed NonPayment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payment
final CardPayment.Element.CardAuthentication.MessageCategory.Builder payment(CardPayment.Element.CardAuthentication.MessageCategory.Payment payment)
Fields specific to payment authentication attempts.
-
payment
final CardPayment.Element.CardAuthentication.MessageCategory.Builder payment(Optional<CardPayment.Element.CardAuthentication.MessageCategory.Payment> payment)
Alias for calling Builder.payment with
payment.orElse(null).
-
payment
final CardPayment.Element.CardAuthentication.MessageCategory.Builder payment(JsonField<CardPayment.Element.CardAuthentication.MessageCategory.Payment> payment)
Sets Builder.payment to an arbitrary JSON value.
You should usually call Builder.payment with a well-typed Payment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardAuthentication.MessageCategory.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.MessageCategory.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.MessageCategory.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.MessageCategory.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.MessageCategory.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication.MessageCategory build()
Returns an immutable instance of MessageCategory.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category() .nonPayment() .payment()
-
-
-
-