Class CardPayment.Element.CardAuthentication.MessageCategory.Payment
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.MessageCategory.PaymentFields specific to payment authentication attempts.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.MessageCategory.Payment.BuilderA builder for Payment.
public final classCardPayment.Element.CardAuthentication.MessageCategory.Payment.TransactionTypeThe type of transaction being authenticated.
-
Method Summary
-
-
Method Detail
-
purchaseAmount
final Long purchaseAmount()
The purchase amount in minor units.
-
purchaseAmountCardholderEstimated
final Optional<Long> purchaseAmountCardholderEstimated()
The purchase amount in the cardholder's currency (i.e., USD) estimated using daily conversion rates from the card network.
-
purchaseCurrency
final String purchaseCurrency()
The ISO 4217 code for the authentication attempt's purchase currency.
-
transactionType
final Optional<CardPayment.Element.CardAuthentication.MessageCategory.Payment.TransactionType> transactionType()
The type of transaction being authenticated.
-
_purchaseAmount
final JsonField<Long> _purchaseAmount()
Returns the raw JSON value of purchaseAmount.
Unlike purchaseAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseAmountCardholderEstimated
final JsonField<Long> _purchaseAmountCardholderEstimated()
Returns the raw JSON value of purchaseAmountCardholderEstimated.
Unlike purchaseAmountCardholderEstimated, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseCurrency
final JsonField<String> _purchaseCurrency()
Returns the raw JSON value of purchaseCurrency.
Unlike purchaseCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionType
final JsonField<CardPayment.Element.CardAuthentication.MessageCategory.Payment.TransactionType> _transactionType()
Returns the raw JSON value of transactionType.
Unlike transactionType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardPayment.Element.CardAuthentication.MessageCategory.Payment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardAuthentication.MessageCategory.Payment.Builder builder()
Returns a mutable builder for constructing an instance of Payment.
The following fields are required:
.purchaseAmount() .purchaseAmountCardholderEstimated() .purchaseCurrency() .transactionType()
-
-
-
-