Class CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator implements EnumThe 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumCardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.KnownAn enum containing RequestorAuthenticationIndicator's known values.
public enumCardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.ValueAn enum containing RequestorAuthenticationIndicator's known values, as well as an _UNKNOWN member.
An instance of RequestorAuthenticationIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorPAYMENT_TRANSACTIONpublic final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorRECURRING_TRANSACTIONpublic final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorINSTALLMENT_TRANSACTIONpublic final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorADD_CARDpublic final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorMAINTAIN_CARDpublic final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorEMV_TOKEN_CARDHOLDER_VERIFICATIONpublic final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorBILLING_AGREEMENT
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
of
final static CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator of(String value)
-
-
-
-