Enum CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known extends Enum<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known>
An enum containing RequestorAuthenticationIndicator's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PAYMENT_TRANSACTIONThe authentication is for a payment transaction.
RECURRING_TRANSACTIONThe authentication is for a recurring transaction.
INSTALLMENT_TRANSACTIONThe authentication is for an installment transaction.
ADD_CARDThe authentication is for adding a card.
MAINTAIN_CARDThe authentication is for maintaining a card.
EMV_TOKEN_CARDHOLDER_VERIFICATIONThe authentication is for EMV token cardholder verification.
BILLING_AGREEMENTThe authentication is for a billing agreement.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known>getEntries()An enum containing RequestorAuthenticationIndicator's known values. -
-
Method Detail
-
valueOf
final CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator.Known> getEntries()
An enum containing RequestorAuthenticationIndicator's known values.
-
-
-
-