Enum CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value extends Enum<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value>
An enum containing RequestorChallengeIndicator's known values, as well as an _UNKNOWN member.
An instance of RequestorChallengeIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NO_PREFERENCENo preference.
NO_CHALLENGE_REQUESTEDNo challenge requested.
CHALLENGE_REQUESTED_3DS_REQUESTOR_PREFERENCEChallenge requested, 3DS Requestor preference.
CHALLENGE_REQUESTED_MANDATEChallenge requested, mandate.
NO_CHALLENGE_REQUESTED_TRANSACTIONAL_RISK_ANALYSIS_ALREADY_PERFORMEDNo challenge requested, transactional risk analysis already performed.
NO_CHALLENGE_REQUESTED_DATA_SHARE_ONLYNo challenge requested, data share only.
NO_CHALLENGE_REQUESTED_STRONG_CONSUMER_AUTHENTICATION_ALREADY_PERFORMEDNo challenge requested, strong consumer authentication already performed.
NO_CHALLENGE_REQUESTED_UTILIZE_WHITELIST_EXEMPTION_IF_NO_CHALLENGE_REQUIREDNo challenge requested, utilize whitelist exemption if no challenge required.
CHALLENGE_REQUESTED_WHITELIST_PROMPT_REQUESTED_IF_CHALLENGE_REQUIREDChallenge requested, whitelist prompt requested if challenge required.
_UNKNOWNAn enum member indicating that RequestorChallengeIndicator was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value>getEntries()An enum containing RequestorChallengeIndicator's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator.Value> getEntries()
An enum containing RequestorChallengeIndicator's known values, as well as an _UNKNOWN member.
An instance of RequestorChallengeIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-