Enum CardPayment.Element.CardAuthentication.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPayment.Element.CardAuthentication.Status.Known extends Enum<CardPayment.Element.CardAuthentication.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPayment.Element.CardAuthentication.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description DENIEDThe authentication attempt was denied.
AUTHENTICATED_WITH_CHALLENGEThe authentication attempt was authenticated with a challenge.
AUTHENTICATED_WITHOUT_CHALLENGEThe authentication attempt was authenticated without a challenge.
AWAITING_CHALLENGEThe authentication attempt is awaiting a challenge.
VALIDATING_CHALLENGEThe authentication attempt is validating a challenge.
CANCELEDThe authentication attempt was canceled.
TIMED_OUT_AWAITING_CHALLENGEThe authentication attempt timed out while awaiting a challenge.
ERROREDThe authentication attempt errored.
EXCEEDED_ATTEMPT_THRESHOLDThe authentication attempt exceeded the attempt threshold.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardAuthentication.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPayment.Element.CardAuthentication.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPayment.Element.CardAuthentication.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final CardPayment.Element.CardAuthentication.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPayment.Element.CardAuthentication.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPayment.Element.CardAuthentication.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-