Class CardPayment.Element.CardAuthorization.Verification.CardVerificationCode
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthorization.Verification.CardVerificationCodeFields related to verification of the Card Verification Code, a 3-digit code on the back of the card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthorization.Verification.CardVerificationCode.BuilderA builder for CardVerificationCode.
public final classCardPayment.Element.CardAuthorization.Verification.CardVerificationCode.ResultThe result of verifying the Card Verification Code.
-
Method Summary
Modifier and Type Method Description final CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Resultresult()The result of verifying the Card Verification Code. final JsonField<CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Result>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.BuildertoBuilder()final CardPayment.Element.CardAuthorization.Verification.CardVerificationCodevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Builderbuilder()Returns a mutable builder for constructing an instance of CardVerificationCode. -
-
Method Detail
-
result
final CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Result result()
The result of verifying the Card Verification Code.
-
_result
final JsonField<CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthorization.Verification.CardVerificationCode validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardAuthorization.Verification.CardVerificationCode.Builder builder()
Returns a mutable builder for constructing an instance of CardVerificationCode.
The following fields are required:
.result()
-
-
-
-