Class CardPayment.Element.CardAuthorizationExpiration
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthorizationExpirationA Card Authorization Expiration object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization_expiration. Card Authorization Expirations are cancellations of authorizations that were never settled by the acquirer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthorizationExpiration.BuilderA builder for CardAuthorizationExpiration.
public final classCardPayment.Element.CardAuthorizationExpiration.CurrencyThe ISO 4217 code for the reversal's currency.
public final classCardPayment.Element.CardAuthorizationExpiration.NetworkThe card network used to process this card authorization.
public final classCardPayment.Element.CardAuthorizationExpiration.TypeA constant representing the object's type. For this resource it will always be
card_authorization_expiration.
-
Method Summary
-
-
Method Detail
-
cardAuthorizationId
final String cardAuthorizationId()
The identifier for the Card Authorization this reverses.
-
currency
final CardPayment.Element.CardAuthorizationExpiration.Currency currency()
The ISO 4217 code for the reversal's currency.
-
expiredAmount
final Long expiredAmount()
The amount of this authorization expiration in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
network
final CardPayment.Element.CardAuthorizationExpiration.Network network()
The card network used to process this card authorization.
-
type
final CardPayment.Element.CardAuthorizationExpiration.Type type()
A constant representing the object's type. For this resource it will always be
card_authorization_expiration.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorizationId
final JsonField<String> _cardAuthorizationId()
Returns the raw JSON value of cardAuthorizationId.
Unlike cardAuthorizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CardPayment.Element.CardAuthorizationExpiration.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_expiredAmount
final JsonField<Long> _expiredAmount()
Returns the raw JSON value of expiredAmount.
Unlike expiredAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<CardPayment.Element.CardAuthorizationExpiration.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardAuthorizationExpiration.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthorizationExpiration.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthorizationExpiration validate()
-
builder
final static CardPayment.Element.CardAuthorizationExpiration.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationExpiration.
The following fields are required:
.id() .cardAuthorizationId() .currency() .expiredAmount() .network() .type()
-
-
-
-