Class CardPayment.Element.CardBalanceInquiry

  • All Implemented Interfaces:

    
    public final class CardPayment.Element.CardBalanceInquiry
    
                        

    A Card Balance Inquiry object. This field will be present in the JSON response if and only if category is equal to card_balance_inquiry. Card Balance Inquiries are transactions that allow merchants to check the available balance on a card without placing a hold on funds, commonly used when a customer requests their balance at an ATM.