Class CardPayment.Element.CardFinancial.NetworkIdentifiers
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardFinancial.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardFinancial.NetworkIdentifiers.BuilderA builder for NetworkIdentifiers.
-
Method Summary
Modifier and Type Method Description final Optional<String>authorizationIdentificationResponse()The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response. final Optional<String>retrievalReferenceNumber()A life-cycle identifier used across e.g., an authorization and a reversal. final Optional<String>traceNumber()A counter used to verify an individual authorization. final Optional<String>transactionId()A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests. final JsonField<String>_authorizationIdentificationResponse()Returns the raw JSON value of authorizationIdentificationResponse. final JsonField<String>_retrievalReferenceNumber()Returns the raw JSON value of retrievalReferenceNumber. final JsonField<String>_traceNumber()Returns the raw JSON value of traceNumber. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardFinancial.NetworkIdentifiers.BuildertoBuilder()final CardPayment.Element.CardFinancial.NetworkIdentifiersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardFinancial.NetworkIdentifiers.Builderbuilder()Returns a mutable builder for constructing an instance of NetworkIdentifiers. -
-
Method Detail
-
authorizationIdentificationResponse
final Optional<String> authorizationIdentificationResponse()
The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.
-
retrievalReferenceNumber
final Optional<String> retrievalReferenceNumber()
A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.
-
traceNumber
final Optional<String> traceNumber()
A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.
-
transactionId
final Optional<String> transactionId()
A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.
-
_authorizationIdentificationResponse
final JsonField<String> _authorizationIdentificationResponse()
Returns the raw JSON value of authorizationIdentificationResponse.
Unlike authorizationIdentificationResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_retrievalReferenceNumber
final JsonField<String> _retrievalReferenceNumber()
Returns the raw JSON value of retrievalReferenceNumber.
Unlike retrievalReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_traceNumber
final JsonField<String> _traceNumber()
Returns the raw JSON value of traceNumber.
Unlike traceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardFinancial.NetworkIdentifiers.Builder toBuilder()
-
validate
final CardPayment.Element.CardFinancial.NetworkIdentifiers validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardFinancial.NetworkIdentifiers.Builder builder()
Returns a mutable builder for constructing an instance of NetworkIdentifiers.
The following fields are required:
.authorizationIdentificationResponse() .retrievalReferenceNumber() .traceNumber() .transactionId()
-
-
-
-