Class CardPayment.Element.CardFuelConfirmation
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardFuelConfirmationA Card Fuel Confirmation object. This field will be present in the JSON response if and only if
categoryis equal tocard_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardFuelConfirmation.BuilderA builder for CardFuelConfirmation.
public final classCardPayment.Element.CardFuelConfirmation.CurrencyThe ISO 4217 code for the increment's currency.
public final classCardPayment.Element.CardFuelConfirmation.NetworkThe card network used to process this card authorization.
public final classCardPayment.Element.CardFuelConfirmation.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardFuelConfirmation.SchemeFeepublic final classCardPayment.Element.CardFuelConfirmation.TypeA constant representing the object's type. For this resource it will always be
card_fuel_confirmation.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Fuel Confirmation identifier. final StringcardAuthorizationId()The identifier for the Card Authorization this updates. final CardPayment.Element.CardFuelConfirmation.Currencycurrency()The ISO 4217 code for the increment's currency. final CardPayment.Element.CardFuelConfirmation.Networknetwork()The card network used to process this card authorization. final CardPayment.Element.CardFuelConfirmation.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Card Fuel Confirmation. final List<CardPayment.Element.CardFuelConfirmation.SchemeFee>schemeFees()The scheme fees associated with this card fuel confirmation. final CardPayment.Element.CardFuelConfirmation.Typetype()A constant representing the object's type. final LongupdatedAuthorizationAmount()The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_cardAuthorizationId()Returns the raw JSON value of cardAuthorizationId. final JsonField<CardPayment.Element.CardFuelConfirmation.Currency>_currency()Returns the raw JSON value of currency. final JsonField<CardPayment.Element.CardFuelConfirmation.Network>_network()Returns the raw JSON value of network. final JsonField<CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<List<CardPayment.Element.CardFuelConfirmation.SchemeFee>>_schemeFees()Returns the raw JSON value of schemeFees. final JsonField<CardPayment.Element.CardFuelConfirmation.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_updatedAuthorizationAmount()Returns the raw JSON value of updatedAuthorizationAmount. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardFuelConfirmation.BuildertoBuilder()final CardPayment.Element.CardFuelConfirmationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardFuelConfirmation.Builderbuilder()Returns a mutable builder for constructing an instance of CardFuelConfirmation. -
-
Method Detail
-
cardAuthorizationId
final String cardAuthorizationId()
The identifier for the Card Authorization this updates.
-
currency
final CardPayment.Element.CardFuelConfirmation.Currency currency()
The ISO 4217 code for the increment's currency.
-
network
final CardPayment.Element.CardFuelConfirmation.Network network()
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Fuel Confirmation.
-
schemeFees
final List<CardPayment.Element.CardFuelConfirmation.SchemeFee> schemeFees()
The scheme fees associated with this card fuel confirmation.
-
type
final CardPayment.Element.CardFuelConfirmation.Type type()
A constant representing the object's type. For this resource it will always be
card_fuel_confirmation.
-
updatedAuthorizationAmount
final Long updatedAuthorizationAmount()
The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorizationId
final JsonField<String> _cardAuthorizationId()
Returns the raw JSON value of cardAuthorizationId.
Unlike cardAuthorizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CardPayment.Element.CardFuelConfirmation.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<CardPayment.Element.CardFuelConfirmation.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_schemeFees
final JsonField<List<CardPayment.Element.CardFuelConfirmation.SchemeFee>> _schemeFees()
Returns the raw JSON value of schemeFees.
Unlike schemeFees, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardFuelConfirmation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAuthorizationAmount
final JsonField<Long> _updatedAuthorizationAmount()
Returns the raw JSON value of updatedAuthorizationAmount.
Unlike updatedAuthorizationAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardFuelConfirmation.Builder toBuilder()
-
validate
final CardPayment.Element.CardFuelConfirmation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardFuelConfirmation.Builder builder()
Returns a mutable builder for constructing an instance of CardFuelConfirmation.
The following fields are required:
.id() .cardAuthorizationId() .currency() .network() .networkIdentifiers() .pendingTransactionId() .schemeFees() .type() .updatedAuthorizationAmount()
-
-
-
-