Class CardPayment.Element.CardFuelConfirmation.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardFuelConfirmation.BuilderA builder for CardFuelConfirmation.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardFuelConfirmation.Builder id(String id)
The Card Fuel Confirmation identifier.
-
id
final CardPayment.Element.CardFuelConfirmation.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorizationId
final CardPayment.Element.CardFuelConfirmation.Builder cardAuthorizationId(String cardAuthorizationId)
The identifier for the Card Authorization this updates.
-
cardAuthorizationId
final CardPayment.Element.CardFuelConfirmation.Builder cardAuthorizationId(JsonField<String> cardAuthorizationId)
Sets Builder.cardAuthorizationId to an arbitrary JSON value.
You should usually call Builder.cardAuthorizationId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final CardPayment.Element.CardFuelConfirmation.Builder currency(CardPayment.Element.CardFuelConfirmation.Currency currency)
The ISO 4217 code for the increment's currency.
-
currency
final CardPayment.Element.CardFuelConfirmation.Builder currency(JsonField<CardPayment.Element.CardFuelConfirmation.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final CardPayment.Element.CardFuelConfirmation.Builder network(CardPayment.Element.CardFuelConfirmation.Network network)
The card network used to process this card authorization.
-
network
final CardPayment.Element.CardFuelConfirmation.Builder network(JsonField<CardPayment.Element.CardFuelConfirmation.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final CardPayment.Element.CardFuelConfirmation.Builder networkIdentifiers(CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardFuelConfirmation.Builder networkIdentifiers(JsonField<CardPayment.Element.CardFuelConfirmation.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final CardPayment.Element.CardFuelConfirmation.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Fuel Confirmation.
-
pendingTransactionId
final CardPayment.Element.CardFuelConfirmation.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final CardPayment.Element.CardFuelConfirmation.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPayment.Element.CardFuelConfirmation.Builder type(CardPayment.Element.CardFuelConfirmation.Type type)
A constant representing the object's type. For this resource it will always be
card_fuel_confirmation.
-
type
final CardPayment.Element.CardFuelConfirmation.Builder type(JsonField<CardPayment.Element.CardFuelConfirmation.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAuthorizationAmount
final CardPayment.Element.CardFuelConfirmation.Builder updatedAuthorizationAmount(Long updatedAuthorizationAmount)
The updated authorization amount after this fuel confirmation, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
updatedAuthorizationAmount
final CardPayment.Element.CardFuelConfirmation.Builder updatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)
Sets Builder.updatedAuthorizationAmount to an arbitrary JSON value.
You should usually call Builder.updatedAuthorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardFuelConfirmation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardFuelConfirmation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardFuelConfirmation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardFuelConfirmation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardFuelConfirmation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardFuelConfirmation build()
Returns an immutable instance of CardFuelConfirmation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .cardAuthorizationId() .currency() .network() .networkIdentifiers() .pendingTransactionId() .type() .updatedAuthorizationAmount()
-
-
-
-