Class CardPayment.Element.CardIncrement

  • All Implemented Interfaces:

    
    public final class CardPayment.Element.CardIncrement
    
                        

    A Card Increment object. This field will be present in the JSON response if and only if category is equal to card_increment. Card Increments increase the pending amount of an authorized transaction.