Class CardPayment.Element.CardIncrement.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardIncrement.BuilderA builder for CardIncrement.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardIncrement.Builder id(String id)
The Card Increment identifier.
-
id
final CardPayment.Element.CardIncrement.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
actioner
final CardPayment.Element.CardIncrement.Builder actioner(CardPayment.Element.CardIncrement.Actioner actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final CardPayment.Element.CardIncrement.Builder actioner(JsonField<CardPayment.Element.CardIncrement.Actioner> actioner)
Sets Builder.actioner to an arbitrary JSON value.
You should usually call Builder.actioner with a well-typed Actioner value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final CardPayment.Element.CardIncrement.Builder amount(Long amount)
The amount of this increment in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final CardPayment.Element.CardIncrement.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorizationId
final CardPayment.Element.CardIncrement.Builder cardAuthorizationId(String cardAuthorizationId)
The identifier for the Card Authorization this increments.
-
cardAuthorizationId
final CardPayment.Element.CardIncrement.Builder cardAuthorizationId(JsonField<String> cardAuthorizationId)
Sets Builder.cardAuthorizationId to an arbitrary JSON value.
You should usually call Builder.cardAuthorizationId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final CardPayment.Element.CardIncrement.Builder currency(CardPayment.Element.CardIncrement.Currency currency)
The ISO 4217 code for the increment's currency.
-
currency
final CardPayment.Element.CardIncrement.Builder currency(JsonField<CardPayment.Element.CardIncrement.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final CardPayment.Element.CardIncrement.Builder network(CardPayment.Element.CardIncrement.Network network)
The card network used to process this card authorization.
-
network
final CardPayment.Element.CardIncrement.Builder network(JsonField<CardPayment.Element.CardIncrement.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final CardPayment.Element.CardIncrement.Builder networkIdentifiers(CardPayment.Element.CardIncrement.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardIncrement.Builder networkIdentifiers(JsonField<CardPayment.Element.CardIncrement.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(Long networkRiskScore)
Alias for Builder.networkRiskScore.
This unboxed primitive overload exists for backwards compatibility.
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(Optional<Long> networkRiskScore)
Alias for calling Builder.networkRiskScore with
networkRiskScore.orElse(null).
-
networkRiskScore
final CardPayment.Element.CardIncrement.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final CardPayment.Element.CardIncrement.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Increment.
-
pendingTransactionId
final CardPayment.Element.CardIncrement.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final CardPayment.Element.CardIncrement.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
realTimeDecisionId
final CardPayment.Element.CardIncrement.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
-
realTimeDecisionId
final CardPayment.Element.CardIncrement.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
Alias for calling Builder.realTimeDecisionId with
realTimeDecisionId.orElse(null).
-
realTimeDecisionId
final CardPayment.Element.CardIncrement.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
Sets Builder.realTimeDecisionId to an arbitrary JSON value.
You should usually call Builder.realTimeDecisionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPayment.Element.CardIncrement.Builder type(CardPayment.Element.CardIncrement.Type type)
A constant representing the object's type. For this resource it will always be
card_increment.
-
type
final CardPayment.Element.CardIncrement.Builder type(JsonField<CardPayment.Element.CardIncrement.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAuthorizationAmount
final CardPayment.Element.CardIncrement.Builder updatedAuthorizationAmount(Long updatedAuthorizationAmount)
The updated authorization amount after this increment, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
updatedAuthorizationAmount
final CardPayment.Element.CardIncrement.Builder updatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)
Sets Builder.updatedAuthorizationAmount to an arbitrary JSON value.
You should usually call Builder.updatedAuthorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardIncrement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardIncrement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardIncrement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardIncrement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardIncrement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardIncrement build()
Returns an immutable instance of CardIncrement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .actioner() .amount() .cardAuthorizationId() .currency() .network() .networkIdentifiers() .networkRiskScore() .pendingTransactionId() .realTimeDecisionId() .type() .updatedAuthorizationAmount()
-
-
-
-