Class CardPayment.Element.CardRefund.Cashback
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardRefund.CashbackCashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardRefund.Cashback.BuilderA builder for Cashback.
public final classCardPayment.Element.CardRefund.Cashback.CurrencyThe ISO 4217 code for the cashback.
-
Method Summary
Modifier and Type Method Description final Stringamount()The cashback amount given as a string containing a decimal number. final CardPayment.Element.CardRefund.Cashback.Currencycurrency()The ISO 4217 code for the cashback. final JsonField<String>_amount()Returns the raw JSON value of amount. final JsonField<CardPayment.Element.CardRefund.Cashback.Currency>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardRefund.Cashback.BuildertoBuilder()final CardPayment.Element.CardRefund.Cashbackvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardRefund.Cashback.Builderbuilder()Returns a mutable builder for constructing an instance of Cashback. -
-
Method Detail
-
amount
final String amount()
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
currency
final CardPayment.Element.CardRefund.Cashback.Currency currency()
The ISO 4217 code for the cashback.
-
_amount
final JsonField<String> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CardPayment.Element.CardRefund.Cashback.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardRefund.Cashback.Builder toBuilder()
-
validate
final CardPayment.Element.CardRefund.Cashback validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardRefund.Cashback.Builder builder()
Returns a mutable builder for constructing an instance of Cashback.
The following fields are required:
.amount() .currency()
-
-
-
-