Class CardPayment.Element.CardReversal
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardReversalA Card Reversal object. This field will be present in the JSON response if and only if
categoryis equal tocard_reversal. Card Reversals cancel parts of or the entirety of an existing Card Authorization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardReversal.BuilderA builder for CardReversal.
public final classCardPayment.Element.CardReversal.CurrencyThe ISO 4217 code for the reversal's currency.
public final classCardPayment.Element.CardReversal.NetworkThe card network used to process this card authorization.
public final classCardPayment.Element.CardReversal.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardReversal.ReversalReasonWhy this reversal was initiated.
public final classCardPayment.Element.CardReversal.TypeA constant representing the object's type. For this resource it will always be
card_reversal.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Reversal identifier. final StringcardAuthorizationId()The identifier for the Card Authorization this reverses. final CardPayment.Element.CardReversal.Currencycurrency()The ISO 4217 code for the reversal's currency. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final Optional<String>merchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final CardPayment.Element.CardReversal.Networknetwork()The card network used to process this card authorization. final CardPayment.Element.CardReversal.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Card Reversal. final LongreversalAmount()The amount of this reversal in the minor unit of the transaction's currency. final Optional<CardPayment.Element.CardReversal.ReversalReason>reversalReason()Why this reversal was initiated. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardReversal.Typetype()A constant representing the object's type. final LongupdatedAuthorizationAmount()The amount left pending on the Card Authorization in the minor unit of the transaction's currency. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_cardAuthorizationId()Returns the raw JSON value of cardAuthorizationId. final JsonField<CardPayment.Element.CardReversal.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<CardPayment.Element.CardReversal.Network>_network()Returns the raw JSON value of network. final JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<Long>_reversalAmount()Returns the raw JSON value of reversalAmount. final JsonField<CardPayment.Element.CardReversal.ReversalReason>_reversalReason()Returns the raw JSON value of reversalReason. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final JsonField<CardPayment.Element.CardReversal.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_updatedAuthorizationAmount()Returns the raw JSON value of updatedAuthorizationAmount. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardReversal.BuildertoBuilder()final CardPayment.Element.CardReversalvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardReversal.Builderbuilder()Returns a mutable builder for constructing an instance of CardReversal. -
-
Method Detail
-
cardAuthorizationId
final String cardAuthorizationId()
The identifier for the Card Authorization this reverses.
-
currency
final CardPayment.Element.CardReversal.Currency currency()
The ISO 4217 code for the reversal's currency.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
network
final CardPayment.Element.CardReversal.Network network()
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardReversal.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Reversal.
-
reversalAmount
final Long reversalAmount()
The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversalReason
final Optional<CardPayment.Element.CardReversal.ReversalReason> reversalReason()
Why this reversal was initiated.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardReversal.Type type()
A constant representing the object's type. For this resource it will always be
card_reversal.
-
updatedAuthorizationAmount
final Long updatedAuthorizationAmount()
The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorizationId
final JsonField<String> _cardAuthorizationId()
Returns the raw JSON value of cardAuthorizationId.
Unlike cardAuthorizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CardPayment.Element.CardReversal.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<CardPayment.Element.CardReversal.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_reversalAmount
final JsonField<Long> _reversalAmount()
Returns the raw JSON value of reversalAmount.
Unlike reversalAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_reversalReason
final JsonField<CardPayment.Element.CardReversal.ReversalReason> _reversalReason()
Returns the raw JSON value of reversalReason.
Unlike reversalReason, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardReversal.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAuthorizationAmount
final JsonField<Long> _updatedAuthorizationAmount()
Returns the raw JSON value of updatedAuthorizationAmount.
Unlike updatedAuthorizationAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardReversal.Builder toBuilder()
-
validate
final CardPayment.Element.CardReversal validate()
-
builder
final static CardPayment.Element.CardReversal.Builder builder()
Returns a mutable builder for constructing an instance of CardReversal.
The following fields are required:
.id() .cardAuthorizationId() .currency() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .network() .networkIdentifiers() .pendingTransactionId() .reversalAmount() .reversalReason() .terminalId() .type() .updatedAuthorizationAmount()
-
-
-
-