Class CardPayment.Element.CardReversal.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardReversal.BuilderA builder for CardReversal.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardReversal.Builder id(String id)
The Card Reversal identifier.
-
id
final CardPayment.Element.CardReversal.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorizationId
final CardPayment.Element.CardReversal.Builder cardAuthorizationId(String cardAuthorizationId)
The identifier for the Card Authorization this reverses.
-
cardAuthorizationId
final CardPayment.Element.CardReversal.Builder cardAuthorizationId(JsonField<String> cardAuthorizationId)
Sets Builder.cardAuthorizationId to an arbitrary JSON value.
You should usually call Builder.cardAuthorizationId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final CardPayment.Element.CardReversal.Builder currency(CardPayment.Element.CardReversal.Currency currency)
The ISO 4217 code for the reversal's currency.
-
currency
final CardPayment.Element.CardReversal.Builder currency(JsonField<CardPayment.Element.CardReversal.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final CardPayment.Element.CardReversal.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardReversal.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardPayment.Element.CardReversal.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardReversal.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCity
final CardPayment.Element.CardReversal.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardReversal.Builder merchantCity(Optional<String> merchantCity)
Alias for calling Builder.merchantCity with
merchantCity.orElse(null).
-
merchantCity
final CardPayment.Element.CardReversal.Builder merchantCity(JsonField<String> merchantCity)
Sets Builder.merchantCity to an arbitrary JSON value.
You should usually call Builder.merchantCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final CardPayment.Element.CardReversal.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardReversal.Builder merchantCountry(Optional<String> merchantCountry)
Alias for calling Builder.merchantCountry with
merchantCountry.orElse(null).
-
merchantCountry
final CardPayment.Element.CardReversal.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantDescriptor
final CardPayment.Element.CardReversal.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final CardPayment.Element.CardReversal.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
Sets Builder.merchantDescriptor to an arbitrary JSON value.
You should usually call Builder.merchantDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final CardPayment.Element.CardReversal.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardReversal.Builder merchantPostalCode(Optional<String> merchantPostalCode)
Alias for calling Builder.merchantPostalCode with
merchantPostalCode.orElse(null).
-
merchantPostalCode
final CardPayment.Element.CardReversal.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final CardPayment.Element.CardReversal.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardReversal.Builder merchantState(Optional<String> merchantState)
Alias for calling Builder.merchantState with
merchantState.orElse(null).
-
merchantState
final CardPayment.Element.CardReversal.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final CardPayment.Element.CardReversal.Builder network(CardPayment.Element.CardReversal.Network network)
The card network used to process this card authorization.
-
network
final CardPayment.Element.CardReversal.Builder network(JsonField<CardPayment.Element.CardReversal.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final CardPayment.Element.CardReversal.Builder networkIdentifiers(CardPayment.Element.CardReversal.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardReversal.Builder networkIdentifiers(JsonField<CardPayment.Element.CardReversal.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final CardPayment.Element.CardReversal.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Card Reversal.
-
pendingTransactionId
final CardPayment.Element.CardReversal.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final CardPayment.Element.CardReversal.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentCurrency
final CardPayment.Element.CardReversal.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the reversal's presentment currency.
-
presentmentCurrency
final CardPayment.Element.CardReversal.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
Sets Builder.presentmentCurrency to an arbitrary JSON value.
You should usually call Builder.presentmentCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversalAmount
final CardPayment.Element.CardReversal.Builder reversalAmount(Long reversalAmount)
The amount of this reversal in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversalAmount
final CardPayment.Element.CardReversal.Builder reversalAmount(JsonField<Long> reversalAmount)
Sets Builder.reversalAmount to an arbitrary JSON value.
You should usually call Builder.reversalAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversalPresentmentAmount
final CardPayment.Element.CardReversal.Builder reversalPresentmentAmount(Long reversalPresentmentAmount)
The amount of this reversal in the minor unit of the transaction's presentment currency. For dollars, for example, this is cents.
-
reversalPresentmentAmount
final CardPayment.Element.CardReversal.Builder reversalPresentmentAmount(JsonField<Long> reversalPresentmentAmount)
Sets Builder.reversalPresentmentAmount to an arbitrary JSON value.
You should usually call Builder.reversalPresentmentAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversalReason
final CardPayment.Element.CardReversal.Builder reversalReason(CardPayment.Element.CardReversal.ReversalReason reversalReason)
Why this reversal was initiated.
-
reversalReason
final CardPayment.Element.CardReversal.Builder reversalReason(Optional<CardPayment.Element.CardReversal.ReversalReason> reversalReason)
Alias for calling Builder.reversalReason with
reversalReason.orElse(null).
-
reversalReason
final CardPayment.Element.CardReversal.Builder reversalReason(JsonField<CardPayment.Element.CardReversal.ReversalReason> reversalReason)
Sets Builder.reversalReason to an arbitrary JSON value.
You should usually call Builder.reversalReason with a well-typed ReversalReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
terminalId
final CardPayment.Element.CardReversal.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardReversal.Builder terminalId(Optional<String> terminalId)
Alias for calling Builder.terminalId with
terminalId.orElse(null).
-
terminalId
final CardPayment.Element.CardReversal.Builder terminalId(JsonField<String> terminalId)
Sets Builder.terminalId to an arbitrary JSON value.
You should usually call Builder.terminalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPayment.Element.CardReversal.Builder type(CardPayment.Element.CardReversal.Type type)
A constant representing the object's type. For this resource it will always be
card_reversal.
-
type
final CardPayment.Element.CardReversal.Builder type(JsonField<CardPayment.Element.CardReversal.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAuthorizationAmount
final CardPayment.Element.CardReversal.Builder updatedAuthorizationAmount(Long updatedAuthorizationAmount)
The amount left pending on the Card Authorization in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
updatedAuthorizationAmount
final CardPayment.Element.CardReversal.Builder updatedAuthorizationAmount(JsonField<Long> updatedAuthorizationAmount)
Sets Builder.updatedAuthorizationAmount to an arbitrary JSON value.
You should usually call Builder.updatedAuthorizationAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAuthorizationPresentmentAmount
final CardPayment.Element.CardReversal.Builder updatedAuthorizationPresentmentAmount(Long updatedAuthorizationPresentmentAmount)
The amount left pending on the Card Authorization in the minor unit of the transaction's presentment currency. For dollars, for example, this is cents.
-
updatedAuthorizationPresentmentAmount
final CardPayment.Element.CardReversal.Builder updatedAuthorizationPresentmentAmount(JsonField<Long> updatedAuthorizationPresentmentAmount)
Sets Builder.updatedAuthorizationPresentmentAmount to an arbitrary JSON value.
You should usually call Builder.updatedAuthorizationPresentmentAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardReversal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardReversal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardReversal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardReversal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardReversal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardReversal build()
Returns an immutable instance of CardReversal.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .cardAuthorizationId() .currency() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .network() .networkIdentifiers() .pendingTransactionId() .presentmentCurrency() .reversalAmount() .reversalPresentmentAmount() .reversalReason() .terminalId() .type() .updatedAuthorizationAmount() .updatedAuthorizationPresentmentAmount()
-
-
-
-