Class CardPayment.Element.CardValidation

  • All Implemented Interfaces:

    
    public final class CardPayment.Element.CardValidation
    
                        

    An Inbound Card Validation object. This field will be present in the JSON response if and only if category is equal to card_validation. Inbound Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.