Class CardPayment.Element.CardValidation.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardValidation.BuilderA builder for CardValidation.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardValidation.Builder id(String id)
The Card Validation identifier.
-
id
final CardPayment.Element.CardValidation.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
actioner
final CardPayment.Element.CardValidation.Builder actioner(CardPayment.Element.CardValidation.Actioner actioner)
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final CardPayment.Element.CardValidation.Builder actioner(JsonField<CardPayment.Element.CardValidation.Actioner> actioner)
Sets Builder.actioner to an arbitrary JSON value.
You should usually call Builder.actioner with a well-typed Actioner value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalAmounts
final CardPayment.Element.CardValidation.Builder additionalAmounts(CardPayment.Element.CardValidation.AdditionalAmounts additionalAmounts)
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
additionalAmounts
final CardPayment.Element.CardValidation.Builder additionalAmounts(JsonField<CardPayment.Element.CardValidation.AdditionalAmounts> additionalAmounts)
Sets Builder.additionalAmounts to an arbitrary JSON value.
You should usually call Builder.additionalAmounts with a well-typed AdditionalAmounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final CardPayment.Element.CardValidation.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPayment.Element.CardValidation.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final CardPayment.Element.CardValidation.Builder currency(CardPayment.Element.CardValidation.Currency currency)
The ISO 4217 code for the transaction's currency.
-
currency
final CardPayment.Element.CardValidation.Builder currency(JsonField<CardPayment.Element.CardValidation.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenId
final CardPayment.Element.CardValidation.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final CardPayment.Element.CardValidation.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
Alias for calling Builder.digitalWalletTokenId with
digitalWalletTokenId.orElse(null).
-
digitalWalletTokenId
final CardPayment.Element.CardValidation.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
Sets Builder.digitalWalletTokenId to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final CardPayment.Element.CardValidation.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardValidation.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardPayment.Element.CardValidation.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardValidation.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCity
final CardPayment.Element.CardValidation.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardPayment.Element.CardValidation.Builder merchantCity(Optional<String> merchantCity)
Alias for calling Builder.merchantCity with
merchantCity.orElse(null).
-
merchantCity
final CardPayment.Element.CardValidation.Builder merchantCity(JsonField<String> merchantCity)
Sets Builder.merchantCity to an arbitrary JSON value.
You should usually call Builder.merchantCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final CardPayment.Element.CardValidation.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardValidation.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantDescriptor
final CardPayment.Element.CardValidation.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final CardPayment.Element.CardValidation.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
Sets Builder.merchantDescriptor to an arbitrary JSON value.
You should usually call Builder.merchantDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final CardPayment.Element.CardValidation.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final CardPayment.Element.CardValidation.Builder merchantPostalCode(Optional<String> merchantPostalCode)
Alias for calling Builder.merchantPostalCode with
merchantPostalCode.orElse(null).
-
merchantPostalCode
final CardPayment.Element.CardValidation.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final CardPayment.Element.CardValidation.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardPayment.Element.CardValidation.Builder merchantState(Optional<String> merchantState)
Alias for calling Builder.merchantState with
merchantState.orElse(null).
-
merchantState
final CardPayment.Element.CardValidation.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkDetails
final CardPayment.Element.CardValidation.Builder networkDetails(CardPayment.Element.CardValidation.NetworkDetails networkDetails)
Fields specific to the
network.
-
networkDetails
final CardPayment.Element.CardValidation.Builder networkDetails(JsonField<CardPayment.Element.CardValidation.NetworkDetails> networkDetails)
Sets Builder.networkDetails to an arbitrary JSON value.
You should usually call Builder.networkDetails with a well-typed NetworkDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final CardPayment.Element.CardValidation.Builder networkIdentifiers(CardPayment.Element.CardValidation.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final CardPayment.Element.CardValidation.Builder networkIdentifiers(JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(Long networkRiskScore)
Alias for Builder.networkRiskScore.
This unboxed primitive overload exists for backwards compatibility.
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(Optional<Long> networkRiskScore)
Alias for calling Builder.networkRiskScore with
networkRiskScore.orElse(null).
-
networkRiskScore
final CardPayment.Element.CardValidation.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCardId
final CardPayment.Element.CardValidation.Builder physicalCardId(String physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final CardPayment.Element.CardValidation.Builder physicalCardId(Optional<String> physicalCardId)
Alias for calling Builder.physicalCardId with
physicalCardId.orElse(null).
-
physicalCardId
final CardPayment.Element.CardValidation.Builder physicalCardId(JsonField<String> physicalCardId)
Sets Builder.physicalCardId to an arbitrary JSON value.
You should usually call Builder.physicalCardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
realTimeDecisionId
final CardPayment.Element.CardValidation.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final CardPayment.Element.CardValidation.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
Alias for calling Builder.realTimeDecisionId with
realTimeDecisionId.orElse(null).
-
realTimeDecisionId
final CardPayment.Element.CardValidation.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
Sets Builder.realTimeDecisionId to an arbitrary JSON value.
You should usually call Builder.realTimeDecisionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
terminalId
final CardPayment.Element.CardValidation.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardPayment.Element.CardValidation.Builder terminalId(Optional<String> terminalId)
Alias for calling Builder.terminalId with
terminalId.orElse(null).
-
terminalId
final CardPayment.Element.CardValidation.Builder terminalId(JsonField<String> terminalId)
Sets Builder.terminalId to an arbitrary JSON value.
You should usually call Builder.terminalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPayment.Element.CardValidation.Builder type(CardPayment.Element.CardValidation.Type type)
A constant representing the object's type. For this resource it will always be
inbound_card_validation.
-
type
final CardPayment.Element.CardValidation.Builder type(JsonField<CardPayment.Element.CardValidation.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verification
final CardPayment.Element.CardValidation.Builder verification(CardPayment.Element.CardValidation.Verification verification)
Fields related to verification of cardholder-provided values.
-
verification
final CardPayment.Element.CardValidation.Builder verification(JsonField<CardPayment.Element.CardValidation.Verification> verification)
Sets Builder.verification to an arbitrary JSON value.
You should usually call Builder.verification with a well-typed Verification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardValidation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardValidation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardValidation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardValidation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardValidation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardValidation build()
Returns an immutable instance of CardValidation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .actioner() .additionalAmounts() .cardPaymentId() .currency() .digitalWalletTokenId() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .realTimeDecisionId() .terminalId() .type() .verification()
-
-
-
-