Class CardPayment.Element.CardValidation.NetworkDetails.Pulse
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardValidation.NetworkDetails.PulseFields specific to the
pulsenetwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardValidation.NetworkDetails.Pulse.BuilderA builder for Pulse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardValidation.NetworkDetails.Pulse.BuildertoBuilder()final CardPayment.Element.CardValidation.NetworkDetails.Pulsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardValidation.NetworkDetails.Pulse.Builderbuilder()Returns a mutable builder for constructing an instance of Pulse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardValidation.NetworkDetails.Pulse.Builder toBuilder()
-
validate
final CardPayment.Element.CardValidation.NetworkDetails.Pulse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardValidation.NetworkDetails.Pulse.Builder builder()
Returns a mutable builder for constructing an instance of Pulse.
-
-
-
-