Class CardPayment.Element.Other
-
- All Implemented Interfaces:
public final class CardPayment.Element.OtherIf the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.Other.BuilderA builder for Other.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.Other.BuildertoBuilder()final CardPayment.Element.Othervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.Other.Builderbuilder()Returns a mutable builder for constructing an instance of Other. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.Other.Builder toBuilder()
-
validate
final CardPayment.Element.Other validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.Other.Builder builder()
Returns a mutable builder for constructing an instance of Other.
-
-
-
-