Class CardPayment.State
-
- All Implemented Interfaces:
public final class CardPayment.StateThe summarized state of this card payment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.State.BuilderA builder for State.
-
Method Summary
Modifier and Type Method Description final LongauthorizedAmount()The total authorized amount in the minor unit of the transaction's currency. final LongfuelConfirmedAmount()The total amount from fuel confirmations in the minor unit of the transaction's currency. final LongincrementedAmount()The total incrementally updated authorized amount in the minor unit of the transaction's currency. final LongrefundAuthorizedAmount()The total refund authorized amount in the minor unit of the transaction's currency. final LongrefundedAmount()The total refunded amount in the minor unit of the transaction's currency. final LongreversedAmount()The total reversed amount in the minor unit of the transaction's currency. final LongsettledAmount()The total settled amount in the minor unit of the transaction's currency. final JsonField<Long>_authorizedAmount()Returns the raw JSON value of authorizedAmount. final JsonField<Long>_fuelConfirmedAmount()Returns the raw JSON value of fuelConfirmedAmount. final JsonField<Long>_incrementedAmount()Returns the raw JSON value of incrementedAmount. final JsonField<Long>_refundAuthorizedAmount()Returns the raw JSON value of refundAuthorizedAmount. final JsonField<Long>_refundedAmount()Returns the raw JSON value of refundedAmount. final JsonField<Long>_reversedAmount()Returns the raw JSON value of reversedAmount. final JsonField<Long>_settledAmount()Returns the raw JSON value of settledAmount. final Map<String, JsonValue>_additionalProperties()final CardPayment.State.BuildertoBuilder()final CardPayment.Statevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.State.Builderbuilder()Returns a mutable builder for constructing an instance of State. -
-
Method Detail
-
authorizedAmount
final Long authorizedAmount()
The total authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
fuelConfirmedAmount
final Long fuelConfirmedAmount()
The total amount from fuel confirmations in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
incrementedAmount
final Long incrementedAmount()
The total incrementally updated authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
refundAuthorizedAmount
final Long refundAuthorizedAmount()
The total refund authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
refundedAmount
final Long refundedAmount()
The total refunded amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversedAmount
final Long reversedAmount()
The total reversed amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
settledAmount
final Long settledAmount()
The total settled amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_authorizedAmount
final JsonField<Long> _authorizedAmount()
Returns the raw JSON value of authorizedAmount.
Unlike authorizedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_fuelConfirmedAmount
final JsonField<Long> _fuelConfirmedAmount()
Returns the raw JSON value of fuelConfirmedAmount.
Unlike fuelConfirmedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_incrementedAmount
final JsonField<Long> _incrementedAmount()
Returns the raw JSON value of incrementedAmount.
Unlike incrementedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_refundAuthorizedAmount
final JsonField<Long> _refundAuthorizedAmount()
Returns the raw JSON value of refundAuthorizedAmount.
Unlike refundAuthorizedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_refundedAmount
final JsonField<Long> _refundedAmount()
Returns the raw JSON value of refundedAmount.
Unlike refundedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_reversedAmount
final JsonField<Long> _reversedAmount()
Returns the raw JSON value of reversedAmount.
Unlike reversedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_settledAmount
final JsonField<Long> _settledAmount()
Returns the raw JSON value of settledAmount.
Unlike settledAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.State.Builder toBuilder()
-
validate
final CardPayment.State validate()
-
builder
final static CardPayment.State.Builder builder()
Returns a mutable builder for constructing an instance of State.
The following fields are required:
.authorizedAmount() .fuelConfirmedAmount() .incrementedAmount() .refundAuthorizedAmount() .refundedAmount() .reversedAmount() .settledAmount()
-
-
-
-