Class CardPayment.State.Builder
-
- All Implemented Interfaces:
public final class CardPayment.State.BuilderA builder for State.
-
-
Method Summary
Modifier and Type Method Description final CardPayment.State.BuilderauthorizedAmount(Long authorizedAmount)The total authorized amount in the minor unit of the transaction's currency. final CardPayment.State.BuilderauthorizedAmount(JsonField<Long> authorizedAmount)Sets Builder.authorizedAmount to an arbitrary JSON value. final CardPayment.State.BuilderfuelConfirmedAmount(Long fuelConfirmedAmount)The total amount from fuel confirmations in the minor unit of the transaction's currency. final CardPayment.State.BuilderfuelConfirmedAmount(JsonField<Long> fuelConfirmedAmount)Sets Builder.fuelConfirmedAmount to an arbitrary JSON value. final CardPayment.State.BuilderincrementedAmount(Long incrementedAmount)The total incrementally updated authorized amount in the minor unit of the transaction's currency. final CardPayment.State.BuilderincrementedAmount(JsonField<Long> incrementedAmount)Sets Builder.incrementedAmount to an arbitrary JSON value. final CardPayment.State.BuilderreversedAmount(Long reversedAmount)The total reversed amount in the minor unit of the transaction's currency. final CardPayment.State.BuilderreversedAmount(JsonField<Long> reversedAmount)Sets Builder.reversedAmount to an arbitrary JSON value. final CardPayment.State.BuildersettledAmount(Long settledAmount)The total settled or refunded amount in the minor unit of the transaction's currency. final CardPayment.State.BuildersettledAmount(JsonField<Long> settledAmount)Sets Builder.settledAmount to an arbitrary JSON value. final CardPayment.State.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.State.BuilderputAdditionalProperty(String key, JsonValue value)final CardPayment.State.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPayment.State.BuilderremoveAdditionalProperty(String key)final CardPayment.State.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPayment.Statebuild()Returns an immutable instance of State. -
-
Method Detail
-
authorizedAmount
final CardPayment.State.Builder authorizedAmount(Long authorizedAmount)
The total authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
authorizedAmount
final CardPayment.State.Builder authorizedAmount(JsonField<Long> authorizedAmount)
Sets Builder.authorizedAmount to an arbitrary JSON value.
You should usually call Builder.authorizedAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fuelConfirmedAmount
final CardPayment.State.Builder fuelConfirmedAmount(Long fuelConfirmedAmount)
The total amount from fuel confirmations in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
fuelConfirmedAmount
final CardPayment.State.Builder fuelConfirmedAmount(JsonField<Long> fuelConfirmedAmount)
Sets Builder.fuelConfirmedAmount to an arbitrary JSON value.
You should usually call Builder.fuelConfirmedAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
incrementedAmount
final CardPayment.State.Builder incrementedAmount(Long incrementedAmount)
The total incrementally updated authorized amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
incrementedAmount
final CardPayment.State.Builder incrementedAmount(JsonField<Long> incrementedAmount)
Sets Builder.incrementedAmount to an arbitrary JSON value.
You should usually call Builder.incrementedAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversedAmount
final CardPayment.State.Builder reversedAmount(Long reversedAmount)
The total reversed amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
reversedAmount
final CardPayment.State.Builder reversedAmount(JsonField<Long> reversedAmount)
Sets Builder.reversedAmount to an arbitrary JSON value.
You should usually call Builder.reversedAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settledAmount
final CardPayment.State.Builder settledAmount(Long settledAmount)
The total settled or refunded amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
settledAmount
final CardPayment.State.Builder settledAmount(JsonField<Long> settledAmount)
Sets Builder.settledAmount to an arbitrary JSON value.
You should usually call Builder.settledAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.State.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.State.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.State.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.State.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.State.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.State build()
Returns an immutable instance of State.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.authorizedAmount() .fuelConfirmedAmount() .incrementedAmount() .reversedAmount() .settledAmount()
-
-
-
-