Class CardPaymentListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class CardPaymentListPage implements Page<CardPayment>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPaymentListPage.BuilderA builder for CardPaymentListPage.
-
Method Summary
Modifier and Type Method Description final List<CardPayment>data()Delegates to CardPaymentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to CardPaymentListPageResponse, but gracefully handles missing data. List<CardPayment>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final CardPaymentListParamsnextPageParams()CardPaymentListPagenextPage()Returns the page after this one by making another request. final AutoPager<CardPayment>autoPager()final CardPaymentListParamsparams()The parameters that were used to request this page. final CardPaymentListPageResponseresponse()The response that this page was parsed from. final CardPaymentListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPaymentListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardPaymentListPage. -
-
Method Detail
-
data
final List<CardPayment> data()
Delegates to CardPaymentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CardPaymentListPageResponse, but gracefully handles missing data.
-
items
List<CardPayment> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final CardPaymentListParams nextPageParams()
-
nextPage
CardPaymentListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<CardPayment> autoPager()
-
params
final CardPaymentListParams params()
The parameters that were used to request this page.
-
response
final CardPaymentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardPaymentListPage.Builder toBuilder()
-
builder
final static CardPaymentListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardPaymentListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-