Class CardPaymentListPageAsync
-
- All Implemented Interfaces:
public final class CardPaymentListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPaymentListPageAsync.BuilderA builder for CardPaymentListPageAsync.
public final classCardPaymentListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<CardPayment>data()Delegates to CardPaymentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to CardPaymentListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CardPaymentListParams>getNextPageParams()final CompletableFuture<Optional<CardPaymentListPageAsync>>getNextPage()final CardPaymentListPageAsync.AutoPagerautoPager()final CardPaymentListParamsparams()The parameters that were used to request this page. final CardPaymentListPageResponseresponse()The response that this page was parsed from. final CardPaymentListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPaymentListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of CardPaymentListPageAsync. -
-
Method Detail
-
data
final List<CardPayment> data()
Delegates to CardPaymentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CardPaymentListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardPaymentListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CardPaymentListPageAsync>> getNextPage()
-
autoPager
final CardPaymentListPageAsync.AutoPager autoPager()
-
params
final CardPaymentListParams params()
The parameters that were used to request this page.
-
response
final CardPaymentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardPaymentListPageAsync.Builder toBuilder()
-
builder
final static CardPaymentListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CardPaymentListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-