Class CardPaymentListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardPaymentListPageAsync.BuilderA builder for CardPaymentListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardPaymentListPageAsync.Builderservice(CardPaymentServiceAsync service)final CardPaymentListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CardPaymentListPageAsync.Builderparams(CardPaymentListParams params)The parameters that were used to request this page. final CardPaymentListPageAsync.Builderresponse(CardPaymentListPageResponse response)The response that this page was parsed from. final CardPaymentListPageAsyncbuild()Returns an immutable instance of CardPaymentListPageAsync. -
-
Method Detail
-
service
final CardPaymentListPageAsync.Builder service(CardPaymentServiceAsync service)
-
streamHandlerExecutor
final CardPaymentListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CardPaymentListPageAsync.Builder params(CardPaymentListParams params)
The parameters that were used to request this page.
-
response
final CardPaymentListPageAsync.Builder response(CardPaymentListPageResponse response)
The response that this page was parsed from.
-
build
final CardPaymentListPageAsync build()
Returns an immutable instance of CardPaymentListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-