Class CardPaymentListPageResponse
-
- All Implemented Interfaces:
public final class CardPaymentListPageResponseA list of Card Payment objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPaymentListPageResponse.BuilderA builder for CardPaymentListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CardPayment>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<CardPayment>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final CardPaymentListPageResponse.BuildertoBuilder()final CardPaymentListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPaymentListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardPaymentListPageResponse. -
-
Method Detail
-
data
final List<CardPayment> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<CardPayment>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPaymentListPageResponse.Builder toBuilder()
-
validate
final CardPaymentListPageResponse validate()
-
builder
final static CardPaymentListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardPaymentListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-