Class CardPurchaseSupplement
-
- All Implemented Interfaces:
public final class CardPurchaseSupplementAdditional information about a card purchase (e.g., settlement or refund), such as level 3 line item data.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplement.BuilderA builder for CardPurchaseSupplement.
public final classCardPurchaseSupplement.InvoiceInvoice-level information about the payment.
public final classCardPurchaseSupplement.LineItempublic final classCardPurchaseSupplement.ShippingShipping information for the purchase.
public final classCardPurchaseSupplement.TypeA constant representing the object's type. For this resource it will always be
card_purchase_supplement.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Purchase Supplement identifier. final Optional<String>cardPaymentId()The ID of the Card Payment this transaction belongs to. final Optional<CardPurchaseSupplement.Invoice>invoice()Invoice-level information about the payment. final Optional<List<CardPurchaseSupplement.LineItem>>lineItems()Line item information, such as individual products purchased. final Optional<CardPurchaseSupplement.Shipping>shipping()Shipping information for the purchase. final StringtransactionId()The ID of the transaction. final CardPurchaseSupplement.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<CardPurchaseSupplement.Invoice>_invoice()Returns the raw JSON value of invoice. final JsonField<List<CardPurchaseSupplement.LineItem>>_lineItems()Returns the raw JSON value of lineItems. final JsonField<CardPurchaseSupplement.Shipping>_shipping()Returns the raw JSON value of shipping. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<CardPurchaseSupplement.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardPurchaseSupplement.BuildertoBuilder()final CardPurchaseSupplementvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPurchaseSupplement.Builderbuilder()Returns a mutable builder for constructing an instance of CardPurchaseSupplement. -
-
Method Detail
-
cardPaymentId
final Optional<String> cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
invoice
final Optional<CardPurchaseSupplement.Invoice> invoice()
Invoice-level information about the payment.
-
lineItems
final Optional<List<CardPurchaseSupplement.LineItem>> lineItems()
Line item information, such as individual products purchased.
-
shipping
final Optional<CardPurchaseSupplement.Shipping> shipping()
Shipping information for the purchase.
-
transactionId
final String transactionId()
The ID of the transaction.
-
type
final CardPurchaseSupplement.Type type()
A constant representing the object's type. For this resource it will always be
card_purchase_supplement.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_invoice
final JsonField<CardPurchaseSupplement.Invoice> _invoice()
Returns the raw JSON value of invoice.
Unlike invoice, this method doesn't throw if the JSON field has an unexpected type.
-
_lineItems
final JsonField<List<CardPurchaseSupplement.LineItem>> _lineItems()
Returns the raw JSON value of lineItems.
Unlike lineItems, this method doesn't throw if the JSON field has an unexpected type.
-
_shipping
final JsonField<CardPurchaseSupplement.Shipping> _shipping()
Returns the raw JSON value of shipping.
Unlike shipping, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPurchaseSupplement.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPurchaseSupplement.Builder toBuilder()
-
validate
final CardPurchaseSupplement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPurchaseSupplement.Builder builder()
Returns a mutable builder for constructing an instance of CardPurchaseSupplement.
The following fields are required:
.id() .cardPaymentId() .invoice() .lineItems() .shipping() .transactionId() .type()
-
-
-
-