Class CardPurchaseSupplement.Builder
-
- All Implemented Interfaces:
public final class CardPurchaseSupplement.BuilderA builder for CardPurchaseSupplement.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPurchaseSupplement.Builder id(String id)
The Card Purchase Supplement identifier.
-
id
final CardPurchaseSupplement.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final CardPurchaseSupplement.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPurchaseSupplement.Builder cardPaymentId(Optional<String> cardPaymentId)
Alias for calling Builder.cardPaymentId with
cardPaymentId.orElse(null).
-
cardPaymentId
final CardPurchaseSupplement.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
invoice
final CardPurchaseSupplement.Builder invoice(CardPurchaseSupplement.Invoice invoice)
Invoice-level information about the payment.
-
invoice
final CardPurchaseSupplement.Builder invoice(Optional<CardPurchaseSupplement.Invoice> invoice)
Alias for calling Builder.invoice with
invoice.orElse(null).
-
invoice
final CardPurchaseSupplement.Builder invoice(JsonField<CardPurchaseSupplement.Invoice> invoice)
Sets Builder.invoice to an arbitrary JSON value.
You should usually call Builder.invoice with a well-typed Invoice value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lineItems
final CardPurchaseSupplement.Builder lineItems(List<CardPurchaseSupplement.LineItem> lineItems)
Line item information, such as individual products purchased.
-
lineItems
final CardPurchaseSupplement.Builder lineItems(Optional<List<CardPurchaseSupplement.LineItem>> lineItems)
Alias for calling Builder.lineItems with
lineItems.orElse(null).
-
lineItems
final CardPurchaseSupplement.Builder lineItems(JsonField<List<CardPurchaseSupplement.LineItem>> lineItems)
Sets Builder.lineItems to an arbitrary JSON value.
You should usually call Builder.lineItems with a well-typed
List<LineItem>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addLineItem
final CardPurchaseSupplement.Builder addLineItem(CardPurchaseSupplement.LineItem lineItem)
-
transactionId
final CardPurchaseSupplement.Builder transactionId(String transactionId)
The ID of the transaction.
-
transactionId
final CardPurchaseSupplement.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPurchaseSupplement.Builder type(CardPurchaseSupplement.Type type)
A constant representing the object's type. For this resource it will always be
card_purchase_supplement.
-
type
final CardPurchaseSupplement.Builder type(JsonField<CardPurchaseSupplement.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPurchaseSupplement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPurchaseSupplement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPurchaseSupplement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPurchaseSupplement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPurchaseSupplement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPurchaseSupplement build()
Returns an immutable instance of CardPurchaseSupplement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .cardPaymentId() .invoice() .lineItems() .transactionId() .type()
-
-
-
-