Class CardPurchaseSupplement.Invoice
-
- All Implemented Interfaces:
public final class CardPurchaseSupplement.InvoiceInvoice-level information about the payment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplement.Invoice.BuilderA builder for Invoice.
public final classCardPurchaseSupplement.Invoice.DiscountTreatmentCodeIndicates how the merchant applied the discount.
public final classCardPurchaseSupplement.Invoice.TaxTreatmentsIndicates how the merchant applied taxes.
-
Method Summary
-
-
Method Detail
-
discountAmount
final Optional<Long> discountAmount()
Discount given to cardholder.
-
discountCurrency
final Optional<String> discountCurrency()
The ISO 4217 code for the discount.
-
discountTreatmentCode
final Optional<CardPurchaseSupplement.Invoice.DiscountTreatmentCode> discountTreatmentCode()
Indicates how the merchant applied the discount.
-
dutyTaxAmount
final Optional<Long> dutyTaxAmount()
Amount of duty taxes.
-
dutyTaxCurrency
final Optional<String> dutyTaxCurrency()
The ISO 4217 code for the duty tax.
-
shippingAmount
final Optional<Long> shippingAmount()
The shipping cost.
-
shippingCurrency
final Optional<String> shippingCurrency()
The ISO 4217 code for the shipping cost.
-
shippingDestinationCountryCode
final Optional<String> shippingDestinationCountryCode()
Country code of the shipping destination.
-
shippingDestinationPostalCode
final Optional<String> shippingDestinationPostalCode()
Postal code of the shipping destination.
-
shippingSourcePostalCode
final Optional<String> shippingSourcePostalCode()
Postal code of the location being shipped from.
-
shippingTaxAmount
final Optional<Long> shippingTaxAmount()
Taxes paid for freight and shipping.
-
shippingTaxCurrency
final Optional<String> shippingTaxCurrency()
The ISO 4217 code for the shipping tax.
-
shippingTaxRate
final Optional<String> shippingTaxRate()
Tax rate for freight and shipping.
-
taxTreatments
final Optional<CardPurchaseSupplement.Invoice.TaxTreatments> taxTreatments()
Indicates how the merchant applied taxes.
-
uniqueValueAddedTaxInvoiceReference
final Optional<String> uniqueValueAddedTaxInvoiceReference()
Value added tax invoice reference number.
-
_discountAmount
final JsonField<Long> _discountAmount()
Returns the raw JSON value of discountAmount.
Unlike discountAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_discountCurrency
final JsonField<String> _discountCurrency()
Returns the raw JSON value of discountCurrency.
Unlike discountCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_discountTreatmentCode
final JsonField<CardPurchaseSupplement.Invoice.DiscountTreatmentCode> _discountTreatmentCode()
Returns the raw JSON value of discountTreatmentCode.
Unlike discountTreatmentCode, this method doesn't throw if the JSON field has an unexpected type.
-
_dutyTaxAmount
final JsonField<Long> _dutyTaxAmount()
Returns the raw JSON value of dutyTaxAmount.
Unlike dutyTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_dutyTaxCurrency
final JsonField<String> _dutyTaxCurrency()
Returns the raw JSON value of dutyTaxCurrency.
Unlike dutyTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_orderDate
final JsonField<LocalDate> _orderDate()
Returns the raw JSON value of orderDate.
Unlike orderDate, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAmount
final JsonField<Long> _shippingAmount()
Returns the raw JSON value of shippingAmount.
Unlike shippingAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingCurrency
final JsonField<String> _shippingCurrency()
Returns the raw JSON value of shippingCurrency.
Unlike shippingCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingDestinationCountryCode
final JsonField<String> _shippingDestinationCountryCode()
Returns the raw JSON value of shippingDestinationCountryCode.
Unlike shippingDestinationCountryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingDestinationPostalCode
final JsonField<String> _shippingDestinationPostalCode()
Returns the raw JSON value of shippingDestinationPostalCode.
Unlike shippingDestinationPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingSourcePostalCode
final JsonField<String> _shippingSourcePostalCode()
Returns the raw JSON value of shippingSourcePostalCode.
Unlike shippingSourcePostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingTaxAmount
final JsonField<Long> _shippingTaxAmount()
Returns the raw JSON value of shippingTaxAmount.
Unlike shippingTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingTaxCurrency
final JsonField<String> _shippingTaxCurrency()
Returns the raw JSON value of shippingTaxCurrency.
Unlike shippingTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingTaxRate
final JsonField<String> _shippingTaxRate()
Returns the raw JSON value of shippingTaxRate.
Unlike shippingTaxRate, this method doesn't throw if the JSON field has an unexpected type.
-
_taxTreatments
final JsonField<CardPurchaseSupplement.Invoice.TaxTreatments> _taxTreatments()
Returns the raw JSON value of taxTreatments.
Unlike taxTreatments, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueValueAddedTaxInvoiceReference
final JsonField<String> _uniqueValueAddedTaxInvoiceReference()
Returns the raw JSON value of uniqueValueAddedTaxInvoiceReference.
Unlike uniqueValueAddedTaxInvoiceReference, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPurchaseSupplement.Invoice.Builder toBuilder()
-
validate
final CardPurchaseSupplement.Invoice validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPurchaseSupplement.Invoice.Builder builder()
Returns a mutable builder for constructing an instance of Invoice.
The following fields are required:
.discountAmount() .discountCurrency() .discountTreatmentCode() .dutyTaxAmount() .dutyTaxCurrency() .orderDate() .shippingAmount() .shippingCurrency() .shippingDestinationCountryCode() .shippingDestinationPostalCode() .shippingSourcePostalCode() .shippingTaxAmount() .shippingTaxCurrency() .shippingTaxRate() .taxTreatments() .uniqueValueAddedTaxInvoiceReference()
-
-
-
-