Class CardPurchaseSupplement.Invoice.Builder
-
- All Implemented Interfaces:
public final class CardPurchaseSupplement.Invoice.BuilderA builder for Invoice.
-
-
Method Summary
-
-
Method Detail
-
discountAmount
final CardPurchaseSupplement.Invoice.Builder discountAmount(Long discountAmount)
Discount given to cardholder.
-
discountAmount
final CardPurchaseSupplement.Invoice.Builder discountAmount(Long discountAmount)
Alias for Builder.discountAmount.
This unboxed primitive overload exists for backwards compatibility.
-
discountAmount
final CardPurchaseSupplement.Invoice.Builder discountAmount(Optional<Long> discountAmount)
Alias for calling Builder.discountAmount with
discountAmount.orElse(null).
-
discountAmount
final CardPurchaseSupplement.Invoice.Builder discountAmount(JsonField<Long> discountAmount)
Sets Builder.discountAmount to an arbitrary JSON value.
You should usually call Builder.discountAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
discountCurrency
final CardPurchaseSupplement.Invoice.Builder discountCurrency(String discountCurrency)
The ISO 4217 code for the discount.
-
discountCurrency
final CardPurchaseSupplement.Invoice.Builder discountCurrency(Optional<String> discountCurrency)
Alias for calling Builder.discountCurrency with
discountCurrency.orElse(null).
-
discountCurrency
final CardPurchaseSupplement.Invoice.Builder discountCurrency(JsonField<String> discountCurrency)
Sets Builder.discountCurrency to an arbitrary JSON value.
You should usually call Builder.discountCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
discountTreatmentCode
final CardPurchaseSupplement.Invoice.Builder discountTreatmentCode(CardPurchaseSupplement.Invoice.DiscountTreatmentCode discountTreatmentCode)
Indicates how the merchant applied the discount.
-
discountTreatmentCode
final CardPurchaseSupplement.Invoice.Builder discountTreatmentCode(Optional<CardPurchaseSupplement.Invoice.DiscountTreatmentCode> discountTreatmentCode)
Alias for calling Builder.discountTreatmentCode with
discountTreatmentCode.orElse(null).
-
discountTreatmentCode
final CardPurchaseSupplement.Invoice.Builder discountTreatmentCode(JsonField<CardPurchaseSupplement.Invoice.DiscountTreatmentCode> discountTreatmentCode)
Sets Builder.discountTreatmentCode to an arbitrary JSON value.
You should usually call Builder.discountTreatmentCode with a well-typed DiscountTreatmentCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dutyTaxAmount
final CardPurchaseSupplement.Invoice.Builder dutyTaxAmount(Long dutyTaxAmount)
Amount of duty taxes.
-
dutyTaxAmount
final CardPurchaseSupplement.Invoice.Builder dutyTaxAmount(Long dutyTaxAmount)
Alias for Builder.dutyTaxAmount.
This unboxed primitive overload exists for backwards compatibility.
-
dutyTaxAmount
final CardPurchaseSupplement.Invoice.Builder dutyTaxAmount(Optional<Long> dutyTaxAmount)
Alias for calling Builder.dutyTaxAmount with
dutyTaxAmount.orElse(null).
-
dutyTaxAmount
final CardPurchaseSupplement.Invoice.Builder dutyTaxAmount(JsonField<Long> dutyTaxAmount)
Sets Builder.dutyTaxAmount to an arbitrary JSON value.
You should usually call Builder.dutyTaxAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dutyTaxCurrency
final CardPurchaseSupplement.Invoice.Builder dutyTaxCurrency(String dutyTaxCurrency)
The ISO 4217 code for the duty tax.
-
dutyTaxCurrency
final CardPurchaseSupplement.Invoice.Builder dutyTaxCurrency(Optional<String> dutyTaxCurrency)
Alias for calling Builder.dutyTaxCurrency with
dutyTaxCurrency.orElse(null).
-
dutyTaxCurrency
final CardPurchaseSupplement.Invoice.Builder dutyTaxCurrency(JsonField<String> dutyTaxCurrency)
Sets Builder.dutyTaxCurrency to an arbitrary JSON value.
You should usually call Builder.dutyTaxCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
orderDate
final CardPurchaseSupplement.Invoice.Builder orderDate(LocalDate orderDate)
Date the order was taken.
-
orderDate
final CardPurchaseSupplement.Invoice.Builder orderDate(Optional<LocalDate> orderDate)
Alias for calling Builder.orderDate with
orderDate.orElse(null).
-
orderDate
final CardPurchaseSupplement.Invoice.Builder orderDate(JsonField<LocalDate> orderDate)
Sets Builder.orderDate to an arbitrary JSON value.
You should usually call Builder.orderDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAmount
final CardPurchaseSupplement.Invoice.Builder shippingAmount(Long shippingAmount)
The shipping cost.
-
shippingAmount
final CardPurchaseSupplement.Invoice.Builder shippingAmount(Long shippingAmount)
Alias for Builder.shippingAmount.
This unboxed primitive overload exists for backwards compatibility.
-
shippingAmount
final CardPurchaseSupplement.Invoice.Builder shippingAmount(Optional<Long> shippingAmount)
Alias for calling Builder.shippingAmount with
shippingAmount.orElse(null).
-
shippingAmount
final CardPurchaseSupplement.Invoice.Builder shippingAmount(JsonField<Long> shippingAmount)
Sets Builder.shippingAmount to an arbitrary JSON value.
You should usually call Builder.shippingAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingCurrency
final CardPurchaseSupplement.Invoice.Builder shippingCurrency(String shippingCurrency)
The ISO 4217 code for the shipping cost.
-
shippingCurrency
final CardPurchaseSupplement.Invoice.Builder shippingCurrency(Optional<String> shippingCurrency)
Alias for calling Builder.shippingCurrency with
shippingCurrency.orElse(null).
-
shippingCurrency
final CardPurchaseSupplement.Invoice.Builder shippingCurrency(JsonField<String> shippingCurrency)
Sets Builder.shippingCurrency to an arbitrary JSON value.
You should usually call Builder.shippingCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingDestinationCountryCode
final CardPurchaseSupplement.Invoice.Builder shippingDestinationCountryCode(String shippingDestinationCountryCode)
Country code of the shipping destination.
-
shippingDestinationCountryCode
final CardPurchaseSupplement.Invoice.Builder shippingDestinationCountryCode(Optional<String> shippingDestinationCountryCode)
Alias for calling Builder.shippingDestinationCountryCode with
shippingDestinationCountryCode.orElse(null).
-
shippingDestinationCountryCode
final CardPurchaseSupplement.Invoice.Builder shippingDestinationCountryCode(JsonField<String> shippingDestinationCountryCode)
Sets Builder.shippingDestinationCountryCode to an arbitrary JSON value.
You should usually call Builder.shippingDestinationCountryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingDestinationPostalCode
final CardPurchaseSupplement.Invoice.Builder shippingDestinationPostalCode(String shippingDestinationPostalCode)
Postal code of the shipping destination.
-
shippingDestinationPostalCode
final CardPurchaseSupplement.Invoice.Builder shippingDestinationPostalCode(Optional<String> shippingDestinationPostalCode)
Alias for calling Builder.shippingDestinationPostalCode with
shippingDestinationPostalCode.orElse(null).
-
shippingDestinationPostalCode
final CardPurchaseSupplement.Invoice.Builder shippingDestinationPostalCode(JsonField<String> shippingDestinationPostalCode)
Sets Builder.shippingDestinationPostalCode to an arbitrary JSON value.
You should usually call Builder.shippingDestinationPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingSourcePostalCode
final CardPurchaseSupplement.Invoice.Builder shippingSourcePostalCode(String shippingSourcePostalCode)
Postal code of the location being shipped from.
-
shippingSourcePostalCode
final CardPurchaseSupplement.Invoice.Builder shippingSourcePostalCode(Optional<String> shippingSourcePostalCode)
Alias for calling Builder.shippingSourcePostalCode with
shippingSourcePostalCode.orElse(null).
-
shippingSourcePostalCode
final CardPurchaseSupplement.Invoice.Builder shippingSourcePostalCode(JsonField<String> shippingSourcePostalCode)
Sets Builder.shippingSourcePostalCode to an arbitrary JSON value.
You should usually call Builder.shippingSourcePostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingTaxAmount
final CardPurchaseSupplement.Invoice.Builder shippingTaxAmount(Long shippingTaxAmount)
Taxes paid for freight and shipping.
-
shippingTaxAmount
final CardPurchaseSupplement.Invoice.Builder shippingTaxAmount(Long shippingTaxAmount)
Alias for Builder.shippingTaxAmount.
This unboxed primitive overload exists for backwards compatibility.
-
shippingTaxAmount
final CardPurchaseSupplement.Invoice.Builder shippingTaxAmount(Optional<Long> shippingTaxAmount)
Alias for calling Builder.shippingTaxAmount with
shippingTaxAmount.orElse(null).
-
shippingTaxAmount
final CardPurchaseSupplement.Invoice.Builder shippingTaxAmount(JsonField<Long> shippingTaxAmount)
Sets Builder.shippingTaxAmount to an arbitrary JSON value.
You should usually call Builder.shippingTaxAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingTaxCurrency
final CardPurchaseSupplement.Invoice.Builder shippingTaxCurrency(String shippingTaxCurrency)
The ISO 4217 code for the shipping tax.
-
shippingTaxCurrency
final CardPurchaseSupplement.Invoice.Builder shippingTaxCurrency(Optional<String> shippingTaxCurrency)
Alias for calling Builder.shippingTaxCurrency with
shippingTaxCurrency.orElse(null).
-
shippingTaxCurrency
final CardPurchaseSupplement.Invoice.Builder shippingTaxCurrency(JsonField<String> shippingTaxCurrency)
Sets Builder.shippingTaxCurrency to an arbitrary JSON value.
You should usually call Builder.shippingTaxCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingTaxRate
final CardPurchaseSupplement.Invoice.Builder shippingTaxRate(String shippingTaxRate)
Tax rate for freight and shipping.
-
shippingTaxRate
final CardPurchaseSupplement.Invoice.Builder shippingTaxRate(Optional<String> shippingTaxRate)
Alias for calling Builder.shippingTaxRate with
shippingTaxRate.orElse(null).
-
shippingTaxRate
final CardPurchaseSupplement.Invoice.Builder shippingTaxRate(JsonField<String> shippingTaxRate)
Sets Builder.shippingTaxRate to an arbitrary JSON value.
You should usually call Builder.shippingTaxRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxTreatments
final CardPurchaseSupplement.Invoice.Builder taxTreatments(CardPurchaseSupplement.Invoice.TaxTreatments taxTreatments)
Indicates how the merchant applied taxes.
-
taxTreatments
final CardPurchaseSupplement.Invoice.Builder taxTreatments(Optional<CardPurchaseSupplement.Invoice.TaxTreatments> taxTreatments)
Alias for calling Builder.taxTreatments with
taxTreatments.orElse(null).
-
taxTreatments
final CardPurchaseSupplement.Invoice.Builder taxTreatments(JsonField<CardPurchaseSupplement.Invoice.TaxTreatments> taxTreatments)
Sets Builder.taxTreatments to an arbitrary JSON value.
You should usually call Builder.taxTreatments with a well-typed TaxTreatments value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueValueAddedTaxInvoiceReference
final CardPurchaseSupplement.Invoice.Builder uniqueValueAddedTaxInvoiceReference(String uniqueValueAddedTaxInvoiceReference)
Value added tax invoice reference number.
-
uniqueValueAddedTaxInvoiceReference
final CardPurchaseSupplement.Invoice.Builder uniqueValueAddedTaxInvoiceReference(Optional<String> uniqueValueAddedTaxInvoiceReference)
Alias for calling Builder.uniqueValueAddedTaxInvoiceReference with
uniqueValueAddedTaxInvoiceReference.orElse(null).
-
uniqueValueAddedTaxInvoiceReference
final CardPurchaseSupplement.Invoice.Builder uniqueValueAddedTaxInvoiceReference(JsonField<String> uniqueValueAddedTaxInvoiceReference)
Sets Builder.uniqueValueAddedTaxInvoiceReference to an arbitrary JSON value.
You should usually call Builder.uniqueValueAddedTaxInvoiceReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPurchaseSupplement.Invoice.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPurchaseSupplement.Invoice.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPurchaseSupplement.Invoice.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPurchaseSupplement.Invoice.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPurchaseSupplement.Invoice.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPurchaseSupplement.Invoice build()
Returns an immutable instance of Invoice.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.discountAmount() .discountCurrency() .discountTreatmentCode() .dutyTaxAmount() .dutyTaxCurrency() .orderDate() .shippingAmount() .shippingCurrency() .shippingDestinationCountryCode() .shippingDestinationPostalCode() .shippingSourcePostalCode() .shippingTaxAmount() .shippingTaxCurrency() .shippingTaxRate() .taxTreatments() .uniqueValueAddedTaxInvoiceReference()
-
-
-
-