Class CardPurchaseSupplement.LineItem
-
- All Implemented Interfaces:
public final class CardPurchaseSupplement.LineItem
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplement.LineItem.BuilderA builder for LineItem.
public final classCardPurchaseSupplement.LineItem.DetailIndicatorIndicates the type of line item.
public final classCardPurchaseSupplement.LineItem.DiscountTreatmentCodeIndicates how the merchant applied the discount for this specific line item.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Purchase Supplement Line Item identifier. final Optional<CardPurchaseSupplement.LineItem.DetailIndicator>detailIndicator()Indicates the type of line item. final Optional<Long>discountAmount()Discount amount for this specific line item. final Optional<String>discountCurrency()The ISO 4217 code for the discount. final Optional<CardPurchaseSupplement.LineItem.DiscountTreatmentCode>discountTreatmentCode()Indicates how the merchant applied the discount for this specific line item. final Optional<String>itemCommodityCode()Code used to categorize the purchase item. final Optional<String>itemDescriptor()Description of the purchase item. final Optional<String>itemQuantity()The number of units of the product being purchased. final Optional<String>productCode()Code used to categorize the product being purchased. final Optional<Long>salesTaxAmount()Sales tax amount for this line item. final Optional<String>salesTaxCurrency()The ISO 4217 code for the sales tax assessed. final Optional<String>salesTaxRate()Sales tax rate for this line item. final Optional<Long>totalAmount()Total amount of all line items. final Optional<String>totalAmountCurrency()The ISO 4217 code for the total amount. final Optional<String>unitCost()Cost of line item per unit of measure, in major units. final Optional<String>unitCostCurrency()The ISO 4217 code for the unit cost. final Optional<String>unitOfMeasureCode()Code indicating unit of measure (gallons, etc.). final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CardPurchaseSupplement.LineItem.DetailIndicator>_detailIndicator()Returns the raw JSON value of detailIndicator. final JsonField<Long>_discountAmount()Returns the raw JSON value of discountAmount. final JsonField<String>_discountCurrency()Returns the raw JSON value of discountCurrency. final JsonField<CardPurchaseSupplement.LineItem.DiscountTreatmentCode>_discountTreatmentCode()Returns the raw JSON value of discountTreatmentCode. final JsonField<String>_itemCommodityCode()Returns the raw JSON value of itemCommodityCode. final JsonField<String>_itemDescriptor()Returns the raw JSON value of itemDescriptor. final JsonField<String>_itemQuantity()Returns the raw JSON value of itemQuantity. final JsonField<String>_productCode()Returns the raw JSON value of productCode. final JsonField<Long>_salesTaxAmount()Returns the raw JSON value of salesTaxAmount. final JsonField<String>_salesTaxCurrency()Returns the raw JSON value of salesTaxCurrency. final JsonField<String>_salesTaxRate()Returns the raw JSON value of salesTaxRate. final JsonField<Long>_totalAmount()Returns the raw JSON value of totalAmount. final JsonField<String>_totalAmountCurrency()Returns the raw JSON value of totalAmountCurrency. final JsonField<String>_unitCost()Returns the raw JSON value of unitCost. final JsonField<String>_unitCostCurrency()Returns the raw JSON value of unitCostCurrency. final JsonField<String>_unitOfMeasureCode()Returns the raw JSON value of unitOfMeasureCode. final Map<String, JsonValue>_additionalProperties()final CardPurchaseSupplement.LineItem.BuildertoBuilder()final CardPurchaseSupplement.LineItemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPurchaseSupplement.LineItem.Builderbuilder()Returns a mutable builder for constructing an instance of LineItem. -
-
Method Detail
-
detailIndicator
final Optional<CardPurchaseSupplement.LineItem.DetailIndicator> detailIndicator()
Indicates the type of line item.
-
discountAmount
final Optional<Long> discountAmount()
Discount amount for this specific line item.
-
discountCurrency
final Optional<String> discountCurrency()
The ISO 4217 code for the discount.
-
discountTreatmentCode
final Optional<CardPurchaseSupplement.LineItem.DiscountTreatmentCode> discountTreatmentCode()
Indicates how the merchant applied the discount for this specific line item.
-
itemCommodityCode
final Optional<String> itemCommodityCode()
Code used to categorize the purchase item.
-
itemDescriptor
final Optional<String> itemDescriptor()
Description of the purchase item.
-
itemQuantity
final Optional<String> itemQuantity()
The number of units of the product being purchased.
-
productCode
final Optional<String> productCode()
Code used to categorize the product being purchased.
-
salesTaxAmount
final Optional<Long> salesTaxAmount()
Sales tax amount for this line item.
-
salesTaxCurrency
final Optional<String> salesTaxCurrency()
The ISO 4217 code for the sales tax assessed.
-
salesTaxRate
final Optional<String> salesTaxRate()
Sales tax rate for this line item.
-
totalAmount
final Optional<Long> totalAmount()
Total amount of all line items.
-
totalAmountCurrency
final Optional<String> totalAmountCurrency()
The ISO 4217 code for the total amount.
-
unitCostCurrency
final Optional<String> unitCostCurrency()
The ISO 4217 code for the unit cost.
-
unitOfMeasureCode
final Optional<String> unitOfMeasureCode()
Code indicating unit of measure (gallons, etc.).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_detailIndicator
final JsonField<CardPurchaseSupplement.LineItem.DetailIndicator> _detailIndicator()
Returns the raw JSON value of detailIndicator.
Unlike detailIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_discountAmount
final JsonField<Long> _discountAmount()
Returns the raw JSON value of discountAmount.
Unlike discountAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_discountCurrency
final JsonField<String> _discountCurrency()
Returns the raw JSON value of discountCurrency.
Unlike discountCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_discountTreatmentCode
final JsonField<CardPurchaseSupplement.LineItem.DiscountTreatmentCode> _discountTreatmentCode()
Returns the raw JSON value of discountTreatmentCode.
Unlike discountTreatmentCode, this method doesn't throw if the JSON field has an unexpected type.
-
_itemCommodityCode
final JsonField<String> _itemCommodityCode()
Returns the raw JSON value of itemCommodityCode.
Unlike itemCommodityCode, this method doesn't throw if the JSON field has an unexpected type.
-
_itemDescriptor
final JsonField<String> _itemDescriptor()
Returns the raw JSON value of itemDescriptor.
Unlike itemDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_itemQuantity
final JsonField<String> _itemQuantity()
Returns the raw JSON value of itemQuantity.
Unlike itemQuantity, this method doesn't throw if the JSON field has an unexpected type.
-
_productCode
final JsonField<String> _productCode()
Returns the raw JSON value of productCode.
Unlike productCode, this method doesn't throw if the JSON field has an unexpected type.
-
_salesTaxAmount
final JsonField<Long> _salesTaxAmount()
Returns the raw JSON value of salesTaxAmount.
Unlike salesTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_salesTaxCurrency
final JsonField<String> _salesTaxCurrency()
Returns the raw JSON value of salesTaxCurrency.
Unlike salesTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_salesTaxRate
final JsonField<String> _salesTaxRate()
Returns the raw JSON value of salesTaxRate.
Unlike salesTaxRate, this method doesn't throw if the JSON field has an unexpected type.
-
_totalAmount
final JsonField<Long> _totalAmount()
Returns the raw JSON value of totalAmount.
Unlike totalAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_totalAmountCurrency
final JsonField<String> _totalAmountCurrency()
Returns the raw JSON value of totalAmountCurrency.
Unlike totalAmountCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_unitCost
final JsonField<String> _unitCost()
Returns the raw JSON value of unitCost.
Unlike unitCost, this method doesn't throw if the JSON field has an unexpected type.
-
_unitCostCurrency
final JsonField<String> _unitCostCurrency()
Returns the raw JSON value of unitCostCurrency.
Unlike unitCostCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_unitOfMeasureCode
final JsonField<String> _unitOfMeasureCode()
Returns the raw JSON value of unitOfMeasureCode.
Unlike unitOfMeasureCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPurchaseSupplement.LineItem.Builder toBuilder()
-
validate
final CardPurchaseSupplement.LineItem validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPurchaseSupplement.LineItem.Builder builder()
Returns a mutable builder for constructing an instance of LineItem.
The following fields are required:
.id() .detailIndicator() .discountAmount() .discountCurrency() .discountTreatmentCode() .itemCommodityCode() .itemDescriptor() .itemQuantity() .productCode() .salesTaxAmount() .salesTaxCurrency() .salesTaxRate() .totalAmount() .totalAmountCurrency() .unitCost() .unitCostCurrency() .unitOfMeasureCode()
-
-
-
-