Enum CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value extends Enum<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value>
An enum containing DiscountTreatmentCode's known values, as well as an _UNKNOWN member.
An instance of DiscountTreatmentCode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NO_LINE_ITEM_LEVEL_DISCOUNT_PROVIDEDNo line item level discount provided
TAX_CALCULATED_ON_POST_DISCOUNT_LINE_ITEM_TOTALTax calculated on post discount line item total
TAX_CALCULATED_ON_PRE_DISCOUNT_LINE_ITEM_TOTALTax calculated on pre discount line item total
_UNKNOWNAn enum member indicating that DiscountTreatmentCode was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardPurchaseSupplement.LineItem.DiscountTreatmentCode.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value>getEntries()An enum containing DiscountTreatmentCode's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPurchaseSupplement.LineItem.DiscountTreatmentCode.Value> getEntries()
An enum containing DiscountTreatmentCode's known values, as well as an _UNKNOWN member.
An instance of DiscountTreatmentCode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-