Class CardPurchaseSupplementListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class CardPurchaseSupplementListPage implements Page<CardPurchaseSupplement>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplementListPage.BuilderA builder for CardPurchaseSupplementListPage.
-
Method Summary
Modifier and Type Method Description final List<CardPurchaseSupplement>data()Delegates to CardPurchaseSupplementListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to CardPurchaseSupplementListPageResponse, but gracefully handles missing data. List<CardPurchaseSupplement>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final CardPurchaseSupplementListParamsnextPageParams()CardPurchaseSupplementListPagenextPage()Returns the page after this one by making another request. final AutoPager<CardPurchaseSupplement>autoPager()final CardPurchaseSupplementListParamsparams()The parameters that were used to request this page. final CardPurchaseSupplementListPageResponseresponse()The response that this page was parsed from. final CardPurchaseSupplementListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPurchaseSupplementListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardPurchaseSupplementListPage. -
-
Method Detail
-
data
final List<CardPurchaseSupplement> data()
Delegates to CardPurchaseSupplementListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CardPurchaseSupplementListPageResponse, but gracefully handles missing data.
-
items
List<CardPurchaseSupplement> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final CardPurchaseSupplementListParams nextPageParams()
-
nextPage
CardPurchaseSupplementListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<CardPurchaseSupplement> autoPager()
-
params
final CardPurchaseSupplementListParams params()
The parameters that were used to request this page.
-
response
final CardPurchaseSupplementListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardPurchaseSupplementListPage.Builder toBuilder()
-
builder
final static CardPurchaseSupplementListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardPurchaseSupplementListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-