Class CardPurchaseSupplementListPageAsync
-
- All Implemented Interfaces:
public final class CardPurchaseSupplementListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplementListPageAsync.BuilderA builder for CardPurchaseSupplementListPageAsync.
public final classCardPurchaseSupplementListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<CardPurchaseSupplement> data()
Delegates to CardPurchaseSupplementListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CardPurchaseSupplementListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CardPurchaseSupplementListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CardPurchaseSupplementListPageAsync>> getNextPage()
-
autoPager
final CardPurchaseSupplementListPageAsync.AutoPager autoPager()
-
params
final CardPurchaseSupplementListParams params()
The parameters that were used to request this page.
-
response
final CardPurchaseSupplementListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardPurchaseSupplementListPageAsync.Builder toBuilder()
-
builder
final static CardPurchaseSupplementListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CardPurchaseSupplementListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-