Class CardPurchaseSupplementListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardPurchaseSupplementListPageAsync.BuilderA builder for CardPurchaseSupplementListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardPurchaseSupplementListPageAsync.Builderservice(CardPurchaseSupplementServiceAsync service)final CardPurchaseSupplementListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CardPurchaseSupplementListPageAsync.Builderparams(CardPurchaseSupplementListParams params)The parameters that were used to request this page. final CardPurchaseSupplementListPageAsync.Builderresponse(CardPurchaseSupplementListPageResponse response)The response that this page was parsed from. final CardPurchaseSupplementListPageAsyncbuild()Returns an immutable instance of CardPurchaseSupplementListPageAsync. -
-
Method Detail
-
service
final CardPurchaseSupplementListPageAsync.Builder service(CardPurchaseSupplementServiceAsync service)
-
streamHandlerExecutor
final CardPurchaseSupplementListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CardPurchaseSupplementListPageAsync.Builder params(CardPurchaseSupplementListParams params)
The parameters that were used to request this page.
-
response
final CardPurchaseSupplementListPageAsync.Builder response(CardPurchaseSupplementListPageResponse response)
The response that this page was parsed from.
-
build
final CardPurchaseSupplementListPageAsync build()
Returns an immutable instance of CardPurchaseSupplementListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-