Class CardPushTransfer
-
- All Implemented Interfaces:
public final class CardPushTransferCard Push Transfers send funds to a recipient's payment card in real-time.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.BuilderA builder for CardPushTransfer.
public final classCardPushTransfer.AcceptanceIf the transfer is accepted by the recipient bank, this will contain supplemental details.
public final classCardPushTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classCardPushTransfer.BusinessApplicationIdentifierThe Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
public final classCardPushTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classCardPushTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classCardPushTransfer.DeclineIf the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.
public final classCardPushTransfer.PresentmentAmountThe amount that was transferred. The receiving bank will have converted this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
public final classCardPushTransfer.RouteThe card network route used for the transfer.
public final classCardPushTransfer.StatusThe lifecycle status of the transfer.
public final classCardPushTransfer.SubmissionAfter the transfer is submitted to the card network, this will contain supplemental details.
public final classCardPushTransfer.TypeA constant representing the object's type. For this resource it will always be
card_push_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Push Transfer's identifier. final Optional<CardPushTransfer.Acceptance>acceptance()If the transfer is accepted by the recipient bank, this will contain supplemental details. final StringaccountId()The Account from which the transfer was sent. final Optional<CardPushTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final CardPushTransfer.BusinessApplicationIdentifierbusinessApplicationIdentifier()The Business Application Identifier describes the type of transaction being performed. final Optional<CardPushTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final StringcardTokenId()The ID of the Card Token that was used to validate the card. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<CardPushTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final Optional<CardPushTransfer.Decline>decline()If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringmerchantCategoryCode()The merchant category code (MCC) of the merchant (generally your business) sending the transfer. final StringmerchantCityName()The city name of the merchant (generally your business) sending the transfer. final Optional<String>merchantLegalBusinessName()The legal business name of the merchant (generally your business) sending the transfer. final StringmerchantName()The merchant name shows up as the statement descriptor for the transfer. final StringmerchantNamePrefix()For certain Business Application Identifiers, the statement descriptor is merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.final StringmerchantPostalCode()The postal code of the merchant (generally your business) sending the transfer. final StringmerchantState()The state of the merchant (generally your business) sending the transfer. final Optional<String>merchantStreetAddress()The street address of the merchant (generally your business) sending the transfer. final CardPushTransfer.PresentmentAmountpresentmentAmount()The amount that was transferred. final Optional<String>recipientAddressCity()The city of the recipient. final Optional<String>recipientAddressLine1()The first line of the recipient's address. final Optional<String>recipientAddressPostalCode()The postal code of the recipient. final Optional<String>recipientAddressState()The state or province of the recipient. final StringrecipientName()The name of the funds recipient. final CardPushTransfer.Routeroute()The card network route used for the transfer. final StringsenderAddressCity()The city of the sender. final StringsenderAddressLine1()The address line 1 of the sender. final StringsenderAddressPostalCode()The postal code of the sender. final StringsenderAddressState()The state of the sender. final StringsenderName()The name of the funds originator. final StringsourceAccountNumberId()The Account Number the recipient will see as having sent the transfer. final CardPushTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<CardPushTransfer.Submission>submission()After the transfer is submitted to the card network, this will contain supplemental details. final CardPushTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CardPushTransfer.Acceptance>_acceptance()Returns the raw JSON value of acceptance. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<CardPushTransfer.Approval>_approval()Returns the raw JSON value of approval. final JsonField<CardPushTransfer.BusinessApplicationIdentifier>_businessApplicationIdentifier()Returns the raw JSON value of businessApplicationIdentifier. final JsonField<CardPushTransfer.Cancellation>_cancellation()Returns the raw JSON value of cancellation. final JsonField<String>_cardTokenId()Returns the raw JSON value of cardTokenId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CardPushTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<CardPushTransfer.Decline>_decline()Returns the raw JSON value of decline. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCityName()Returns the raw JSON value of merchantCityName. final JsonField<String>_merchantLegalBusinessName()Returns the raw JSON value of merchantLegalBusinessName. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<String>_merchantNamePrefix()Returns the raw JSON value of merchantNamePrefix. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<String>_merchantStreetAddress()Returns the raw JSON value of merchantStreetAddress. final JsonField<CardPushTransfer.PresentmentAmount>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_recipientAddressCity()Returns the raw JSON value of recipientAddressCity. final JsonField<String>_recipientAddressLine1()Returns the raw JSON value of recipientAddressLine1. final JsonField<String>_recipientAddressPostalCode()Returns the raw JSON value of recipientAddressPostalCode. final JsonField<String>_recipientAddressState()Returns the raw JSON value of recipientAddressState. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<CardPushTransfer.Route>_route()Returns the raw JSON value of route. final JsonField<String>_senderAddressCity()Returns the raw JSON value of senderAddressCity. final JsonField<String>_senderAddressLine1()Returns the raw JSON value of senderAddressLine1. final JsonField<String>_senderAddressPostalCode()Returns the raw JSON value of senderAddressPostalCode. final JsonField<String>_senderAddressState()Returns the raw JSON value of senderAddressState. final JsonField<String>_senderName()Returns the raw JSON value of senderName. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<CardPushTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<CardPushTransfer.Submission>_submission()Returns the raw JSON value of submission. final JsonField<CardPushTransfer.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardPushTransfer.BuildertoBuilder()final CardPushTransfervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of CardPushTransfer. -
-
Method Detail
-
acceptance
final Optional<CardPushTransfer.Acceptance> acceptance()
If the transfer is accepted by the recipient bank, this will contain supplemental details.
-
approval
final Optional<CardPushTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
businessApplicationIdentifier
final CardPushTransfer.BusinessApplicationIdentifier businessApplicationIdentifier()
The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
-
cancellation
final Optional<CardPushTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cardTokenId
final String cardTokenId()
The ID of the Card Token that was used to validate the card.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<CardPushTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
decline
final Optional<CardPushTransfer.Decline> decline()
If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
merchantCategoryCode
final String merchantCategoryCode()
The merchant category code (MCC) of the merchant (generally your business) sending the transfer. This is a four-digit code that describes the type of business or service provided by the merchant. Your program must be approved for the specified MCC in order to use it.
-
merchantCityName
final String merchantCityName()
The city name of the merchant (generally your business) sending the transfer.
-
merchantLegalBusinessName
final Optional<String> merchantLegalBusinessName()
The legal business name of the merchant (generally your business) sending the transfer.
-
merchantName
final String merchantName()
The merchant name shows up as the statement descriptor for the transfer. This is typically the name of your business or organization.
-
merchantNamePrefix
final String merchantNamePrefix()
For certain Business Application Identifiers, the statement descriptor is
merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.
-
merchantPostalCode
final String merchantPostalCode()
The postal code of the merchant (generally your business) sending the transfer.
-
merchantState
final String merchantState()
The state of the merchant (generally your business) sending the transfer.
-
merchantStreetAddress
final Optional<String> merchantStreetAddress()
The street address of the merchant (generally your business) sending the transfer.
-
presentmentAmount
final CardPushTransfer.PresentmentAmount presentmentAmount()
The amount that was transferred. The receiving bank will have converted this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
recipientAddressCity
final Optional<String> recipientAddressCity()
The city of the recipient. Required if the card is issued in Canada.
-
recipientAddressLine1
final Optional<String> recipientAddressLine1()
The first line of the recipient's address. Required if the card is issued in Canada.
-
recipientAddressPostalCode
final Optional<String> recipientAddressPostalCode()
The postal code of the recipient. Required if the card is issued in Canada.
-
recipientAddressState
final Optional<String> recipientAddressState()
The state or province of the recipient. Required if the card is issued in Canada.
-
recipientName
final String recipientName()
The name of the funds recipient.
-
route
final CardPushTransfer.Route route()
The card network route used for the transfer.
-
senderAddressCity
final String senderAddressCity()
The city of the sender.
-
senderAddressLine1
final String senderAddressLine1()
The address line 1 of the sender.
-
senderAddressPostalCode
final String senderAddressPostalCode()
The postal code of the sender.
-
senderAddressState
final String senderAddressState()
The state of the sender.
-
senderName
final String senderName()
The name of the funds originator.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number the recipient will see as having sent the transfer.
-
status
final CardPushTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<CardPushTransfer.Submission> submission()
After the transfer is submitted to the card network, this will contain supplemental details.
-
type
final CardPushTransfer.Type type()
A constant representing the object's type. For this resource it will always be
card_push_transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptance
final JsonField<CardPushTransfer.Acceptance> _acceptance()
Returns the raw JSON value of acceptance.
Unlike acceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_approval
final JsonField<CardPushTransfer.Approval> _approval()
Returns the raw JSON value of approval.
Unlike approval, this method doesn't throw if the JSON field has an unexpected type.
-
_businessApplicationIdentifier
final JsonField<CardPushTransfer.BusinessApplicationIdentifier> _businessApplicationIdentifier()
Returns the raw JSON value of businessApplicationIdentifier.
Unlike businessApplicationIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_cancellation
final JsonField<CardPushTransfer.Cancellation> _cancellation()
Returns the raw JSON value of cancellation.
Unlike cancellation, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokenId
final JsonField<String> _cardTokenId()
Returns the raw JSON value of cardTokenId.
Unlike cardTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<CardPushTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_decline
final JsonField<CardPushTransfer.Decline> _decline()
Returns the raw JSON value of decline.
Unlike decline, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCityName
final JsonField<String> _merchantCityName()
Returns the raw JSON value of merchantCityName.
Unlike merchantCityName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantLegalBusinessName
final JsonField<String> _merchantLegalBusinessName()
Returns the raw JSON value of merchantLegalBusinessName.
Unlike merchantLegalBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantNamePrefix
final JsonField<String> _merchantNamePrefix()
Returns the raw JSON value of merchantNamePrefix.
Unlike merchantNamePrefix, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantStreetAddress
final JsonField<String> _merchantStreetAddress()
Returns the raw JSON value of merchantStreetAddress.
Unlike merchantStreetAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<CardPushTransfer.PresentmentAmount> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressCity
final JsonField<String> _recipientAddressCity()
Returns the raw JSON value of recipientAddressCity.
Unlike recipientAddressCity, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine1
final JsonField<String> _recipientAddressLine1()
Returns the raw JSON value of recipientAddressLine1.
Unlike recipientAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressPostalCode
final JsonField<String> _recipientAddressPostalCode()
Returns the raw JSON value of recipientAddressPostalCode.
Unlike recipientAddressPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressState
final JsonField<String> _recipientAddressState()
Returns the raw JSON value of recipientAddressState.
Unlike recipientAddressState, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<CardPushTransfer.Route> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressCity
final JsonField<String> _senderAddressCity()
Returns the raw JSON value of senderAddressCity.
Unlike senderAddressCity, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressLine1
final JsonField<String> _senderAddressLine1()
Returns the raw JSON value of senderAddressLine1.
Unlike senderAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressPostalCode
final JsonField<String> _senderAddressPostalCode()
Returns the raw JSON value of senderAddressPostalCode.
Unlike senderAddressPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressState
final JsonField<String> _senderAddressState()
Returns the raw JSON value of senderAddressState.
Unlike senderAddressState, this method doesn't throw if the JSON field has an unexpected type.
-
_senderName
final JsonField<String> _senderName()
Returns the raw JSON value of senderName.
Unlike senderName, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardPushTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<CardPushTransfer.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPushTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.Builder toBuilder()
-
validate
final CardPushTransfer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPushTransfer.Builder builder()
Returns a mutable builder for constructing an instance of CardPushTransfer.
The following fields are required:
.id() .acceptance() .accountId() .approval() .businessApplicationIdentifier() .cancellation() .cardTokenId() .createdAt() .createdBy() .decline() .idempotencyKey() .merchantCategoryCode() .merchantCityName() .merchantLegalBusinessName() .merchantName() .merchantNamePrefix() .merchantPostalCode() .merchantState() .merchantStreetAddress() .presentmentAmount() .recipientAddressCity() .recipientAddressLine1() .recipientAddressPostalCode() .recipientAddressState() .recipientName() .route() .senderAddressCity() .senderAddressLine1() .senderAddressPostalCode() .senderAddressState() .senderName() .sourceAccountNumberId() .status() .submission() .type()
-
-
-
-