Class CardPushTransfer.Acceptance
-
- All Implemented Interfaces:
public final class CardPushTransfer.AcceptanceIf the transfer is accepted by the recipient bank, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.Acceptance.BuilderA builder for Acceptance.
public final classCardPushTransfer.Acceptance.CardVerificationValue2ResultThe result of the Card Verification Value 2 match.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The ISO 8601 date and time at which the transfer was accepted by the issuing bank. final StringauthorizationIdentificationResponse()The authorization identification response from the issuing bank. final Optional<CardPushTransfer.Acceptance.CardVerificationValue2Result>cardVerificationValue2Result()The result of the Card Verification Value 2 match. final Optional<String>networkTransactionIdentifier()A unique identifier for the transaction on the card network. final LongsettlementAmount()The transfer amount in USD cents. final JsonField<OffsetDateTime>_acceptedAt()Returns the raw JSON value of acceptedAt. final JsonField<String>_authorizationIdentificationResponse()Returns the raw JSON value of authorizationIdentificationResponse. final JsonField<CardPushTransfer.Acceptance.CardVerificationValue2Result>_cardVerificationValue2Result()Returns the raw JSON value of cardVerificationValue2Result. final JsonField<String>_networkTransactionIdentifier()Returns the raw JSON value of networkTransactionIdentifier. final JsonField<Long>_settlementAmount()Returns the raw JSON value of settlementAmount. final Map<String, JsonValue>_additionalProperties()final CardPushTransfer.Acceptance.BuildertoBuilder()final CardPushTransfer.Acceptancevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransfer.Acceptance.Builderbuilder()Returns a mutable builder for constructing an instance of Acceptance. -
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the transfer was accepted by the issuing bank.
-
authorizationIdentificationResponse
final String authorizationIdentificationResponse()
The authorization identification response from the issuing bank.
-
cardVerificationValue2Result
final Optional<CardPushTransfer.Acceptance.CardVerificationValue2Result> cardVerificationValue2Result()
The result of the Card Verification Value 2 match.
-
networkTransactionIdentifier
final Optional<String> networkTransactionIdentifier()
A unique identifier for the transaction on the card network.
-
settlementAmount
final Long settlementAmount()
The transfer amount in USD cents.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationIdentificationResponse
final JsonField<String> _authorizationIdentificationResponse()
Returns the raw JSON value of authorizationIdentificationResponse.
Unlike authorizationIdentificationResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_cardVerificationValue2Result
final JsonField<CardPushTransfer.Acceptance.CardVerificationValue2Result> _cardVerificationValue2Result()
Returns the raw JSON value of cardVerificationValue2Result.
Unlike cardVerificationValue2Result, this method doesn't throw if the JSON field has an unexpected type.
-
_networkTransactionIdentifier
final JsonField<String> _networkTransactionIdentifier()
Returns the raw JSON value of networkTransactionIdentifier.
Unlike networkTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.Acceptance.Builder toBuilder()
-
validate
final CardPushTransfer.Acceptance validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPushTransfer.Acceptance.Builder builder()
Returns a mutable builder for constructing an instance of Acceptance.
The following fields are required:
.acceptedAt() .authorizationIdentificationResponse() .cardVerificationValue2Result() .networkTransactionIdentifier() .settlementAmount()
-
-
-
-