Class CardPushTransfer.Acceptance.Builder
-
- All Implemented Interfaces:
public final class CardPushTransfer.Acceptance.BuilderA builder for Acceptance.
-
-
Method Summary
-
-
Method Detail
-
acceptedAt
final CardPushTransfer.Acceptance.Builder acceptedAt(OffsetDateTime acceptedAt)
The ISO 8601 date and time at which the transfer was accepted by the issuing bank.
-
acceptedAt
final CardPushTransfer.Acceptance.Builder acceptedAt(JsonField<OffsetDateTime> acceptedAt)
Sets Builder.acceptedAt to an arbitrary JSON value.
You should usually call Builder.acceptedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizationIdentificationResponse
final CardPushTransfer.Acceptance.Builder authorizationIdentificationResponse(String authorizationIdentificationResponse)
The authorization identification response from the issuing bank.
-
authorizationIdentificationResponse
final CardPushTransfer.Acceptance.Builder authorizationIdentificationResponse(JsonField<String> authorizationIdentificationResponse)
Sets Builder.authorizationIdentificationResponse to an arbitrary JSON value.
You should usually call Builder.authorizationIdentificationResponse with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardVerificationValue2Result
final CardPushTransfer.Acceptance.Builder cardVerificationValue2Result(CardPushTransfer.Acceptance.CardVerificationValue2Result cardVerificationValue2Result)
The result of the Card Verification Value 2 match.
-
cardVerificationValue2Result
final CardPushTransfer.Acceptance.Builder cardVerificationValue2Result(Optional<CardPushTransfer.Acceptance.CardVerificationValue2Result> cardVerificationValue2Result)
Alias for calling Builder.cardVerificationValue2Result with
cardVerificationValue2Result.orElse(null).
-
cardVerificationValue2Result
final CardPushTransfer.Acceptance.Builder cardVerificationValue2Result(JsonField<CardPushTransfer.Acceptance.CardVerificationValue2Result> cardVerificationValue2Result)
Sets Builder.cardVerificationValue2Result to an arbitrary JSON value.
You should usually call Builder.cardVerificationValue2Result with a well-typed CardVerificationValue2Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkTransactionIdentifier
final CardPushTransfer.Acceptance.Builder networkTransactionIdentifier(String networkTransactionIdentifier)
A unique identifier for the transaction on the card network.
-
networkTransactionIdentifier
final CardPushTransfer.Acceptance.Builder networkTransactionIdentifier(Optional<String> networkTransactionIdentifier)
Alias for calling Builder.networkTransactionIdentifier with
networkTransactionIdentifier.orElse(null).
-
networkTransactionIdentifier
final CardPushTransfer.Acceptance.Builder networkTransactionIdentifier(JsonField<String> networkTransactionIdentifier)
Sets Builder.networkTransactionIdentifier to an arbitrary JSON value.
You should usually call Builder.networkTransactionIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlementAmount
final CardPushTransfer.Acceptance.Builder settlementAmount(Long settlementAmount)
The transfer amount in USD cents.
-
settlementAmount
final CardPushTransfer.Acceptance.Builder settlementAmount(JsonField<Long> settlementAmount)
Sets Builder.settlementAmount to an arbitrary JSON value.
You should usually call Builder.settlementAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPushTransfer.Acceptance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPushTransfer.Acceptance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPushTransfer.Acceptance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPushTransfer.Acceptance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPushTransfer.Acceptance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPushTransfer.Acceptance build()
Returns an immutable instance of Acceptance.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.acceptedAt() .authorizationIdentificationResponse() .cardVerificationValue2Result() .networkTransactionIdentifier() .settlementAmount()
-
-
-
-