Class CardPushTransfer.Builder
-
- All Implemented Interfaces:
public final class CardPushTransfer.BuilderA builder for CardPushTransfer.
-
-
Method Summary
Modifier and Type Method Description final CardPushTransfer.Builderid(String id)The Card Push Transfer's identifier. final CardPushTransfer.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final CardPushTransfer.Builderacceptance(CardPushTransfer.Acceptance acceptance)If the transfer is accepted by the recipient bank, this will contain supplemental details. final CardPushTransfer.Builderacceptance(Optional<CardPushTransfer.Acceptance> acceptance)Alias for calling Builder.acceptance with acceptance.orElse(null).final CardPushTransfer.Builderacceptance(JsonField<CardPushTransfer.Acceptance> acceptance)Sets Builder.acceptance to an arbitrary JSON value. final CardPushTransfer.BuilderaccountId(String accountId)The Account from which the transfer was sent. final CardPushTransfer.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final CardPushTransfer.Builderapproval(CardPushTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final CardPushTransfer.Builderapproval(Optional<CardPushTransfer.Approval> approval)Alias for calling Builder.approval with approval.orElse(null).final CardPushTransfer.Builderapproval(JsonField<CardPushTransfer.Approval> approval)Sets Builder.approval to an arbitrary JSON value. final CardPushTransfer.BuilderbusinessApplicationIdentifier(CardPushTransfer.BusinessApplicationIdentifier businessApplicationIdentifier)The Business Application Identifier describes the type of transaction being performed. final CardPushTransfer.BuilderbusinessApplicationIdentifier(JsonField<CardPushTransfer.BusinessApplicationIdentifier> businessApplicationIdentifier)Sets Builder.businessApplicationIdentifier to an arbitrary JSON value. final CardPushTransfer.Buildercancellation(CardPushTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final CardPushTransfer.Buildercancellation(Optional<CardPushTransfer.Cancellation> cancellation)Alias for calling Builder.cancellation with cancellation.orElse(null).final CardPushTransfer.Buildercancellation(JsonField<CardPushTransfer.Cancellation> cancellation)Sets Builder.cancellation to an arbitrary JSON value. final CardPushTransfer.BuildercardTokenId(String cardTokenId)The ID of the Card Token that was used to validate the card. final CardPushTransfer.BuildercardTokenId(JsonField<String> cardTokenId)Sets Builder.cardTokenId to an arbitrary JSON value. final CardPushTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final CardPushTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final CardPushTransfer.BuildercreatedBy(CardPushTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final CardPushTransfer.BuildercreatedBy(Optional<CardPushTransfer.CreatedBy> createdBy)Alias for calling Builder.createdBy with createdBy.orElse(null).final CardPushTransfer.BuildercreatedBy(JsonField<CardPushTransfer.CreatedBy> createdBy)Sets Builder.createdBy to an arbitrary JSON value. final CardPushTransfer.Builderdecline(CardPushTransfer.Decline decline)If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details. final CardPushTransfer.Builderdecline(Optional<CardPushTransfer.Decline> decline)Alias for calling Builder.decline with decline.orElse(null).final CardPushTransfer.Builderdecline(JsonField<CardPushTransfer.Decline> decline)Sets Builder.decline to an arbitrary JSON value. final CardPushTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final CardPushTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final CardPushTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final CardPushTransfer.BuildermerchantCategoryCode(String merchantCategoryCode)The merchant category code (MCC) of the merchant (generally your business) sending the transfer. final CardPushTransfer.BuildermerchantCategoryCode(JsonField<String> merchantCategoryCode)Sets Builder.merchantCategoryCode to an arbitrary JSON value. final CardPushTransfer.BuildermerchantCityName(String merchantCityName)The city name of the merchant (generally your business) sending the transfer. final CardPushTransfer.BuildermerchantCityName(JsonField<String> merchantCityName)Sets Builder.merchantCityName to an arbitrary JSON value. final CardPushTransfer.BuildermerchantName(String merchantName)The merchant name shows up as the statement descriptor for the transfer. final CardPushTransfer.BuildermerchantName(JsonField<String> merchantName)Sets Builder.merchantName to an arbitrary JSON value. final CardPushTransfer.BuildermerchantNamePrefix(String merchantNamePrefix)For certain Business Application Identifiers, the statement descriptor is merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.final CardPushTransfer.BuildermerchantNamePrefix(JsonField<String> merchantNamePrefix)Sets Builder.merchantNamePrefix to an arbitrary JSON value. final CardPushTransfer.BuildermerchantPostalCode(String merchantPostalCode)The postal code of the merchant (generally your business) sending the transfer. final CardPushTransfer.BuildermerchantPostalCode(JsonField<String> merchantPostalCode)Sets Builder.merchantPostalCode to an arbitrary JSON value. final CardPushTransfer.BuildermerchantState(String merchantState)The state of the merchant (generally your business) sending the transfer. final CardPushTransfer.BuildermerchantState(JsonField<String> merchantState)Sets Builder.merchantState to an arbitrary JSON value. final CardPushTransfer.BuilderpresentmentAmount(CardPushTransfer.PresentmentAmount presentmentAmount)The amount that was transferred. final CardPushTransfer.BuilderpresentmentAmount(JsonField<CardPushTransfer.PresentmentAmount> presentmentAmount)Sets Builder.presentmentAmount to an arbitrary JSON value. final CardPushTransfer.BuilderrecipientName(String recipientName)The name of the funds recipient. final CardPushTransfer.BuilderrecipientName(JsonField<String> recipientName)Sets Builder.recipientName to an arbitrary JSON value. final CardPushTransfer.Builderroute(CardPushTransfer.Route route)The card network route used for the transfer. final CardPushTransfer.Builderroute(JsonField<CardPushTransfer.Route> route)Sets Builder.route to an arbitrary JSON value. final CardPushTransfer.BuildersenderAddressCity(String senderAddressCity)The city of the sender. final CardPushTransfer.BuildersenderAddressCity(JsonField<String> senderAddressCity)Sets Builder.senderAddressCity to an arbitrary JSON value. final CardPushTransfer.BuildersenderAddressLine1(String senderAddressLine1)The address line 1 of the sender. final CardPushTransfer.BuildersenderAddressLine1(JsonField<String> senderAddressLine1)Sets Builder.senderAddressLine1 to an arbitrary JSON value. final CardPushTransfer.BuildersenderAddressPostalCode(String senderAddressPostalCode)The postal code of the sender. final CardPushTransfer.BuildersenderAddressPostalCode(JsonField<String> senderAddressPostalCode)Sets Builder.senderAddressPostalCode to an arbitrary JSON value. final CardPushTransfer.BuildersenderAddressState(String senderAddressState)The state of the sender. final CardPushTransfer.BuildersenderAddressState(JsonField<String> senderAddressState)Sets Builder.senderAddressState to an arbitrary JSON value. final CardPushTransfer.BuildersenderName(String senderName)The name of the funds originator. final CardPushTransfer.BuildersenderName(JsonField<String> senderName)Sets Builder.senderName to an arbitrary JSON value. final CardPushTransfer.BuildersourceAccountNumberId(String sourceAccountNumberId)The Account Number the recipient will see as having sent the transfer. final CardPushTransfer.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)Sets Builder.sourceAccountNumberId to an arbitrary JSON value. final CardPushTransfer.Builderstatus(CardPushTransfer.Status status)The lifecycle status of the transfer. final CardPushTransfer.Builderstatus(JsonField<CardPushTransfer.Status> status)Sets Builder.status to an arbitrary JSON value. final CardPushTransfer.Buildersubmission(CardPushTransfer.Submission submission)After the transfer is submitted to the card network, this will contain supplemental details. final CardPushTransfer.Buildersubmission(Optional<CardPushTransfer.Submission> submission)Alias for calling Builder.submission with submission.orElse(null).final CardPushTransfer.Buildersubmission(JsonField<CardPushTransfer.Submission> submission)Sets Builder.submission to an arbitrary JSON value. final CardPushTransfer.Buildertype(CardPushTransfer.Type type)A constant representing the object's type. final CardPushTransfer.Buildertype(JsonField<CardPushTransfer.Type> type)Sets Builder.type to an arbitrary JSON value. final CardPushTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardPushTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final CardPushTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardPushTransfer.BuilderremoveAdditionalProperty(String key)final CardPushTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardPushTransferbuild()Returns an immutable instance of CardPushTransfer. -
-
Method Detail
-
id
final CardPushTransfer.Builder id(String id)
The Card Push Transfer's identifier.
-
id
final CardPushTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acceptance
final CardPushTransfer.Builder acceptance(CardPushTransfer.Acceptance acceptance)
If the transfer is accepted by the recipient bank, this will contain supplemental details.
-
acceptance
final CardPushTransfer.Builder acceptance(Optional<CardPushTransfer.Acceptance> acceptance)
Alias for calling Builder.acceptance with
acceptance.orElse(null).
-
acceptance
final CardPushTransfer.Builder acceptance(JsonField<CardPushTransfer.Acceptance> acceptance)
Sets Builder.acceptance to an arbitrary JSON value.
You should usually call Builder.acceptance with a well-typed Acceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final CardPushTransfer.Builder accountId(String accountId)
The Account from which the transfer was sent.
-
accountId
final CardPushTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approval
final CardPushTransfer.Builder approval(CardPushTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final CardPushTransfer.Builder approval(Optional<CardPushTransfer.Approval> approval)
Alias for calling Builder.approval with
approval.orElse(null).
-
approval
final CardPushTransfer.Builder approval(JsonField<CardPushTransfer.Approval> approval)
Sets Builder.approval to an arbitrary JSON value.
You should usually call Builder.approval with a well-typed Approval value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
businessApplicationIdentifier
final CardPushTransfer.Builder businessApplicationIdentifier(CardPushTransfer.BusinessApplicationIdentifier businessApplicationIdentifier)
The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
-
businessApplicationIdentifier
final CardPushTransfer.Builder businessApplicationIdentifier(JsonField<CardPushTransfer.BusinessApplicationIdentifier> businessApplicationIdentifier)
Sets Builder.businessApplicationIdentifier to an arbitrary JSON value.
You should usually call Builder.businessApplicationIdentifier with a well-typed BusinessApplicationIdentifier value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cancellation
final CardPushTransfer.Builder cancellation(CardPushTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final CardPushTransfer.Builder cancellation(Optional<CardPushTransfer.Cancellation> cancellation)
Alias for calling Builder.cancellation with
cancellation.orElse(null).
-
cancellation
final CardPushTransfer.Builder cancellation(JsonField<CardPushTransfer.Cancellation> cancellation)
Sets Builder.cancellation to an arbitrary JSON value.
You should usually call Builder.cancellation with a well-typed Cancellation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardTokenId
final CardPushTransfer.Builder cardTokenId(String cardTokenId)
The ID of the Card Token that was used to validate the card.
-
cardTokenId
final CardPushTransfer.Builder cardTokenId(JsonField<String> cardTokenId)
Sets Builder.cardTokenId to an arbitrary JSON value.
You should usually call Builder.cardTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CardPushTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final CardPushTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdBy
final CardPushTransfer.Builder createdBy(CardPushTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final CardPushTransfer.Builder createdBy(Optional<CardPushTransfer.CreatedBy> createdBy)
Alias for calling Builder.createdBy with
createdBy.orElse(null).
-
createdBy
final CardPushTransfer.Builder createdBy(JsonField<CardPushTransfer.CreatedBy> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed CreatedBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decline
final CardPushTransfer.Builder decline(CardPushTransfer.Decline decline)
If the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.
-
decline
final CardPushTransfer.Builder decline(Optional<CardPushTransfer.Decline> decline)
Alias for calling Builder.decline with
decline.orElse(null).
-
decline
final CardPushTransfer.Builder decline(JsonField<CardPushTransfer.Decline> decline)
Sets Builder.decline to an arbitrary JSON value.
You should usually call Builder.decline with a well-typed Decline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final CardPushTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CardPushTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final CardPushTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardPushTransfer.Builder merchantCategoryCode(String merchantCategoryCode)
The merchant category code (MCC) of the merchant (generally your business) sending the transfer. This is a four-digit code that describes the type of business or service provided by the merchant. Your program must be approved for the specified MCC in order to use it.
-
merchantCategoryCode
final CardPushTransfer.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCityName
final CardPushTransfer.Builder merchantCityName(String merchantCityName)
The city name of the merchant (generally your business) sending the transfer.
-
merchantCityName
final CardPushTransfer.Builder merchantCityName(JsonField<String> merchantCityName)
Sets Builder.merchantCityName to an arbitrary JSON value.
You should usually call Builder.merchantCityName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final CardPushTransfer.Builder merchantName(String merchantName)
The merchant name shows up as the statement descriptor for the transfer. This is typically the name of your business or organization.
-
merchantName
final CardPushTransfer.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantNamePrefix
final CardPushTransfer.Builder merchantNamePrefix(String merchantNamePrefix)
For certain Business Application Identifiers, the statement descriptor is
merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.
-
merchantNamePrefix
final CardPushTransfer.Builder merchantNamePrefix(JsonField<String> merchantNamePrefix)
Sets Builder.merchantNamePrefix to an arbitrary JSON value.
You should usually call Builder.merchantNamePrefix with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final CardPushTransfer.Builder merchantPostalCode(String merchantPostalCode)
The postal code of the merchant (generally your business) sending the transfer.
-
merchantPostalCode
final CardPushTransfer.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final CardPushTransfer.Builder merchantState(String merchantState)
The state of the merchant (generally your business) sending the transfer.
-
merchantState
final CardPushTransfer.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentAmount
final CardPushTransfer.Builder presentmentAmount(CardPushTransfer.PresentmentAmount presentmentAmount)
The amount that was transferred. The receiving bank will have converted this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
presentmentAmount
final CardPushTransfer.Builder presentmentAmount(JsonField<CardPushTransfer.PresentmentAmount> presentmentAmount)
Sets Builder.presentmentAmount to an arbitrary JSON value.
You should usually call Builder.presentmentAmount with a well-typed PresentmentAmount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final CardPushTransfer.Builder recipientName(String recipientName)
The name of the funds recipient.
-
recipientName
final CardPushTransfer.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
route
final CardPushTransfer.Builder route(CardPushTransfer.Route route)
The card network route used for the transfer.
-
route
final CardPushTransfer.Builder route(JsonField<CardPushTransfer.Route> route)
Sets Builder.route to an arbitrary JSON value.
You should usually call Builder.route with a well-typed Route value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressCity
final CardPushTransfer.Builder senderAddressCity(String senderAddressCity)
The city of the sender.
-
senderAddressCity
final CardPushTransfer.Builder senderAddressCity(JsonField<String> senderAddressCity)
Sets Builder.senderAddressCity to an arbitrary JSON value.
You should usually call Builder.senderAddressCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressLine1
final CardPushTransfer.Builder senderAddressLine1(String senderAddressLine1)
The address line 1 of the sender.
-
senderAddressLine1
final CardPushTransfer.Builder senderAddressLine1(JsonField<String> senderAddressLine1)
Sets Builder.senderAddressLine1 to an arbitrary JSON value.
You should usually call Builder.senderAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressPostalCode
final CardPushTransfer.Builder senderAddressPostalCode(String senderAddressPostalCode)
The postal code of the sender.
-
senderAddressPostalCode
final CardPushTransfer.Builder senderAddressPostalCode(JsonField<String> senderAddressPostalCode)
Sets Builder.senderAddressPostalCode to an arbitrary JSON value.
You should usually call Builder.senderAddressPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressState
final CardPushTransfer.Builder senderAddressState(String senderAddressState)
The state of the sender.
-
senderAddressState
final CardPushTransfer.Builder senderAddressState(JsonField<String> senderAddressState)
Sets Builder.senderAddressState to an arbitrary JSON value.
You should usually call Builder.senderAddressState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderName
final CardPushTransfer.Builder senderName(String senderName)
The name of the funds originator.
-
senderName
final CardPushTransfer.Builder senderName(JsonField<String> senderName)
Sets Builder.senderName to an arbitrary JSON value.
You should usually call Builder.senderName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final CardPushTransfer.Builder sourceAccountNumberId(String sourceAccountNumberId)
The Account Number the recipient will see as having sent the transfer.
-
sourceAccountNumberId
final CardPushTransfer.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardPushTransfer.Builder status(CardPushTransfer.Status status)
The lifecycle status of the transfer.
-
status
final CardPushTransfer.Builder status(JsonField<CardPushTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submission
final CardPushTransfer.Builder submission(CardPushTransfer.Submission submission)
After the transfer is submitted to the card network, this will contain supplemental details.
-
submission
final CardPushTransfer.Builder submission(Optional<CardPushTransfer.Submission> submission)
Alias for calling Builder.submission with
submission.orElse(null).
-
submission
final CardPushTransfer.Builder submission(JsonField<CardPushTransfer.Submission> submission)
Sets Builder.submission to an arbitrary JSON value.
You should usually call Builder.submission with a well-typed Submission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPushTransfer.Builder type(CardPushTransfer.Type type)
A constant representing the object's type. For this resource it will always be
card_push_transfer.
-
type
final CardPushTransfer.Builder type(JsonField<CardPushTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPushTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPushTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPushTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPushTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPushTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPushTransfer build()
Returns an immutable instance of CardPushTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .acceptance() .accountId() .approval() .businessApplicationIdentifier() .cancellation() .cardTokenId() .createdAt() .createdBy() .decline() .idempotencyKey() .merchantCategoryCode() .merchantCityName() .merchantName() .merchantNamePrefix() .merchantPostalCode() .merchantState() .presentmentAmount() .recipientName() .route() .senderAddressCity() .senderAddressLine1() .senderAddressPostalCode() .senderAddressState() .senderName() .sourceAccountNumberId() .status() .submission() .type()
-
-
-
-