Class CardPushTransfer.BusinessApplicationIdentifier

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class CardPushTransfer.BusinessApplicationIdentifier
     implements Enum
                        

    The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.