Enum CardPushTransfer.BusinessApplicationIdentifier.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPushTransfer.BusinessApplicationIdentifier.Known extends Enum<CardPushTransfer.BusinessApplicationIdentifier.Known>
An enum containing BusinessApplicationIdentifier's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPushTransfer.BusinessApplicationIdentifier.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_TO_ACCOUNTAccount to Account
BUSINESS_TO_BUSINESSBusiness to Business
MONEY_TRANSFER_BANK_INITIATEDMoney Transfer Bank Initiated
NON_CARD_BILL_PAYMENTNon-Card Bill Payment
CONSUMER_BILL_PAYMENTConsumer Bill Payment
CARD_BILL_PAYMENTCard Bill Payment
FUNDS_DISBURSEMENTFunds Disbursement
FUNDS_TRANSFERFunds Transfer
LOYALTY_AND_OFFERSLoyalty and Offers
MERCHANT_DISBURSEMENTMerchant Disbursement
MERCHANT_PAYMENTMerchant Payment
PERSON_TO_PERSONPerson to Person
TOP_UPTop Up
WALLET_TRANSFERWallet Transfer
-
Method Summary
Modifier and Type Method Description final CardPushTransfer.BusinessApplicationIdentifier.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPushTransfer.BusinessApplicationIdentifier.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPushTransfer.BusinessApplicationIdentifier.Known>getEntries()An enum containing BusinessApplicationIdentifier's known values. -
-
Method Detail
-
valueOf
final CardPushTransfer.BusinessApplicationIdentifier.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPushTransfer.BusinessApplicationIdentifier.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPushTransfer.BusinessApplicationIdentifier.Known> getEntries()
An enum containing BusinessApplicationIdentifier's known values.
-
-
-
-