Class CardPushTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class CardPushTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classCardPushTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classCardPushTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classCardPushTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classCardPushTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final CardPushTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<CardPushTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final Optional<CardPushTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<CardPushTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<CardPushTransfer.CreatedBy.Category>_category()Returns the raw JSON value of category. final JsonField<CardPushTransfer.CreatedBy.ApiKey>_apiKey()Returns the raw JSON value of apiKey. final JsonField<CardPushTransfer.CreatedBy.OAuthApplication>_oauthApplication()Returns the raw JSON value of oauthApplication. final JsonField<CardPushTransfer.CreatedBy.User>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final CardPushTransfer.CreatedBy.BuildertoBuilder()final CardPushTransfer.CreatedByvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransfer.CreatedBy.Builderbuilder()Returns a mutable builder for constructing an instance of CreatedBy. -
-
Method Detail
-
category
final CardPushTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
apiKey
final Optional<CardPushTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
oauthApplication
final Optional<CardPushTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<CardPushTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_category
final JsonField<CardPushTransfer.CreatedBy.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_apiKey
final JsonField<CardPushTransfer.CreatedBy.ApiKey> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthApplication
final JsonField<CardPushTransfer.CreatedBy.OAuthApplication> _oauthApplication()
Returns the raw JSON value of oauthApplication.
Unlike oauthApplication, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<CardPushTransfer.CreatedBy.User> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.CreatedBy.Builder toBuilder()
-
validate
final CardPushTransfer.CreatedBy validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPushTransfer.CreatedBy.Builder builder()
Returns a mutable builder for constructing an instance of CreatedBy.
The following fields are required:
.category()
-
-
-
-