Class CardPushTransfer.CreatedBy.ApiKey
-
- All Implemented Interfaces:
public final class CardPushTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.CreatedBy.ApiKey.BuilderA builder for ApiKey.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The description set for the API key when it was created. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final CardPushTransfer.CreatedBy.ApiKey.BuildertoBuilder()final CardPushTransfer.CreatedBy.ApiKeyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransfer.CreatedBy.ApiKey.Builderbuilder()Returns a mutable builder for constructing an instance of ApiKey. -
-
Method Detail
-
description
final Optional<String> description()
The description set for the API key when it was created.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.CreatedBy.ApiKey.Builder toBuilder()
-
validate
final CardPushTransfer.CreatedBy.ApiKey validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPushTransfer.CreatedBy.ApiKey.Builder builder()
Returns a mutable builder for constructing an instance of ApiKey.
The following fields are required:
.description()
-
-
-
-