Class CardPushTransfer.PresentmentAmount
-
- All Implemented Interfaces:
public final class CardPushTransfer.PresentmentAmountThe amount that was transferred. The receiving bank will have converted this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.PresentmentAmount.BuilderA builder for PresentmentAmount.
public final classCardPushTransfer.PresentmentAmount.CurrencyThe ISO 4217 currency code.
-
Method Summary
Modifier and Type Method Description final CardPushTransfer.PresentmentAmount.Currencycurrency()The ISO 4217 currency code. final Stringvalue()The amount value represented as a string containing a decimal number in major units (so e.g., "12.34" for $12.34). final JsonField<CardPushTransfer.PresentmentAmount.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final CardPushTransfer.PresentmentAmount.BuildertoBuilder()final CardPushTransfer.PresentmentAmountvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransfer.PresentmentAmount.Builderbuilder()Returns a mutable builder for constructing an instance of PresentmentAmount. -
-
Method Detail
-
currency
final CardPushTransfer.PresentmentAmount.Currency currency()
The ISO 4217 currency code.
-
value
final String value()
The amount value represented as a string containing a decimal number in major units (so e.g., "12.34" for $12.34).
-
_currency
final JsonField<CardPushTransfer.PresentmentAmount.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.PresentmentAmount.Builder toBuilder()
-
validate
final CardPushTransfer.PresentmentAmount validate()
-
builder
final static CardPushTransfer.PresentmentAmount.Builder builder()
Returns a mutable builder for constructing an instance of PresentmentAmount.
The following fields are required:
.currency() .value()
-
-
-
-