Class CardPushTransfer.PresentmentAmount.Builder
-
- All Implemented Interfaces:
public final class CardPushTransfer.PresentmentAmount.BuilderA builder for PresentmentAmount.
-
-
Method Summary
-
-
Method Detail
-
currency
final CardPushTransfer.PresentmentAmount.Builder currency(CardPushTransfer.PresentmentAmount.Currency currency)
The ISO 4217 currency code.
-
currency
final CardPushTransfer.PresentmentAmount.Builder currency(JsonField<CardPushTransfer.PresentmentAmount.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final CardPushTransfer.PresentmentAmount.Builder value(String value)
The amount value represented as a string containing a decimal number in major units (so e.g., "12.34" for $12.34).
-
value
final CardPushTransfer.PresentmentAmount.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPushTransfer.PresentmentAmount.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPushTransfer.PresentmentAmount.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPushTransfer.PresentmentAmount.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPushTransfer.PresentmentAmount.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPushTransfer.PresentmentAmount.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPushTransfer.PresentmentAmount build()
Returns an immutable instance of PresentmentAmount.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.currency() .value()
-
-
-
-