Enum CardPushTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPushTransfer.Status.Known extends Enum<CardPushTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPushTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_APPROVALThe transfer is pending approval.
CANCELEDThe transfer has been canceled.
PENDING_REVIEWINGThe transfer is pending review by Increase.
REQUIRES_ATTENTIONThe transfer requires attention from an Increase operator.
PENDING_SUBMISSIONThe transfer is queued to be submitted to the card network.
SUBMITTEDThe transfer has been submitted and is pending a response from the card network.
COMPLETEThe transfer has been sent successfully and is complete.
DECLINEDThe transfer was declined by the network or the recipient's bank.
-
Method Summary
Modifier and Type Method Description final CardPushTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPushTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPushTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final CardPushTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPushTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPushTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-