Class CardPushTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardPushTransferCreateParams implements Params
Create a Card Push Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransferCreateParams.BuilderA builder for CardPushTransferCreateParams.
public final classCardPushTransferCreateParams.Bodypublic final classCardPushTransferCreateParams.BusinessApplicationIdentifierThe Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
public final classCardPushTransferCreateParams.PresentmentAmountThe amount to transfer. The receiving bank will convert this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
Method Summary
Modifier and Type Method Description final CardPushTransferCreateParams.BusinessApplicationIdentifierbusinessApplicationIdentifier()The Business Application Identifier describes the type of transaction being performed. final StringcardTokenId()The Increase identifier for the Card Token that represents the card number you're pushing funds to. final StringmerchantCategoryCode()The merchant category code (MCC) of the merchant (generally your business) sending the transfer. final StringmerchantCityName()The city name of the merchant (generally your business) sending the transfer. final StringmerchantName()The merchant name shows up as the statement descriptor for the transfer. final StringmerchantNamePrefix()For certain Business Application Identifiers, the statement descriptor is merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.final StringmerchantPostalCode()The postal code of the merchant (generally your business) sending the transfer. final StringmerchantState()The state of the merchant (generally your business) sending the transfer. final CardPushTransferCreateParams.PresentmentAmountpresentmentAmount()The amount to transfer. final StringrecipientName()The name of the funds recipient. final StringsenderAddressCity()The city of the sender. final StringsenderAddressLine1()The address line 1 of the sender. final StringsenderAddressPostalCode()The postal code of the sender. final StringsenderAddressState()The state of the sender. final StringsenderName()The name of the funds originator. final StringsourceAccountNumberId()The identifier of the Account Number from which to send the transfer. final Optional<String>merchantLegalBusinessName()The legal business name of the merchant (generally your business) sending the transfer. final Optional<String>merchantStreetAddress()The street address of the merchant (generally your business) sending the transfer. final Optional<String>recipientAddressCity()The city of the recipient. final Optional<String>recipientAddressLine1()The first line of the recipient's address. final Optional<String>recipientAddressPostalCode()The postal code of the recipient. final Optional<String>recipientAddressState()The state or province of the recipient. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final JsonField<CardPushTransferCreateParams.BusinessApplicationIdentifier>_businessApplicationIdentifier()Returns the raw JSON value of businessApplicationIdentifier. final JsonField<String>_cardTokenId()Returns the raw JSON value of cardTokenId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCityName()Returns the raw JSON value of merchantCityName. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<String>_merchantNamePrefix()Returns the raw JSON value of merchantNamePrefix. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<CardPushTransferCreateParams.PresentmentAmount>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<String>_senderAddressCity()Returns the raw JSON value of senderAddressCity. final JsonField<String>_senderAddressLine1()Returns the raw JSON value of senderAddressLine1. final JsonField<String>_senderAddressPostalCode()Returns the raw JSON value of senderAddressPostalCode. final JsonField<String>_senderAddressState()Returns the raw JSON value of senderAddressState. final JsonField<String>_senderName()Returns the raw JSON value of senderName. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<String>_merchantLegalBusinessName()Returns the raw JSON value of merchantLegalBusinessName. final JsonField<String>_merchantStreetAddress()Returns the raw JSON value of merchantStreetAddress. final JsonField<String>_recipientAddressCity()Returns the raw JSON value of recipientAddressCity. final JsonField<String>_recipientAddressLine1()Returns the raw JSON value of recipientAddressLine1. final JsonField<String>_recipientAddressPostalCode()Returns the raw JSON value of recipientAddressPostalCode. final JsonField<String>_recipientAddressState()Returns the raw JSON value of recipientAddressState. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardPushTransferCreateParams.BuildertoBuilder()final CardPushTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardPushTransferCreateParams. -
-
Method Detail
-
businessApplicationIdentifier
final CardPushTransferCreateParams.BusinessApplicationIdentifier businessApplicationIdentifier()
The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
-
cardTokenId
final String cardTokenId()
The Increase identifier for the Card Token that represents the card number you're pushing funds to.
-
merchantCategoryCode
final String merchantCategoryCode()
The merchant category code (MCC) of the merchant (generally your business) sending the transfer. This is a four-digit code that describes the type of business or service provided by the merchant. Your program must be approved for the specified MCC in order to use it.
-
merchantCityName
final String merchantCityName()
The city name of the merchant (generally your business) sending the transfer.
-
merchantName
final String merchantName()
The merchant name shows up as the statement descriptor for the transfer. This is typically the name of your business or organization.
-
merchantNamePrefix
final String merchantNamePrefix()
For certain Business Application Identifiers, the statement descriptor is
merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.
-
merchantPostalCode
final String merchantPostalCode()
The postal code of the merchant (generally your business) sending the transfer.
-
merchantState
final String merchantState()
The state of the merchant (generally your business) sending the transfer.
-
presentmentAmount
final CardPushTransferCreateParams.PresentmentAmount presentmentAmount()
The amount to transfer. The receiving bank will convert this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
recipientName
final String recipientName()
The name of the funds recipient.
-
senderAddressCity
final String senderAddressCity()
The city of the sender.
-
senderAddressLine1
final String senderAddressLine1()
The address line 1 of the sender.
-
senderAddressPostalCode
final String senderAddressPostalCode()
The postal code of the sender.
-
senderAddressState
final String senderAddressState()
The state of the sender.
-
senderName
final String senderName()
The name of the funds originator.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer.
-
merchantLegalBusinessName
final Optional<String> merchantLegalBusinessName()
The legal business name of the merchant (generally your business) sending the transfer. Required if the card is issued in Canada.
-
merchantStreetAddress
final Optional<String> merchantStreetAddress()
The street address of the merchant (generally your business) sending the transfer. Required if the card is issued in Canada.
-
recipientAddressCity
final Optional<String> recipientAddressCity()
The city of the recipient. Required if the card is issued in Canada.
-
recipientAddressLine1
final Optional<String> recipientAddressLine1()
The first line of the recipient's address. Required if the card is issued in Canada.
-
recipientAddressPostalCode
final Optional<String> recipientAddressPostalCode()
The postal code of the recipient. Required if the card is issued in Canada.
-
recipientAddressState
final Optional<String> recipientAddressState()
The state or province of the recipient. Required if the card is issued in Canada.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
_businessApplicationIdentifier
final JsonField<CardPushTransferCreateParams.BusinessApplicationIdentifier> _businessApplicationIdentifier()
Returns the raw JSON value of businessApplicationIdentifier.
Unlike businessApplicationIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokenId
final JsonField<String> _cardTokenId()
Returns the raw JSON value of cardTokenId.
Unlike cardTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCityName
final JsonField<String> _merchantCityName()
Returns the raw JSON value of merchantCityName.
Unlike merchantCityName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantNamePrefix
final JsonField<String> _merchantNamePrefix()
Returns the raw JSON value of merchantNamePrefix.
Unlike merchantNamePrefix, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<CardPushTransferCreateParams.PresentmentAmount> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressCity
final JsonField<String> _senderAddressCity()
Returns the raw JSON value of senderAddressCity.
Unlike senderAddressCity, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressLine1
final JsonField<String> _senderAddressLine1()
Returns the raw JSON value of senderAddressLine1.
Unlike senderAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressPostalCode
final JsonField<String> _senderAddressPostalCode()
Returns the raw JSON value of senderAddressPostalCode.
Unlike senderAddressPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_senderAddressState
final JsonField<String> _senderAddressState()
Returns the raw JSON value of senderAddressState.
Unlike senderAddressState, this method doesn't throw if the JSON field has an unexpected type.
-
_senderName
final JsonField<String> _senderName()
Returns the raw JSON value of senderName.
Unlike senderName, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantLegalBusinessName
final JsonField<String> _merchantLegalBusinessName()
Returns the raw JSON value of merchantLegalBusinessName.
Unlike merchantLegalBusinessName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantStreetAddress
final JsonField<String> _merchantStreetAddress()
Returns the raw JSON value of merchantStreetAddress.
Unlike merchantStreetAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressCity
final JsonField<String> _recipientAddressCity()
Returns the raw JSON value of recipientAddressCity.
Unlike recipientAddressCity, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine1
final JsonField<String> _recipientAddressLine1()
Returns the raw JSON value of recipientAddressLine1.
Unlike recipientAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressPostalCode
final JsonField<String> _recipientAddressPostalCode()
Returns the raw JSON value of recipientAddressPostalCode.
Unlike recipientAddressPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressState
final JsonField<String> _recipientAddressState()
Returns the raw JSON value of recipientAddressState.
Unlike recipientAddressState, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardPushTransferCreateParams.Builder toBuilder()
-
_body
final CardPushTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardPushTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardPushTransferCreateParams.
The following fields are required:
.businessApplicationIdentifier() .cardTokenId() .merchantCategoryCode() .merchantCityName() .merchantName() .merchantNamePrefix() .merchantPostalCode() .merchantState() .presentmentAmount() .recipientName() .senderAddressCity() .senderAddressLine1() .senderAddressPostalCode() .senderAddressState() .senderName() .sourceAccountNumberId()
-
-
-
-