Class CardPushTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardPushTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
businessApplicationIdentifier
final CardPushTransferCreateParams.Body.Builder businessApplicationIdentifier(CardPushTransferCreateParams.BusinessApplicationIdentifier businessApplicationIdentifier)
The Business Application Identifier describes the type of transaction being performed. Your program must be approved for the specified Business Application Identifier in order to use it.
-
businessApplicationIdentifier
final CardPushTransferCreateParams.Body.Builder businessApplicationIdentifier(JsonField<CardPushTransferCreateParams.BusinessApplicationIdentifier> businessApplicationIdentifier)
Sets Builder.businessApplicationIdentifier to an arbitrary JSON value.
You should usually call Builder.businessApplicationIdentifier with a well-typed BusinessApplicationIdentifier value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardTokenId
final CardPushTransferCreateParams.Body.Builder cardTokenId(String cardTokenId)
The Increase identifier for the Card Token that represents the card number you're pushing funds to.
-
cardTokenId
final CardPushTransferCreateParams.Body.Builder cardTokenId(JsonField<String> cardTokenId)
Sets Builder.cardTokenId to an arbitrary JSON value.
You should usually call Builder.cardTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardPushTransferCreateParams.Body.Builder merchantCategoryCode(String merchantCategoryCode)
The merchant category code (MCC) of the merchant (generally your business) sending the transfer. This is a four-digit code that describes the type of business or service provided by the merchant. Your program must be approved for the specified MCC in order to use it.
-
merchantCategoryCode
final CardPushTransferCreateParams.Body.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCityName
final CardPushTransferCreateParams.Body.Builder merchantCityName(String merchantCityName)
The city name of the merchant (generally your business) sending the transfer.
-
merchantCityName
final CardPushTransferCreateParams.Body.Builder merchantCityName(JsonField<String> merchantCityName)
Sets Builder.merchantCityName to an arbitrary JSON value.
You should usually call Builder.merchantCityName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final CardPushTransferCreateParams.Body.Builder merchantName(String merchantName)
The merchant name shows up as the statement descriptor for the transfer. This is typically the name of your business or organization.
-
merchantName
final CardPushTransferCreateParams.Body.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantNamePrefix
final CardPushTransferCreateParams.Body.Builder merchantNamePrefix(String merchantNamePrefix)
For certain Business Application Identifiers, the statement descriptor is
merchant_name_prefix*sender_name, where themerchant_name_prefixis a one to four character prefix that identifies the merchant.
-
merchantNamePrefix
final CardPushTransferCreateParams.Body.Builder merchantNamePrefix(JsonField<String> merchantNamePrefix)
Sets Builder.merchantNamePrefix to an arbitrary JSON value.
You should usually call Builder.merchantNamePrefix with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final CardPushTransferCreateParams.Body.Builder merchantPostalCode(String merchantPostalCode)
The postal code of the merchant (generally your business) sending the transfer.
-
merchantPostalCode
final CardPushTransferCreateParams.Body.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final CardPushTransferCreateParams.Body.Builder merchantState(String merchantState)
The state of the merchant (generally your business) sending the transfer.
-
merchantState
final CardPushTransferCreateParams.Body.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentAmount
final CardPushTransferCreateParams.Body.Builder presentmentAmount(CardPushTransferCreateParams.PresentmentAmount presentmentAmount)
The amount to transfer. The receiving bank will convert this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
presentmentAmount
final CardPushTransferCreateParams.Body.Builder presentmentAmount(JsonField<CardPushTransferCreateParams.PresentmentAmount> presentmentAmount)
Sets Builder.presentmentAmount to an arbitrary JSON value.
You should usually call Builder.presentmentAmount with a well-typed PresentmentAmount value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final CardPushTransferCreateParams.Body.Builder recipientName(String recipientName)
The name of the funds recipient.
-
recipientName
final CardPushTransferCreateParams.Body.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressCity
final CardPushTransferCreateParams.Body.Builder senderAddressCity(String senderAddressCity)
The city of the sender.
-
senderAddressCity
final CardPushTransferCreateParams.Body.Builder senderAddressCity(JsonField<String> senderAddressCity)
Sets Builder.senderAddressCity to an arbitrary JSON value.
You should usually call Builder.senderAddressCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressLine1
final CardPushTransferCreateParams.Body.Builder senderAddressLine1(String senderAddressLine1)
The address line 1 of the sender.
-
senderAddressLine1
final CardPushTransferCreateParams.Body.Builder senderAddressLine1(JsonField<String> senderAddressLine1)
Sets Builder.senderAddressLine1 to an arbitrary JSON value.
You should usually call Builder.senderAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressPostalCode
final CardPushTransferCreateParams.Body.Builder senderAddressPostalCode(String senderAddressPostalCode)
The postal code of the sender.
-
senderAddressPostalCode
final CardPushTransferCreateParams.Body.Builder senderAddressPostalCode(JsonField<String> senderAddressPostalCode)
Sets Builder.senderAddressPostalCode to an arbitrary JSON value.
You should usually call Builder.senderAddressPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderAddressState
final CardPushTransferCreateParams.Body.Builder senderAddressState(String senderAddressState)
The state of the sender.
-
senderAddressState
final CardPushTransferCreateParams.Body.Builder senderAddressState(JsonField<String> senderAddressState)
Sets Builder.senderAddressState to an arbitrary JSON value.
You should usually call Builder.senderAddressState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderName
final CardPushTransferCreateParams.Body.Builder senderName(String senderName)
The name of the funds originator.
-
senderName
final CardPushTransferCreateParams.Body.Builder senderName(JsonField<String> senderName)
Sets Builder.senderName to an arbitrary JSON value.
You should usually call Builder.senderName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final CardPushTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer.
-
sourceAccountNumberId
final CardPushTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantLegalBusinessName
final CardPushTransferCreateParams.Body.Builder merchantLegalBusinessName(String merchantLegalBusinessName)
The legal business name of the merchant (generally your business) sending the transfer. Required if the card is issued in Canada.
-
merchantLegalBusinessName
final CardPushTransferCreateParams.Body.Builder merchantLegalBusinessName(JsonField<String> merchantLegalBusinessName)
Sets Builder.merchantLegalBusinessName to an arbitrary JSON value.
You should usually call Builder.merchantLegalBusinessName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantStreetAddress
final CardPushTransferCreateParams.Body.Builder merchantStreetAddress(String merchantStreetAddress)
The street address of the merchant (generally your business) sending the transfer. Required if the card is issued in Canada.
-
merchantStreetAddress
final CardPushTransferCreateParams.Body.Builder merchantStreetAddress(JsonField<String> merchantStreetAddress)
Sets Builder.merchantStreetAddress to an arbitrary JSON value.
You should usually call Builder.merchantStreetAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressCity
final CardPushTransferCreateParams.Body.Builder recipientAddressCity(String recipientAddressCity)
The city of the recipient. Required if the card is issued in Canada.
-
recipientAddressCity
final CardPushTransferCreateParams.Body.Builder recipientAddressCity(JsonField<String> recipientAddressCity)
Sets Builder.recipientAddressCity to an arbitrary JSON value.
You should usually call Builder.recipientAddressCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine1
final CardPushTransferCreateParams.Body.Builder recipientAddressLine1(String recipientAddressLine1)
The first line of the recipient's address. Required if the card is issued in Canada.
-
recipientAddressLine1
final CardPushTransferCreateParams.Body.Builder recipientAddressLine1(JsonField<String> recipientAddressLine1)
Sets Builder.recipientAddressLine1 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressPostalCode
final CardPushTransferCreateParams.Body.Builder recipientAddressPostalCode(String recipientAddressPostalCode)
The postal code of the recipient. Required if the card is issued in Canada.
-
recipientAddressPostalCode
final CardPushTransferCreateParams.Body.Builder recipientAddressPostalCode(JsonField<String> recipientAddressPostalCode)
Sets Builder.recipientAddressPostalCode to an arbitrary JSON value.
You should usually call Builder.recipientAddressPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressState
final CardPushTransferCreateParams.Body.Builder recipientAddressState(String recipientAddressState)
The state or province of the recipient. Required if the card is issued in Canada.
-
recipientAddressState
final CardPushTransferCreateParams.Body.Builder recipientAddressState(JsonField<String> recipientAddressState)
Sets Builder.recipientAddressState to an arbitrary JSON value.
You should usually call Builder.recipientAddressState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final CardPushTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final CardPushTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPushTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPushTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPushTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPushTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPushTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPushTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.businessApplicationIdentifier() .cardTokenId() .merchantCategoryCode() .merchantCityName() .merchantName() .merchantNamePrefix() .merchantPostalCode() .merchantState() .presentmentAmount() .recipientName() .senderAddressCity() .senderAddressLine1() .senderAddressPostalCode() .senderAddressState() .senderName() .sourceAccountNumberId()
-
-
-
-