Enum CardPushTransferCreateParams.BusinessApplicationIdentifier.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardPushTransferCreateParams.BusinessApplicationIdentifier.Value extends Enum<CardPushTransferCreateParams.BusinessApplicationIdentifier.Value>
An enum containing BusinessApplicationIdentifier's known values, as well as an _UNKNOWN member.
An instance of BusinessApplicationIdentifier can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardPushTransferCreateParams.BusinessApplicationIdentifier.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_TO_ACCOUNTAccount to Account
BUSINESS_TO_BUSINESSBusiness to Business
MONEY_TRANSFER_BANK_INITIATEDMoney Transfer Bank Initiated
NON_CARD_BILL_PAYMENTNon-Card Bill Payment
CONSUMER_BILL_PAYMENTConsumer Bill Payment
CARD_BILL_PAYMENTCard Bill Payment
FUNDS_DISBURSEMENTFunds Disbursement
FUNDS_TRANSFERFunds Transfer
LOYALTY_AND_OFFERSLoyalty and Offers
MERCHANT_DISBURSEMENTMerchant Disbursement
MERCHANT_PAYMENTMerchant Payment
PERSON_TO_PERSONPerson to Person
TOP_UPTop Up
WALLET_TRANSFERWallet Transfer
_UNKNOWNAn enum member indicating that BusinessApplicationIdentifier was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardPushTransferCreateParams.BusinessApplicationIdentifier.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardPushTransferCreateParams.BusinessApplicationIdentifier.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardPushTransferCreateParams.BusinessApplicationIdentifier.Value>getEntries()An enum containing BusinessApplicationIdentifier's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardPushTransferCreateParams.BusinessApplicationIdentifier.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardPushTransferCreateParams.BusinessApplicationIdentifier.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardPushTransferCreateParams.BusinessApplicationIdentifier.Value> getEntries()
An enum containing BusinessApplicationIdentifier's known values, as well as an _UNKNOWN member.
An instance of BusinessApplicationIdentifier can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-