Class CardPushTransferCreateParams.PresentmentAmount
-
- All Implemented Interfaces:
public final class CardPushTransferCreateParams.PresentmentAmountThe amount to transfer. The receiving bank will convert this to the cardholder's currency. The amount that is applied to your Increase account matches the currency of your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransferCreateParams.PresentmentAmount.BuilderA builder for PresentmentAmount.
public final classCardPushTransferCreateParams.PresentmentAmount.CurrencyThe ISO 4217 currency code representing the currency of the amount.
-
Method Summary
Modifier and Type Method Description final CardPushTransferCreateParams.PresentmentAmount.Currencycurrency()The ISO 4217 currency code representing the currency of the amount. final Stringvalue()The amount value as a decimal string in the currency's major unit. final JsonField<CardPushTransferCreateParams.PresentmentAmount.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final CardPushTransferCreateParams.PresentmentAmount.BuildertoBuilder()final CardPushTransferCreateParams.PresentmentAmountvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransferCreateParams.PresentmentAmount.Builderbuilder()Returns a mutable builder for constructing an instance of PresentmentAmount. -
-
Method Detail
-
currency
final CardPushTransferCreateParams.PresentmentAmount.Currency currency()
The ISO 4217 currency code representing the currency of the amount.
-
value
final String value()
The amount value as a decimal string in the currency's major unit. For example, for USD, '1234.56' represents 1234 dollars and 56 cents. For JPY, '1234' represents 1234 yen. A currency with minor units requires at least one decimal place and supports up to the number of decimal places defined by the currency's minor units. A currency without minor units does not support any decimal places.
-
_currency
final JsonField<CardPushTransferCreateParams.PresentmentAmount.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransferCreateParams.PresentmentAmount.Builder toBuilder()
-
validate
final CardPushTransferCreateParams.PresentmentAmount validate()
-
builder
final static CardPushTransferCreateParams.PresentmentAmount.Builder builder()
Returns a mutable builder for constructing an instance of PresentmentAmount.
The following fields are required:
.currency() .value()
-
-
-
-