Class CardPushTransferCreateParams.PresentmentAmount.Builder
-
- All Implemented Interfaces:
public final class CardPushTransferCreateParams.PresentmentAmount.BuilderA builder for PresentmentAmount.
-
-
Method Summary
-
-
Method Detail
-
currency
final CardPushTransferCreateParams.PresentmentAmount.Builder currency(CardPushTransferCreateParams.PresentmentAmount.Currency currency)
The ISO 4217 currency code representing the currency of the amount.
-
currency
final CardPushTransferCreateParams.PresentmentAmount.Builder currency(JsonField<CardPushTransferCreateParams.PresentmentAmount.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final CardPushTransferCreateParams.PresentmentAmount.Builder value(String value)
The amount value as a decimal string in the currency's major unit. For example, for USD, '1234.56' represents 1234 dollars and 56 cents. For JPY, '1234' represents 1234 yen. A currency with minor units requires at least one decimal place and supports up to the number of decimal places defined by the currency's minor units. A currency without minor units does not support any decimal places.
-
value
final CardPushTransferCreateParams.PresentmentAmount.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPushTransferCreateParams.PresentmentAmount.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPushTransferCreateParams.PresentmentAmount.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPushTransferCreateParams.PresentmentAmount.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPushTransferCreateParams.PresentmentAmount.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPushTransferCreateParams.PresentmentAmount.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPushTransferCreateParams.PresentmentAmount build()
Returns an immutable instance of PresentmentAmount.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.currency() .value()
-
-
-
-