Class CardPushTransferListPage.Builder
-
- All Implemented Interfaces:
public final class CardPushTransferListPage.BuilderA builder for CardPushTransferListPage.
-
-
Method Summary
Modifier and Type Method Description final CardPushTransferListPage.Builderservice(CardPushTransferService service)final CardPushTransferListPage.Builderparams(CardPushTransferListParams params)The parameters that were used to request this page. final CardPushTransferListPage.Builderresponse(CardPushTransferListPageResponse response)The response that this page was parsed from. final CardPushTransferListPagebuild()Returns an immutable instance of CardPushTransferListPage. -
-
Method Detail
-
service
final CardPushTransferListPage.Builder service(CardPushTransferService service)
-
params
final CardPushTransferListPage.Builder params(CardPushTransferListParams params)
The parameters that were used to request this page.
-
response
final CardPushTransferListPage.Builder response(CardPushTransferListPageResponse response)
The response that this page was parsed from.
-
build
final CardPushTransferListPage build()
Returns an immutable instance of CardPushTransferListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-