Class CardPushTransferListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardPushTransferListPageAsync.BuilderA builder for CardPushTransferListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardPushTransferListPageAsync.Builderservice(CardPushTransferServiceAsync service)final CardPushTransferListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CardPushTransferListPageAsync.Builderparams(CardPushTransferListParams params)The parameters that were used to request this page. final CardPushTransferListPageAsync.Builderresponse(CardPushTransferListPageResponse response)The response that this page was parsed from. final CardPushTransferListPageAsyncbuild()Returns an immutable instance of CardPushTransferListPageAsync. -
-
Method Detail
-
service
final CardPushTransferListPageAsync.Builder service(CardPushTransferServiceAsync service)
-
streamHandlerExecutor
final CardPushTransferListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CardPushTransferListPageAsync.Builder params(CardPushTransferListParams params)
The parameters that were used to request this page.
-
response
final CardPushTransferListPageAsync.Builder response(CardPushTransferListPageResponse response)
The response that this page was parsed from.
-
build
final CardPushTransferListPageAsync build()
Returns an immutable instance of CardPushTransferListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-