Class CardPushTransferRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardPushTransferRetrieveParams implements Params
Retrieve a Card Push Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransferRetrieveParams.BuilderA builder for CardPushTransferRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cardPushTransferId()The identifier of the Card Push Transfer. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardPushTransferRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransferRetrieveParamsnone()final static CardPushTransferRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardPushTransferRetrieveParams. -
-
Method Detail
-
cardPushTransferId
final Optional<String> cardPushTransferId()
The identifier of the Card Push Transfer.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardPushTransferRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardPushTransferRetrieveParams none()
-
builder
final static CardPushTransferRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of CardPushTransferRetrieveParams.
-
-
-
-