Class Card
-
- All Implemented Interfaces:
public final class CardCards may operate on credit, debit, or prepaid BINs. They’ll immediately work for online purchases after you create them. All cards work on a good funds model, and maintain a maximum limit of 100% of the Account’s available balance at the time of transaction. Funds are deducted from the Account upon transaction settlement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.BuilderA builder for Card.
public final classCard.AuthorizationControlsControls that restrict how this card can be used.
public final classCard.BillingAddressThe Card's billing address.
public final classCard.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
public final classCard.StatusThis indicates if payments can be made with the card.
public final classCard.TypeA constant representing the object's type. For this resource it will always be
card.
-
Method Summary
Modifier and Type Method Description final Stringid()The card identifier. final StringaccountId()The identifier for the account this card belongs to. final Optional<Card.AuthorizationControls>authorizationControls()Controls that restrict how this card can be used. final Card.BillingAddressbillingAddress()The Card's billing address. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Card was created. final Optional<String>description()The card's description for display purposes. final Optional<Card.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The identifier for the entity associated with this card. final LongexpirationMonth()The month the card expires in M format (e.g., August is 8). final LongexpirationYear()The year the card expires in YYYY format (e.g., 2025). final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Stringlast4()The last 4 digits of the Card's Primary Account Number. final Card.Statusstatus()This indicates if payments can be made with the card. final Card.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Card.AuthorizationControls>_authorizationControls()Returns the raw JSON value of authorizationControls. final JsonField<Card.BillingAddress>_billingAddress()Returns the raw JSON value of billingAddress. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Card.DigitalWallet>_digitalWallet()Returns the raw JSON value of digitalWallet. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<Long>_expirationMonth()Returns the raw JSON value of expirationMonth. final JsonField<Long>_expirationYear()Returns the raw JSON value of expirationYear. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_last4()Returns the raw JSON value of last4. final JsonField<Card.Status>_status()Returns the raw JSON value of status. final JsonField<Card.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Card.BuildertoBuilder()final Cardvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.Builderbuilder()Returns a mutable builder for constructing an instance of Card. -
-
Method Detail
-
authorizationControls
final Optional<Card.AuthorizationControls> authorizationControls()
Controls that restrict how this card can be used.
-
billingAddress
final Card.BillingAddress billingAddress()
The Card's billing address.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Card was created.
-
description
final Optional<String> description()
The card's description for display purposes.
-
digitalWallet
final Optional<Card.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
expirationMonth
final Long expirationMonth()
The month the card expires in M format (e.g., August is 8).
-
expirationYear
final Long expirationYear()
The year the card expires in YYYY format (e.g., 2025).
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final Card.Status status()
This indicates if payments can be made with the card.
-
type
final Card.Type type()
A constant representing the object's type. For this resource it will always be
card.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationControls
final JsonField<Card.AuthorizationControls> _authorizationControls()
Returns the raw JSON value of authorizationControls.
Unlike authorizationControls, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddress
final JsonField<Card.BillingAddress> _billingAddress()
Returns the raw JSON value of billingAddress.
Unlike billingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<Card.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationMonth
final JsonField<Long> _expirationMonth()
Returns the raw JSON value of expirationMonth.
Unlike expirationMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationYear
final JsonField<Long> _expirationYear()
Returns the raw JSON value of expirationYear.
Unlike expirationYear, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_last4
final JsonField<String> _last4()
Returns the raw JSON value of last4.
Unlike last4, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Card.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Card.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.Builder toBuilder()
-
builder
final static Card.Builder builder()
Returns a mutable builder for constructing an instance of Card.
The following fields are required:
.id() .accountId() .authorizationControls() .billingAddress() .createdAt() .description() .digitalWallet() .entityId() .expirationMonth() .expirationYear() .idempotencyKey() .last4() .status() .type()
-
-
-
-