Class Card.AuthorizationControls
-
- All Implemented Interfaces:
public final class Card.AuthorizationControlsControls that restrict how this card can be used.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.BuilderA builder for AuthorizationControls.
public final classCard.AuthorizationControls.MerchantAcceptorIdentifierRestricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
public final classCard.AuthorizationControls.MerchantCategoryCodeRestricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
public final classCard.AuthorizationControls.MerchantCountryRestricts which merchant countries are allowed or blocked for authorizations on this card.
public final classCard.AuthorizationControls.UsageControls how many times this card can be used.
-
Method Summary
-
-
Method Detail
-
merchantAcceptorIdentifier
final Optional<Card.AuthorizationControls.MerchantAcceptorIdentifier> merchantAcceptorIdentifier()
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
merchantCategoryCode
final Optional<Card.AuthorizationControls.MerchantCategoryCode> merchantCategoryCode()
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
merchantCountry
final Optional<Card.AuthorizationControls.MerchantCountry> merchantCountry()
Restricts which merchant countries are allowed or blocked for authorizations on this card.
-
usage
final Optional<Card.AuthorizationControls.Usage> usage()
Controls how many times this card can be used.
-
_merchantAcceptorIdentifier
final JsonField<Card.AuthorizationControls.MerchantAcceptorIdentifier> _merchantAcceptorIdentifier()
Returns the raw JSON value of merchantAcceptorIdentifier.
Unlike merchantAcceptorIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<Card.AuthorizationControls.MerchantCategoryCode> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<Card.AuthorizationControls.MerchantCountry> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<Card.AuthorizationControls.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.AuthorizationControls.Builder toBuilder()
-
validate
final Card.AuthorizationControls validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Card.AuthorizationControls.Builder builder()
Returns a mutable builder for constructing an instance of AuthorizationControls.
The following fields are required:
.merchantAcceptorIdentifier() .merchantCategoryCode() .merchantCountry() .usage()
-
-
-
-