Class Card.AuthorizationControls.Builder
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.BuilderA builder for AuthorizationControls.
-
-
Method Summary
-
-
Method Detail
-
merchantAcceptorIdentifier
final Card.AuthorizationControls.Builder merchantAcceptorIdentifier(Card.AuthorizationControls.MerchantAcceptorIdentifier merchantAcceptorIdentifier)
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
merchantAcceptorIdentifier
final Card.AuthorizationControls.Builder merchantAcceptorIdentifier(Optional<Card.AuthorizationControls.MerchantAcceptorIdentifier> merchantAcceptorIdentifier)
Alias for calling Builder.merchantAcceptorIdentifier with
merchantAcceptorIdentifier.orElse(null).
-
merchantAcceptorIdentifier
final Card.AuthorizationControls.Builder merchantAcceptorIdentifier(JsonField<Card.AuthorizationControls.MerchantAcceptorIdentifier> merchantAcceptorIdentifier)
Sets Builder.merchantAcceptorIdentifier to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorIdentifier with a well-typed MerchantAcceptorIdentifier value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final Card.AuthorizationControls.Builder merchantCategoryCode(Card.AuthorizationControls.MerchantCategoryCode merchantCategoryCode)
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
merchantCategoryCode
final Card.AuthorizationControls.Builder merchantCategoryCode(Optional<Card.AuthorizationControls.MerchantCategoryCode> merchantCategoryCode)
Alias for calling Builder.merchantCategoryCode with
merchantCategoryCode.orElse(null).
-
merchantCategoryCode
final Card.AuthorizationControls.Builder merchantCategoryCode(JsonField<Card.AuthorizationControls.MerchantCategoryCode> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed MerchantCategoryCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final Card.AuthorizationControls.Builder merchantCountry(Card.AuthorizationControls.MerchantCountry merchantCountry)
Restricts which merchant countries are allowed or blocked for authorizations on this card.
-
merchantCountry
final Card.AuthorizationControls.Builder merchantCountry(Optional<Card.AuthorizationControls.MerchantCountry> merchantCountry)
Alias for calling Builder.merchantCountry with
merchantCountry.orElse(null).
-
merchantCountry
final Card.AuthorizationControls.Builder merchantCountry(JsonField<Card.AuthorizationControls.MerchantCountry> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed MerchantCountry value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
usage
final Card.AuthorizationControls.Builder usage(Card.AuthorizationControls.Usage usage)
Controls how many times this card can be used.
-
usage
final Card.AuthorizationControls.Builder usage(Optional<Card.AuthorizationControls.Usage> usage)
Alias for calling Builder.usage with
usage.orElse(null).
-
usage
final Card.AuthorizationControls.Builder usage(JsonField<Card.AuthorizationControls.Usage> usage)
Sets Builder.usage to an arbitrary JSON value.
You should usually call Builder.usage with a well-typed Usage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Card.AuthorizationControls.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Card.AuthorizationControls.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Card.AuthorizationControls.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Card.AuthorizationControls.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Card.AuthorizationControls.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Card.AuthorizationControls build()
Returns an immutable instance of AuthorizationControls.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.merchantAcceptorIdentifier() .merchantCategoryCode() .merchantCountry() .usage()
-
-
-
-