Class Card.AuthorizationControls.MerchantAcceptorIdentifier
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.MerchantAcceptorIdentifierRestricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.MerchantAcceptorIdentifier.BuilderA builder for MerchantAcceptorIdentifier.
public final classCard.AuthorizationControls.MerchantAcceptorIdentifier.Allowedpublic final classCard.AuthorizationControls.MerchantAcceptorIdentifier.Blocked
-
Method Summary
-
-
Method Detail
-
allowed
final Optional<List<Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed>> allowed()
The Merchant Acceptor IDs that are allowed for authorizations on this card.
-
blocked
final Optional<List<Card.AuthorizationControls.MerchantAcceptorIdentifier.Blocked>> blocked()
The Merchant Acceptor IDs that are blocked for authorizations on this card.
-
_allowed
final JsonField<List<Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed>> _allowed()
Returns the raw JSON value of allowed.
Unlike allowed, this method doesn't throw if the JSON field has an unexpected type.
-
_blocked
final JsonField<List<Card.AuthorizationControls.MerchantAcceptorIdentifier.Blocked>> _blocked()
Returns the raw JSON value of blocked.
Unlike blocked, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.AuthorizationControls.MerchantAcceptorIdentifier.Builder toBuilder()
-
validate
final Card.AuthorizationControls.MerchantAcceptorIdentifier validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Card.AuthorizationControls.MerchantAcceptorIdentifier.Builder builder()
Returns a mutable builder for constructing an instance of MerchantAcceptorIdentifier.
The following fields are required:
.allowed() .blocked()
-
-
-
-