Package com.increase.api.models.cards
Class Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.BuilderA builder for Allowed.
-
Method Summary
Modifier and Type Method Description final Stringidentifier()The Merchant Acceptor ID. final JsonField<String>_identifier()Returns the raw JSON value of identifier. final Map<String, JsonValue>_additionalProperties()final Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.BuildertoBuilder()final Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.Builderbuilder()Returns a mutable builder for constructing an instance of Allowed. -
-
Method Detail
-
identifier
final String identifier()
The Merchant Acceptor ID.
-
_identifier
final JsonField<String> _identifier()
Returns the raw JSON value of identifier.
Unlike identifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Card.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.Builder builder()
Returns a mutable builder for constructing an instance of Allowed.
The following fields are required:
.identifier()
-
-
-
-