Class Card.AuthorizationControls.MerchantCategoryCode
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.MerchantCategoryCodeRestricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.MerchantCategoryCode.BuilderA builder for MerchantCategoryCode.
public final classCard.AuthorizationControls.MerchantCategoryCode.Allowedpublic final classCard.AuthorizationControls.MerchantCategoryCode.Blocked
-
Method Summary
-
-
Method Detail
-
allowed
final Optional<List<Card.AuthorizationControls.MerchantCategoryCode.Allowed>> allowed()
The Merchant Category Codes that are allowed for authorizations on this card.
-
blocked
final Optional<List<Card.AuthorizationControls.MerchantCategoryCode.Blocked>> blocked()
The Merchant Category Codes that are blocked for authorizations on this card.
-
_allowed
final JsonField<List<Card.AuthorizationControls.MerchantCategoryCode.Allowed>> _allowed()
Returns the raw JSON value of allowed.
Unlike allowed, this method doesn't throw if the JSON field has an unexpected type.
-
_blocked
final JsonField<List<Card.AuthorizationControls.MerchantCategoryCode.Blocked>> _blocked()
Returns the raw JSON value of blocked.
Unlike blocked, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.AuthorizationControls.MerchantCategoryCode.Builder toBuilder()
-
validate
final Card.AuthorizationControls.MerchantCategoryCode validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Card.AuthorizationControls.MerchantCategoryCode.Builder builder()
Returns a mutable builder for constructing an instance of MerchantCategoryCode.
The following fields are required:
.allowed() .blocked()
-
-
-
-