Package com.increase.api.models.cards
Class Card.AuthorizationControls.MerchantCategoryCode.Allowed
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.MerchantCategoryCode.Allowed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.MerchantCategoryCode.Allowed.BuilderA builder for Allowed.
-
Method Summary
Modifier and Type Method Description final Stringcode()The Merchant Category Code (MCC). final JsonField<String>_code()Returns the raw JSON value of code. final Map<String, JsonValue>_additionalProperties()final Card.AuthorizationControls.MerchantCategoryCode.Allowed.BuildertoBuilder()final Card.AuthorizationControls.MerchantCategoryCode.Allowedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.AuthorizationControls.MerchantCategoryCode.Allowed.Builderbuilder()Returns a mutable builder for constructing an instance of Allowed. -
-
Method Detail
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.AuthorizationControls.MerchantCategoryCode.Allowed.Builder toBuilder()
-
validate
final Card.AuthorizationControls.MerchantCategoryCode.Allowed validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Card.AuthorizationControls.MerchantCategoryCode.Allowed.Builder builder()
Returns a mutable builder for constructing an instance of Allowed.
The following fields are required:
.code()
-
-
-
-