Package com.increase.api.models.cards
Class Card.AuthorizationControls.MerchantCountry.Blocked
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.MerchantCountry.Blocked
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.MerchantCountry.Blocked.BuilderA builder for Blocked.
-
Method Summary
Modifier and Type Method Description final Stringcountry()The ISO 3166-1 alpha-2 country code. final JsonField<String>_country()Returns the raw JSON value of country. final Map<String, JsonValue>_additionalProperties()final Card.AuthorizationControls.MerchantCountry.Blocked.BuildertoBuilder()final Card.AuthorizationControls.MerchantCountry.Blockedvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.AuthorizationControls.MerchantCountry.Blocked.Builderbuilder()Returns a mutable builder for constructing an instance of Blocked. -
-
Method Detail
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.AuthorizationControls.MerchantCountry.Blocked.Builder toBuilder()
-
validate
final Card.AuthorizationControls.MerchantCountry.Blocked validate()
-
builder
final static Card.AuthorizationControls.MerchantCountry.Blocked.Builder builder()
Returns a mutable builder for constructing an instance of Blocked.
The following fields are required:
.country()
-
-
-
-