Class Card.BillingAddress
-
- All Implemented Interfaces:
public final class Card.BillingAddressThe Card's billing address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.BillingAddress.BuilderA builder for BillingAddress.
-
Method Summary
Modifier and Type Method Description final Optional<String>city()The city of the billing address. final Optional<String>line1()The first line of the billing address. final Optional<String>line2()The second line of the billing address. final Optional<String>postalCode()The postal code of the billing address. final Optional<String>state()The US state of the billing address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final Card.BillingAddress.BuildertoBuilder()final Card.BillingAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Card.BillingAddress.Builderbuilder()Returns a mutable builder for constructing an instance of BillingAddress. -
-
Method Detail
-
postalCode
final Optional<String> postalCode()
The postal code of the billing address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.BillingAddress.Builder toBuilder()
-
validate
final Card.BillingAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Card.BillingAddress.Builder builder()
Returns a mutable builder for constructing an instance of BillingAddress.
The following fields are required:
.city() .line1() .line2() .postalCode() .state()
-
-
-
-