Class Card.BillingAddress.Builder
-
- All Implemented Interfaces:
public final class Card.BillingAddress.BuilderA builder for BillingAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final Card.BillingAddress.Builder city(String city)
The city of the billing address.
-
city
final Card.BillingAddress.Builder city(Optional<String> city)
Alias for calling Builder.city with
city.orElse(null).
-
city
final Card.BillingAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final Card.BillingAddress.Builder line1(String line1)
The first line of the billing address.
-
line1
final Card.BillingAddress.Builder line1(Optional<String> line1)
Alias for calling Builder.line1 with
line1.orElse(null).
-
line1
final Card.BillingAddress.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final Card.BillingAddress.Builder line2(String line2)
The second line of the billing address.
-
line2
final Card.BillingAddress.Builder line2(Optional<String> line2)
Alias for calling Builder.line2 with
line2.orElse(null).
-
line2
final Card.BillingAddress.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final Card.BillingAddress.Builder postalCode(String postalCode)
The postal code of the billing address.
-
postalCode
final Card.BillingAddress.Builder postalCode(Optional<String> postalCode)
Alias for calling Builder.postalCode with
postalCode.orElse(null).
-
postalCode
final Card.BillingAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Card.BillingAddress.Builder state(String state)
The US state of the billing address.
-
state
final Card.BillingAddress.Builder state(Optional<String> state)
Alias for calling Builder.state with
state.orElse(null).
-
state
final Card.BillingAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Card.BillingAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Card.BillingAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Card.BillingAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Card.BillingAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Card.BillingAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Card.BillingAddress build()
Returns an immutable instance of BillingAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .line1() .line2() .postalCode() .state()
-
-
-
-