Class Card.Builder
-
- All Implemented Interfaces:
public final class Card.BuilderA builder for Card.
-
-
Method Summary
Modifier and Type Method Description final Card.Builderid(String id)The card identifier. final Card.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Card.BuilderaccountId(String accountId)The identifier for the account this card belongs to. final Card.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final Card.BuilderbillingAddress(Card.BillingAddress billingAddress)The Card's billing address. final Card.BuilderbillingAddress(JsonField<Card.BillingAddress> billingAddress)Sets Builder.billingAddress to an arbitrary JSON value. final Card.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the Card was created. final Card.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Card.Builderdescription(String description)The card's description for display purposes. final Card.Builderdescription(Optional<String> description)Alias for calling Builder.description with description.orElse(null).final Card.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final Card.BuilderdigitalWallet(Card.DigitalWallet digitalWallet)The contact information used in the two-factor steps for digital wallet card creation. final Card.BuilderdigitalWallet(Optional<Card.DigitalWallet> digitalWallet)Alias for calling Builder.digitalWallet with digitalWallet.orElse(null).final Card.BuilderdigitalWallet(JsonField<Card.DigitalWallet> digitalWallet)Sets Builder.digitalWallet to an arbitrary JSON value. final Card.BuilderentityId(String entityId)The identifier for the entity associated with this card. final Card.BuilderentityId(Optional<String> entityId)Alias for calling Builder.entityId with entityId.orElse(null).final Card.BuilderentityId(JsonField<String> entityId)Sets Builder.entityId to an arbitrary JSON value. final Card.BuilderexpirationMonth(Long expirationMonth)The month the card expires in M format (e.g., August is 8). final Card.BuilderexpirationMonth(JsonField<Long> expirationMonth)Sets Builder.expirationMonth to an arbitrary JSON value. final Card.BuilderexpirationYear(Long expirationYear)The year the card expires in YYYY format (e.g., 2025). final Card.BuilderexpirationYear(JsonField<Long> expirationYear)Sets Builder.expirationYear to an arbitrary JSON value. final Card.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Card.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final Card.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final Card.Builderlast4(String last4)The last 4 digits of the Card's Primary Account Number. final Card.Builderlast4(JsonField<String> last4)Sets Builder.last4 to an arbitrary JSON value. final Card.Builderstatus(Card.Status status)This indicates if payments can be made with the card. final Card.Builderstatus(JsonField<Card.Status> status)Sets Builder.status to an arbitrary JSON value. final Card.Buildertype(Card.Type type)A constant representing the object's type. final Card.Buildertype(JsonField<Card.Type> type)Sets Builder.type to an arbitrary JSON value. final Card.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderputAdditionalProperty(String key, JsonValue value)final Card.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Card.BuilderremoveAdditionalProperty(String key)final Card.BuilderremoveAllAdditionalProperties(Set<String> keys)final Cardbuild()Returns an immutable instance of Card. -
-
Method Detail
-
id
final Card.Builder id(String id)
The card identifier.
-
id
final Card.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final Card.Builder accountId(String accountId)
The identifier for the account this card belongs to.
-
accountId
final Card.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddress
final Card.Builder billingAddress(Card.BillingAddress billingAddress)
The Card's billing address.
-
billingAddress
final Card.Builder billingAddress(JsonField<Card.BillingAddress> billingAddress)
Sets Builder.billingAddress to an arbitrary JSON value.
You should usually call Builder.billingAddress with a well-typed BillingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Card.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Card was created.
-
createdAt
final Card.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Card.Builder description(String description)
The card's description for display purposes.
-
description
final Card.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final Card.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final Card.Builder digitalWallet(Card.DigitalWallet digitalWallet)
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
digitalWallet
final Card.Builder digitalWallet(Optional<Card.DigitalWallet> digitalWallet)
Alias for calling Builder.digitalWallet with
digitalWallet.orElse(null).
-
digitalWallet
final Card.Builder digitalWallet(JsonField<Card.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final Card.Builder entityId(String entityId)
The identifier for the entity associated with this card.
-
entityId
final Card.Builder entityId(Optional<String> entityId)
Alias for calling Builder.entityId with
entityId.orElse(null).
-
entityId
final Card.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationMonth
final Card.Builder expirationMonth(Long expirationMonth)
The month the card expires in M format (e.g., August is 8).
-
expirationMonth
final Card.Builder expirationMonth(JsonField<Long> expirationMonth)
Sets Builder.expirationMonth to an arbitrary JSON value.
You should usually call Builder.expirationMonth with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationYear
final Card.Builder expirationYear(Long expirationYear)
The year the card expires in YYYY format (e.g., 2025).
-
expirationYear
final Card.Builder expirationYear(JsonField<Long> expirationYear)
Sets Builder.expirationYear to an arbitrary JSON value.
You should usually call Builder.expirationYear with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final Card.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Card.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final Card.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
last4
final Card.Builder last4(String last4)
The last 4 digits of the Card's Primary Account Number.
-
last4
final Card.Builder last4(JsonField<String> last4)
Sets Builder.last4 to an arbitrary JSON value.
You should usually call Builder.last4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Card.Builder status(Card.Status status)
This indicates if payments can be made with the card.
-
status
final Card.Builder status(JsonField<Card.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Card.Builder type(Card.Type type)
A constant representing the object's type. For this resource it will always be
card.
-
type
final Card.Builder type(JsonField<Card.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Card.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Card.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Card.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Card.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Card.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Card build()
Returns an immutable instance of Card.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .billingAddress() .createdAt() .description() .digitalWallet() .entityId() .expirationMonth() .expirationYear() .idempotencyKey() .last4() .status() .type()
-
-
-
-