Class CardCreateDetailsIframeParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class CardCreateDetailsIframeParams
     implements Params
                        

    Create an iframe URL for a Card to display the card details. More details about styling and usage can be found in the /documentation/embedded-card-component.