Package com.increase.api.models.cards
Class CardCreateDetailsIframeParams.Body
-
- All Implemented Interfaces:
public final class CardCreateDetailsIframeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateDetailsIframeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>physicalCardId()The identifier of the Physical Card to create an iframe for. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final Map<String, JsonValue>_additionalProperties()final CardCreateDetailsIframeParams.Body.BuildertoBuilder()final CardCreateDetailsIframeParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateDetailsIframeParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
physicalCardId
final Optional<String> physicalCardId()
The identifier of the Physical Card to create an iframe for. This will inform the appearance of the card rendered in the iframe.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateDetailsIframeParams.Body.Builder toBuilder()
-
validate
final CardCreateDetailsIframeParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateDetailsIframeParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-