Package com.increase.api.models.cards
Class CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.BuilderA builder for Allowed.
-
Method Summary
Modifier and Type Method Description final Stringidentifier()The Merchant Acceptor ID. final JsonField<String>_identifier()Returns the raw JSON value of identifier. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.BuildertoBuilder()final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowedvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.Builderbuilder()Returns a mutable builder for constructing an instance of Allowed. -
-
Method Detail
-
identifier
final String identifier()
The Merchant Acceptor ID.
-
_identifier
final JsonField<String> _identifier()
Returns the raw JSON value of identifier.
Unlike identifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.Builder toBuilder()
-
builder
final static CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed.Builder builder()
Returns a mutable builder for constructing an instance of Allowed.
The following fields are required:
.identifier()
-
-
-
-