Class CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.BuilderA builder for MerchantAcceptorIdentifier.
-
-
Method Summary
-
-
Method Detail
-
allowed
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder allowed(List<CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed> allowed)
The Merchant Acceptor IDs that are allowed for authorizations on this card. Authorizations with Merchant Acceptor IDs not in this list will be declined.
-
allowed
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder allowed(JsonField<List<CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed>> allowed)
Sets Builder.allowed to an arbitrary JSON value.
You should usually call Builder.allowed with a well-typed
List<Allowed>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAllowed
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder addAllowed(CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed allowed)
Adds a single Allowed to Builder.allowed.
-
blocked
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder blocked(List<CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Blocked> blocked)
The Merchant Acceptor IDs that are blocked for authorizations on this card. Authorizations with Merchant Acceptor IDs in this list will be declined.
-
blocked
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder blocked(JsonField<List<CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Blocked>> blocked)
Sets Builder.blocked to an arbitrary JSON value.
You should usually call Builder.blocked with a well-typed
List<Blocked>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBlocked
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder addBlocked(CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Blocked blocked)
Adds a single Blocked to Builder.blocked.
-
additionalProperties
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardCreateParams.AuthorizationControls.MerchantAcceptorIdentifier build()
Returns an immutable instance of MerchantAcceptorIdentifier.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-