Package com.increase.api.models.cards
Class CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed.BuilderA builder for Allowed.
-
Method Summary
Modifier and Type Method Description final Stringcode()The Merchant Category Code. final JsonField<String>_code()Returns the raw JSON value of code. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed.BuildertoBuilder()final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowedvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed.Builderbuilder()Returns a mutable builder for constructing an instance of Allowed. -
-
Method Detail
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed.Builder toBuilder()
-
builder
final static CardCreateParams.AuthorizationControls.MerchantCategoryCode.Allowed.Builder builder()
Returns a mutable builder for constructing an instance of Allowed.
The following fields are required:
.code()
-
-
-
-