Package com.increase.api.models.cards
Class CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked.BuilderA builder for Blocked.
-
Method Summary
Modifier and Type Method Description final Stringcode()The Merchant Category Code. final JsonField<String>_code()Returns the raw JSON value of code. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked.BuildertoBuilder()final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blockedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked.Builderbuilder()Returns a mutable builder for constructing an instance of Blocked. -
-
Method Detail
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked.Builder toBuilder()
-
validate
final CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateParams.AuthorizationControls.MerchantCategoryCode.Blocked.Builder builder()
Returns a mutable builder for constructing an instance of Blocked.
The following fields are required:
.code()
-
-
-
-