Class CardCreateParams.AuthorizationControls.MerchantCountry
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantCountryRestricts which merchant countries are allowed or blocked for authorizations on this card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.MerchantCountry.BuilderA builder for MerchantCountry.
public final classCardCreateParams.AuthorizationControls.MerchantCountry.Allowedpublic final classCardCreateParams.AuthorizationControls.MerchantCountry.Blocked
-
Method Summary
-
-
Method Detail
-
allowed
final Optional<List<CardCreateParams.AuthorizationControls.MerchantCountry.Allowed>> allowed()
The merchant countries that are allowed for authorizations on this card. Authorizations with merchant countries not in this list will be declined.
-
blocked
final Optional<List<CardCreateParams.AuthorizationControls.MerchantCountry.Blocked>> blocked()
The merchant countries that are blocked for authorizations on this card. Authorizations with merchant countries in this list will be declined.
-
_allowed
final JsonField<List<CardCreateParams.AuthorizationControls.MerchantCountry.Allowed>> _allowed()
Returns the raw JSON value of allowed.
Unlike allowed, this method doesn't throw if the JSON field has an unexpected type.
-
_blocked
final JsonField<List<CardCreateParams.AuthorizationControls.MerchantCountry.Blocked>> _blocked()
Returns the raw JSON value of blocked.
Unlike blocked, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder toBuilder()
-
validate
final CardCreateParams.AuthorizationControls.MerchantCountry validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateParams.AuthorizationControls.MerchantCountry.Builder builder()
Returns a mutable builder for constructing an instance of MerchantCountry.
-
-
-
-