Package com.increase.api.models.cards
Class CardCreateParams.AuthorizationControls.MerchantCountry.Allowed
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantCountry.Allowed
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.MerchantCountry.Allowed.BuilderA builder for Allowed.
-
Method Summary
Modifier and Type Method Description final Stringcountry()The ISO 3166-1 alpha-2 country code. final JsonField<String>_country()Returns the raw JSON value of country. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.BuildertoBuilder()final CardCreateParams.AuthorizationControls.MerchantCountry.Allowedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builderbuilder()Returns a mutable builder for constructing an instance of Allowed. -
-
Method Detail
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder builder()
Returns a mutable builder for constructing an instance of Allowed.
The following fields are required:
.country()
-
-
-
-