Package com.increase.api.models.cards
Class CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.BuilderA builder for Allowed.
-
-
Method Summary
-
-
Method Detail
-
country
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder country(String country)
The ISO 3166-1 alpha-2 country code.
-
country
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardCreateParams.AuthorizationControls.MerchantCountry.Allowed build()
Returns an immutable instance of Allowed.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.country()
-
-
-
-