Class CardCreateParams.AuthorizationControls.MerchantCountry.Builder
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.MerchantCountry.BuilderA builder for MerchantCountry.
-
-
Method Summary
-
-
Method Detail
-
allowed
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder allowed(List<CardCreateParams.AuthorizationControls.MerchantCountry.Allowed> allowed)
The merchant countries that are allowed for authorizations on this card. Authorizations with merchant countries not in this list will be declined.
-
allowed
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder allowed(JsonField<List<CardCreateParams.AuthorizationControls.MerchantCountry.Allowed>> allowed)
Sets Builder.allowed to an arbitrary JSON value.
You should usually call Builder.allowed with a well-typed
List<Allowed>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAllowed
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder addAllowed(CardCreateParams.AuthorizationControls.MerchantCountry.Allowed allowed)
Adds a single Allowed to Builder.allowed.
-
blocked
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder blocked(List<CardCreateParams.AuthorizationControls.MerchantCountry.Blocked> blocked)
The merchant countries that are blocked for authorizations on this card. Authorizations with merchant countries in this list will be declined.
-
blocked
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder blocked(JsonField<List<CardCreateParams.AuthorizationControls.MerchantCountry.Blocked>> blocked)
Sets Builder.blocked to an arbitrary JSON value.
You should usually call Builder.blocked with a well-typed
List<Blocked>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBlocked
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder addBlocked(CardCreateParams.AuthorizationControls.MerchantCountry.Blocked blocked)
Adds a single Blocked to Builder.blocked.
-
additionalProperties
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardCreateParams.AuthorizationControls.MerchantCountry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardCreateParams.AuthorizationControls.MerchantCountry build()
Returns an immutable instance of MerchantCountry.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-