Class CardCreateParams.AuthorizationControls.Usage
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.UsageControls how many times this card can be used.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.Usage.BuilderA builder for Usage.
public final classCardCreateParams.AuthorizationControls.Usage.CategoryWhether the card is for a single use or multiple uses.
public final classCardCreateParams.AuthorizationControls.Usage.MultiUseControls for multi-use cards. Required if and only if
categoryismulti_use.public final classCardCreateParams.AuthorizationControls.Usage.SingleUseControls for single-use cards. Required if and only if
categoryissingle_use.
-
Method Summary
-
-
Method Detail
-
category
final CardCreateParams.AuthorizationControls.Usage.Category category()
Whether the card is for a single use or multiple uses.
-
multiUse
final Optional<CardCreateParams.AuthorizationControls.Usage.MultiUse> multiUse()
Controls for multi-use cards. Required if and only if
categoryismulti_use.
-
singleUse
final Optional<CardCreateParams.AuthorizationControls.Usage.SingleUse> singleUse()
Controls for single-use cards. Required if and only if
categoryissingle_use.
-
_category
final JsonField<CardCreateParams.AuthorizationControls.Usage.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_multiUse
final JsonField<CardCreateParams.AuthorizationControls.Usage.MultiUse> _multiUse()
Returns the raw JSON value of multiUse.
Unlike multiUse, this method doesn't throw if the JSON field has an unexpected type.
-
_singleUse
final JsonField<CardCreateParams.AuthorizationControls.Usage.SingleUse> _singleUse()
Returns the raw JSON value of singleUse.
Unlike singleUse, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.AuthorizationControls.Usage.Builder toBuilder()
-
validate
final CardCreateParams.AuthorizationControls.Usage validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateParams.AuthorizationControls.Usage.Builder builder()
Returns a mutable builder for constructing an instance of Usage.
The following fields are required:
.category()
-
-
-
-