Package com.increase.api.models.cards
Class CardCreateParams.AuthorizationControls.Usage.SingleUse
-
- All Implemented Interfaces:
public final class CardCreateParams.AuthorizationControls.Usage.SingleUseControls for single-use cards. Required if and only if
categoryissingle_use.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.AuthorizationControls.Usage.SingleUse.BuilderA builder for SingleUse.
public final classCardCreateParams.AuthorizationControls.Usage.SingleUse.SettlementAmountThe settlement amount constraint for this single-use card.
-
Method Summary
Modifier and Type Method Description final CardCreateParams.AuthorizationControls.Usage.SingleUse.SettlementAmountsettlementAmount()The settlement amount constraint for this single-use card. final JsonField<CardCreateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount>_settlementAmount()Returns the raw JSON value of settlementAmount. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.AuthorizationControls.Usage.SingleUse.BuildertoBuilder()final CardCreateParams.AuthorizationControls.Usage.SingleUsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.AuthorizationControls.Usage.SingleUse.Builderbuilder()Returns a mutable builder for constructing an instance of SingleUse. -
-
Method Detail
-
settlementAmount
final CardCreateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount settlementAmount()
The settlement amount constraint for this single-use card.
-
_settlementAmount
final JsonField<CardCreateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.AuthorizationControls.Usage.SingleUse.Builder toBuilder()
-
validate
final CardCreateParams.AuthorizationControls.Usage.SingleUse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateParams.AuthorizationControls.Usage.SingleUse.Builder builder()
Returns a mutable builder for constructing an instance of SingleUse.
The following fields are required:
.settlementAmount()
-
-
-
-