Class CardCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final CardCreateParams.Body.Builder accountId(String accountId)
The Account the card should belong to.
-
accountId
final CardCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizationControls
final CardCreateParams.Body.Builder authorizationControls(CardCreateParams.AuthorizationControls authorizationControls)
Controls that restrict how this card can be used.
-
authorizationControls
final CardCreateParams.Body.Builder authorizationControls(JsonField<CardCreateParams.AuthorizationControls> authorizationControls)
Sets Builder.authorizationControls to an arbitrary JSON value.
You should usually call Builder.authorizationControls with a well-typed AuthorizationControls value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddress
final CardCreateParams.Body.Builder billingAddress(CardCreateParams.BillingAddress billingAddress)
The card's billing address.
-
billingAddress
final CardCreateParams.Body.Builder billingAddress(JsonField<CardCreateParams.BillingAddress> billingAddress)
Sets Builder.billingAddress to an arbitrary JSON value.
You should usually call Builder.billingAddress with a well-typed BillingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final CardCreateParams.Body.Builder description(String description)
The description you choose to give the card.
-
description
final CardCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final CardCreateParams.Body.Builder digitalWallet(CardCreateParams.DigitalWallet digitalWallet)
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
digitalWallet
final CardCreateParams.Body.Builder digitalWallet(JsonField<CardCreateParams.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final CardCreateParams.Body.Builder entityId(String entityId)
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
entityId
final CardCreateParams.Body.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId()
-
-
-
-