Class CardCreateParams.DigitalWallet
-
- All Implemented Interfaces:
public final class CardCreateParams.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.DigitalWallet.BuilderA builder for DigitalWallet.
-
Method Summary
Modifier and Type Method Description final Optional<String>digitalCardProfileId()The digital card profile assigned to this digital card. final Optional<String>email()An email address that can be used to contact and verify the cardholder via one-time passcode over email. final Optional<String>phone()A phone number that can be used to contact and verify the cardholder via one-time passcode over SMS. final JsonField<String>_digitalCardProfileId()Returns the raw JSON value of digitalCardProfileId. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_phone()Returns the raw JSON value of phone. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.DigitalWallet.BuildertoBuilder()final CardCreateParams.DigitalWalletvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.DigitalWallet.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalWallet. -
-
Method Detail
-
digitalCardProfileId
final Optional<String> digitalCardProfileId()
The digital card profile assigned to this digital card.
-
email
final Optional<String> email()
An email address that can be used to contact and verify the cardholder via one-time passcode over email.
-
phone
final Optional<String> phone()
A phone number that can be used to contact and verify the cardholder via one-time passcode over SMS.
-
_digitalCardProfileId
final JsonField<String> _digitalCardProfileId()
Returns the raw JSON value of digitalCardProfileId.
Unlike digitalCardProfileId, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_phone
final JsonField<String> _phone()
Returns the raw JSON value of phone.
Unlike phone, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.DigitalWallet.Builder toBuilder()
-
validate
final CardCreateParams.DigitalWallet validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardCreateParams.DigitalWallet.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWallet.
-
-
-
-