Class CardDetails

  • All Implemented Interfaces:

    
    public final class CardDetails
    
                        

    An object containing the sensitive details (card number, CVC, PIN, etc) for a Card. These details are not included in the Card object. If you'd prefer to never access these details directly, you can use the /documentation/embedded-card-component to display the information to your users.