Class CardDetails.Builder
-
- All Implemented Interfaces:
public final class CardDetails.BuilderA builder for CardDetails.
-
-
Method Summary
Modifier and Type Method Description final CardDetails.BuildercardId(String cardId)The identifier for the Card for which sensitive details have been returned. final CardDetails.BuildercardId(JsonField<String> cardId)Sets Builder.cardId to an arbitrary JSON value. final CardDetails.BuilderexpirationMonth(Long expirationMonth)The month the card expires in M format (e.g., August is 8). final CardDetails.BuilderexpirationMonth(JsonField<Long> expirationMonth)Sets Builder.expirationMonth to an arbitrary JSON value. final CardDetails.BuilderexpirationYear(Long expirationYear)The year the card expires in YYYY format (e.g., 2025). final CardDetails.BuilderexpirationYear(JsonField<Long> expirationYear)Sets Builder.expirationYear to an arbitrary JSON value. final CardDetails.Builderpin(String pin)The 4-digit PIN for the card, for use with ATMs. final CardDetails.Builderpin(JsonField<String> pin)Sets Builder.pin to an arbitrary JSON value. final CardDetails.BuilderprimaryAccountNumber(String primaryAccountNumber)The card number. final CardDetails.BuilderprimaryAccountNumber(JsonField<String> primaryAccountNumber)Sets Builder.primaryAccountNumber to an arbitrary JSON value. final CardDetails.Buildertype(CardDetails.Type type)A constant representing the object's type. final CardDetails.Buildertype(JsonField<CardDetails.Type> type)Sets Builder.type to an arbitrary JSON value. final CardDetails.BuilderverificationCode(String verificationCode)The three-digit verification code for the card. final CardDetails.BuilderverificationCode(JsonField<String> verificationCode)Sets Builder.verificationCode to an arbitrary JSON value. final CardDetails.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardDetails.BuilderputAdditionalProperty(String key, JsonValue value)final CardDetails.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardDetails.BuilderremoveAdditionalProperty(String key)final CardDetails.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardDetailsbuild()Returns an immutable instance of CardDetails. -
-
Method Detail
-
cardId
final CardDetails.Builder cardId(String cardId)
The identifier for the Card for which sensitive details have been returned.
-
cardId
final CardDetails.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationMonth
final CardDetails.Builder expirationMonth(Long expirationMonth)
The month the card expires in M format (e.g., August is 8).
-
expirationMonth
final CardDetails.Builder expirationMonth(JsonField<Long> expirationMonth)
Sets Builder.expirationMonth to an arbitrary JSON value.
You should usually call Builder.expirationMonth with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationYear
final CardDetails.Builder expirationYear(Long expirationYear)
The year the card expires in YYYY format (e.g., 2025).
-
expirationYear
final CardDetails.Builder expirationYear(JsonField<Long> expirationYear)
Sets Builder.expirationYear to an arbitrary JSON value.
You should usually call Builder.expirationYear with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pin
final CardDetails.Builder pin(String pin)
The 4-digit PIN for the card, for use with ATMs.
-
pin
final CardDetails.Builder pin(JsonField<String> pin)
Sets Builder.pin to an arbitrary JSON value.
You should usually call Builder.pin with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
primaryAccountNumber
final CardDetails.Builder primaryAccountNumber(String primaryAccountNumber)
The card number.
-
primaryAccountNumber
final CardDetails.Builder primaryAccountNumber(JsonField<String> primaryAccountNumber)
Sets Builder.primaryAccountNumber to an arbitrary JSON value.
You should usually call Builder.primaryAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardDetails.Builder type(CardDetails.Type type)
A constant representing the object's type. For this resource it will always be
card_details.
-
type
final CardDetails.Builder type(JsonField<CardDetails.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verificationCode
final CardDetails.Builder verificationCode(String verificationCode)
The three-digit verification code for the card. It's also known as the Card Verification Code (CVC), the Card Verification Value (CVV), or the Card Identification (CID).
-
verificationCode
final CardDetails.Builder verificationCode(JsonField<String> verificationCode)
Sets Builder.verificationCode to an arbitrary JSON value.
You should usually call Builder.verificationCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardDetails.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardDetails.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardDetails.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardDetails.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardDetails.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardDetails build()
Returns an immutable instance of CardDetails.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardId() .expirationMonth() .expirationYear() .pin() .primaryAccountNumber() .type() .verificationCode()
-
-
-
-