Class CardIframeUrl
-
- All Implemented Interfaces:
public final class CardIframeUrlAn object containing the iframe URL for a Card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardIframeUrl.BuilderA builder for CardIframeUrl.
public final classCardIframeUrl.TypeA constant representing the object's type. For this resource it will always be
card_iframe_url.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeexpiresAt()The time the iframe URL will expire. final StringiframeUrl()The iframe URL for the Card. final CardIframeUrl.Typetype()A constant representing the object's type. final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final JsonField<String>_iframeUrl()Returns the raw JSON value of iframeUrl. final JsonField<CardIframeUrl.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardIframeUrl.BuildertoBuilder()final CardIframeUrlvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardIframeUrl.Builderbuilder()Returns a mutable builder for constructing an instance of CardIframeUrl. -
-
Method Detail
-
expiresAt
final OffsetDateTime expiresAt()
The time the iframe URL will expire.
-
type
final CardIframeUrl.Type type()
A constant representing the object's type. For this resource it will always be
card_iframe_url.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_iframeUrl
final JsonField<String> _iframeUrl()
Returns the raw JSON value of iframeUrl.
Unlike iframeUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardIframeUrl.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardIframeUrl.Builder toBuilder()
-
validate
final CardIframeUrl validate()
-
builder
final static CardIframeUrl.Builder builder()
Returns a mutable builder for constructing an instance of CardIframeUrl.
The following fields are required:
.expiresAt() .iframeUrl() .type()
-
-
-
-