Class CardIframeUrl.Builder
-
- All Implemented Interfaces:
public final class CardIframeUrl.BuilderA builder for CardIframeUrl.
-
-
Method Summary
-
-
Method Detail
-
expiresAt
final CardIframeUrl.Builder expiresAt(OffsetDateTime expiresAt)
The time the iframe URL will expire.
-
expiresAt
final CardIframeUrl.Builder expiresAt(JsonField<OffsetDateTime> expiresAt)
Sets Builder.expiresAt to an arbitrary JSON value.
You should usually call Builder.expiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
iframeUrl
final CardIframeUrl.Builder iframeUrl(String iframeUrl)
The iframe URL for the Card. Treat this as an opaque URL.
-
iframeUrl
final CardIframeUrl.Builder iframeUrl(JsonField<String> iframeUrl)
Sets Builder.iframeUrl to an arbitrary JSON value.
You should usually call Builder.iframeUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardIframeUrl.Builder type(CardIframeUrl.Type type)
A constant representing the object's type. For this resource it will always be
card_iframe_url.
-
type
final CardIframeUrl.Builder type(JsonField<CardIframeUrl.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardIframeUrl.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardIframeUrl.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardIframeUrl.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardIframeUrl.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardIframeUrl.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardIframeUrl build()
Returns an immutable instance of CardIframeUrl.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.expiresAt() .iframeUrl() .type()
-
-
-
-