Class CardUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardUpdateParams implements Params
Update a Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.BuilderA builder for CardUpdateParams.
public final classCardUpdateParams.Bodypublic final classCardUpdateParams.AuthorizationControlsControls that restrict how this card can be used.
public final classCardUpdateParams.BillingAddressThe card's updated billing address.
public final classCardUpdateParams.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
public final classCardUpdateParams.StatusThe status to update the Card with.
-
Method Summary
Modifier and Type Method Description final Optional<String>cardId()The card identifier. final Optional<CardUpdateParams.AuthorizationControls>authorizationControls()Controls that restrict how this card can be used. final Optional<CardUpdateParams.BillingAddress>billingAddress()The card's updated billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardUpdateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final Optional<CardUpdateParams.Status>status()The status to update the Card with. final JsonField<CardUpdateParams.AuthorizationControls>_authorizationControls()Returns the raw JSON value of authorizationControls. final JsonField<CardUpdateParams.BillingAddress>_billingAddress()Returns the raw JSON value of billingAddress. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<CardUpdateParams.DigitalWallet>_digitalWallet()Returns the raw JSON value of digitalWallet. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<CardUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardUpdateParams.BuildertoBuilder()final CardUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdateParamsnone()final static CardUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardUpdateParams. -
-
Method Detail
-
authorizationControls
final Optional<CardUpdateParams.AuthorizationControls> authorizationControls()
Controls that restrict how this card can be used.
-
billingAddress
final Optional<CardUpdateParams.BillingAddress> billingAddress()
The card's updated billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardUpdateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
status
final Optional<CardUpdateParams.Status> status()
The status to update the Card with.
-
_authorizationControls
final JsonField<CardUpdateParams.AuthorizationControls> _authorizationControls()
Returns the raw JSON value of authorizationControls.
Unlike authorizationControls, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddress
final JsonField<CardUpdateParams.BillingAddress> _billingAddress()
Returns the raw JSON value of billingAddress.
Unlike billingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<CardUpdateParams.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardUpdateParams.Builder toBuilder()
-
_body
final CardUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardUpdateParams none()
-
builder
final static CardUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardUpdateParams.
-
-
-
-