Class CardUpdateParams.AuthorizationControls
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControlsControls that restrict how this card can be used.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.BuilderA builder for AuthorizationControls.
public final classCardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifierRestricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
public final classCardUpdateParams.AuthorizationControls.MerchantCategoryCodeRestricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
public final classCardUpdateParams.AuthorizationControls.MerchantCountryRestricts which merchant countries are allowed or blocked for authorizations on this card.
public final classCardUpdateParams.AuthorizationControls.UsageControls how many times this card can be used.
-
Method Summary
-
-
Method Detail
-
merchantAcceptorIdentifier
final Optional<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier> merchantAcceptorIdentifier()
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
merchantCategoryCode
final Optional<CardUpdateParams.AuthorizationControls.MerchantCategoryCode> merchantCategoryCode()
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
merchantCountry
final Optional<CardUpdateParams.AuthorizationControls.MerchantCountry> merchantCountry()
Restricts which merchant countries are allowed or blocked for authorizations on this card.
-
usage
final Optional<CardUpdateParams.AuthorizationControls.Usage> usage()
Controls how many times this card can be used.
-
_merchantAcceptorIdentifier
final JsonField<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier> _merchantAcceptorIdentifier()
Returns the raw JSON value of merchantAcceptorIdentifier.
Unlike merchantAcceptorIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<CardUpdateParams.AuthorizationControls.MerchantCategoryCode> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<CardUpdateParams.AuthorizationControls.MerchantCountry> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_usage
final JsonField<CardUpdateParams.AuthorizationControls.Usage> _usage()
Returns the raw JSON value of usage.
Unlike usage, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls validate()
-
builder
final static CardUpdateParams.AuthorizationControls.Builder builder()
Returns a mutable builder for constructing an instance of AuthorizationControls.
-
-
-
-