Class CardUpdateParams.AuthorizationControls.Builder
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.BuilderA builder for AuthorizationControls.
-
-
Method Summary
-
-
Method Detail
-
merchantAcceptorIdentifier
final CardUpdateParams.AuthorizationControls.Builder merchantAcceptorIdentifier(CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier merchantAcceptorIdentifier)
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
merchantAcceptorIdentifier
final CardUpdateParams.AuthorizationControls.Builder merchantAcceptorIdentifier(JsonField<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier> merchantAcceptorIdentifier)
Sets Builder.merchantAcceptorIdentifier to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorIdentifier with a well-typed MerchantAcceptorIdentifier value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardUpdateParams.AuthorizationControls.Builder merchantCategoryCode(CardUpdateParams.AuthorizationControls.MerchantCategoryCode merchantCategoryCode)
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
merchantCategoryCode
final CardUpdateParams.AuthorizationControls.Builder merchantCategoryCode(JsonField<CardUpdateParams.AuthorizationControls.MerchantCategoryCode> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed MerchantCategoryCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final CardUpdateParams.AuthorizationControls.Builder merchantCountry(CardUpdateParams.AuthorizationControls.MerchantCountry merchantCountry)
Restricts which merchant countries are allowed or blocked for authorizations on this card.
-
merchantCountry
final CardUpdateParams.AuthorizationControls.Builder merchantCountry(JsonField<CardUpdateParams.AuthorizationControls.MerchantCountry> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed MerchantCountry value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
usage
final CardUpdateParams.AuthorizationControls.Builder usage(CardUpdateParams.AuthorizationControls.Usage usage)
Controls how many times this card can be used.
-
usage
final CardUpdateParams.AuthorizationControls.Builder usage(JsonField<CardUpdateParams.AuthorizationControls.Usage> usage)
Sets Builder.usage to an arbitrary JSON value.
You should usually call Builder.usage with a well-typed Usage value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardUpdateParams.AuthorizationControls.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardUpdateParams.AuthorizationControls.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardUpdateParams.AuthorizationControls.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardUpdateParams.AuthorizationControls.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardUpdateParams.AuthorizationControls.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardUpdateParams.AuthorizationControls build()
Returns an immutable instance of AuthorizationControls.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-