Class CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifierRestricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.BuilderA builder for MerchantAcceptorIdentifier.
public final classCardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowedpublic final classCardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Blocked
-
Method Summary
-
-
Method Detail
-
allowed
final Optional<List<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed>> allowed()
The Merchant Acceptor IDs that are allowed for authorizations on this card. Authorizations with Merchant Acceptor IDs not in this list will be declined.
-
blocked
final Optional<List<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Blocked>> blocked()
The Merchant Acceptor IDs that are blocked for authorizations on this card. Authorizations with Merchant Acceptor IDs in this list will be declined.
-
_allowed
final JsonField<List<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Allowed>> _allowed()
Returns the raw JSON value of allowed.
Unlike allowed, this method doesn't throw if the JSON field has an unexpected type.
-
_blocked
final JsonField<List<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Blocked>> _blocked()
Returns the raw JSON value of blocked.
Unlike blocked, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder toBuilder()
-
builder
final static CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier.Builder builder()
Returns a mutable builder for constructing an instance of MerchantAcceptorIdentifier.
-
-
-
-