Class CardUpdateParams.AuthorizationControls.MerchantCategoryCode
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.MerchantCategoryCodeRestricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.MerchantCategoryCode.BuilderA builder for MerchantCategoryCode.
public final classCardUpdateParams.AuthorizationControls.MerchantCategoryCode.Allowedpublic final classCardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked
-
Method Summary
-
-
Method Detail
-
allowed
final Optional<List<CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Allowed>> allowed()
The Merchant Category Codes that are allowed for authorizations on this card. Authorizations with Merchant Category Codes not in this list will be declined.
-
blocked
final Optional<List<CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked>> blocked()
The Merchant Category Codes that are blocked for authorizations on this card. Authorizations with Merchant Category Codes in this list will be declined.
-
_allowed
final JsonField<List<CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Allowed>> _allowed()
Returns the raw JSON value of allowed.
Unlike allowed, this method doesn't throw if the JSON field has an unexpected type.
-
_blocked
final JsonField<List<CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked>> _blocked()
Returns the raw JSON value of blocked.
Unlike blocked, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls.MerchantCategoryCode validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Builder builder()
Returns a mutable builder for constructing an instance of MerchantCategoryCode.
-
-
-
-