Package com.increase.api.models.cards
Class CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked.BuilderA builder for Blocked.
-
Method Summary
Modifier and Type Method Description final Stringcode()The Merchant Category Code. final JsonField<String>_code()Returns the raw JSON value of code. final Map<String, JsonValue>_additionalProperties()final CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked.BuildertoBuilder()final CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blockedvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked.Builderbuilder()Returns a mutable builder for constructing an instance of Blocked. -
-
Method Detail
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked.Builder toBuilder()
-
builder
final static CardUpdateParams.AuthorizationControls.MerchantCategoryCode.Blocked.Builder builder()
Returns a mutable builder for constructing an instance of Blocked.
The following fields are required:
.code()
-
-
-
-