Class CardUpdateParams.AuthorizationControls.MerchantCountry
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.MerchantCountryRestricts which merchant countries are allowed or blocked for authorizations on this card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.MerchantCountry.BuilderA builder for MerchantCountry.
public final classCardUpdateParams.AuthorizationControls.MerchantCountry.Allowedpublic final classCardUpdateParams.AuthorizationControls.MerchantCountry.Blocked
-
Method Summary
-
-
Method Detail
-
allowed
final Optional<List<CardUpdateParams.AuthorizationControls.MerchantCountry.Allowed>> allowed()
The merchant countries that are allowed for authorizations on this card. Authorizations with merchant countries not in this list will be declined.
-
blocked
final Optional<List<CardUpdateParams.AuthorizationControls.MerchantCountry.Blocked>> blocked()
The merchant countries that are blocked for authorizations on this card. Authorizations with merchant countries in this list will be declined.
-
_allowed
final JsonField<List<CardUpdateParams.AuthorizationControls.MerchantCountry.Allowed>> _allowed()
Returns the raw JSON value of allowed.
Unlike allowed, this method doesn't throw if the JSON field has an unexpected type.
-
_blocked
final JsonField<List<CardUpdateParams.AuthorizationControls.MerchantCountry.Blocked>> _blocked()
Returns the raw JSON value of blocked.
Unlike blocked, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.MerchantCountry.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls.MerchantCountry validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardUpdateParams.AuthorizationControls.MerchantCountry.Builder builder()
Returns a mutable builder for constructing an instance of MerchantCountry.
-
-
-
-