Class CardUpdateParams.AuthorizationControls.Usage
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.UsageControls how many times this card can be used.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.Usage.BuilderA builder for Usage.
public final classCardUpdateParams.AuthorizationControls.Usage.CategoryWhether the card is for a single use or multiple uses.
public final classCardUpdateParams.AuthorizationControls.Usage.MultiUseControls for multi-use cards. Required if and only if
categoryismulti_use.public final classCardUpdateParams.AuthorizationControls.Usage.SingleUseControls for single-use cards. Required if and only if
categoryissingle_use.
-
Method Summary
-
-
Method Detail
-
category
final CardUpdateParams.AuthorizationControls.Usage.Category category()
Whether the card is for a single use or multiple uses.
-
multiUse
final Optional<CardUpdateParams.AuthorizationControls.Usage.MultiUse> multiUse()
Controls for multi-use cards. Required if and only if
categoryismulti_use.
-
singleUse
final Optional<CardUpdateParams.AuthorizationControls.Usage.SingleUse> singleUse()
Controls for single-use cards. Required if and only if
categoryissingle_use.
-
_category
final JsonField<CardUpdateParams.AuthorizationControls.Usage.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_multiUse
final JsonField<CardUpdateParams.AuthorizationControls.Usage.MultiUse> _multiUse()
Returns the raw JSON value of multiUse.
Unlike multiUse, this method doesn't throw if the JSON field has an unexpected type.
-
_singleUse
final JsonField<CardUpdateParams.AuthorizationControls.Usage.SingleUse> _singleUse()
Returns the raw JSON value of singleUse.
Unlike singleUse, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.Usage.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls.Usage validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardUpdateParams.AuthorizationControls.Usage.Builder builder()
Returns a mutable builder for constructing an instance of Usage.
The following fields are required:
.category()
-
-
-
-