Class CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.BuilderA builder for SpendingLimit.
public final classCardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.IntervalThe interval at which the spending limit is enforced.
public final classCardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.MerchantCategoryCode
-
Method Summary
-
-
Method Detail
-
interval
final CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval interval()
The interval at which the spending limit is enforced.
-
settlementAmount
final Long settlementAmount()
The maximum settlement amount permitted in the given interval.
-
merchantCategoryCodes
final Optional<List<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.MerchantCategoryCode>> merchantCategoryCodes()
The Merchant Category Codes this spending limit applies to. If not set, the limit applies to all transactions.
-
_interval
final JsonField<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval> _interval()
Returns the raw JSON value of interval.
Unlike interval, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCodes
final JsonField<List<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.MerchantCategoryCode>> _merchantCategoryCodes()
Returns the raw JSON value of merchantCategoryCodes.
Unlike merchantCategoryCodes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Builder builder()
Returns a mutable builder for constructing an instance of SpendingLimit.
The following fields are required:
.interval() .settlementAmount()
-
-
-
-