Enum CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value extends Enum<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value>
An enum containing Interval's known values, as well as an _UNKNOWN member.
An instance of Interval can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ALL_TIMEThe spending limit applies over the lifetime of the card.
PER_TRANSACTIONThe spending limit applies per transaction.
PER_DAYThe spending limit applies per day. Resets nightly at midnight UTC.
PER_WEEKThe spending limit applies per week. Resets weekly on Mondays at midnight UTC.
PER_MONTHThe spending limit applies per month. Resets on the first of the month, midnight UTC.
_UNKNOWNAn enum member indicating that Interval was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value>getEntries()An enum containing Interval's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardUpdateParams.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval.Value> getEntries()
An enum containing Interval's known values, as well as an _UNKNOWN member.
An instance of Interval can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-