Package com.increase.api.models.cards
Class CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmountThe settlement amount constraint for this single-use card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount.BuilderA builder for SettlementAmount.
public final classCardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount.ComparisonThe operator used to compare the settlement amount.
-
Method Summary
-
-
Method Detail
-
comparison
final CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount.Comparison comparison()
The operator used to compare the settlement amount.
-
_comparison
final JsonField<CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount.Comparison> _comparison()
Returns the raw JSON value of comparison.
Unlike comparison, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<Long> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardUpdateParams.AuthorizationControls.Usage.SingleUse.SettlementAmount.Builder builder()
Returns a mutable builder for constructing an instance of SettlementAmount.
The following fields are required:
.comparison() .value()
-
-
-
-