Class CardUpdateParams.BillingAddress
-
- All Implemented Interfaces:
public final class CardUpdateParams.BillingAddressThe card's updated billing address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.BillingAddress.BuilderA builder for BillingAddress.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the billing address. final Stringline1()The first line of the billing address. final StringpostalCode()The postal code of the billing address. final Stringstate()The US state of the billing address. final Optional<String>line2()The second line of the billing address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_line2()Returns the raw JSON value of line2. final Map<String, JsonValue>_additionalProperties()final CardUpdateParams.BillingAddress.BuildertoBuilder()final CardUpdateParams.BillingAddressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdateParams.BillingAddress.Builderbuilder()Returns a mutable builder for constructing an instance of BillingAddress. -
-
Method Detail
-
postalCode
final String postalCode()
The postal code of the billing address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.BillingAddress.Builder toBuilder()
-
validate
final CardUpdateParams.BillingAddress validate()
-
builder
final static CardUpdateParams.BillingAddress.Builder builder()
Returns a mutable builder for constructing an instance of BillingAddress.
The following fields are required:
.city() .line1() .postalCode() .state()
-
-
-
-