Class CardUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
billingAddress
final CardUpdateParams.Body.Builder billingAddress(CardUpdateParams.BillingAddress billingAddress)
The card's updated billing address.
-
billingAddress
final CardUpdateParams.Body.Builder billingAddress(JsonField<CardUpdateParams.BillingAddress> billingAddress)
Sets Builder.billingAddress to an arbitrary JSON value.
You should usually call Builder.billingAddress with a well-typed BillingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final CardUpdateParams.Body.Builder description(String description)
The description you choose to give the card.
-
description
final CardUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final CardUpdateParams.Body.Builder digitalWallet(CardUpdateParams.DigitalWallet digitalWallet)
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
digitalWallet
final CardUpdateParams.Body.Builder digitalWallet(JsonField<CardUpdateParams.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final CardUpdateParams.Body.Builder entityId(String entityId)
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
entityId
final CardUpdateParams.Body.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardUpdateParams.Body.Builder status(CardUpdateParams.Status status)
The status to update the Card with.
-
status
final CardUpdateParams.Body.Builder status(JsonField<CardUpdateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-