Class CardUpdateParams.DigitalWallet.Builder
-
- All Implemented Interfaces:
public final class CardUpdateParams.DigitalWallet.BuilderA builder for DigitalWallet.
-
-
Method Summary
-
-
Method Detail
-
digitalCardProfileId
final CardUpdateParams.DigitalWallet.Builder digitalCardProfileId(String digitalCardProfileId)
The digital card profile assigned to this digital card.
-
digitalCardProfileId
final CardUpdateParams.DigitalWallet.Builder digitalCardProfileId(JsonField<String> digitalCardProfileId)
Sets Builder.digitalCardProfileId to an arbitrary JSON value.
You should usually call Builder.digitalCardProfileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final CardUpdateParams.DigitalWallet.Builder email(String email)
An email address that can be used to verify the cardholder via one-time passcode over email.
-
email
final CardUpdateParams.DigitalWallet.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phone
final CardUpdateParams.DigitalWallet.Builder phone(String phone)
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
-
phone
final CardUpdateParams.DigitalWallet.Builder phone(JsonField<String> phone)
Sets Builder.phone to an arbitrary JSON value.
You should usually call Builder.phone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardUpdateParams.DigitalWallet.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardUpdateParams.DigitalWallet.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardUpdateParams.DigitalWallet.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardUpdateParams.DigitalWallet.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardUpdateParams.DigitalWallet.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardUpdateParams.DigitalWallet build()
Returns an immutable instance of DigitalWallet.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-