Package com.increase.api.models.cards
Class CardUpdatePinParams.Body
-
- All Implemented Interfaces:
public final class CardUpdatePinParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdatePinParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringpin()The 4-digit PIN for the card, for use with ATMs. final JsonField<String>_pin()Returns the raw JSON value of pin. final Map<String, JsonValue>_additionalProperties()final CardUpdatePinParams.Body.BuildertoBuilder()final CardUpdatePinParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdatePinParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_pin
final JsonField<String> _pin()
Returns the raw JSON value of pin.
Unlike pin, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdatePinParams.Body.Builder toBuilder()
-
validate
final CardUpdatePinParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardUpdatePinParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.pin()
-
-
-
-