Class CardToken
-
- All Implemented Interfaces:
public final class CardTokenCard Tokens represent a tokenized card number that can be used for Card Push Transfers and Card Validations.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardToken.BuilderA builder for CardToken.
public final classCardToken.TypeA constant representing the object's type. For this resource it will always be
card_token.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Token's identifier. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the card token was created. final LocalDateexpirationDate()The ISO 8601 date when the card expires. final Stringlast4()The last 4 digits of the card number. final Longlength()The length of the card number. final Stringprefix()The prefix of the card number, usually 8 digits. final CardToken.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<LocalDate>_expirationDate()Returns the raw JSON value of expirationDate. final JsonField<String>_last4()Returns the raw JSON value of last4. final JsonField<Long>_length()Returns the raw JSON value of length. final JsonField<String>_prefix()Returns the raw JSON value of prefix. final JsonField<CardToken.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardToken.BuildertoBuilder()final CardTokenvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardToken.Builderbuilder()Returns a mutable builder for constructing an instance of CardToken. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the card token was created.
-
expirationDate
final LocalDate expirationDate()
The ISO 8601 date when the card expires.
-
type
final CardToken.Type type()
A constant representing the object's type. For this resource it will always be
card_token.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
Returns the raw JSON value of expirationDate.
Unlike expirationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_last4
final JsonField<String> _last4()
Returns the raw JSON value of last4.
Unlike last4, this method doesn't throw if the JSON field has an unexpected type.
-
_length
final JsonField<Long> _length()
Returns the raw JSON value of length.
Unlike length, this method doesn't throw if the JSON field has an unexpected type.
-
_prefix
final JsonField<String> _prefix()
Returns the raw JSON value of prefix.
Unlike prefix, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardToken.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardToken.Builder toBuilder()
-
validate
final CardToken validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardToken.Builder builder()
Returns a mutable builder for constructing an instance of CardToken.
The following fields are required:
.id() .createdAt() .expirationDate() .last4() .length() .prefix() .type()
-
-
-
-