Class CardToken.Builder
-
- All Implemented Interfaces:
public final class CardToken.BuilderA builder for CardToken.
-
-
Method Summary
Modifier and Type Method Description final CardToken.Builderid(String id)The Card Token's identifier. final CardToken.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final CardToken.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the card token was created. final CardToken.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final CardToken.BuilderexpirationDate(LocalDate expirationDate)The ISO 8601 date when the card expires. final CardToken.BuilderexpirationDate(JsonField<LocalDate> expirationDate)Sets Builder.expirationDate to an arbitrary JSON value. final CardToken.Builderlast4(String last4)The last 4 digits of the card number. final CardToken.Builderlast4(JsonField<String> last4)Sets Builder.last4 to an arbitrary JSON value. final CardToken.Builderlength(Long length)The length of the card number. final CardToken.Builderlength(JsonField<Long> length)Sets Builder.length to an arbitrary JSON value. final CardToken.Builderprefix(String prefix)The prefix of the card number, usually 8 digits. final CardToken.Builderprefix(JsonField<String> prefix)Sets Builder.prefix to an arbitrary JSON value. final CardToken.Buildertype(CardToken.Type type)A constant representing the object's type. final CardToken.Buildertype(JsonField<CardToken.Type> type)Sets Builder.type to an arbitrary JSON value. final CardToken.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CardToken.BuilderputAdditionalProperty(String key, JsonValue value)final CardToken.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CardToken.BuilderremoveAdditionalProperty(String key)final CardToken.BuilderremoveAllAdditionalProperties(Set<String> keys)final CardTokenbuild()Returns an immutable instance of CardToken. -
-
Method Detail
-
id
final CardToken.Builder id(String id)
The Card Token's identifier.
-
id
final CardToken.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CardToken.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the card token was created.
-
createdAt
final CardToken.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationDate
final CardToken.Builder expirationDate(LocalDate expirationDate)
The ISO 8601 date when the card expires.
-
expirationDate
final CardToken.Builder expirationDate(JsonField<LocalDate> expirationDate)
Sets Builder.expirationDate to an arbitrary JSON value.
You should usually call Builder.expirationDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
last4
final CardToken.Builder last4(String last4)
The last 4 digits of the card number.
-
last4
final CardToken.Builder last4(JsonField<String> last4)
Sets Builder.last4 to an arbitrary JSON value.
You should usually call Builder.last4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
length
final CardToken.Builder length(Long length)
The length of the card number.
-
length
final CardToken.Builder length(JsonField<Long> length)
Sets Builder.length to an arbitrary JSON value.
You should usually call Builder.length with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prefix
final CardToken.Builder prefix(String prefix)
The prefix of the card number, usually 8 digits.
-
prefix
final CardToken.Builder prefix(JsonField<String> prefix)
Sets Builder.prefix to an arbitrary JSON value.
You should usually call Builder.prefix with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardToken.Builder type(CardToken.Type type)
A constant representing the object's type. For this resource it will always be
card_token.
-
type
final CardToken.Builder type(JsonField<CardToken.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardToken.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardToken.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardToken.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardToken.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardToken.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-