Class CardTokenCapabilities

  • All Implemented Interfaces:

    
    public final class CardTokenCapabilities
    
                        

    The capabilities of a Card Token describe whether the card can be used for specific operations, such as Card Push Transfers. The capabilities can change over time based on the issuing bank's configuration of the card range.