Class CardTokenCapabilities.Route
-
- All Implemented Interfaces:
public final class CardTokenCapabilities.Route
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenCapabilities.Route.BuilderA builder for Route.
public final classCardTokenCapabilities.Route.CrossBorderPushTransfersWhether you can push funds to the card using cross-border Card Push Transfers.
public final classCardTokenCapabilities.Route.DomesticPushTransfersWhether you can push funds to the card using domestic Card Push Transfers.
public final classCardTokenCapabilities.Route.InnerRouteThe card network route the capabilities apply to.
-
Method Summary
Modifier and Type Method Description final CardTokenCapabilities.Route.CrossBorderPushTransferscrossBorderPushTransfers()Whether you can push funds to the card using cross-border Card Push Transfers. final CardTokenCapabilities.Route.DomesticPushTransfersdomesticPushTransfers()Whether you can push funds to the card using domestic Card Push Transfers. final StringissuerCountry()The ISO-3166-1 alpha-2 country code of the card's issuing bank. final CardTokenCapabilities.Route.InnerRouteroute()The card network route the capabilities apply to. final JsonField<CardTokenCapabilities.Route.CrossBorderPushTransfers>_crossBorderPushTransfers()Returns the raw JSON value of crossBorderPushTransfers. final JsonField<CardTokenCapabilities.Route.DomesticPushTransfers>_domesticPushTransfers()Returns the raw JSON value of domesticPushTransfers. final JsonField<String>_issuerCountry()Returns the raw JSON value of issuerCountry. final JsonField<CardTokenCapabilities.Route.InnerRoute>_route()Returns the raw JSON value of route. final Map<String, JsonValue>_additionalProperties()final CardTokenCapabilities.Route.BuildertoBuilder()final CardTokenCapabilities.Routevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenCapabilities.Route.Builderbuilder()Returns a mutable builder for constructing an instance of Route. -
-
Method Detail
-
crossBorderPushTransfers
final CardTokenCapabilities.Route.CrossBorderPushTransfers crossBorderPushTransfers()
Whether you can push funds to the card using cross-border Card Push Transfers.
-
domesticPushTransfers
final CardTokenCapabilities.Route.DomesticPushTransfers domesticPushTransfers()
Whether you can push funds to the card using domestic Card Push Transfers.
-
issuerCountry
final String issuerCountry()
The ISO-3166-1 alpha-2 country code of the card's issuing bank.
-
route
final CardTokenCapabilities.Route.InnerRoute route()
The card network route the capabilities apply to.
-
_crossBorderPushTransfers
final JsonField<CardTokenCapabilities.Route.CrossBorderPushTransfers> _crossBorderPushTransfers()
Returns the raw JSON value of crossBorderPushTransfers.
Unlike crossBorderPushTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_domesticPushTransfers
final JsonField<CardTokenCapabilities.Route.DomesticPushTransfers> _domesticPushTransfers()
Returns the raw JSON value of domesticPushTransfers.
Unlike domesticPushTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_issuerCountry
final JsonField<String> _issuerCountry()
Returns the raw JSON value of issuerCountry.
Unlike issuerCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<CardTokenCapabilities.Route.InnerRoute> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTokenCapabilities.Route.Builder toBuilder()
-
validate
final CardTokenCapabilities.Route validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardTokenCapabilities.Route.Builder builder()
Returns a mutable builder for constructing an instance of Route.
The following fields are required:
.crossBorderPushTransfers() .domesticPushTransfers() .issuerCountry() .route()
-
-
-
-