Class CardTokenListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class CardTokenListPage implements Page<CardToken>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenListPage.BuilderA builder for CardTokenListPage.
-
Method Summary
Modifier and Type Method Description final List<CardToken>data()Delegates to CardTokenListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to CardTokenListPageResponse, but gracefully handles missing data. List<CardToken>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final CardTokenListParamsnextPageParams()CardTokenListPagenextPage()Returns the page after this one by making another request. final AutoPager<CardToken>autoPager()final CardTokenListParamsparams()The parameters that were used to request this page. final CardTokenListPageResponseresponse()The response that this page was parsed from. final CardTokenListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CardTokenListPage. -
-
Method Detail
-
data
final List<CardToken> data()
Delegates to CardTokenListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CardTokenListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final CardTokenListParams nextPageParams()
-
nextPage
CardTokenListPage nextPage()
Returns the page after this one by making another request.
-
params
final CardTokenListParams params()
The parameters that were used to request this page.
-
response
final CardTokenListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CardTokenListPage.Builder toBuilder()
-
builder
final static CardTokenListPage.Builder builder()
Returns a mutable builder for constructing an instance of CardTokenListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-