Class CardTokenListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CardTokenListPageAsync.BuilderA builder for CardTokenListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CardTokenListPageAsync.Builderservice(CardTokenServiceAsync service)final CardTokenListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CardTokenListPageAsync.Builderparams(CardTokenListParams params)The parameters that were used to request this page. final CardTokenListPageAsync.Builderresponse(CardTokenListPageResponse response)The response that this page was parsed from. final CardTokenListPageAsyncbuild()Returns an immutable instance of CardTokenListPageAsync. -
-
Method Detail
-
service
final CardTokenListPageAsync.Builder service(CardTokenServiceAsync service)
-
streamHandlerExecutor
final CardTokenListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CardTokenListPageAsync.Builder params(CardTokenListParams params)
The parameters that were used to request this page.
-
response
final CardTokenListPageAsync.Builder response(CardTokenListPageResponse response)
The response that this page was parsed from.
-
build
final CardTokenListPageAsync build()
Returns an immutable instance of CardTokenListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-