Class CardTokenListPageResponse
-
- All Implemented Interfaces:
public final class CardTokenListPageResponseA list of Card Token objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenListPageResponse.BuilderA builder for CardTokenListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CardToken>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<CardToken>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final CardTokenListPageResponse.BuildertoBuilder()final CardTokenListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardTokenListPageResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<CardToken>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTokenListPageResponse.Builder toBuilder()
-
validate
final CardTokenListPageResponse validate()
-
builder
final static CardTokenListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardTokenListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-