Class CardTokenListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardTokenListParams implements Params
List Card Tokens
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenListParams.BuilderA builder for CardTokenListParams.
public final classCardTokenListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<CardTokenListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardTokenListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenListParamsnone()final static CardTokenListParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardTokenListParams. -
-
Method Detail
-
createdAt
final Optional<CardTokenListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardTokenListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardTokenListParams none()
-
builder
final static CardTokenListParams.Builder builder()
Returns a mutable builder for constructing an instance of CardTokenListParams.
-
-
-
-