Class CardValidation
-
- All Implemented Interfaces:
public final class CardValidationCard Validations are used to validate a card and its cardholder before sending funds to or pulling funds from a card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidation.BuilderA builder for CardValidation.
public final classCardValidation.AcceptanceIf the validation is accepted by the recipient bank, this will contain supplemental details.
public final classCardValidation.CreatedByWhat object created the validation, either via the API or the dashboard.
public final classCardValidation.DeclineIf the validation is rejected by the card network or the destination financial institution, this will contain supplemental details.
public final classCardValidation.RouteThe card network route used for the validation.
public final classCardValidation.StatusThe lifecycle status of the validation.
public final classCardValidation.SubmissionAfter the validation is submitted to the card network, this will contain supplemental details.
public final classCardValidation.TypeA constant representing the object's type. For this resource it will always be
card_validation.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Validation's identifier. final Optional<CardValidation.Acceptance>acceptance()If the validation is accepted by the recipient bank, this will contain supplemental details. final StringaccountId()The identifier of the Account from which to send the validation. final StringcardTokenId()The ID of the Card Token that was used to validate the card. final Optional<String>cardholderFirstName()The cardholder's first name. final Optional<String>cardholderLastName()The cardholder's last name. final Optional<String>cardholderMiddleName()The cardholder's middle name. final Optional<String>cardholderPostalCode()The postal code of the cardholder's address. final Optional<String>cardholderStreetAddress()The cardholder's street address. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the validation was created. final Optional<CardValidation.CreatedBy>createdBy()What object created the validation, either via the API or the dashboard. final Optional<CardValidation.Decline>decline()If the validation is rejected by the card network or the destination financial institution, this will contain supplemental details. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringmerchantCategoryCode()A four-digit code (MCC) identifying the type of business or service provided by the merchant. final StringmerchantCityName()The city where the merchant (typically your business) is located. final StringmerchantName()The merchant name that will appear in the cardholder’s statement descriptor. final StringmerchantPostalCode()The postal code for the merchant’s (typically your business’s) location. final StringmerchantState()The U.S. final CardValidation.Routeroute()The card network route used for the validation. final CardValidation.Statusstatus()The lifecycle status of the validation. final Optional<CardValidation.Submission>submission()After the validation is submitted to the card network, this will contain supplemental details. final CardValidation.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CardValidation.Acceptance>_acceptance()Returns the raw JSON value of acceptance. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_cardTokenId()Returns the raw JSON value of cardTokenId. final JsonField<String>_cardholderFirstName()Returns the raw JSON value of cardholderFirstName. final JsonField<String>_cardholderLastName()Returns the raw JSON value of cardholderLastName. final JsonField<String>_cardholderMiddleName()Returns the raw JSON value of cardholderMiddleName. final JsonField<String>_cardholderPostalCode()Returns the raw JSON value of cardholderPostalCode. final JsonField<String>_cardholderStreetAddress()Returns the raw JSON value of cardholderStreetAddress. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CardValidation.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<CardValidation.Decline>_decline()Returns the raw JSON value of decline. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCityName()Returns the raw JSON value of merchantCityName. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<CardValidation.Route>_route()Returns the raw JSON value of route. final JsonField<CardValidation.Status>_status()Returns the raw JSON value of status. final JsonField<CardValidation.Submission>_submission()Returns the raw JSON value of submission. final JsonField<CardValidation.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardValidation.BuildertoBuilder()final CardValidationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidation.Builderbuilder()Returns a mutable builder for constructing an instance of CardValidation. -
-
Method Detail
-
acceptance
final Optional<CardValidation.Acceptance> acceptance()
If the validation is accepted by the recipient bank, this will contain supplemental details.
-
cardTokenId
final String cardTokenId()
The ID of the Card Token that was used to validate the card.
-
cardholderFirstName
final Optional<String> cardholderFirstName()
The cardholder's first name.
-
cardholderLastName
final Optional<String> cardholderLastName()
The cardholder's last name.
-
cardholderMiddleName
final Optional<String> cardholderMiddleName()
The cardholder's middle name.
-
cardholderPostalCode
final Optional<String> cardholderPostalCode()
The postal code of the cardholder's address.
-
cardholderStreetAddress
final Optional<String> cardholderStreetAddress()
The cardholder's street address.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the validation was created.
-
createdBy
final Optional<CardValidation.CreatedBy> createdBy()
What object created the validation, either via the API or the dashboard.
-
decline
final Optional<CardValidation.Decline> decline()
If the validation is rejected by the card network or the destination financial institution, this will contain supplemental details.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
merchantCategoryCode
final String merchantCategoryCode()
A four-digit code (MCC) identifying the type of business or service provided by the merchant.
-
merchantCityName
final String merchantCityName()
The city where the merchant (typically your business) is located.
-
merchantName
final String merchantName()
The merchant name that will appear in the cardholder’s statement descriptor. Typically your business name.
-
merchantPostalCode
final String merchantPostalCode()
The postal code for the merchant’s (typically your business’s) location.
-
merchantState
final String merchantState()
The U.S. state where the merchant (typically your business) is located.
-
route
final CardValidation.Route route()
The card network route used for the validation.
-
status
final CardValidation.Status status()
The lifecycle status of the validation.
-
submission
final Optional<CardValidation.Submission> submission()
After the validation is submitted to the card network, this will contain supplemental details.
-
type
final CardValidation.Type type()
A constant representing the object's type. For this resource it will always be
card_validation.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptance
final JsonField<CardValidation.Acceptance> _acceptance()
Returns the raw JSON value of acceptance.
Unlike acceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokenId
final JsonField<String> _cardTokenId()
Returns the raw JSON value of cardTokenId.
Unlike cardTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderFirstName
final JsonField<String> _cardholderFirstName()
Returns the raw JSON value of cardholderFirstName.
Unlike cardholderFirstName, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderLastName
final JsonField<String> _cardholderLastName()
Returns the raw JSON value of cardholderLastName.
Unlike cardholderLastName, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderMiddleName
final JsonField<String> _cardholderMiddleName()
Returns the raw JSON value of cardholderMiddleName.
Unlike cardholderMiddleName, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderPostalCode
final JsonField<String> _cardholderPostalCode()
Returns the raw JSON value of cardholderPostalCode.
Unlike cardholderPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderStreetAddress
final JsonField<String> _cardholderStreetAddress()
Returns the raw JSON value of cardholderStreetAddress.
Unlike cardholderStreetAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<CardValidation.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_decline
final JsonField<CardValidation.Decline> _decline()
Returns the raw JSON value of decline.
Unlike decline, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCityName
final JsonField<String> _merchantCityName()
Returns the raw JSON value of merchantCityName.
Unlike merchantCityName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<CardValidation.Route> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardValidation.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<CardValidation.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardValidation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidation.Builder toBuilder()
-
validate
final CardValidation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardValidation.Builder builder()
Returns a mutable builder for constructing an instance of CardValidation.
The following fields are required:
.id() .acceptance() .accountId() .cardTokenId() .cardholderFirstName() .cardholderLastName() .cardholderMiddleName() .cardholderPostalCode() .cardholderStreetAddress() .createdAt() .createdBy() .decline() .idempotencyKey() .merchantCategoryCode() .merchantCityName() .merchantName() .merchantPostalCode() .merchantState() .route() .status() .submission() .type()
-
-
-
-