Class CardValidation.Acceptance
-
- All Implemented Interfaces:
public final class CardValidation.AcceptanceIf the validation is accepted by the recipient bank, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidation.Acceptance.BuilderA builder for Acceptance.
public final classCardValidation.Acceptance.CardVerificationValue2ResultThe result of the Card Verification Value 2 match.
public final classCardValidation.Acceptance.CardholderFirstNameResultThe result of the cardholder first name match.
public final classCardValidation.Acceptance.CardholderFullNameResultThe result of the cardholder full name match.
public final classCardValidation.Acceptance.CardholderLastNameResultThe result of the cardholder last name match.
public final classCardValidation.Acceptance.CardholderMiddleNameResultThe result of the cardholder middle name match.
public final classCardValidation.Acceptance.CardholderPostalCodeResultThe result of the cardholder postal code match.
public final classCardValidation.Acceptance.CardholderStreetAddressResultThe result of the cardholder street address match.
-
Method Summary
-
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the validation was accepted by the issuing bank.
-
authorizationIdentificationResponse
final String authorizationIdentificationResponse()
The authorization identification response from the issuing bank.
-
cardVerificationValue2Result
final Optional<CardValidation.Acceptance.CardVerificationValue2Result> cardVerificationValue2Result()
The result of the Card Verification Value 2 match.
-
cardholderFirstNameResult
final Optional<CardValidation.Acceptance.CardholderFirstNameResult> cardholderFirstNameResult()
The result of the cardholder first name match.
-
cardholderFullNameResult
final Optional<CardValidation.Acceptance.CardholderFullNameResult> cardholderFullNameResult()
The result of the cardholder full name match.
-
cardholderLastNameResult
final Optional<CardValidation.Acceptance.CardholderLastNameResult> cardholderLastNameResult()
The result of the cardholder last name match.
-
cardholderMiddleNameResult
final Optional<CardValidation.Acceptance.CardholderMiddleNameResult> cardholderMiddleNameResult()
The result of the cardholder middle name match.
-
cardholderPostalCodeResult
final Optional<CardValidation.Acceptance.CardholderPostalCodeResult> cardholderPostalCodeResult()
The result of the cardholder postal code match.
-
cardholderStreetAddressResult
final Optional<CardValidation.Acceptance.CardholderStreetAddressResult> cardholderStreetAddressResult()
The result of the cardholder street address match.
-
networkTransactionIdentifier
final Optional<String> networkTransactionIdentifier()
A unique identifier for the transaction on the card network.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationIdentificationResponse
final JsonField<String> _authorizationIdentificationResponse()
Returns the raw JSON value of authorizationIdentificationResponse.
Unlike authorizationIdentificationResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_cardVerificationValue2Result
final JsonField<CardValidation.Acceptance.CardVerificationValue2Result> _cardVerificationValue2Result()
Returns the raw JSON value of cardVerificationValue2Result.
Unlike cardVerificationValue2Result, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderFirstNameResult
final JsonField<CardValidation.Acceptance.CardholderFirstNameResult> _cardholderFirstNameResult()
Returns the raw JSON value of cardholderFirstNameResult.
Unlike cardholderFirstNameResult, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderFullNameResult
final JsonField<CardValidation.Acceptance.CardholderFullNameResult> _cardholderFullNameResult()
Returns the raw JSON value of cardholderFullNameResult.
Unlike cardholderFullNameResult, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderLastNameResult
final JsonField<CardValidation.Acceptance.CardholderLastNameResult> _cardholderLastNameResult()
Returns the raw JSON value of cardholderLastNameResult.
Unlike cardholderLastNameResult, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderMiddleNameResult
final JsonField<CardValidation.Acceptance.CardholderMiddleNameResult> _cardholderMiddleNameResult()
Returns the raw JSON value of cardholderMiddleNameResult.
Unlike cardholderMiddleNameResult, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderPostalCodeResult
final JsonField<CardValidation.Acceptance.CardholderPostalCodeResult> _cardholderPostalCodeResult()
Returns the raw JSON value of cardholderPostalCodeResult.
Unlike cardholderPostalCodeResult, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderStreetAddressResult
final JsonField<CardValidation.Acceptance.CardholderStreetAddressResult> _cardholderStreetAddressResult()
Returns the raw JSON value of cardholderStreetAddressResult.
Unlike cardholderStreetAddressResult, this method doesn't throw if the JSON field has an unexpected type.
-
_networkTransactionIdentifier
final JsonField<String> _networkTransactionIdentifier()
Returns the raw JSON value of networkTransactionIdentifier.
Unlike networkTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidation.Acceptance.Builder toBuilder()
-
validate
final CardValidation.Acceptance validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardValidation.Acceptance.Builder builder()
Returns a mutable builder for constructing an instance of Acceptance.
The following fields are required:
.acceptedAt() .authorizationIdentificationResponse() .cardVerificationValue2Result() .cardholderFirstNameResult() .cardholderFullNameResult() .cardholderLastNameResult() .cardholderMiddleNameResult() .cardholderPostalCodeResult() .cardholderStreetAddressResult() .networkTransactionIdentifier()
-
-
-
-