Enum CardValidation.Acceptance.CardVerificationValue2Result.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardValidation.Acceptance.CardVerificationValue2Result.Value extends Enum<CardValidation.Acceptance.CardVerificationValue2Result.Value>
An enum containing CardVerificationValue2Result's known values, as well as an _UNKNOWN member.
An instance of CardVerificationValue2Result can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardValidation.Acceptance.CardVerificationValue2Result.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description MATCHThe Card Verification Value 2 (CVV2) matches the expected value.
NO_MATCHThe Card Verification Value 2 (CVV2) does not match the expected value.
_UNKNOWNAn enum member indicating that CardVerificationValue2Result was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardValidation.Acceptance.CardVerificationValue2Result.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardValidation.Acceptance.CardVerificationValue2Result.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardValidation.Acceptance.CardVerificationValue2Result.Value>getEntries()An enum containing CardVerificationValue2Result's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardValidation.Acceptance.CardVerificationValue2Result.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardValidation.Acceptance.CardVerificationValue2Result.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardValidation.Acceptance.CardVerificationValue2Result.Value> getEntries()
An enum containing CardVerificationValue2Result's known values, as well as an _UNKNOWN member.
An instance of CardVerificationValue2Result can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-