Class CardValidation.CreatedBy
-
- All Implemented Interfaces:
public final class CardValidation.CreatedByWhat object created the validation, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidation.CreatedBy.BuilderA builder for CreatedBy.
public final classCardValidation.CreatedBy.CategoryThe type of object that created this transfer.
public final classCardValidation.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classCardValidation.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classCardValidation.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final CardValidation.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<CardValidation.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final Optional<CardValidation.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<CardValidation.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<CardValidation.CreatedBy.Category>_category()Returns the raw JSON value of category. final JsonField<CardValidation.CreatedBy.ApiKey>_apiKey()Returns the raw JSON value of apiKey. final JsonField<CardValidation.CreatedBy.OAuthApplication>_oauthApplication()Returns the raw JSON value of oauthApplication. final JsonField<CardValidation.CreatedBy.User>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final CardValidation.CreatedBy.BuildertoBuilder()final CardValidation.CreatedByvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidation.CreatedBy.Builderbuilder()Returns a mutable builder for constructing an instance of CreatedBy. -
-
Method Detail
-
category
final CardValidation.CreatedBy.Category category()
The type of object that created this transfer.
-
apiKey
final Optional<CardValidation.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
oauthApplication
final Optional<CardValidation.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<CardValidation.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_category
final JsonField<CardValidation.CreatedBy.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_apiKey
final JsonField<CardValidation.CreatedBy.ApiKey> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthApplication
final JsonField<CardValidation.CreatedBy.OAuthApplication> _oauthApplication()
Returns the raw JSON value of oauthApplication.
Unlike oauthApplication, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<CardValidation.CreatedBy.User> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidation.CreatedBy.Builder toBuilder()
-
validate
final CardValidation.CreatedBy validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardValidation.CreatedBy.Builder builder()
Returns a mutable builder for constructing an instance of CreatedBy.
The following fields are required:
.category()
-
-
-
-