Class CardValidation.CreatedBy.User
-
- All Implemented Interfaces:
public final class CardValidation.CreatedBy.UserIf present, details about the User that created the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidation.CreatedBy.User.BuilderA builder for User.
-
Method Summary
Modifier and Type Method Description final Stringemail()The email address of the User. final JsonField<String>_email()Returns the raw JSON value of email. final Map<String, JsonValue>_additionalProperties()final CardValidation.CreatedBy.User.BuildertoBuilder()final CardValidation.CreatedBy.Uservalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidation.CreatedBy.User.Builderbuilder()Returns a mutable builder for constructing an instance of User. -
-
Method Detail
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidation.CreatedBy.User.Builder toBuilder()
-
validate
final CardValidation.CreatedBy.User validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardValidation.CreatedBy.User.Builder builder()
Returns a mutable builder for constructing an instance of User.
The following fields are required:
.email()
-
-
-
-