Enum CardValidation.Decline.Reason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardValidation.Decline.Reason.Value extends Enum<CardValidation.Decline.Reason.Value>
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardValidation.Decline.Reason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description DO_NOT_HONORThe card issuer has declined the transaction without providing a specific reason.
ACTIVITY_COUNT_LIMIT_EXCEEDEDThe number of transactions for the card has exceeded the limit set by the issuer.
REFER_TO_CARD_ISSUERThe card issuer requires the cardholder to contact them for further information regarding the transaction.
REFER_TO_CARD_ISSUER_SPECIAL_CONDITIONThe card issuer requires the cardholder to contact them due to a special condition related to the transaction.
INVALID_MERCHANTThe merchant is not valid for this transaction.
PICK_UP_CARDThe card should be retained by the terminal.
ERRORAn error occurred during processing of the transaction.
PICK_UP_CARD_SPECIALThe card should be retained by the terminal due to a special condition.
INVALID_TRANSACTIONThe transaction is invalid and cannot be processed.
INVALID_AMOUNTThe amount of the transaction is invalid.
INVALID_ACCOUNT_NUMBERThe account number provided is invalid.
NO_SUCH_ISSUERThe issuer of the card could not be found.
RE_ENTER_TRANSACTIONThe transaction should be re-entered for processing.
NO_CREDIT_ACCOUNTThere is no credit account associated with the card.
PICK_UP_CARD_LOSTThe card should be retained by the terminal because it has been reported lost.
PICK_UP_CARD_STOLENThe card should be retained by the terminal because it has been reported stolen.
CLOSED_ACCOUNTThe account associated with the card has been closed.
INSUFFICIENT_FUNDSThere are insufficient funds in the account to complete the transaction.
NO_CHECKING_ACCOUNTThere is no checking account associated with the card.
NO_SAVINGS_ACCOUNTThere is no savings account associated with the card.
EXPIRED_CARDThe card has expired and cannot be used for transactions.
TRANSACTION_NOT_PERMITTED_TO_CARDHOLDERThe transaction is not permitted for this cardholder.
TRANSACTION_NOT_ALLOWED_AT_TERMINALThe transaction is not allowed at this terminal.
TRANSACTION_NOT_SUPPORTED_OR_BLOCKED_BY_ISSUERThe transaction is not supported or has been blocked by the issuer.
SUSPECTED_FRAUDThe transaction has been flagged as suspected fraud and cannot be processed.
ACTIVITY_AMOUNT_LIMIT_EXCEEDEDThe amount of activity on the card has exceeded the limit set by the issuer.
RESTRICTED_CARDThe card has restrictions that prevent it from being used for this transaction.
SECURITY_VIOLATIONA security violation has occurred, preventing the transaction from being processed.
TRANSACTION_DOES_NOT_FULFILL_ANTI_MONEY_LAUNDERING_REQUIREMENTThe transaction does not meet the anti-money laundering requirements set by the issuer.
BLOCKED_BY_CARDHOLDERThe transaction was blocked by the cardholder.
BLOCKED_FIRST_USEThe first use of the card has been blocked by the issuer.
CREDIT_ISSUER_UNAVAILABLEThe credit issuer is currently unavailable to process the transaction.
NEGATIVE_CARD_VERIFICATION_VALUE_RESULTSThe card verification value (CVV) results were negative, indicating a potential issue with the card.
ISSUER_UNAVAILABLEThe issuer of the card is currently unavailable to process the transaction.
FINANCIAL_INSTITUTION_CANNOT_BE_FOUNDThe financial institution associated with the card could not be found.
TRANSACTION_CANNOT_BE_COMPLETEDThe transaction cannot be completed due to an unspecified reason.
DUPLICATE_TRANSACTIONThe transaction is a duplicate of a previous transaction and cannot be processed again.
SYSTEM_MALFUNCTIONA system malfunction occurred, preventing the transaction from being processed.
ADDITIONAL_CUSTOMER_AUTHENTICATION_REQUIREDAdditional customer authentication is required to complete the transaction.
SURCHARGE_AMOUNT_NOT_PERMITTEDThe surcharge amount applied to the transaction is not permitted by the issuer.
DECLINE_FOR_CVV2_FAILUREThe transaction was declined due to a failure in verifying the CVV2 code.
STOP_PAYMENT_ORDERA stop payment order has been placed on this transaction.
REVOCATION_OF_AUTHORIZATION_ORDERAn order has been placed to revoke authorization for this transaction.
REVOCATION_OF_ALL_AUTHORIZATIONS_ORDERAn order has been placed to revoke all authorizations for this cardholder.
UNABLE_TO_LOCATE_RECORDThe record associated with the transaction could not be located.
FILE_IS_TEMPORARILY_UNAVAILABLEThe file needed for the transaction is temporarily unavailable.
INCORRECT_PINThe PIN entered for the transaction is incorrect.
ALLOWABLE_NUMBER_OF_PIN_ENTRY_TRIES_EXCEEDEDThe allowable number of PIN entry tries has been exceeded.
UNABLE_TO_LOCATE_PREVIOUS_MESSAGEThe previous message associated with the transaction could not be located.
PIN_ERROR_FOUNDAn error was found with the PIN associated with the transaction.
CANNOT_VERIFY_PINThe PIN associated with the transaction could not be verified.
VERIFICATION_DATA_FAILEDThe verification data associated with the transaction has failed.
SURCHARGE_AMOUNT_NOT_SUPPORTED_BY_DEBIT_NETWORK_ISSUERThe surcharge amount is not supported by the debit network issuer.
CASH_SERVICE_NOT_AVAILABLECash service is not available for this transaction.
CASHBACK_REQUEST_EXCEEDS_ISSUER_LIMITThe cashback request exceeds the issuer limit.
TRANSACTION_AMOUNT_EXCEEDS_PRE_AUTHORIZED_APPROVAL_AMOUNTThe transaction amount exceeds the pre-authorized approval amount.
TRANSACTION_DOES_NOT_QUALIFY_FOR_VISA_PINThe transaction does not qualify for Visa PIN processing.
OFFLINE_DECLINEDThe transaction was declined offline.
UNABLE_TO_GO_ONLINEThe terminal was unable to go online to process the transaction.
VALID_ACCOUNT_BUT_AMOUNT_NOT_SUPPORTEDThe account is valid but the transaction amount is not supported.
INVALID_USE_OF_MERCHANT_CATEGORY_CODE_CORRECT_AND_REATTEMPTThe merchant category code was used incorrectly; correct it and reattempt the transaction.
CARD_AUTHENTICATION_FAILEDThe card authentication process has failed.
_UNKNOWNAn enum member indicating that Reason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardValidation.Decline.Reason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardValidation.Decline.Reason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardValidation.Decline.Reason.Value>getEntries()An enum containing Reason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardValidation.Decline.Reason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardValidation.Decline.Reason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardValidation.Decline.Reason.Value> getEntries()
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-