Class CardValidationCreateParams.Body
-
- All Implemented Interfaces:
public final class CardValidationCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidationCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account from which to send the validation. final StringcardTokenId()The Increase identifier for the Card Token that represents the card number you're validating. final StringmerchantCategoryCode()A four-digit code (MCC) identifying the type of business or service provided by the merchant. final StringmerchantCityName()The city where the merchant (typically your business) is located. final StringmerchantName()The merchant name that will appear in the cardholder’s statement descriptor. final StringmerchantPostalCode()The postal code for the merchant’s (typically your business’s) location. final StringmerchantState()The U.S. final Optional<String>cardholderFirstName()The cardholder's first name. final Optional<String>cardholderLastName()The cardholder's last name. final Optional<String>cardholderMiddleName()The cardholder's middle name. final Optional<String>cardholderPostalCode()The postal code of the cardholder's address. final Optional<String>cardholderStreetAddress()The cardholder's street address. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_cardTokenId()Returns the raw JSON value of cardTokenId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCityName()Returns the raw JSON value of merchantCityName. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<String>_cardholderFirstName()Returns the raw JSON value of cardholderFirstName. final JsonField<String>_cardholderLastName()Returns the raw JSON value of cardholderLastName. final JsonField<String>_cardholderMiddleName()Returns the raw JSON value of cardholderMiddleName. final JsonField<String>_cardholderPostalCode()Returns the raw JSON value of cardholderPostalCode. final JsonField<String>_cardholderStreetAddress()Returns the raw JSON value of cardholderStreetAddress. final Map<String, JsonValue>_additionalProperties()final CardValidationCreateParams.Body.BuildertoBuilder()final CardValidationCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidationCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
cardTokenId
final String cardTokenId()
The Increase identifier for the Card Token that represents the card number you're validating.
-
merchantCategoryCode
final String merchantCategoryCode()
A four-digit code (MCC) identifying the type of business or service provided by the merchant.
-
merchantCityName
final String merchantCityName()
The city where the merchant (typically your business) is located.
-
merchantName
final String merchantName()
The merchant name that will appear in the cardholder’s statement descriptor. Typically your business name.
-
merchantPostalCode
final String merchantPostalCode()
The postal code for the merchant’s (typically your business’s) location.
-
merchantState
final String merchantState()
The U.S. state where the merchant (typically your business) is located.
-
cardholderFirstName
final Optional<String> cardholderFirstName()
The cardholder's first name.
-
cardholderLastName
final Optional<String> cardholderLastName()
The cardholder's last name.
-
cardholderMiddleName
final Optional<String> cardholderMiddleName()
The cardholder's middle name.
-
cardholderPostalCode
final Optional<String> cardholderPostalCode()
The postal code of the cardholder's address.
-
cardholderStreetAddress
final Optional<String> cardholderStreetAddress()
The cardholder's street address.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardTokenId
final JsonField<String> _cardTokenId()
Returns the raw JSON value of cardTokenId.
Unlike cardTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCityName
final JsonField<String> _merchantCityName()
Returns the raw JSON value of merchantCityName.
Unlike merchantCityName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderFirstName
final JsonField<String> _cardholderFirstName()
Returns the raw JSON value of cardholderFirstName.
Unlike cardholderFirstName, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderLastName
final JsonField<String> _cardholderLastName()
Returns the raw JSON value of cardholderLastName.
Unlike cardholderLastName, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderMiddleName
final JsonField<String> _cardholderMiddleName()
Returns the raw JSON value of cardholderMiddleName.
Unlike cardholderMiddleName, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderPostalCode
final JsonField<String> _cardholderPostalCode()
Returns the raw JSON value of cardholderPostalCode.
Unlike cardholderPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderStreetAddress
final JsonField<String> _cardholderStreetAddress()
Returns the raw JSON value of cardholderStreetAddress.
Unlike cardholderStreetAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidationCreateParams.Body.Builder toBuilder()
-
validate
final CardValidationCreateParams.Body validate()
-
builder
final static CardValidationCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .cardTokenId() .merchantCategoryCode() .merchantCityName() .merchantName() .merchantPostalCode() .merchantState()
-
-
-
-