Class CardValidationCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardValidationCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final CardValidationCreateParams.Body.Builder accountId(String accountId)
The identifier of the Account from which to send the validation.
-
accountId
final CardValidationCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardTokenId
final CardValidationCreateParams.Body.Builder cardTokenId(String cardTokenId)
The Increase identifier for the Card Token that represents the card number you're validating.
-
cardTokenId
final CardValidationCreateParams.Body.Builder cardTokenId(JsonField<String> cardTokenId)
Sets Builder.cardTokenId to an arbitrary JSON value.
You should usually call Builder.cardTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardValidationCreateParams.Body.Builder merchantCategoryCode(String merchantCategoryCode)
A four-digit code (MCC) identifying the type of business or service provided by the merchant.
-
merchantCategoryCode
final CardValidationCreateParams.Body.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCityName
final CardValidationCreateParams.Body.Builder merchantCityName(String merchantCityName)
The city where the merchant (typically your business) is located.
-
merchantCityName
final CardValidationCreateParams.Body.Builder merchantCityName(JsonField<String> merchantCityName)
Sets Builder.merchantCityName to an arbitrary JSON value.
You should usually call Builder.merchantCityName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final CardValidationCreateParams.Body.Builder merchantName(String merchantName)
The merchant name that will appear in the cardholder’s statement descriptor. Typically your business name.
-
merchantName
final CardValidationCreateParams.Body.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final CardValidationCreateParams.Body.Builder merchantPostalCode(String merchantPostalCode)
The postal code for the merchant’s (typically your business’s) location.
-
merchantPostalCode
final CardValidationCreateParams.Body.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final CardValidationCreateParams.Body.Builder merchantState(String merchantState)
The U.S. state where the merchant (typically your business) is located.
-
merchantState
final CardValidationCreateParams.Body.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderFirstName
final CardValidationCreateParams.Body.Builder cardholderFirstName(String cardholderFirstName)
The cardholder's first name.
-
cardholderFirstName
final CardValidationCreateParams.Body.Builder cardholderFirstName(JsonField<String> cardholderFirstName)
Sets Builder.cardholderFirstName to an arbitrary JSON value.
You should usually call Builder.cardholderFirstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderLastName
final CardValidationCreateParams.Body.Builder cardholderLastName(String cardholderLastName)
The cardholder's last name.
-
cardholderLastName
final CardValidationCreateParams.Body.Builder cardholderLastName(JsonField<String> cardholderLastName)
Sets Builder.cardholderLastName to an arbitrary JSON value.
You should usually call Builder.cardholderLastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderMiddleName
final CardValidationCreateParams.Body.Builder cardholderMiddleName(String cardholderMiddleName)
The cardholder's middle name.
-
cardholderMiddleName
final CardValidationCreateParams.Body.Builder cardholderMiddleName(JsonField<String> cardholderMiddleName)
Sets Builder.cardholderMiddleName to an arbitrary JSON value.
You should usually call Builder.cardholderMiddleName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderPostalCode
final CardValidationCreateParams.Body.Builder cardholderPostalCode(String cardholderPostalCode)
The postal code of the cardholder's address.
-
cardholderPostalCode
final CardValidationCreateParams.Body.Builder cardholderPostalCode(JsonField<String> cardholderPostalCode)
Sets Builder.cardholderPostalCode to an arbitrary JSON value.
You should usually call Builder.cardholderPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderStreetAddress
final CardValidationCreateParams.Body.Builder cardholderStreetAddress(String cardholderStreetAddress)
The cardholder's street address.
-
cardholderStreetAddress
final CardValidationCreateParams.Body.Builder cardholderStreetAddress(JsonField<String> cardholderStreetAddress)
Sets Builder.cardholderStreetAddress to an arbitrary JSON value.
You should usually call Builder.cardholderStreetAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardValidationCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardValidationCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardValidationCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardValidationCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardValidationCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardValidationCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .cardTokenId() .merchantCategoryCode() .merchantCityName() .merchantName() .merchantPostalCode() .merchantState()
-
-
-
-