Class CardValidationListPage.Builder
-
- All Implemented Interfaces:
public final class CardValidationListPage.BuilderA builder for CardValidationListPage.
-
-
Method Summary
Modifier and Type Method Description final CardValidationListPage.Builderservice(CardValidationService service)final CardValidationListPage.Builderparams(CardValidationListParams params)The parameters that were used to request this page. final CardValidationListPage.Builderresponse(CardValidationListPageResponse response)The response that this page was parsed from. final CardValidationListPagebuild()Returns an immutable instance of CardValidationListPage. -
-
Method Detail
-
service
final CardValidationListPage.Builder service(CardValidationService service)
-
params
final CardValidationListPage.Builder params(CardValidationListParams params)
The parameters that were used to request this page.
-
response
final CardValidationListPage.Builder response(CardValidationListPageResponse response)
The response that this page was parsed from.
-
build
final CardValidationListPage build()
Returns an immutable instance of CardValidationListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-