Class CardValidationListPageResponse
-
- All Implemented Interfaces:
public final class CardValidationListPageResponseA list of Card Validation objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidationListPageResponse.BuilderA builder for CardValidationListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CardValidation>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<CardValidation>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final CardValidationListPageResponse.BuildertoBuilder()final CardValidationListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidationListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardValidationListPageResponse. -
-
Method Detail
-
data
final List<CardValidation> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
_data
final JsonField<List<CardValidation>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidationListPageResponse.Builder toBuilder()
-
validate
final CardValidationListPageResponse validate()
-
builder
final static CardValidationListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardValidationListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-