Class CardValidationListPageResponse.Builder
-
- All Implemented Interfaces:
public final class CardValidationListPageResponse.BuilderA builder for CardValidationListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final CardValidationListPageResponse.Builder data(List<CardValidation> data)
The contents of the list.
-
data
final CardValidationListPageResponse.Builder data(JsonField<List<CardValidation>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<CardValidation>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final CardValidationListPageResponse.Builder addData(CardValidation data)
Adds a single CardValidation to Builder.data.
-
nextCursor
final CardValidationListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final CardValidationListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final CardValidationListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardValidationListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardValidationListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardValidationListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardValidationListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardValidationListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardValidationListPageResponse build()
Returns an immutable instance of CardValidationListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-