Class CardValidationListParams.CreatedAt
-
- All Implemented Interfaces:
public final class CardValidationListParams.CreatedAt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidationListParams.CreatedAt.BuilderA builder for CreatedAt.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>after()Return results after this ISO 8601 timestamp. final Optional<OffsetDateTime>before()Return results before this ISO 8601 timestamp. final Optional<OffsetDateTime>onOrAfter()Return results on or after this ISO 8601 timestamp. final Optional<OffsetDateTime>onOrBefore()Return results on or before this ISO 8601 timestamp. final QueryParams_additionalProperties()Query params to send with the request. final CardValidationListParams.CreatedAt.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidationListParams.CreatedAt.Builderbuilder()Returns a mutable builder for constructing an instance of CreatedAt. -
-
Method Detail
-
after
final Optional<OffsetDateTime> after()
Return results after this ISO 8601 timestamp.
-
before
final Optional<OffsetDateTime> before()
Return results before this ISO 8601 timestamp.
-
onOrAfter
final Optional<OffsetDateTime> onOrAfter()
Return results on or after this ISO 8601 timestamp.
-
onOrBefore
final Optional<OffsetDateTime> onOrBefore()
Return results on or before this ISO 8601 timestamp.
-
_additionalProperties
final QueryParams _additionalProperties()
Query params to send with the request.
-
toBuilder
final CardValidationListParams.CreatedAt.Builder toBuilder()
-
builder
final static CardValidationListParams.CreatedAt.Builder builder()
Returns a mutable builder for constructing an instance of CreatedAt.
-
-
-
-