Enum CardValidationListParams.Status.In.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardValidationListParams.Status.In.Known extends Enum<CardValidationListParams.Status.In.Known>
An enum containing In's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardValidationListParams.Status.In.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description REQUIRES_ATTENTIONThe validation requires attention from an Increase operator.
PENDING_SUBMISSIONThe validation is queued to be submitted to the card network.
SUBMITTEDThe validation has been submitted and is pending a response from the card network.
COMPLETEThe validation has been sent successfully and is complete.
DECLINEDThe validation was declined by the network or the recipient's bank.
-
Method Summary
Modifier and Type Method Description final CardValidationListParams.Status.In.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardValidationListParams.Status.In.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardValidationListParams.Status.In.Known>getEntries()An enum containing In's known values. -
-
Method Detail
-
valueOf
final CardValidationListParams.Status.In.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardValidationListParams.Status.In.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardValidationListParams.Status.In.Known> getEntries()
An enum containing In's known values.
-
-
-
-