Class CardValidationRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardValidationRetrieveParams implements Params
Retrieve a Card Validation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidationRetrieveParams.BuilderA builder for CardValidationRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cardValidationId()The identifier of the Card Validation. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardValidationRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidationRetrieveParamsnone()final static CardValidationRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardValidationRetrieveParams. -
-
Method Detail
-
cardValidationId
final Optional<String> cardValidationId()
The identifier of the Card Validation.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardValidationRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardValidationRetrieveParams none()
-
builder
final static CardValidationRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of CardValidationRetrieveParams.
-
-
-
-