Class CheckDeposit
-
- All Implemented Interfaces:
public final class CheckDepositCheck Deposits allow you to deposit images of paper checks into your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.BuilderA builder for CheckDeposit.
public final classCheckDeposit.DepositAcceptanceOnce your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
public final classCheckDeposit.DepositAdjustmentpublic final classCheckDeposit.DepositRejectionIf your deposit is rejected by Increase, this will contain details as to why it was rejected.
public final classCheckDeposit.DepositReturnIf your deposit is returned, this will contain details as to why it was returned.
public final classCheckDeposit.DepositSubmissionAfter the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
public final classCheckDeposit.InboundFundsHoldIncrease will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
public final classCheckDeposit.StatusThe status of the Check Deposit.
public final classCheckDeposit.TypeA constant representing the object's type. For this resource it will always be
check_deposit.
-
Method Summary
Modifier and Type Method Description final Stringid()The deposit's identifier. final StringaccountId()The Account the check was deposited into. final Longamount()The deposited amount in USD cents. final Optional<String>backImageFileId()The ID for the File containing the image of the back of the check. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<CheckDeposit.DepositAcceptance>depositAcceptance()Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check. final List<CheckDeposit.DepositAdjustment>depositAdjustments()If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments. final Optional<CheckDeposit.DepositRejection>depositRejection()If your deposit is rejected by Increase, this will contain details as to why it was rejected. final Optional<CheckDeposit.DepositReturn>depositReturn()If your deposit is returned, this will contain details as to why it was returned. final Optional<CheckDeposit.DepositSubmission>depositSubmission()After the check is parsed, it is submitted to the Check21 network for processing. final Optional<String>description()The description of the Check Deposit, for display purposes only. final StringfrontImageFileId()The ID for the File containing the image of the front of the check. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<CheckDeposit.InboundFundsHold>inboundFundsHold()Increase will sometimes hold the funds for Check Deposits. final Optional<String>inboundMailItemId()If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item. final Optional<String>lockboxRecipientId()If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it. final CheckDeposit.Statusstatus()The status of the Check Deposit. final Optional<String>transactionId()The ID for the Transaction created by the deposit. final CheckDeposit.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CheckDeposit.DepositAcceptance>_depositAcceptance()Returns the raw JSON value of depositAcceptance. final JsonField<List<CheckDeposit.DepositAdjustment>>_depositAdjustments()Returns the raw JSON value of depositAdjustments. final JsonField<CheckDeposit.DepositRejection>_depositRejection()Returns the raw JSON value of depositRejection. final JsonField<CheckDeposit.DepositReturn>_depositReturn()Returns the raw JSON value of depositReturn. final JsonField<CheckDeposit.DepositSubmission>_depositSubmission()Returns the raw JSON value of depositSubmission. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<CheckDeposit.InboundFundsHold>_inboundFundsHold()Returns the raw JSON value of inboundFundsHold. final JsonField<String>_inboundMailItemId()Returns the raw JSON value of inboundMailItemId. final JsonField<String>_lockboxRecipientId()Returns the raw JSON value of lockboxRecipientId. final JsonField<CheckDeposit.Status>_status()Returns the raw JSON value of status. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<CheckDeposit.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.BuildertoBuilder()final CheckDepositvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDeposit. -
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The ID for the File containing the image of the back of the check.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
depositAcceptance
final Optional<CheckDeposit.DepositAcceptance> depositAcceptance()
Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
depositAdjustments
final List<CheckDeposit.DepositAdjustment> depositAdjustments()
If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments.
-
depositRejection
final Optional<CheckDeposit.DepositRejection> depositRejection()
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
depositReturn
final Optional<CheckDeposit.DepositReturn> depositReturn()
If your deposit is returned, this will contain details as to why it was returned.
-
depositSubmission
final Optional<CheckDeposit.DepositSubmission> depositSubmission()
After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
-
description
final Optional<String> description()
The description of the Check Deposit, for display purposes only.
-
frontImageFileId
final String frontImageFileId()
The ID for the File containing the image of the front of the check.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundFundsHold
final Optional<CheckDeposit.InboundFundsHold> inboundFundsHold()
Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
-
inboundMailItemId
final Optional<String> inboundMailItemId()
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.
-
lockboxRecipientId
final Optional<String> lockboxRecipientId()
If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it.
-
status
final CheckDeposit.Status status()
The status of the Check Deposit.
-
transactionId
final Optional<String> transactionId()
The ID for the Transaction created by the deposit.
-
type
final CheckDeposit.Type type()
A constant representing the object's type. For this resource it will always be
check_deposit.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_depositAcceptance
final JsonField<CheckDeposit.DepositAcceptance> _depositAcceptance()
Returns the raw JSON value of depositAcceptance.
Unlike depositAcceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_depositAdjustments
final JsonField<List<CheckDeposit.DepositAdjustment>> _depositAdjustments()
Returns the raw JSON value of depositAdjustments.
Unlike depositAdjustments, this method doesn't throw if the JSON field has an unexpected type.
-
_depositRejection
final JsonField<CheckDeposit.DepositRejection> _depositRejection()
Returns the raw JSON value of depositRejection.
Unlike depositRejection, this method doesn't throw if the JSON field has an unexpected type.
-
_depositReturn
final JsonField<CheckDeposit.DepositReturn> _depositReturn()
Returns the raw JSON value of depositReturn.
Unlike depositReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_depositSubmission
final JsonField<CheckDeposit.DepositSubmission> _depositSubmission()
Returns the raw JSON value of depositSubmission.
Unlike depositSubmission, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundFundsHold
final JsonField<CheckDeposit.InboundFundsHold> _inboundFundsHold()
Returns the raw JSON value of inboundFundsHold.
Unlike inboundFundsHold, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundMailItemId
final JsonField<String> _inboundMailItemId()
Returns the raw JSON value of inboundMailItemId.
Unlike inboundMailItemId, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxRecipientId
final JsonField<String> _lockboxRecipientId()
Returns the raw JSON value of lockboxRecipientId.
Unlike lockboxRecipientId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CheckDeposit.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CheckDeposit.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDeposit.Builder toBuilder()
-
validate
final CheckDeposit validate()
-
builder
final static CheckDeposit.Builder builder()
Returns a mutable builder for constructing an instance of CheckDeposit.
The following fields are required:
.id() .accountId() .amount() .backImageFileId() .createdAt() .depositAcceptance() .depositAdjustments() .depositRejection() .depositReturn() .depositSubmission() .description() .frontImageFileId() .idempotencyKey() .inboundFundsHold() .inboundMailItemId() .lockboxRecipientId() .status() .transactionId() .type()
-
-
-
-