Class CheckDeposit.Builder
-
- All Implemented Interfaces:
public final class CheckDeposit.BuilderA builder for CheckDeposit.
-
-
Method Summary
Modifier and Type Method Description final CheckDeposit.Builderid(String id)The deposit's identifier. final CheckDeposit.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final CheckDeposit.BuilderaccountId(String accountId)The Account the check was deposited into. final CheckDeposit.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final CheckDeposit.Builderamount(Long amount)The deposited amount in USD cents. final CheckDeposit.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final CheckDeposit.BuilderbackImageFileId(String backImageFileId)The ID for the File containing the image of the back of the check. final CheckDeposit.BuilderbackImageFileId(Optional<String> backImageFileId)Alias for calling Builder.backImageFileId with backImageFileId.orElse(null).final CheckDeposit.BuilderbackImageFileId(JsonField<String> backImageFileId)Sets Builder.backImageFileId to an arbitrary JSON value. final CheckDeposit.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final CheckDeposit.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final CheckDeposit.BuilderdepositAcceptance(CheckDeposit.DepositAcceptance depositAcceptance)Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check. final CheckDeposit.BuilderdepositAcceptance(Optional<CheckDeposit.DepositAcceptance> depositAcceptance)Alias for calling Builder.depositAcceptance with depositAcceptance.orElse(null).final CheckDeposit.BuilderdepositAcceptance(JsonField<CheckDeposit.DepositAcceptance> depositAcceptance)Sets Builder.depositAcceptance to an arbitrary JSON value. final CheckDeposit.BuilderdepositAdjustments(List<CheckDeposit.DepositAdjustment> depositAdjustments)If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments. final CheckDeposit.BuilderdepositAdjustments(JsonField<List<CheckDeposit.DepositAdjustment>> depositAdjustments)Sets Builder.depositAdjustments to an arbitrary JSON value. final CheckDeposit.BuilderaddDepositAdjustment(CheckDeposit.DepositAdjustment depositAdjustment)Adds a single DepositAdjustment to depositAdjustments. final CheckDeposit.BuilderdepositRejection(CheckDeposit.DepositRejection depositRejection)If your deposit is rejected by Increase, this will contain details as to why it was rejected. final CheckDeposit.BuilderdepositRejection(Optional<CheckDeposit.DepositRejection> depositRejection)Alias for calling Builder.depositRejection with depositRejection.orElse(null).final CheckDeposit.BuilderdepositRejection(JsonField<CheckDeposit.DepositRejection> depositRejection)Sets Builder.depositRejection to an arbitrary JSON value. final CheckDeposit.BuilderdepositReturn(CheckDeposit.DepositReturn depositReturn)If your deposit is returned, this will contain details as to why it was returned. final CheckDeposit.BuilderdepositReturn(Optional<CheckDeposit.DepositReturn> depositReturn)Alias for calling Builder.depositReturn with depositReturn.orElse(null).final CheckDeposit.BuilderdepositReturn(JsonField<CheckDeposit.DepositReturn> depositReturn)Sets Builder.depositReturn to an arbitrary JSON value. final CheckDeposit.BuilderdepositSubmission(CheckDeposit.DepositSubmission depositSubmission)After the check is parsed, it is submitted to the Check21 network for processing. final CheckDeposit.BuilderdepositSubmission(Optional<CheckDeposit.DepositSubmission> depositSubmission)Alias for calling Builder.depositSubmission with depositSubmission.orElse(null).final CheckDeposit.BuilderdepositSubmission(JsonField<CheckDeposit.DepositSubmission> depositSubmission)Sets Builder.depositSubmission to an arbitrary JSON value. final CheckDeposit.Builderdescription(String description)The description of the Check Deposit, for display purposes only. final CheckDeposit.Builderdescription(Optional<String> description)Alias for calling Builder.description with description.orElse(null).final CheckDeposit.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final CheckDeposit.BuilderfrontImageFileId(String frontImageFileId)The ID for the File containing the image of the front of the check. final CheckDeposit.BuilderfrontImageFileId(JsonField<String> frontImageFileId)Sets Builder.frontImageFileId to an arbitrary JSON value. final CheckDeposit.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final CheckDeposit.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final CheckDeposit.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final CheckDeposit.BuilderinboundFundsHold(CheckDeposit.InboundFundsHold inboundFundsHold)Increase will sometimes hold the funds for Check Deposits. final CheckDeposit.BuilderinboundFundsHold(Optional<CheckDeposit.InboundFundsHold> inboundFundsHold)Alias for calling Builder.inboundFundsHold with inboundFundsHold.orElse(null).final CheckDeposit.BuilderinboundFundsHold(JsonField<CheckDeposit.InboundFundsHold> inboundFundsHold)Sets Builder.inboundFundsHold to an arbitrary JSON value. final CheckDeposit.BuilderinboundMailItemId(String inboundMailItemId)If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item. final CheckDeposit.BuilderinboundMailItemId(Optional<String> inboundMailItemId)Alias for calling Builder.inboundMailItemId with inboundMailItemId.orElse(null).final CheckDeposit.BuilderinboundMailItemId(JsonField<String> inboundMailItemId)Sets Builder.inboundMailItemId to an arbitrary JSON value. final CheckDeposit.BuilderlockboxRecipientId(String lockboxRecipientId)If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it. final CheckDeposit.BuilderlockboxRecipientId(Optional<String> lockboxRecipientId)Alias for calling Builder.lockboxRecipientId with lockboxRecipientId.orElse(null).final CheckDeposit.BuilderlockboxRecipientId(JsonField<String> lockboxRecipientId)Sets Builder.lockboxRecipientId to an arbitrary JSON value. final CheckDeposit.Builderstatus(CheckDeposit.Status status)The status of the Check Deposit. final CheckDeposit.Builderstatus(JsonField<CheckDeposit.Status> status)Sets Builder.status to an arbitrary JSON value. final CheckDeposit.BuildertransactionId(String transactionId)The ID for the Transaction created by the deposit. final CheckDeposit.BuildertransactionId(Optional<String> transactionId)Alias for calling Builder.transactionId with transactionId.orElse(null).final CheckDeposit.BuildertransactionId(JsonField<String> transactionId)Sets Builder.transactionId to an arbitrary JSON value. final CheckDeposit.Buildertype(CheckDeposit.Type type)A constant representing the object's type. final CheckDeposit.Buildertype(JsonField<CheckDeposit.Type> type)Sets Builder.type to an arbitrary JSON value. final CheckDeposit.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckDeposit.BuilderputAdditionalProperty(String key, JsonValue value)final CheckDeposit.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckDeposit.BuilderremoveAdditionalProperty(String key)final CheckDeposit.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckDepositbuild()Returns an immutable instance of CheckDeposit. -
-
Method Detail
-
id
final CheckDeposit.Builder id(String id)
The deposit's identifier.
-
id
final CheckDeposit.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final CheckDeposit.Builder accountId(String accountId)
The Account the check was deposited into.
-
accountId
final CheckDeposit.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final CheckDeposit.Builder amount(Long amount)
The deposited amount in USD cents.
-
amount
final CheckDeposit.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backImageFileId
final CheckDeposit.Builder backImageFileId(String backImageFileId)
The ID for the File containing the image of the back of the check.
-
backImageFileId
final CheckDeposit.Builder backImageFileId(Optional<String> backImageFileId)
Alias for calling Builder.backImageFileId with
backImageFileId.orElse(null).
-
backImageFileId
final CheckDeposit.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CheckDeposit.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final CheckDeposit.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
depositAcceptance
final CheckDeposit.Builder depositAcceptance(CheckDeposit.DepositAcceptance depositAcceptance)
Once your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
depositAcceptance
final CheckDeposit.Builder depositAcceptance(Optional<CheckDeposit.DepositAcceptance> depositAcceptance)
Alias for calling Builder.depositAcceptance with
depositAcceptance.orElse(null).
-
depositAcceptance
final CheckDeposit.Builder depositAcceptance(JsonField<CheckDeposit.DepositAcceptance> depositAcceptance)
Sets Builder.depositAcceptance to an arbitrary JSON value.
You should usually call Builder.depositAcceptance with a well-typed DepositAcceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
depositAdjustments
final CheckDeposit.Builder depositAdjustments(List<CheckDeposit.DepositAdjustment> depositAdjustments)
If the deposit or the return was adjusted by the receiving institution, this will contain details of the adjustments.
-
depositAdjustments
final CheckDeposit.Builder depositAdjustments(JsonField<List<CheckDeposit.DepositAdjustment>> depositAdjustments)
Sets Builder.depositAdjustments to an arbitrary JSON value.
You should usually call Builder.depositAdjustments with a well-typed
List<DepositAdjustment>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addDepositAdjustment
final CheckDeposit.Builder addDepositAdjustment(CheckDeposit.DepositAdjustment depositAdjustment)
Adds a single DepositAdjustment to depositAdjustments.
-
depositRejection
final CheckDeposit.Builder depositRejection(CheckDeposit.DepositRejection depositRejection)
If your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
depositRejection
final CheckDeposit.Builder depositRejection(Optional<CheckDeposit.DepositRejection> depositRejection)
Alias for calling Builder.depositRejection with
depositRejection.orElse(null).
-
depositRejection
final CheckDeposit.Builder depositRejection(JsonField<CheckDeposit.DepositRejection> depositRejection)
Sets Builder.depositRejection to an arbitrary JSON value.
You should usually call Builder.depositRejection with a well-typed DepositRejection value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
depositReturn
final CheckDeposit.Builder depositReturn(CheckDeposit.DepositReturn depositReturn)
If your deposit is returned, this will contain details as to why it was returned.
-
depositReturn
final CheckDeposit.Builder depositReturn(Optional<CheckDeposit.DepositReturn> depositReturn)
Alias for calling Builder.depositReturn with
depositReturn.orElse(null).
-
depositReturn
final CheckDeposit.Builder depositReturn(JsonField<CheckDeposit.DepositReturn> depositReturn)
Sets Builder.depositReturn to an arbitrary JSON value.
You should usually call Builder.depositReturn with a well-typed DepositReturn value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
depositSubmission
final CheckDeposit.Builder depositSubmission(CheckDeposit.DepositSubmission depositSubmission)
After the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
-
depositSubmission
final CheckDeposit.Builder depositSubmission(Optional<CheckDeposit.DepositSubmission> depositSubmission)
Alias for calling Builder.depositSubmission with
depositSubmission.orElse(null).
-
depositSubmission
final CheckDeposit.Builder depositSubmission(JsonField<CheckDeposit.DepositSubmission> depositSubmission)
Sets Builder.depositSubmission to an arbitrary JSON value.
You should usually call Builder.depositSubmission with a well-typed DepositSubmission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final CheckDeposit.Builder description(String description)
The description of the Check Deposit, for display purposes only.
-
description
final CheckDeposit.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final CheckDeposit.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final CheckDeposit.Builder frontImageFileId(String frontImageFileId)
The ID for the File containing the image of the front of the check.
-
frontImageFileId
final CheckDeposit.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final CheckDeposit.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CheckDeposit.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final CheckDeposit.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundFundsHold
final CheckDeposit.Builder inboundFundsHold(CheckDeposit.InboundFundsHold inboundFundsHold)
Increase will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
-
inboundFundsHold
final CheckDeposit.Builder inboundFundsHold(Optional<CheckDeposit.InboundFundsHold> inboundFundsHold)
Alias for calling Builder.inboundFundsHold with
inboundFundsHold.orElse(null).
-
inboundFundsHold
final CheckDeposit.Builder inboundFundsHold(JsonField<CheckDeposit.InboundFundsHold> inboundFundsHold)
Sets Builder.inboundFundsHold to an arbitrary JSON value.
You should usually call Builder.inboundFundsHold with a well-typed InboundFundsHold value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundMailItemId
final CheckDeposit.Builder inboundMailItemId(String inboundMailItemId)
If the Check Deposit was the result of an Inbound Mail Item, this will contain the identifier of the Inbound Mail Item.
-
inboundMailItemId
final CheckDeposit.Builder inboundMailItemId(Optional<String> inboundMailItemId)
Alias for calling Builder.inboundMailItemId with
inboundMailItemId.orElse(null).
-
inboundMailItemId
final CheckDeposit.Builder inboundMailItemId(JsonField<String> inboundMailItemId)
Sets Builder.inboundMailItemId to an arbitrary JSON value.
You should usually call Builder.inboundMailItemId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxRecipientId
final CheckDeposit.Builder lockboxRecipientId(String lockboxRecipientId)
If the Check Deposit was the result of an Inbound Mail Item routed to a Lockbox Recipient, this will contain the identifier of the Lockbox Recipient that received it.
-
lockboxRecipientId
final CheckDeposit.Builder lockboxRecipientId(Optional<String> lockboxRecipientId)
Alias for calling Builder.lockboxRecipientId with
lockboxRecipientId.orElse(null).
-
lockboxRecipientId
final CheckDeposit.Builder lockboxRecipientId(JsonField<String> lockboxRecipientId)
Sets Builder.lockboxRecipientId to an arbitrary JSON value.
You should usually call Builder.lockboxRecipientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CheckDeposit.Builder status(CheckDeposit.Status status)
The status of the Check Deposit.
-
status
final CheckDeposit.Builder status(JsonField<CheckDeposit.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final CheckDeposit.Builder transactionId(String transactionId)
The ID for the Transaction created by the deposit.
-
transactionId
final CheckDeposit.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final CheckDeposit.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CheckDeposit.Builder type(CheckDeposit.Type type)
A constant representing the object's type. For this resource it will always be
check_deposit.
-
type
final CheckDeposit.Builder type(JsonField<CheckDeposit.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckDeposit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckDeposit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckDeposit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckDeposit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckDeposit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckDeposit build()
Returns an immutable instance of CheckDeposit.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount() .backImageFileId() .createdAt() .depositAcceptance() .depositAdjustments() .depositRejection() .depositReturn() .depositSubmission() .description() .frontImageFileId() .idempotencyKey() .inboundFundsHold() .inboundMailItemId() .lockboxRecipientId() .status() .transactionId() .type()
-
-
-
-