Class CheckDeposit.DepositAcceptance
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositAcceptanceOnce your deposit is successfully parsed and accepted by Increase, this will contain details of the parsed check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositAcceptance.BuilderA builder for DepositAcceptance.
public final classCheckDeposit.DepositAcceptance.CurrencyThe ISO 4217 code for the transaction's currency.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number printed on the check. final Longamount()The amount to be deposited in the minor unit of the transaction's currency. final Optional<String>auxiliaryOnUs()An additional line of metadata printed on the check. final StringcheckDepositId()The ID of the Check Deposit that was accepted. final CheckDeposit.DepositAcceptance.Currencycurrency()The ISO 4217 code for the transaction's currency. final StringroutingNumber()The routing number printed on the check. final Optional<String>serialNumber()The check serial number, if present, for consumer checks. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_auxiliaryOnUs()Returns the raw JSON value of auxiliaryOnUs. final JsonField<String>_checkDepositId()Returns the raw JSON value of checkDepositId. final JsonField<CheckDeposit.DepositAcceptance.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_serialNumber()Returns the raw JSON value of serialNumber. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositAcceptance.BuildertoBuilder()final CheckDeposit.DepositAcceptancevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositAcceptance.Builderbuilder()Returns a mutable builder for constructing an instance of DepositAcceptance. -
-
Method Detail
-
accountNumber
final String accountNumber()
The account number printed on the check. This is an account at the bank that issued the check.
-
amount
final Long amount()
The amount to be deposited in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
An additional line of metadata printed on the check. This typically includes the check number for business checks.
-
checkDepositId
final String checkDepositId()
The ID of the Check Deposit that was accepted.
-
currency
final CheckDeposit.DepositAcceptance.Currency currency()
The ISO 4217 code for the transaction's currency.
-
routingNumber
final String routingNumber()
The routing number printed on the check. This is a routing number for the bank that issued the check.
-
serialNumber
final Optional<String> serialNumber()
The check serial number, if present, for consumer checks. For business checks, the serial number is usually in the
auxiliary_on_usfield.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
Returns the raw JSON value of auxiliaryOnUs.
Unlike auxiliaryOnUs, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositId
final JsonField<String> _checkDepositId()
Returns the raw JSON value of checkDepositId.
Unlike checkDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CheckDeposit.DepositAcceptance.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_serialNumber
final JsonField<String> _serialNumber()
Returns the raw JSON value of serialNumber.
Unlike serialNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDeposit.DepositAcceptance.Builder toBuilder()
-
validate
final CheckDeposit.DepositAcceptance validate()
-
builder
final static CheckDeposit.DepositAcceptance.Builder builder()
Returns a mutable builder for constructing an instance of DepositAcceptance.
The following fields are required:
.accountNumber() .amount() .auxiliaryOnUs() .checkDepositId() .currency() .routingNumber() .serialNumber()
-
-
-
-