Class CheckDeposit.DepositAdjustment
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositAdjustment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositAdjustment.BuilderA builder for DepositAdjustment.
public final classCheckDeposit.DepositAdjustment.ReasonThe reason for the adjustment.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeadjustedAt()The time at which the adjustment was received. final Longamount()The amount of the adjustment. final CheckDeposit.DepositAdjustment.Reasonreason()The reason for the adjustment. final StringtransactionId()The id of the transaction for the adjustment. final JsonField<OffsetDateTime>_adjustedAt()Returns the raw JSON value of adjustedAt. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<CheckDeposit.DepositAdjustment.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositAdjustment.BuildertoBuilder()final CheckDeposit.DepositAdjustmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositAdjustment.Builderbuilder()Returns a mutable builder for constructing an instance of DepositAdjustment. -
-
Method Detail
-
adjustedAt
final OffsetDateTime adjustedAt()
The time at which the adjustment was received.
-
reason
final CheckDeposit.DepositAdjustment.Reason reason()
The reason for the adjustment.
-
transactionId
final String transactionId()
The id of the transaction for the adjustment.
-
_adjustedAt
final JsonField<OffsetDateTime> _adjustedAt()
Returns the raw JSON value of adjustedAt.
Unlike adjustedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<CheckDeposit.DepositAdjustment.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDeposit.DepositAdjustment.Builder toBuilder()
-
validate
final CheckDeposit.DepositAdjustment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckDeposit.DepositAdjustment.Builder builder()
Returns a mutable builder for constructing an instance of DepositAdjustment.
The following fields are required:
.adjustedAt() .amount() .reason() .transactionId()
-
-
-
-