Class CheckDeposit.DepositRejection
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositRejectionIf your deposit is rejected by Increase, this will contain details as to why it was rejected.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositRejection.BuilderA builder for DepositRejection.
public final classCheckDeposit.DepositRejection.CurrencyThe ISO 4217 code for the check's currency.
public final classCheckDeposit.DepositRejection.ReasonWhy the check deposit was rejected.
-
Method Summary
Modifier and Type Method Description final Longamount()The rejected amount in the minor unit of check's currency. final StringcheckDepositId()The identifier of the Check Deposit that was rejected. final CheckDeposit.DepositRejection.Currencycurrency()The ISO 4217 code for the check's currency. final StringdeclinedTransactionId()The identifier of the associated declined transaction. final CheckDeposit.DepositRejection.Reasonreason()Why the check deposit was rejected. final OffsetDateTimerejectedAt()The ISO 8601 date and time at which the check deposit was rejected. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_checkDepositId()Returns the raw JSON value of checkDepositId. final JsonField<CheckDeposit.DepositRejection.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_declinedTransactionId()Returns the raw JSON value of declinedTransactionId. final JsonField<CheckDeposit.DepositRejection.Reason>_reason()Returns the raw JSON value of reason. final JsonField<OffsetDateTime>_rejectedAt()Returns the raw JSON value of rejectedAt. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositRejection.BuildertoBuilder()final CheckDeposit.DepositRejectionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositRejection.Builderbuilder()Returns a mutable builder for constructing an instance of DepositRejection. -
-
Method Detail
-
amount
final Long amount()
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
checkDepositId
final String checkDepositId()
The identifier of the Check Deposit that was rejected.
-
currency
final CheckDeposit.DepositRejection.Currency currency()
The ISO 4217 code for the check's currency.
-
declinedTransactionId
final String declinedTransactionId()
The identifier of the associated declined transaction.
-
reason
final CheckDeposit.DepositRejection.Reason reason()
Why the check deposit was rejected.
-
rejectedAt
final OffsetDateTime rejectedAt()
The ISO 8601 date and time at which the check deposit was rejected.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositId
final JsonField<String> _checkDepositId()
Returns the raw JSON value of checkDepositId.
Unlike checkDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CheckDeposit.DepositRejection.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
Returns the raw JSON value of declinedTransactionId.
Unlike declinedTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<CheckDeposit.DepositRejection.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
Returns the raw JSON value of rejectedAt.
Unlike rejectedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDeposit.DepositRejection.Builder toBuilder()
-
validate
final CheckDeposit.DepositRejection validate()
-
builder
final static CheckDeposit.DepositRejection.Builder builder()
Returns a mutable builder for constructing an instance of DepositRejection.
The following fields are required:
.amount() .checkDepositId() .currency() .declinedTransactionId() .reason() .rejectedAt()
-
-
-
-