Class CheckDeposit.DepositRejection.Builder
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositRejection.BuilderA builder for DepositRejection.
-
-
Method Summary
-
-
Method Detail
-
amount
final CheckDeposit.DepositRejection.Builder amount(Long amount)
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
amount
final CheckDeposit.DepositRejection.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositId
final CheckDeposit.DepositRejection.Builder checkDepositId(String checkDepositId)
The identifier of the Check Deposit that was rejected.
-
checkDepositId
final CheckDeposit.DepositRejection.Builder checkDepositId(JsonField<String> checkDepositId)
Sets Builder.checkDepositId to an arbitrary JSON value.
You should usually call Builder.checkDepositId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final CheckDeposit.DepositRejection.Builder currency(CheckDeposit.DepositRejection.Currency currency)
The ISO 4217 code for the check's currency.
-
currency
final CheckDeposit.DepositRejection.Builder currency(JsonField<CheckDeposit.DepositRejection.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declinedTransactionId
final CheckDeposit.DepositRejection.Builder declinedTransactionId(String declinedTransactionId)
The identifier of the associated declined transaction.
-
declinedTransactionId
final CheckDeposit.DepositRejection.Builder declinedTransactionId(JsonField<String> declinedTransactionId)
Sets Builder.declinedTransactionId to an arbitrary JSON value.
You should usually call Builder.declinedTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final CheckDeposit.DepositRejection.Builder reason(CheckDeposit.DepositRejection.Reason reason)
Why the check deposit was rejected.
-
reason
final CheckDeposit.DepositRejection.Builder reason(JsonField<CheckDeposit.DepositRejection.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rejectedAt
final CheckDeposit.DepositRejection.Builder rejectedAt(OffsetDateTime rejectedAt)
The ISO 8601 date and time at which the check deposit was rejected.
-
rejectedAt
final CheckDeposit.DepositRejection.Builder rejectedAt(JsonField<OffsetDateTime> rejectedAt)
Sets Builder.rejectedAt to an arbitrary JSON value.
You should usually call Builder.rejectedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckDeposit.DepositRejection.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckDeposit.DepositRejection.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckDeposit.DepositRejection.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckDeposit.DepositRejection.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckDeposit.DepositRejection.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckDeposit.DepositRejection build()
Returns an immutable instance of DepositRejection.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .checkDepositId() .currency() .declinedTransactionId() .reason() .rejectedAt()
-
-
-
-