Class CheckDeposit.DepositRejection.Reason
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class CheckDeposit.DepositRejection.Reason implements EnumWhy the check deposit was rejected.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumCheckDeposit.DepositRejection.Reason.KnownAn enum containing Reason's known values.
public enumCheckDeposit.DepositRejection.Reason.ValueAn enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static CheckDeposit.DepositRejection.ReasonINCOMPLETE_IMAGEpublic final static CheckDeposit.DepositRejection.ReasonDUPLICATEpublic final static CheckDeposit.DepositRejection.ReasonPOOR_IMAGE_QUALITYpublic final static CheckDeposit.DepositRejection.ReasonINCORRECT_AMOUNTpublic final static CheckDeposit.DepositRejection.ReasonINCORRECT_RECIPIENTpublic final static CheckDeposit.DepositRejection.ReasonNOT_ELIGIBLE_FOR_MOBILE_DEPOSITpublic final static CheckDeposit.DepositRejection.ReasonMISSING_REQUIRED_DATA_ELEMENTSpublic final static CheckDeposit.DepositRejection.ReasonSUSPECTED_FRAUDpublic final static CheckDeposit.DepositRejection.ReasonDEPOSIT_WINDOW_EXPIREDpublic final static CheckDeposit.DepositRejection.ReasonREQUESTED_BY_USERpublic final static CheckDeposit.DepositRejection.ReasonINTERNATIONALpublic final static CheckDeposit.DepositRejection.ReasonUNKNOWN
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final CheckDeposit.DepositRejection.Reason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final CheckDeposit.DepositRejection.Reason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final CheckDeposit.DepositRejection.Reasonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositRejection.Reasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final CheckDeposit.DepositRejection.Reason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final CheckDeposit.DepositRejection.Reason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final CheckDeposit.DepositRejection.Reason validate()
-
of
final static CheckDeposit.DepositRejection.Reason of(String value)
-
-
-
-