Class CheckDeposit.DepositSubmission
-
- All Implemented Interfaces:
public final class CheckDeposit.DepositSubmissionAfter the check is parsed, it is submitted to the Check21 network for processing. This will contain details of the submission.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.DepositSubmission.BuilderA builder for DepositSubmission.
-
Method Summary
Modifier and Type Method Description final StringbackFileId()The ID for the File containing the check back image that was submitted to the Check21 network. final StringfrontFileId()The ID for the File containing the check front image that was submitted to the Check21 network. final OffsetDateTimesubmittedAt()When the check deposit was submitted to the Check21 network for processing. final JsonField<String>_backFileId()Returns the raw JSON value of backFileId. final JsonField<String>_frontFileId()Returns the raw JSON value of frontFileId. final JsonField<OffsetDateTime>_submittedAt()Returns the raw JSON value of submittedAt. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.DepositSubmission.BuildertoBuilder()final CheckDeposit.DepositSubmissionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.DepositSubmission.Builderbuilder()Returns a mutable builder for constructing an instance of DepositSubmission. -
-
Method Detail
-
backFileId
final String backFileId()
The ID for the File containing the check back image that was submitted to the Check21 network.
-
frontFileId
final String frontFileId()
The ID for the File containing the check front image that was submitted to the Check21 network.
-
submittedAt
final OffsetDateTime submittedAt()
When the check deposit was submitted to the Check21 network for processing. During business days, this happens within a few hours of the check being accepted by Increase.
-
_backFileId
final JsonField<String> _backFileId()
Returns the raw JSON value of backFileId.
Unlike backFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontFileId
final JsonField<String> _frontFileId()
Returns the raw JSON value of frontFileId.
Unlike frontFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
Returns the raw JSON value of submittedAt.
Unlike submittedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDeposit.DepositSubmission.Builder toBuilder()
-
validate
final CheckDeposit.DepositSubmission validate()
-
builder
final static CheckDeposit.DepositSubmission.Builder builder()
Returns a mutable builder for constructing an instance of DepositSubmission.
The following fields are required:
.backFileId() .frontFileId() .submittedAt()
-
-
-
-