Class CheckDeposit.InboundFundsHold
-
- All Implemented Interfaces:
public final class CheckDeposit.InboundFundsHoldIncrease will sometimes hold the funds for Check Deposits. If funds are held, this sub-object will contain details of the hold.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDeposit.InboundFundsHold.BuilderA builder for InboundFundsHold.
public final classCheckDeposit.InboundFundsHold.CurrencyThe ISO 4217 code for the hold's currency.
public final classCheckDeposit.InboundFundsHold.StatusThe status of the hold.
public final classCheckDeposit.InboundFundsHold.TypeA constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
Method Summary
Modifier and Type Method Description final Longamount()The held amount in the minor unit of the account's currency. final OffsetDateTimeautomaticallyReleasesAt()When the hold will be released automatically. final OffsetDateTimecreatedAt()The ISO 8601 time at which the hold was created. final CheckDeposit.InboundFundsHold.Currencycurrency()The ISO 4217 code for the hold's currency. final Optional<String>heldTransactionId()The ID of the Transaction for which funds were held. final Optional<String>pendingTransactionId()The ID of the Pending Transaction representing the held funds. final Optional<OffsetDateTime>releasedAt()When the hold was released (if it has been released). final CheckDeposit.InboundFundsHold.Statusstatus()The status of the hold. final CheckDeposit.InboundFundsHold.Typetype()A constant representing the object's type. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_automaticallyReleasesAt()Returns the raw JSON value of automaticallyReleasesAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CheckDeposit.InboundFundsHold.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_heldTransactionId()Returns the raw JSON value of heldTransactionId. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<OffsetDateTime>_releasedAt()Returns the raw JSON value of releasedAt. final JsonField<CheckDeposit.InboundFundsHold.Status>_status()Returns the raw JSON value of status. final JsonField<CheckDeposit.InboundFundsHold.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CheckDeposit.InboundFundsHold.BuildertoBuilder()final CheckDeposit.InboundFundsHoldvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDeposit.InboundFundsHold.Builderbuilder()Returns a mutable builder for constructing an instance of InboundFundsHold. -
-
Method Detail
-
amount
final Long amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final OffsetDateTime automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the hold was created.
-
currency
final CheckDeposit.InboundFundsHold.Currency currency()
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final Optional<String> heldTransactionId()
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final Optional<OffsetDateTime> releasedAt()
When the hold was released (if it has been released).
-
status
final CheckDeposit.InboundFundsHold.Status status()
The status of the hold.
-
type
final CheckDeposit.InboundFundsHold.Type type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_automaticallyReleasesAt
final JsonField<OffsetDateTime> _automaticallyReleasesAt()
Returns the raw JSON value of automaticallyReleasesAt.
Unlike automaticallyReleasesAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CheckDeposit.InboundFundsHold.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_heldTransactionId
final JsonField<String> _heldTransactionId()
Returns the raw JSON value of heldTransactionId.
Unlike heldTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_releasedAt
final JsonField<OffsetDateTime> _releasedAt()
Returns the raw JSON value of releasedAt.
Unlike releasedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CheckDeposit.InboundFundsHold.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CheckDeposit.InboundFundsHold.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDeposit.InboundFundsHold.Builder toBuilder()
-
validate
final CheckDeposit.InboundFundsHold validate()
-
builder
final static CheckDeposit.InboundFundsHold.Builder builder()
Returns a mutable builder for constructing an instance of InboundFundsHold.
The following fields are required:
.amount() .automaticallyReleasesAt() .createdAt() .currency() .heldTransactionId() .pendingTransactionId() .releasedAt() .status() .type()
-
-
-
-