Enum CheckDeposit.Status.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum CheckDeposit.Status.Value
    extends Enum<CheckDeposit.Status.Value>
                        

    An enum containing Status's known values, as well as an _UNKNOWN member.

    An instance of Status can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      PENDING

      The Check Deposit is pending review.

      SUBMITTED

      The Check Deposit has been deposited.

      REJECTED

      The Check Deposit has been rejected.

      RETURNED

      The Check Deposit has been returned.

      _UNKNOWN

      An enum member indicating that Status was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final CheckDeposit.Status.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • values

         final Array<CheckDeposit.Status.Value> values()

        Returns an array containing the constants of this enum type, in the order they're declared.

        This method may be used to iterate over the constants.

      • getEntries

         final EnumEntries<CheckDeposit.Status.Value> getEntries()

        An enum containing Status's known values, as well as an _UNKNOWN member.

        An instance of Status can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.