Class CheckDepositCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CheckDepositCreateParams implements Params
Create a Check Deposit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositCreateParams.BuilderA builder for CheckDepositCreateParams.
public final classCheckDepositCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the Account to deposit the check in. final Longamount()The deposit amount in USD cents. final StringbackImageFileId()The File containing the check's back image. final StringfrontImageFileId()The File containing the check's front image. final Optional<String>description()The description you choose to give the Check Deposit, for display purposes only. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CheckDepositCreateParams.BuildertoBuilder()final CheckDepositCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDepositCreateParams. -
-
Method Detail
-
backImageFileId
final String backImageFileId()
The File containing the check's back image.
-
frontImageFileId
final String frontImageFileId()
The File containing the check's front image.
-
description
final Optional<String> description()
The description you choose to give the Check Deposit, for display purposes only.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CheckDepositCreateParams.Builder toBuilder()
-
_body
final CheckDepositCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CheckDepositCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositCreateParams.
The following fields are required:
.accountId() .amount() .backImageFileId() .frontImageFileId()
-
-
-
-