Class CheckDepositCreateParams.Body
-
- All Implemented Interfaces:
public final class CheckDepositCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the Account to deposit the check in. final Longamount()The deposit amount in USD cents. final StringbackImageFileId()The File containing the check's back image. final StringfrontImageFileId()The File containing the check's front image. final Optional<String>description()The description you choose to give the Check Deposit, for display purposes only. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final CheckDepositCreateParams.Body.BuildertoBuilder()final CheckDepositCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
backImageFileId
final String backImageFileId()
The File containing the check's back image.
-
frontImageFileId
final String frontImageFileId()
The File containing the check's front image.
-
description
final Optional<String> description()
The description you choose to give the Check Deposit, for display purposes only.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDepositCreateParams.Body.Builder toBuilder()
-
validate
final CheckDepositCreateParams.Body validate()
-
builder
final static CheckDepositCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount() .backImageFileId() .frontImageFileId()
-
-
-
-