Class CheckDepositCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CheckDepositCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final CheckDepositCreateParams.Body.Builder accountId(String accountId)
The identifier for the Account to deposit the check in.
-
accountId
final CheckDepositCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final CheckDepositCreateParams.Body.Builder amount(Long amount)
The deposit amount in USD cents.
-
amount
final CheckDepositCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backImageFileId
final CheckDepositCreateParams.Body.Builder backImageFileId(String backImageFileId)
The File containing the check's back image.
-
backImageFileId
final CheckDepositCreateParams.Body.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final CheckDepositCreateParams.Body.Builder frontImageFileId(String frontImageFileId)
The File containing the check's front image.
-
frontImageFileId
final CheckDepositCreateParams.Body.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final CheckDepositCreateParams.Body.Builder description(String description)
The description you choose to give the Check Deposit, for display purposes only.
-
description
final CheckDepositCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckDepositCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckDepositCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckDepositCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckDepositCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckDepositCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckDepositCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .backImageFileId() .frontImageFileId()
-
-
-
-