Class CheckDepositListPageAsync
-
- All Implemented Interfaces:
public final class CheckDepositListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositListPageAsync.BuilderA builder for CheckDepositListPageAsync.
public final classCheckDepositListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<CheckDeposit>data()Delegates to CheckDepositListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to CheckDepositListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<CheckDepositListParams>getNextPageParams()final CompletableFuture<Optional<CheckDepositListPageAsync>>getNextPage()final CheckDepositListPageAsync.AutoPagerautoPager()final CheckDepositListParamsparams()The parameters that were used to request this page. final CheckDepositListPageResponseresponse()The response that this page was parsed from. final CheckDepositListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDepositListPageAsync. -
-
Method Detail
-
data
final List<CheckDeposit> data()
Delegates to CheckDepositListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CheckDepositListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<CheckDepositListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<CheckDepositListPageAsync>> getNextPage()
-
autoPager
final CheckDepositListPageAsync.AutoPager autoPager()
-
params
final CheckDepositListParams params()
The parameters that were used to request this page.
-
response
final CheckDepositListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CheckDepositListPageAsync.Builder toBuilder()
-
builder
final static CheckDepositListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-