Class CheckDepositListPageAsync.Builder
-
- All Implemented Interfaces:
public final class CheckDepositListPageAsync.BuilderA builder for CheckDepositListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final CheckDepositListPageAsync.Builderservice(CheckDepositServiceAsync service)final CheckDepositListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final CheckDepositListPageAsync.Builderparams(CheckDepositListParams params)The parameters that were used to request this page. final CheckDepositListPageAsync.Builderresponse(CheckDepositListPageResponse response)The response that this page was parsed from. final CheckDepositListPageAsyncbuild()Returns an immutable instance of CheckDepositListPageAsync. -
-
Method Detail
-
service
final CheckDepositListPageAsync.Builder service(CheckDepositServiceAsync service)
-
streamHandlerExecutor
final CheckDepositListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final CheckDepositListPageAsync.Builder params(CheckDepositListParams params)
The parameters that were used to request this page.
-
response
final CheckDepositListPageAsync.Builder response(CheckDepositListPageResponse response)
The response that this page was parsed from.
-
build
final CheckDepositListPageAsync build()
Returns an immutable instance of CheckDepositListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-