Class CheckDepositListPageResponse
-
- All Implemented Interfaces:
public final class CheckDepositListPageResponseA list of Check Deposit objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositListPageResponse.BuilderA builder for CheckDepositListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<CheckDeposit>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<CheckDeposit>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final CheckDepositListPageResponse.BuildertoBuilder()final CheckDepositListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDepositListPageResponse. -
-
Method Detail
-
data
final List<CheckDeposit> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<CheckDeposit>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDepositListPageResponse.Builder toBuilder()
-
validate
final CheckDepositListPageResponse validate()
-
builder
final static CheckDepositListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-