Class CheckDepositListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CheckDepositListParams implements Params
List Check Deposits
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositListParams.BuilderA builder for CheckDepositListParams.
public final classCheckDepositListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Check Deposits to those belonging to the specified Account. final Optional<CheckDepositListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<String>idempotencyKey()Filter records to the one with the specified idempotency_keyyou chose for that object.final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CheckDepositListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositListParamsnone()final static CheckDepositListParams.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDepositListParams. -
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Check Deposits to those belonging to the specified Account.
-
createdAt
final Optional<CheckDepositListParams.CreatedAt> createdAt()
-
idempotencyKey
final Optional<String> idempotencyKey()
Filter records to the one with the specified
idempotency_keyyou chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CheckDepositListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CheckDepositListParams none()
-
builder
final static CheckDepositListParams.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositListParams.
-
-
-
-