Class CheckTransfer
-
- All Implemented Interfaces:
public final class CheckTransferCheck Transfers move funds from your Increase account by mailing a physical check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.BuilderA builder for CheckTransfer.
public final classCheckTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classCheckTransfer.BalanceCheckHow the account's available balance should be checked.
public final classCheckTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classCheckTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classCheckTransfer.CurrencyThe ISO 4217 code for the check's currency.
public final classCheckTransfer.FulfillmentMethodWhether Increase will print and mail the check or if you will do it yourself.
public final classCheckTransfer.MailingIf the check has been mailed by Increase, this will contain details of the shipment.
public final classCheckTransfer.PhysicalCheckDetails relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.public final classCheckTransfer.StatusThe lifecycle status of the transfer.
public final classCheckTransfer.StopPaymentRequestAfter a stop-payment is requested on the check, this will contain supplemental details.
public final classCheckTransfer.SubmissionAfter the transfer is submitted, this will contain supplemental details.
public final classCheckTransfer.ThirdPartyDetails relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.public final classCheckTransfer.TypeA constant representing the object's type. For this resource it will always be
check_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Check transfer's identifier. final StringaccountId()The identifier of the Account from which funds will be transferred. final StringaccountNumber()The account number printed on the check. final Longamount()The transfer amount in USD cents. final Optional<CheckTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<String>approvedInboundCheckDepositId()If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final Optional<CheckTransfer.BalanceCheck>balanceCheck()How the account's available balance should be checked. final Optional<CheckTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final StringcheckNumber()The check number printed on the check. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<CheckTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final CheckTransfer.Currencycurrency()The ISO 4217 code for the check's currency. final CheckTransfer.FulfillmentMethodfulfillmentMethod()Whether Increase will print and mail the check or if you will do it yourself. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<CheckTransfer.Mailing>mailing()If the check has been mailed by Increase, this will contain details of the shipment. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<CheckTransfer.PhysicalCheck>physicalCheck()Details relating to the physical check that Increase will print and mail. final StringroutingNumber()The routing number printed on the check. final Optional<String>sourceAccountNumberId()The identifier of the Account Number from which to send the transfer and print on the check. final CheckTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<CheckTransfer.StopPaymentRequest>stopPaymentRequest()After a stop-payment is requested on the check, this will contain supplemental details. final Optional<CheckTransfer.Submission>submission()After the transfer is submitted, this will contain supplemental details. final Optional<CheckTransfer.ThirdParty>thirdParty()Details relating to the custom fulfillment you will perform. final CheckTransfer.Typetype()A constant representing the object's type. final Optional<LocalDate>validUntilDate()If set, the check will be valid on or before this date. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<CheckTransfer.Approval>_approval()Returns the raw JSON value of approval. final JsonField<String>_approvedInboundCheckDepositId()Returns the raw JSON value of approvedInboundCheckDepositId. final JsonField<CheckTransfer.BalanceCheck>_balanceCheck()Returns the raw JSON value of balanceCheck. final JsonField<CheckTransfer.Cancellation>_cancellation()Returns the raw JSON value of cancellation. final JsonField<String>_checkNumber()Returns the raw JSON value of checkNumber. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CheckTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<CheckTransfer.Currency>_currency()Returns the raw JSON value of currency. final JsonField<CheckTransfer.FulfillmentMethod>_fulfillmentMethod()Returns the raw JSON value of fulfillmentMethod. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<CheckTransfer.Mailing>_mailing()Returns the raw JSON value of mailing. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<CheckTransfer.PhysicalCheck>_physicalCheck()Returns the raw JSON value of physicalCheck. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<CheckTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<CheckTransfer.StopPaymentRequest>_stopPaymentRequest()Returns the raw JSON value of stopPaymentRequest. final JsonField<CheckTransfer.Submission>_submission()Returns the raw JSON value of submission. final JsonField<CheckTransfer.ThirdParty>_thirdParty()Returns the raw JSON value of thirdParty. final JsonField<CheckTransfer.Type>_type()Returns the raw JSON value of type. final JsonField<LocalDate>_validUntilDate()Returns the raw JSON value of validUntilDate. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.BuildertoBuilder()final CheckTransfervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of CheckTransfer. -
-
Method Detail
-
accountId
final String accountId()
The identifier of the Account from which funds will be transferred.
-
accountNumber
final String accountNumber()
The account number printed on the check.
-
approval
final Optional<CheckTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approvedInboundCheckDepositId
final Optional<String> approvedInboundCheckDepositId()
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. The Inbound Check Deposit object will have information about any associated Transactions for this Check Transfer.
-
balanceCheck
final Optional<CheckTransfer.BalanceCheck> balanceCheck()
How the account's available balance should be checked.
-
cancellation
final Optional<CheckTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
checkNumber
final String checkNumber()
The check number printed on the check.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<CheckTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final CheckTransfer.Currency currency()
The ISO 4217 code for the check's currency.
-
fulfillmentMethod
final CheckTransfer.FulfillmentMethod fulfillmentMethod()
Whether Increase will print and mail the check or if you will do it yourself.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
mailing
final Optional<CheckTransfer.Mailing> mailing()
If the check has been mailed by Increase, this will contain details of the shipment.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
physicalCheck
final Optional<CheckTransfer.PhysicalCheck> physicalCheck()
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
routingNumber
final String routingNumber()
The routing number printed on the check.
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer and print on the check.
-
status
final CheckTransfer.Status status()
The lifecycle status of the transfer.
-
stopPaymentRequest
final Optional<CheckTransfer.StopPaymentRequest> stopPaymentRequest()
After a stop-payment is requested on the check, this will contain supplemental details.
-
submission
final Optional<CheckTransfer.Submission> submission()
After the transfer is submitted, this will contain supplemental details.
-
thirdParty
final Optional<CheckTransfer.ThirdParty> thirdParty()
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
type
final CheckTransfer.Type type()
A constant representing the object's type. For this resource it will always be
check_transfer.
-
validUntilDate
final Optional<LocalDate> validUntilDate()
If set, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_approval
final JsonField<CheckTransfer.Approval> _approval()
Returns the raw JSON value of approval.
Unlike approval, this method doesn't throw if the JSON field has an unexpected type.
-
_approvedInboundCheckDepositId
final JsonField<String> _approvedInboundCheckDepositId()
Returns the raw JSON value of approvedInboundCheckDepositId.
Unlike approvedInboundCheckDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_balanceCheck
final JsonField<CheckTransfer.BalanceCheck> _balanceCheck()
Returns the raw JSON value of balanceCheck.
Unlike balanceCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_cancellation
final JsonField<CheckTransfer.Cancellation> _cancellation()
Returns the raw JSON value of cancellation.
Unlike cancellation, this method doesn't throw if the JSON field has an unexpected type.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<CheckTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CheckTransfer.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_fulfillmentMethod
final JsonField<CheckTransfer.FulfillmentMethod> _fulfillmentMethod()
Returns the raw JSON value of fulfillmentMethod.
Unlike fulfillmentMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_mailing
final JsonField<CheckTransfer.Mailing> _mailing()
Returns the raw JSON value of mailing.
Unlike mailing, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCheck
final JsonField<CheckTransfer.PhysicalCheck> _physicalCheck()
Returns the raw JSON value of physicalCheck.
Unlike physicalCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CheckTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_stopPaymentRequest
final JsonField<CheckTransfer.StopPaymentRequest> _stopPaymentRequest()
Returns the raw JSON value of stopPaymentRequest.
Unlike stopPaymentRequest, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<CheckTransfer.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdParty
final JsonField<CheckTransfer.ThirdParty> _thirdParty()
Returns the raw JSON value of thirdParty.
Unlike thirdParty, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CheckTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_validUntilDate
final JsonField<LocalDate> _validUntilDate()
Returns the raw JSON value of validUntilDate.
Unlike validUntilDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Builder toBuilder()
-
validate
final CheckTransfer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransfer.Builder builder()
Returns a mutable builder for constructing an instance of CheckTransfer.
The following fields are required:
.id() .accountId() .accountNumber() .amount() .approval() .approvedInboundCheckDepositId() .balanceCheck() .cancellation() .checkNumber() .createdAt() .createdBy() .currency() .fulfillmentMethod() .idempotencyKey() .mailing() .pendingTransactionId() .physicalCheck() .routingNumber() .sourceAccountNumberId() .status() .stopPaymentRequest() .submission() .thirdParty() .type() .validUntilDate()
-
-
-
-