Class CheckTransfer.Approval
-
- All Implemented Interfaces:
public final class CheckTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Approval.BuilderA builder for Approval.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeapprovedAt()The ISO 8601 date and time at which the transfer was approved. final Optional<String>approvedBy()If the Transfer was approved by a user in the dashboard, the email address of that user. final JsonField<OffsetDateTime>_approvedAt()Returns the raw JSON value of approvedAt. final JsonField<String>_approvedBy()Returns the raw JSON value of approvedBy. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Approval.BuildertoBuilder()final CheckTransfer.Approvalvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Approval.Builderbuilder()Returns a mutable builder for constructing an instance of Approval. -
-
Method Detail
-
approvedAt
final OffsetDateTime approvedAt()
The ISO 8601 date and time at which the transfer was approved.
-
approvedBy
final Optional<String> approvedBy()
If the Transfer was approved by a user in the dashboard, the email address of that user.
-
_approvedAt
final JsonField<OffsetDateTime> _approvedAt()
Returns the raw JSON value of approvedAt.
Unlike approvedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_approvedBy
final JsonField<String> _approvedBy()
Returns the raw JSON value of approvedBy.
Unlike approvedBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Approval.Builder toBuilder()
-
validate
final CheckTransfer.Approval validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransfer.Approval.Builder builder()
Returns a mutable builder for constructing an instance of Approval.
The following fields are required:
.approvedAt() .approvedBy()
-
-
-
-