Enum CheckTransfer.BalanceCheck.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.BalanceCheck.Known extends Enum<CheckTransfer.BalanceCheck.Known>
An enum containing BalanceCheck's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.BalanceCheck.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FULLThe available balance of the account must be at least the amount of the check, and a Pending Transaction will be created for the full amount. This is the default behavior if
balance_checkis omitted.NONENo balance check will performed when the check transfer is initiated. A zero-dollar Pending Transaction will be created. The balance will still be checked when the Inbound Check Deposit is created.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.BalanceCheck.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.BalanceCheck.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.BalanceCheck.Known>getEntries()An enum containing BalanceCheck's known values. -
-
Method Detail
-
valueOf
final CheckTransfer.BalanceCheck.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.BalanceCheck.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.BalanceCheck.Known> getEntries()
An enum containing BalanceCheck's known values.
-
-
-
-