Enum CheckTransfer.BalanceCheck.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum CheckTransfer.BalanceCheck.Value
    extends Enum<CheckTransfer.BalanceCheck.Value>
                        

    An enum containing BalanceCheck's known values, as well as an _UNKNOWN member.

    An instance of BalanceCheck can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      FULL

      The available balance of the account must be at least the amount of the check, and a Pending Transaction will be created for the full amount. This is the default behavior if balance_check is omitted.

      NONE

      No balance check will performed when the check transfer is initiated. A zero-dollar Pending Transaction will be created. The balance will still be checked when the Inbound Check Deposit is created.

      _UNKNOWN

      An enum member indicating that BalanceCheck was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final CheckTransfer.BalanceCheck.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<CheckTransfer.BalanceCheck.Value> getEntries()

        An enum containing BalanceCheck's known values, as well as an _UNKNOWN member.

        An instance of BalanceCheck can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.