Class CheckTransfer.Cancellation.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.Cancellation.BuilderA builder for Cancellation.
-
-
Method Summary
-
-
Method Detail
-
canceledAt
final CheckTransfer.Cancellation.Builder canceledAt(OffsetDateTime canceledAt)
The ISO 8601 date and time at which the Transfer was canceled.
-
canceledAt
final CheckTransfer.Cancellation.Builder canceledAt(JsonField<OffsetDateTime> canceledAt)
Sets Builder.canceledAt to an arbitrary JSON value.
You should usually call Builder.canceledAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
canceledBy
final CheckTransfer.Cancellation.Builder canceledBy(String canceledBy)
If the Transfer was canceled by a user in the dashboard, the email address of that user.
-
canceledBy
final CheckTransfer.Cancellation.Builder canceledBy(Optional<String> canceledBy)
Alias for calling Builder.canceledBy with
canceledBy.orElse(null).
-
canceledBy
final CheckTransfer.Cancellation.Builder canceledBy(JsonField<String> canceledBy)
Sets Builder.canceledBy to an arbitrary JSON value.
You should usually call Builder.canceledBy with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.Cancellation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.Cancellation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.Cancellation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.Cancellation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.Cancellation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.Cancellation build()
Returns an immutable instance of Cancellation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.canceledAt() .canceledBy()
-
-
-
-