Class CheckTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class CheckTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classCheckTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classCheckTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classCheckTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classCheckTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<CheckTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final Optional<CheckTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<CheckTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<CheckTransfer.CreatedBy.Category>_category()Returns the raw JSON value of category. final JsonField<CheckTransfer.CreatedBy.ApiKey>_apiKey()Returns the raw JSON value of apiKey. final JsonField<CheckTransfer.CreatedBy.OAuthApplication>_oauthApplication()Returns the raw JSON value of oauthApplication. final JsonField<CheckTransfer.CreatedBy.User>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.CreatedBy.BuildertoBuilder()final CheckTransfer.CreatedByvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.CreatedBy.Builderbuilder()Returns a mutable builder for constructing an instance of CreatedBy. -
-
Method Detail
-
category
final CheckTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
apiKey
final Optional<CheckTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
oauthApplication
final Optional<CheckTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<CheckTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_category
final JsonField<CheckTransfer.CreatedBy.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_apiKey
final JsonField<CheckTransfer.CreatedBy.ApiKey> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthApplication
final JsonField<CheckTransfer.CreatedBy.OAuthApplication> _oauthApplication()
Returns the raw JSON value of oauthApplication.
Unlike oauthApplication, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<CheckTransfer.CreatedBy.User> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.CreatedBy.Builder toBuilder()
-
validate
final CheckTransfer.CreatedBy validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransfer.CreatedBy.Builder builder()
Returns a mutable builder for constructing an instance of CreatedBy.
The following fields are required:
.category()
-
-
-
-