Class CheckTransfer.CreatedBy.OAuthApplication
-
- All Implemented Interfaces:
public final class CheckTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.CreatedBy.OAuthApplication.BuilderA builder for OAuthApplication.
-
Method Summary
Modifier and Type Method Description final Stringname()The name of the OAuth Application. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.CreatedBy.OAuthApplication.BuildertoBuilder()final CheckTransfer.CreatedBy.OAuthApplicationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.CreatedBy.OAuthApplication.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplication. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.CreatedBy.OAuthApplication.Builder toBuilder()
-
validate
final CheckTransfer.CreatedBy.OAuthApplication validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransfer.CreatedBy.OAuthApplication.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplication.
The following fields are required:
.name()
-
-
-
-