Enum CheckTransfer.FulfillmentMethod.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.FulfillmentMethod.Known extends Enum<CheckTransfer.FulfillmentMethod.Known>
An enum containing FulfillmentMethod's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.FulfillmentMethod.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PHYSICAL_CHECKIncrease will print and mail a physical check.
THIRD_PARTYIncrease will not print a check; you are responsible for printing and mailing a check with the provided account number, routing number, check number, and amount.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.FulfillmentMethod.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.FulfillmentMethod.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.FulfillmentMethod.Known>getEntries()An enum containing FulfillmentMethod's known values. -
-
Method Detail
-
valueOf
final CheckTransfer.FulfillmentMethod.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.FulfillmentMethod.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.FulfillmentMethod.Known> getEntries()
An enum containing FulfillmentMethod's known values.
-
-
-
-