Class CheckTransfer.Mailing
-
- All Implemented Interfaces:
public final class CheckTransfer.MailingIf the check has been mailed by Increase, this will contain details of the shipment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Mailing.BuilderA builder for Mailing.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimemailedAt()The ISO 8601 date and time at which the check was mailed. final JsonField<OffsetDateTime>_mailedAt()Returns the raw JSON value of mailedAt. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Mailing.BuildertoBuilder()final CheckTransfer.Mailingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Mailing.Builderbuilder()Returns a mutable builder for constructing an instance of Mailing. -
-
Method Detail
-
mailedAt
final OffsetDateTime mailedAt()
The ISO 8601 date and time at which the check was mailed.
-
_mailedAt
final JsonField<OffsetDateTime> _mailedAt()
Returns the raw JSON value of mailedAt.
Unlike mailedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Mailing.Builder toBuilder()
-
validate
final CheckTransfer.Mailing validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransfer.Mailing.Builder builder()
Returns a mutable builder for constructing an instance of Mailing.
The following fields are required:
.mailedAt()
-
-
-
-