Class CheckTransfer.Mailing.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.Mailing.BuilderA builder for Mailing.
-
-
Method Summary
-
-
Method Detail
-
imageId
final CheckTransfer.Mailing.Builder imageId(String imageId)
The ID of the file corresponding to an image of the check that was mailed, if available.
-
imageId
final CheckTransfer.Mailing.Builder imageId(Optional<String> imageId)
Alias for calling Builder.imageId with
imageId.orElse(null).
-
imageId
final CheckTransfer.Mailing.Builder imageId(JsonField<String> imageId)
Sets Builder.imageId to an arbitrary JSON value.
You should usually call Builder.imageId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mailedAt
final CheckTransfer.Mailing.Builder mailedAt(OffsetDateTime mailedAt)
The ISO 8601 date and time at which the check was mailed.
-
mailedAt
final CheckTransfer.Mailing.Builder mailedAt(JsonField<OffsetDateTime> mailedAt)
Sets Builder.mailedAt to an arbitrary JSON value.
You should usually call Builder.mailedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trackingNumber
final CheckTransfer.Mailing.Builder trackingNumber(String trackingNumber)
The tracking number of the shipment, if available for the shipping method.
-
trackingNumber
final CheckTransfer.Mailing.Builder trackingNumber(Optional<String> trackingNumber)
Alias for calling Builder.trackingNumber with
trackingNumber.orElse(null).
-
trackingNumber
final CheckTransfer.Mailing.Builder trackingNumber(JsonField<String> trackingNumber)
Sets Builder.trackingNumber to an arbitrary JSON value.
You should usually call Builder.trackingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.Mailing.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.Mailing.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.Mailing.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.Mailing.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.Mailing.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.Mailing build()
Returns an immutable instance of Mailing.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.imageId() .mailedAt() .trackingNumber()
-
-
-
-