Class CheckTransfer.PhysicalCheck.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.BuilderA builder for PhysicalCheck.
-
-
Method Summary
-
-
Method Detail
-
attachmentFileId
final CheckTransfer.PhysicalCheck.Builder attachmentFileId(String attachmentFileId)
The ID of the file for the check attachment.
-
attachmentFileId
final CheckTransfer.PhysicalCheck.Builder attachmentFileId(Optional<String> attachmentFileId)
Alias for calling Builder.attachmentFileId with
attachmentFileId.orElse(null).
-
attachmentFileId
final CheckTransfer.PhysicalCheck.Builder attachmentFileId(JsonField<String> attachmentFileId)
Sets Builder.attachmentFileId to an arbitrary JSON value.
You should usually call Builder.attachmentFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkVoucherImageFileId
final CheckTransfer.PhysicalCheck.Builder checkVoucherImageFileId(String checkVoucherImageFileId)
The ID of the file for the check voucher image.
-
checkVoucherImageFileId
final CheckTransfer.PhysicalCheck.Builder checkVoucherImageFileId(Optional<String> checkVoucherImageFileId)
Alias for calling Builder.checkVoucherImageFileId with
checkVoucherImageFileId.orElse(null).
-
checkVoucherImageFileId
final CheckTransfer.PhysicalCheck.Builder checkVoucherImageFileId(JsonField<String> checkVoucherImageFileId)
Sets Builder.checkVoucherImageFileId to an arbitrary JSON value.
You should usually call Builder.checkVoucherImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mailingAddress
final CheckTransfer.PhysicalCheck.Builder mailingAddress(CheckTransfer.PhysicalCheck.MailingAddress mailingAddress)
Details for where Increase will mail the check.
-
mailingAddress
final CheckTransfer.PhysicalCheck.Builder mailingAddress(JsonField<CheckTransfer.PhysicalCheck.MailingAddress> mailingAddress)
Sets Builder.mailingAddress to an arbitrary JSON value.
You should usually call Builder.mailingAddress with a well-typed MailingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memo
final CheckTransfer.PhysicalCheck.Builder memo(String memo)
The descriptor that will be printed on the memo field on the check.
-
memo
final CheckTransfer.PhysicalCheck.Builder memo(Optional<String> memo)
Alias for calling Builder.memo with
memo.orElse(null).
-
memo
final CheckTransfer.PhysicalCheck.Builder memo(JsonField<String> memo)
Sets Builder.memo to an arbitrary JSON value.
You should usually call Builder.memo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
note
final CheckTransfer.PhysicalCheck.Builder note(String note)
The descriptor that will be printed on the letter included with the check.
-
note
final CheckTransfer.PhysicalCheck.Builder note(Optional<String> note)
Alias for calling Builder.note with
note.orElse(null).
-
note
final CheckTransfer.PhysicalCheck.Builder note(JsonField<String> note)
Sets Builder.note to an arbitrary JSON value.
You should usually call Builder.note with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payer
final CheckTransfer.PhysicalCheck.Builder payer(List<CheckTransfer.PhysicalCheck.Payer> payer)
The payer of the check. This will be printed on the top-left portion of the check and defaults to the return address if unspecified.
-
payer
final CheckTransfer.PhysicalCheck.Builder payer(JsonField<List<CheckTransfer.PhysicalCheck.Payer>> payer)
Sets Builder.payer to an arbitrary JSON value.
You should usually call Builder.payer with a well-typed
List<Payer>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayer
final CheckTransfer.PhysicalCheck.Builder addPayer(CheckTransfer.PhysicalCheck.Payer payer)
Adds a single Payer to Builder.payer.
-
recipientName
final CheckTransfer.PhysicalCheck.Builder recipientName(String recipientName)
The name that will be printed on the check.
-
recipientName
final CheckTransfer.PhysicalCheck.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
returnAddress
final CheckTransfer.PhysicalCheck.Builder returnAddress(CheckTransfer.PhysicalCheck.ReturnAddress returnAddress)
The return address to be printed on the check.
-
returnAddress
final CheckTransfer.PhysicalCheck.Builder returnAddress(Optional<CheckTransfer.PhysicalCheck.ReturnAddress> returnAddress)
Alias for calling Builder.returnAddress with
returnAddress.orElse(null).
-
returnAddress
final CheckTransfer.PhysicalCheck.Builder returnAddress(JsonField<CheckTransfer.PhysicalCheck.ReturnAddress> returnAddress)
Sets Builder.returnAddress to an arbitrary JSON value.
You should usually call Builder.returnAddress with a well-typed ReturnAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingMethod
final CheckTransfer.PhysicalCheck.Builder shippingMethod(CheckTransfer.PhysicalCheck.ShippingMethod shippingMethod)
The shipping method for the check.
-
shippingMethod
final CheckTransfer.PhysicalCheck.Builder shippingMethod(JsonField<CheckTransfer.PhysicalCheck.ShippingMethod> shippingMethod)
Sets Builder.shippingMethod to an arbitrary JSON value.
You should usually call Builder.shippingMethod with a well-typed ShippingMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
signature
final CheckTransfer.PhysicalCheck.Builder signature(CheckTransfer.PhysicalCheck.Signature signature)
The signature that will appear on the check.
-
signature
final CheckTransfer.PhysicalCheck.Builder signature(JsonField<CheckTransfer.PhysicalCheck.Signature> signature)
Sets Builder.signature to an arbitrary JSON value.
You should usually call Builder.signature with a well-typed Signature value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trackingUpdates
final CheckTransfer.PhysicalCheck.Builder trackingUpdates(List<CheckTransfer.PhysicalCheck.TrackingUpdate> trackingUpdates)
Tracking updates relating to the physical check's delivery.
-
trackingUpdates
final CheckTransfer.PhysicalCheck.Builder trackingUpdates(JsonField<List<CheckTransfer.PhysicalCheck.TrackingUpdate>> trackingUpdates)
Sets Builder.trackingUpdates to an arbitrary JSON value.
You should usually call Builder.trackingUpdates with a well-typed
List<TrackingUpdate>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTrackingUpdate
final CheckTransfer.PhysicalCheck.Builder addTrackingUpdate(CheckTransfer.PhysicalCheck.TrackingUpdate trackingUpdate)
Adds a single TrackingUpdate to trackingUpdates.
-
additionalProperties
final CheckTransfer.PhysicalCheck.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck build()
Returns an immutable instance of PhysicalCheck.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.attachmentFileId() .checkVoucherImageFileId() .mailingAddress() .memo() .note() .payer() .recipientName() .returnAddress() .shippingMethod() .signature() .trackingUpdates()
-
-
-
-