Class CheckTransfer.PhysicalCheck.MailingAddress.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final CheckTransfer.PhysicalCheck.MailingAddress.Builder city(String city)
The city of the check's destination.
-
city
final CheckTransfer.PhysicalCheck.MailingAddress.Builder city(Optional<String> city)
Alias for calling Builder.city with
city.orElse(null).
-
city
final CheckTransfer.PhysicalCheck.MailingAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line1(String line1)
The street address of the check's destination.
-
line1
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line1(Optional<String> line1)
Alias for calling Builder.line1 with
line1.orElse(null).
-
line1
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line2(String line2)
The second line of the address of the check's destination.
-
line2
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line2(Optional<String> line2)
Alias for calling Builder.line2 with
line2.orElse(null).
-
line2
final CheckTransfer.PhysicalCheck.MailingAddress.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final CheckTransfer.PhysicalCheck.MailingAddress.Builder name(String name)
The name component of the check's mailing address.
-
name
final CheckTransfer.PhysicalCheck.MailingAddress.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final CheckTransfer.PhysicalCheck.MailingAddress.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phone
final CheckTransfer.PhysicalCheck.MailingAddress.Builder phone(String phone)
The phone number to be used in case of delivery issues at the check's mailing address. Only used for FedEx overnight shipping.
-
phone
final CheckTransfer.PhysicalCheck.MailingAddress.Builder phone(Optional<String> phone)
Alias for calling Builder.phone with
phone.orElse(null).
-
phone
final CheckTransfer.PhysicalCheck.MailingAddress.Builder phone(JsonField<String> phone)
Sets Builder.phone to an arbitrary JSON value.
You should usually call Builder.phone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final CheckTransfer.PhysicalCheck.MailingAddress.Builder postalCode(String postalCode)
The postal code of the check's destination.
-
postalCode
final CheckTransfer.PhysicalCheck.MailingAddress.Builder postalCode(Optional<String> postalCode)
Alias for calling Builder.postalCode with
postalCode.orElse(null).
-
postalCode
final CheckTransfer.PhysicalCheck.MailingAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final CheckTransfer.PhysicalCheck.MailingAddress.Builder state(String state)
The state of the check's destination.
-
state
final CheckTransfer.PhysicalCheck.MailingAddress.Builder state(Optional<String> state)
Alias for calling Builder.state with
state.orElse(null).
-
state
final CheckTransfer.PhysicalCheck.MailingAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.PhysicalCheck.MailingAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.MailingAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.MailingAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.MailingAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.MailingAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck.MailingAddress build()
Returns an immutable instance of MailingAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .line1() .line2() .name() .phone() .postalCode() .state()
-
-
-
-