Class CheckTransfer.PhysicalCheck.Signature.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.Signature.BuilderA builder for Signature.
-
-
Method Summary
-
-
Method Detail
-
imageFileId
final CheckTransfer.PhysicalCheck.Signature.Builder imageFileId(String imageFileId)
The ID of a File containing a PNG of the signature.
-
imageFileId
final CheckTransfer.PhysicalCheck.Signature.Builder imageFileId(Optional<String> imageFileId)
Alias for calling Builder.imageFileId with
imageFileId.orElse(null).
-
imageFileId
final CheckTransfer.PhysicalCheck.Signature.Builder imageFileId(JsonField<String> imageFileId)
Sets Builder.imageFileId to an arbitrary JSON value.
You should usually call Builder.imageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final CheckTransfer.PhysicalCheck.Signature.Builder text(String text)
The text that will appear as the signature on the check in cursive font.
-
text
final CheckTransfer.PhysicalCheck.Signature.Builder text(Optional<String> text)
Alias for calling Builder.text with
text.orElse(null).
-
text
final CheckTransfer.PhysicalCheck.Signature.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.PhysicalCheck.Signature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.Signature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.Signature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.Signature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.Signature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck.Signature build()
Returns an immutable instance of Signature.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.imageFileId() .text()
-
-
-
-