Class CheckTransfer.PhysicalCheck.TrackingUpdate.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.TrackingUpdate.BuilderA builder for TrackingUpdate.
-
-
Method Summary
-
-
Method Detail
-
category
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder category(CheckTransfer.PhysicalCheck.TrackingUpdate.Category category)
The type of tracking event.
-
category
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder category(JsonField<CheckTransfer.PhysicalCheck.TrackingUpdate.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder country(String country)
The ISO 3166-1 alpha-2 country code for the country where the event took place.
-
country
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the tracking event took place.
-
createdAt
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder postalCode(String postalCode)
The postal code where the event took place.
-
postalCode
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.PhysicalCheck.TrackingUpdate build()
Returns an immutable instance of TrackingUpdate.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category() .country() .createdAt() .postalCode()
-
-
-
-