Enum CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known extends Enum<CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description IN_TRANSITThe check is in transit.
PROCESSED_FOR_DELIVERYThe check has been processed for delivery.
DELIVEREDThe check has been delivered. Note that some couriers track delivery status based on driver location data rather than an explicit scan. While uncommon, a single check may have more than one delivered event.
DELIVERY_ISSUEThere is an issue preventing delivery. The delivery will be attempted again if possible. If the issue cannot be resolved, the check will be returned to sender.
RETURNED_TO_SENDERDelivery failed and the check was returned to sender.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.PhysicalCheck.TrackingUpdate.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.PhysicalCheck.TrackingUpdate.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-