Enum CheckTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.Status.Known extends Enum<CheckTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_APPROVALThe transfer is awaiting approval.
CANCELEDThe transfer has been canceled.
PENDING_SUBMISSIONThe transfer is pending submission.
REQUIRES_ATTENTIONThe transfer requires attention from an Increase operator.
REJECTEDThe transfer has been rejected.
PENDING_MAILINGThe check is queued for mailing.
MAILEDThe check has been mailed.
DEPOSITEDThe check has been deposited.
STOPPEDA stop-payment was requested for this check.
RETURNEDThe transfer has been returned.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final CheckTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-