Class CheckTransfer.StopPaymentRequest
-
- All Implemented Interfaces:
public final class CheckTransfer.StopPaymentRequestAfter a stop-payment is requested on the check, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.StopPaymentRequest.BuilderA builder for StopPaymentRequest.
public final classCheckTransfer.StopPaymentRequest.ReasonThe reason why this transfer was stopped.
public final classCheckTransfer.StopPaymentRequest.TypeA constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.StopPaymentRequest.Reasonreason()The reason why this transfer was stopped. final OffsetDateTimerequestedAt()The time the stop-payment was requested. final StringtransferId()The ID of the check transfer that was stopped. final CheckTransfer.StopPaymentRequest.Typetype()A constant representing the object's type. final JsonField<CheckTransfer.StopPaymentRequest.Reason>_reason()Returns the raw JSON value of reason. final JsonField<OffsetDateTime>_requestedAt()Returns the raw JSON value of requestedAt. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final JsonField<CheckTransfer.StopPaymentRequest.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.StopPaymentRequest.BuildertoBuilder()final CheckTransfer.StopPaymentRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.StopPaymentRequest.Builderbuilder()Returns a mutable builder for constructing an instance of StopPaymentRequest. -
-
Method Detail
-
reason
final CheckTransfer.StopPaymentRequest.Reason reason()
The reason why this transfer was stopped.
-
requestedAt
final OffsetDateTime requestedAt()
The time the stop-payment was requested.
-
transferId
final String transferId()
The ID of the check transfer that was stopped.
-
type
final CheckTransfer.StopPaymentRequest.Type type()
A constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
-
_reason
final JsonField<CheckTransfer.StopPaymentRequest.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_requestedAt
final JsonField<OffsetDateTime> _requestedAt()
Returns the raw JSON value of requestedAt.
Unlike requestedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CheckTransfer.StopPaymentRequest.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.StopPaymentRequest.Builder toBuilder()
-
validate
final CheckTransfer.StopPaymentRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransfer.StopPaymentRequest.Builder builder()
Returns a mutable builder for constructing an instance of StopPaymentRequest.
The following fields are required:
.reason() .requestedAt() .transferId() .type()
-
-
-
-