Class CheckTransfer.StopPaymentRequest.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.StopPaymentRequest.BuilderA builder for StopPaymentRequest.
-
-
Method Summary
-
-
Method Detail
-
reason
final CheckTransfer.StopPaymentRequest.Builder reason(CheckTransfer.StopPaymentRequest.Reason reason)
The reason why this transfer was stopped.
-
reason
final CheckTransfer.StopPaymentRequest.Builder reason(JsonField<CheckTransfer.StopPaymentRequest.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestedAt
final CheckTransfer.StopPaymentRequest.Builder requestedAt(OffsetDateTime requestedAt)
The time the stop-payment was requested.
-
requestedAt
final CheckTransfer.StopPaymentRequest.Builder requestedAt(JsonField<OffsetDateTime> requestedAt)
Sets Builder.requestedAt to an arbitrary JSON value.
You should usually call Builder.requestedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final CheckTransfer.StopPaymentRequest.Builder transferId(String transferId)
The ID of the check transfer that was stopped.
-
transferId
final CheckTransfer.StopPaymentRequest.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CheckTransfer.StopPaymentRequest.Builder type(CheckTransfer.StopPaymentRequest.Type type)
A constant representing the object's type. For this resource it will always be
check_transfer_stop_payment_request.
-
type
final CheckTransfer.StopPaymentRequest.Builder type(JsonField<CheckTransfer.StopPaymentRequest.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.StopPaymentRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.StopPaymentRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.StopPaymentRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.StopPaymentRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.StopPaymentRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.StopPaymentRequest build()
Returns an immutable instance of StopPaymentRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.reason() .requestedAt() .transferId() .type()
-
-
-
-