Enum CheckTransfer.StopPaymentRequest.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.StopPaymentRequest.Reason.Known extends Enum<CheckTransfer.StopPaymentRequest.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.StopPaymentRequest.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description MAIL_DELIVERY_FAILEDThe check could not be delivered.
REJECTED_BY_INCREASEThe check was canceled by an Increase operator who will provide details out-of-band.
NOT_AUTHORIZEDThe check was not authorized.
VALID_UNTIL_DATE_PASSEDThe check was stopped for
valid_until_datebeing in the past.UNKNOWNThe check was stopped for another reason.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.StopPaymentRequest.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.StopPaymentRequest.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.StopPaymentRequest.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final CheckTransfer.StopPaymentRequest.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.StopPaymentRequest.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.StopPaymentRequest.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-