Class CheckTransfer.Submission
-
- All Implemented Interfaces:
public final class CheckTransfer.SubmissionAfter the transfer is submitted, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Submission.BuilderA builder for Submission.
public final classCheckTransfer.Submission.SubmittedAddressThe address we submitted to the printer. This is what is physically printed on the check.
-
Method Summary
Modifier and Type Method Description final Optional<String>previewFileId()The ID of the file corresponding to an image of the check that was mailed, if available. final CheckTransfer.Submission.SubmittedAddresssubmittedAddress()The address we submitted to the printer. final OffsetDateTimesubmittedAt()When this check was submitted to our check printer. final Optional<String>trackingNumber()The tracking number for the check shipment. final JsonField<String>_previewFileId()Returns the raw JSON value of previewFileId. final JsonField<CheckTransfer.Submission.SubmittedAddress>_submittedAddress()Returns the raw JSON value of submittedAddress. final JsonField<OffsetDateTime>_submittedAt()Returns the raw JSON value of submittedAt. final JsonField<String>_trackingNumber()Returns the raw JSON value of trackingNumber. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Submission.BuildertoBuilder()final CheckTransfer.Submissionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Submission.Builderbuilder()Returns a mutable builder for constructing an instance of Submission. -
-
Method Detail
-
previewFileId
final Optional<String> previewFileId()
The ID of the file corresponding to an image of the check that was mailed, if available.
-
submittedAddress
final CheckTransfer.Submission.SubmittedAddress submittedAddress()
The address we submitted to the printer. This is what is physically printed on the check.
-
submittedAt
final OffsetDateTime submittedAt()
When this check was submitted to our check printer.
-
trackingNumber
final Optional<String> trackingNumber()
The tracking number for the check shipment.
-
_previewFileId
final JsonField<String> _previewFileId()
Returns the raw JSON value of previewFileId.
Unlike previewFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_submittedAddress
final JsonField<CheckTransfer.Submission.SubmittedAddress> _submittedAddress()
Returns the raw JSON value of submittedAddress.
Unlike submittedAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
Returns the raw JSON value of submittedAt.
Unlike submittedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_trackingNumber
final JsonField<String> _trackingNumber()
Returns the raw JSON value of trackingNumber.
Unlike trackingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Submission.Builder toBuilder()
-
validate
final CheckTransfer.Submission validate()
-
builder
final static CheckTransfer.Submission.Builder builder()
Returns a mutable builder for constructing an instance of Submission.
The following fields are required:
.previewFileId() .submittedAddress() .submittedAt() .trackingNumber()
-
-
-
-