Enum CheckTransfer.Submission.AddressCorrectionAction.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.Submission.AddressCorrectionAction.Known extends Enum<CheckTransfer.Submission.AddressCorrectionAction.Known>
An enum containing AddressCorrectionAction's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.Submission.AddressCorrectionAction.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NONENo address correction took place.
STANDARDIZATIONThe address was standardized.
STANDARDIZATION_WITH_ADDRESS_CHANGEThe address was first standardized and then changed because the recipient moved.
ERRORAn error occurred while correcting the address. This typically means the USPS could not find that address. The address was not changed.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.Submission.AddressCorrectionAction.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.Submission.AddressCorrectionAction.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.Submission.AddressCorrectionAction.Known>getEntries()An enum containing AddressCorrectionAction's known values. -
-
Method Detail
-
valueOf
final CheckTransfer.Submission.AddressCorrectionAction.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.Submission.AddressCorrectionAction.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.Submission.AddressCorrectionAction.Known> getEntries()
An enum containing AddressCorrectionAction's known values.
-
-
-
-