Enum CheckTransfer.Submission.AddressCorrectionAction.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransfer.Submission.AddressCorrectionAction.Value extends Enum<CheckTransfer.Submission.AddressCorrectionAction.Value>
An enum containing AddressCorrectionAction's known values, as well as an _UNKNOWN member.
An instance of AddressCorrectionAction can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransfer.Submission.AddressCorrectionAction.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NONENo address correction took place.
STANDARDIZATIONThe address was standardized.
STANDARDIZATION_WITH_ADDRESS_CHANGEThe address was first standardized and then changed because the recipient moved.
ERRORAn error occurred while correcting the address. This typically means the USPS could not find that address. The address was not changed.
_UNKNOWNAn enum member indicating that AddressCorrectionAction was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CheckTransfer.Submission.AddressCorrectionAction.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransfer.Submission.AddressCorrectionAction.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransfer.Submission.AddressCorrectionAction.Value>getEntries()An enum containing AddressCorrectionAction's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CheckTransfer.Submission.AddressCorrectionAction.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransfer.Submission.AddressCorrectionAction.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransfer.Submission.AddressCorrectionAction.Value> getEntries()
An enum containing AddressCorrectionAction's known values, as well as an _UNKNOWN member.
An instance of AddressCorrectionAction can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-