Class CheckTransfer.ThirdParty.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.ThirdParty.BuilderA builder for ThirdParty.
-
-
Method Summary
Modifier and Type Method Description final CheckTransfer.ThirdParty.BuildercheckNumber(String checkNumber)The check number that will be printed on the check. final CheckTransfer.ThirdParty.BuildercheckNumber(Optional<String> checkNumber)Alias for calling Builder.checkNumber with checkNumber.orElse(null).final CheckTransfer.ThirdParty.BuildercheckNumber(JsonField<String> checkNumber)Sets Builder.checkNumber to an arbitrary JSON value. final CheckTransfer.ThirdParty.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.ThirdParty.BuilderputAdditionalProperty(String key, JsonValue value)final CheckTransfer.ThirdParty.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.ThirdParty.BuilderremoveAdditionalProperty(String key)final CheckTransfer.ThirdParty.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckTransfer.ThirdPartybuild()Returns an immutable instance of ThirdParty. -
-
Method Detail
-
checkNumber
final CheckTransfer.ThirdParty.Builder checkNumber(String checkNumber)
The check number that will be printed on the check.
-
checkNumber
final CheckTransfer.ThirdParty.Builder checkNumber(Optional<String> checkNumber)
Alias for calling Builder.checkNumber with
checkNumber.orElse(null).
-
checkNumber
final CheckTransfer.ThirdParty.Builder checkNumber(JsonField<String> checkNumber)
Sets Builder.checkNumber to an arbitrary JSON value.
You should usually call Builder.checkNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.ThirdParty.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.ThirdParty.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.ThirdParty.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.ThirdParty.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.ThirdParty.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer.ThirdParty build()
Returns an immutable instance of ThirdParty.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.checkNumber()
-
-
-
-