Class CheckTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CheckTransferCreateParams implements Params
Create a Check Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.BuilderA builder for CheckTransferCreateParams.
public final classCheckTransferCreateParams.Bodypublic final classCheckTransferCreateParams.FulfillmentMethodWhether Increase will print and mail the check or if you will do it yourself.
public final classCheckTransferCreateParams.BalanceCheckHow the account's available balance should be checked. If omitted, the default behavior is
balance_check: full.public final classCheckTransferCreateParams.PhysicalCheckDetails relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.public final classCheckTransferCreateParams.ThirdPartyDetails relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final CheckTransferCreateParams.FulfillmentMethodfulfillmentMethod()Whether Increase will print and mail the check or if you will do it yourself. final StringsourceAccountNumberId()The identifier of the Account Number from which to send the transfer and print on the check. final Optional<CheckTransferCreateParams.BalanceCheck>balanceCheck()How the account's available balance should be checked. final Optional<String>checkNumber()The check number Increase should use for the check. final Optional<CheckTransferCreateParams.PhysicalCheck>physicalCheck()Details relating to the physical check that Increase will print and mail. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<CheckTransferCreateParams.ThirdParty>thirdParty()Details relating to the custom fulfillment you will perform. final Optional<LocalDate>validUntilDate()If provided, the check will be valid on or before this date. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<CheckTransferCreateParams.FulfillmentMethod>_fulfillmentMethod()Returns the raw JSON value of fulfillmentMethod. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<CheckTransferCreateParams.BalanceCheck>_balanceCheck()Returns the raw JSON value of balanceCheck. final JsonField<String>_checkNumber()Returns the raw JSON value of checkNumber. final JsonField<CheckTransferCreateParams.PhysicalCheck>_physicalCheck()Returns the raw JSON value of physicalCheck. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<CheckTransferCreateParams.ThirdParty>_thirdParty()Returns the raw JSON value of thirdParty. final JsonField<LocalDate>_validUntilDate()Returns the raw JSON value of validUntilDate. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CheckTransferCreateParams.BuildertoBuilder()final CheckTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CheckTransferCreateParams. -
-
Method Detail
-
fulfillmentMethod
final CheckTransferCreateParams.FulfillmentMethod fulfillmentMethod()
Whether Increase will print and mail the check or if you will do it yourself.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer and print on the check.
-
balanceCheck
final Optional<CheckTransferCreateParams.BalanceCheck> balanceCheck()
How the account's available balance should be checked. If omitted, the default behavior is
balance_check: full.
-
checkNumber
final Optional<String> checkNumber()
The check number Increase should use for the check. This should not contain leading zeroes and must be unique across the
source_account_number. If this is omitted, Increase will generate a check number for you.
-
physicalCheck
final Optional<CheckTransferCreateParams.PhysicalCheck> physicalCheck()
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
thirdParty
final Optional<CheckTransferCreateParams.ThirdParty> thirdParty()
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
validUntilDate
final Optional<LocalDate> validUntilDate()
If provided, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_fulfillmentMethod
final JsonField<CheckTransferCreateParams.FulfillmentMethod> _fulfillmentMethod()
Returns the raw JSON value of fulfillmentMethod.
Unlike fulfillmentMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_balanceCheck
final JsonField<CheckTransferCreateParams.BalanceCheck> _balanceCheck()
Returns the raw JSON value of balanceCheck.
Unlike balanceCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCheck
final JsonField<CheckTransferCreateParams.PhysicalCheck> _physicalCheck()
Returns the raw JSON value of physicalCheck.
Unlike physicalCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdParty
final JsonField<CheckTransferCreateParams.ThirdParty> _thirdParty()
Returns the raw JSON value of thirdParty.
Unlike thirdParty, this method doesn't throw if the JSON field has an unexpected type.
-
_validUntilDate
final JsonField<LocalDate> _validUntilDate()
Returns the raw JSON value of validUntilDate.
Unlike validUntilDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CheckTransferCreateParams.Builder toBuilder()
-
_body
final CheckTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CheckTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CheckTransferCreateParams.
The following fields are required:
.accountId() .amount() .fulfillmentMethod() .sourceAccountNumberId()
-
-
-
-