Enum CheckTransferCreateParams.BalanceCheck.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CheckTransferCreateParams.BalanceCheck.Value extends Enum<CheckTransferCreateParams.BalanceCheck.Value>
An enum containing BalanceCheck's known values, as well as an _UNKNOWN member.
An instance of BalanceCheck can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CheckTransferCreateParams.BalanceCheck.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FULLThe available balance of the account must be at least the amount of the check, and a Pending Transaction will be created for the full amount. This is the default behavior if
balance_checkis omitted.NONENo balance check will performed when the check transfer is initiated. A zero-dollar Pending Transaction will be created. The balance will still be checked when the Inbound Check Deposit is created.
_UNKNOWNAn enum member indicating that BalanceCheck was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CheckTransferCreateParams.BalanceCheck.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CheckTransferCreateParams.BalanceCheck.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CheckTransferCreateParams.BalanceCheck.Value>getEntries()An enum containing BalanceCheck's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CheckTransferCreateParams.BalanceCheck.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CheckTransferCreateParams.BalanceCheck.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CheckTransferCreateParams.BalanceCheck.Value> getEntries()
An enum containing BalanceCheck's known values, as well as an _UNKNOWN member.
An instance of BalanceCheck can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-