Class CheckTransferCreateParams.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.BuilderA builder for CheckTransferCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final CheckTransferCreateParams.Builder body(CheckTransferCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
accountId
final CheckTransferCreateParams.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final CheckTransferCreateParams.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final CheckTransferCreateParams.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final CheckTransferCreateParams.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fulfillmentMethod
final CheckTransferCreateParams.Builder fulfillmentMethod(CheckTransferCreateParams.FulfillmentMethod fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
fulfillmentMethod
final CheckTransferCreateParams.Builder fulfillmentMethod(JsonField<CheckTransferCreateParams.FulfillmentMethod> fulfillmentMethod)
Sets Builder.fulfillmentMethod to an arbitrary JSON value.
You should usually call Builder.fulfillmentMethod with a well-typed FulfillmentMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final CheckTransferCreateParams.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
sourceAccountNumberId
final CheckTransferCreateParams.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balanceCheck
final CheckTransferCreateParams.Builder balanceCheck(CheckTransferCreateParams.BalanceCheck balanceCheck)
How the account's available balance should be checked. If omitted, the default behavior is
balance_check: full.
-
balanceCheck
final CheckTransferCreateParams.Builder balanceCheck(JsonField<CheckTransferCreateParams.BalanceCheck> balanceCheck)
Sets Builder.balanceCheck to an arbitrary JSON value.
You should usually call Builder.balanceCheck with a well-typed BalanceCheck value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkNumber
final CheckTransferCreateParams.Builder checkNumber(String checkNumber)
The check number Increase should use for the check. This should not contain leading zeroes and must be unique across the
source_account_number. If this is omitted, Increase will generate a check number for you.
-
checkNumber
final CheckTransferCreateParams.Builder checkNumber(JsonField<String> checkNumber)
Sets Builder.checkNumber to an arbitrary JSON value.
You should usually call Builder.checkNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCheck
final CheckTransferCreateParams.Builder physicalCheck(CheckTransferCreateParams.PhysicalCheck physicalCheck)
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
physicalCheck
final CheckTransferCreateParams.Builder physicalCheck(JsonField<CheckTransferCreateParams.PhysicalCheck> physicalCheck)
Sets Builder.physicalCheck to an arbitrary JSON value.
You should usually call Builder.physicalCheck with a well-typed PhysicalCheck value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final CheckTransferCreateParams.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final CheckTransferCreateParams.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
thirdParty
final CheckTransferCreateParams.Builder thirdParty(CheckTransferCreateParams.ThirdParty thirdParty)
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
thirdParty
final CheckTransferCreateParams.Builder thirdParty(JsonField<CheckTransferCreateParams.ThirdParty> thirdParty)
Sets Builder.thirdParty to an arbitrary JSON value.
You should usually call Builder.thirdParty with a well-typed ThirdParty value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
validUntilDate
final CheckTransferCreateParams.Builder validUntilDate(LocalDate validUntilDate)
If provided, the check will be valid on or before this date. After this date, the check transfer will be automatically stopped and deposits will not be accepted. For checks printed by Increase, this date is included on the check as its expiry.
-
validUntilDate
final CheckTransferCreateParams.Builder validUntilDate(JsonField<LocalDate> validUntilDate)
Sets Builder.validUntilDate to an arbitrary JSON value.
You should usually call Builder.validUntilDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final CheckTransferCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final CheckTransferCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final CheckTransferCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final CheckTransferCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final CheckTransferCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final CheckTransferCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final CheckTransferCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final CheckTransferCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final CheckTransferCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final CheckTransferCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final CheckTransferCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final CheckTransferCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final CheckTransferCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final CheckTransferCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final CheckTransferCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final CheckTransferCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final CheckTransferCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final CheckTransferCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final CheckTransferCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final CheckTransferCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final CheckTransferCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final CheckTransferCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final CheckTransferCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final CheckTransferCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final CheckTransferCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final CheckTransferCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final CheckTransferCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final CheckTransferCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final CheckTransferCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final CheckTransferCreateParams build()
Returns an immutable instance of CheckTransferCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .fulfillmentMethod() .sourceAccountNumberId()
-
-
-
-