Class CheckTransferCreateParams.PhysicalCheck
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheckDetails relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.PhysicalCheck.BuilderA builder for PhysicalCheck.
public final classCheckTransferCreateParams.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
public final classCheckTransferCreateParams.PhysicalCheck.Payerpublic final classCheckTransferCreateParams.PhysicalCheck.ReturnAddressThe return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
public final classCheckTransferCreateParams.PhysicalCheck.ShippingMethodHow to ship the check. For details on pricing, timing, and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
public final classCheckTransferCreateParams.PhysicalCheck.SignatureThe signature that will appear on the check. If not provided, the check will be printed with 'No Signature Required'. At most one of
textandimage_file_idmay be provided.
-
Method Summary
Modifier and Type Method Description final CheckTransferCreateParams.PhysicalCheck.MailingAddressmailingAddress()Details for where Increase will mail the check. final Stringmemo()The descriptor that will be printed on the memo field on the check. final List<CheckTransferCreateParams.PhysicalCheck.Payer>payer()The payer of the check. final StringrecipientName()The name that will be printed on the check in the 'To:' field. final Optional<String>attachmentFileId()The ID of a File to be attached to the check. final Optional<String>checkVoucherImageFileId()The ID of a File to be used as the check voucher image. final Optional<String>note()The descriptor that will be printed on the letter included with the check. final Optional<CheckTransferCreateParams.PhysicalCheck.ReturnAddress>returnAddress()The return address to be printed on the check. final Optional<String>returnAddressName()A custom name to print above the default return address. final Optional<CheckTransferCreateParams.PhysicalCheck.ShippingMethod>shippingMethod()How to ship the check. final Optional<CheckTransferCreateParams.PhysicalCheck.Signature>signature()The signature that will appear on the check. final JsonField<CheckTransferCreateParams.PhysicalCheck.MailingAddress>_mailingAddress()Returns the raw JSON value of mailingAddress. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<List<CheckTransferCreateParams.PhysicalCheck.Payer>>_payer()Returns the raw JSON value of payer. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<String>_attachmentFileId()Returns the raw JSON value of attachmentFileId. final JsonField<String>_checkVoucherImageFileId()Returns the raw JSON value of checkVoucherImageFileId. final JsonField<String>_note()Returns the raw JSON value of note. final JsonField<CheckTransferCreateParams.PhysicalCheck.ReturnAddress>_returnAddress()Returns the raw JSON value of returnAddress. final JsonField<String>_returnAddressName()Returns the raw JSON value of returnAddressName. final JsonField<CheckTransferCreateParams.PhysicalCheck.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final JsonField<CheckTransferCreateParams.PhysicalCheck.Signature>_signature()Returns the raw JSON value of signature. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.PhysicalCheck.BuildertoBuilder()final CheckTransferCreateParams.PhysicalCheckvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.PhysicalCheck.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCheck. -
-
Method Detail
-
mailingAddress
final CheckTransferCreateParams.PhysicalCheck.MailingAddress mailingAddress()
Details for where Increase will mail the check.
-
payer
final List<CheckTransferCreateParams.PhysicalCheck.Payer> payer()
The payer of the check. This will be printed on the top-left portion of the check. This should be an array of up to 4 elements, each of which represents a line of the payer.
-
recipientName
final String recipientName()
The name that will be printed on the check in the 'To:' field.
-
attachmentFileId
final Optional<String> attachmentFileId()
The ID of a File to be attached to the check. This must have
purpose: check_attachment. For details on pricing and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
-
checkVoucherImageFileId
final Optional<String> checkVoucherImageFileId()
The ID of a File to be used as the check voucher image. This must have
purpose: check_voucher_image. For details on pricing and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
-
note
final Optional<String> note()
The descriptor that will be printed on the letter included with the check.
-
returnAddress
final Optional<CheckTransferCreateParams.PhysicalCheck.ReturnAddress> returnAddress()
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
returnAddressName
final Optional<String> returnAddressName()
A custom name to print above the default return address. Cannot be provided together with
return_address.
-
shippingMethod
final Optional<CheckTransferCreateParams.PhysicalCheck.ShippingMethod> shippingMethod()
How to ship the check. For details on pricing, timing, and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
-
signature
final Optional<CheckTransferCreateParams.PhysicalCheck.Signature> signature()
The signature that will appear on the check. If not provided, the check will be printed with 'No Signature Required'. At most one of
textandimage_file_idmay be provided.
-
_mailingAddress
final JsonField<CheckTransferCreateParams.PhysicalCheck.MailingAddress> _mailingAddress()
Returns the raw JSON value of mailingAddress.
Unlike mailingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_payer
final JsonField<List<CheckTransferCreateParams.PhysicalCheck.Payer>> _payer()
Returns the raw JSON value of payer.
Unlike payer, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_attachmentFileId
final JsonField<String> _attachmentFileId()
Returns the raw JSON value of attachmentFileId.
Unlike attachmentFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_checkVoucherImageFileId
final JsonField<String> _checkVoucherImageFileId()
Returns the raw JSON value of checkVoucherImageFileId.
Unlike checkVoucherImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_note
final JsonField<String> _note()
Returns the raw JSON value of note.
Unlike note, this method doesn't throw if the JSON field has an unexpected type.
-
_returnAddress
final JsonField<CheckTransferCreateParams.PhysicalCheck.ReturnAddress> _returnAddress()
Returns the raw JSON value of returnAddress.
Unlike returnAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_returnAddressName
final JsonField<String> _returnAddressName()
Returns the raw JSON value of returnAddressName.
Unlike returnAddressName, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CheckTransferCreateParams.PhysicalCheck.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_signature
final JsonField<CheckTransferCreateParams.PhysicalCheck.Signature> _signature()
Returns the raw JSON value of signature.
Unlike signature, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferCreateParams.PhysicalCheck.Builder toBuilder()
-
validate
final CheckTransferCreateParams.PhysicalCheck validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransferCreateParams.PhysicalCheck.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCheck.
The following fields are required:
.mailingAddress() .memo() .payer() .recipientName()
-
-
-
-