Class CheckTransferCreateParams.PhysicalCheck.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.BuilderA builder for PhysicalCheck.
-
-
Method Summary
-
-
Method Detail
-
mailingAddress
final CheckTransferCreateParams.PhysicalCheck.Builder mailingAddress(CheckTransferCreateParams.PhysicalCheck.MailingAddress mailingAddress)
Details for where Increase will mail the check.
-
mailingAddress
final CheckTransferCreateParams.PhysicalCheck.Builder mailingAddress(JsonField<CheckTransferCreateParams.PhysicalCheck.MailingAddress> mailingAddress)
Sets Builder.mailingAddress to an arbitrary JSON value.
You should usually call Builder.mailingAddress with a well-typed MailingAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
memo
final CheckTransferCreateParams.PhysicalCheck.Builder memo(String memo)
The descriptor that will be printed on the memo field on the check.
-
memo
final CheckTransferCreateParams.PhysicalCheck.Builder memo(JsonField<String> memo)
Sets Builder.memo to an arbitrary JSON value.
You should usually call Builder.memo with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final CheckTransferCreateParams.PhysicalCheck.Builder recipientName(String recipientName)
The name that will be printed on the check in the 'To:' field.
-
recipientName
final CheckTransferCreateParams.PhysicalCheck.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
attachmentFileId
final CheckTransferCreateParams.PhysicalCheck.Builder attachmentFileId(String attachmentFileId)
The ID of a File to be attached to the check. This must have
purpose: check_attachment. For details on pricing and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
-
attachmentFileId
final CheckTransferCreateParams.PhysicalCheck.Builder attachmentFileId(JsonField<String> attachmentFileId)
Sets Builder.attachmentFileId to an arbitrary JSON value.
You should usually call Builder.attachmentFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkVoucherImageFileId
final CheckTransferCreateParams.PhysicalCheck.Builder checkVoucherImageFileId(String checkVoucherImageFileId)
The ID of a File to be used as the check voucher image. This must have
purpose: check_voucher_image. For details on pricing and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
-
checkVoucherImageFileId
final CheckTransferCreateParams.PhysicalCheck.Builder checkVoucherImageFileId(JsonField<String> checkVoucherImageFileId)
Sets Builder.checkVoucherImageFileId to an arbitrary JSON value.
You should usually call Builder.checkVoucherImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
note
final CheckTransferCreateParams.PhysicalCheck.Builder note(String note)
The descriptor that will be printed on the letter included with the check.
-
note
final CheckTransferCreateParams.PhysicalCheck.Builder note(JsonField<String> note)
Sets Builder.note to an arbitrary JSON value.
You should usually call Builder.note with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payer
final CheckTransferCreateParams.PhysicalCheck.Builder payer(List<CheckTransferCreateParams.PhysicalCheck.Payer> payer)
The payer of the check. This will be printed on the top-left portion of the check and defaults to the return address if unspecified. This should be an array of up to 4 elements, each of which represents a line of the payer.
-
payer
final CheckTransferCreateParams.PhysicalCheck.Builder payer(JsonField<List<CheckTransferCreateParams.PhysicalCheck.Payer>> payer)
Sets Builder.payer to an arbitrary JSON value.
You should usually call Builder.payer with a well-typed
List<Payer>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayer
final CheckTransferCreateParams.PhysicalCheck.Builder addPayer(CheckTransferCreateParams.PhysicalCheck.Payer payer)
Adds a single Payer to Builder.payer.
-
returnAddress
final CheckTransferCreateParams.PhysicalCheck.Builder returnAddress(CheckTransferCreateParams.PhysicalCheck.ReturnAddress returnAddress)
The return address to be printed on the check. If omitted this will default to an Increase-owned address that will mark checks as delivery failed and shred them.
-
returnAddress
final CheckTransferCreateParams.PhysicalCheck.Builder returnAddress(JsonField<CheckTransferCreateParams.PhysicalCheck.ReturnAddress> returnAddress)
Sets Builder.returnAddress to an arbitrary JSON value.
You should usually call Builder.returnAddress with a well-typed ReturnAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingMethod
final CheckTransferCreateParams.PhysicalCheck.Builder shippingMethod(CheckTransferCreateParams.PhysicalCheck.ShippingMethod shippingMethod)
How to ship the check. For details on pricing, timing, and restrictions, see https://increase.com/documentation/originating-checks#printing-checks .
-
shippingMethod
final CheckTransferCreateParams.PhysicalCheck.Builder shippingMethod(JsonField<CheckTransferCreateParams.PhysicalCheck.ShippingMethod> shippingMethod)
Sets Builder.shippingMethod to an arbitrary JSON value.
You should usually call Builder.shippingMethod with a well-typed ShippingMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
signature
final CheckTransferCreateParams.PhysicalCheck.Builder signature(CheckTransferCreateParams.PhysicalCheck.Signature signature)
The signature that will appear on the check. If not provided, the check will be printed with 'No Signature Required'. At most one of
textandimage_file_idmay be provided.
-
signature
final CheckTransferCreateParams.PhysicalCheck.Builder signature(JsonField<CheckTransferCreateParams.PhysicalCheck.Signature> signature)
Sets Builder.signature to an arbitrary JSON value.
You should usually call Builder.signature with a well-typed Signature value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransferCreateParams.PhysicalCheck.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.PhysicalCheck build()
Returns an immutable instance of PhysicalCheck.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.mailingAddress() .memo() .recipientName()
-
-
-
-