Class CheckTransferCreateParams.PhysicalCheck.MailingAddress
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city component of the check's destination address. final Stringline1()The first line of the address component of the check's destination address. final StringpostalCode()The postal code component of the check's destination address. final Stringstate()The US state component of the check's destination address. final Optional<String>line2()The second line of the address component of the check's destination address. final Optional<String>name()The name component of the check's destination address. final Optional<String>phone()The phone number to associate with the check's destination address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_phone()Returns the raw JSON value of phone. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.PhysicalCheck.MailingAddress.BuildertoBuilder()final CheckTransferCreateParams.PhysicalCheck.MailingAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builderbuilder()Returns a mutable builder for constructing an instance of MailingAddress. -
-
Method Detail
-
line1
final String line1()
The first line of the address component of the check's destination address.
-
postalCode
final String postalCode()
The postal code component of the check's destination address.
-
line2
final Optional<String> line2()
The second line of the address component of the check's destination address.
-
name
final Optional<String> name()
The name component of the check's destination address. Defaults to the provided
recipient_nameparameter ifnameis not provided.
-
phone
final Optional<String> phone()
The phone number to associate with the check's destination address. The phone number is only used when
shipping_methodisfedex_overnightand will be supplied to FedEx to be used in case of delivery issues.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_phone
final JsonField<String> _phone()
Returns the raw JSON value of phone.
Unlike phone, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder toBuilder()
-
validate
final CheckTransferCreateParams.PhysicalCheck.MailingAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder builder()
Returns a mutable builder for constructing an instance of MailingAddress.
The following fields are required:
.city() .line1() .postalCode() .state()
-
-
-
-