Class CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder city(String city)
The city component of the check's destination address.
-
city
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line1(String line1)
The first line of the address component of the check's destination address.
-
line1
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder postalCode(String postalCode)
The postal code component of the check's destination address.
-
postalCode
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder state(String state)
The US state component of the check's destination address.
-
state
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line2(String line2)
The second line of the address component of the check's destination address.
-
line2
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder name(String name)
The name component of the check's destination address. Defaults to the provided
recipient_nameparameter ifnameis not provided.
-
name
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phone
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder phone(String phone)
The phone number to associate with the check's destination address. The phone number is only used when
shipping_methodisfedex_overnightand will be supplied to FedEx to be used in case of delivery issues.
-
phone
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder phone(JsonField<String> phone)
Sets Builder.phone to an arbitrary JSON value.
You should usually call Builder.phone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.MailingAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.PhysicalCheck.MailingAddress build()
Returns an immutable instance of MailingAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .line1() .postalCode() .state()
-
-
-
-