Class CheckTransferCreateParams.PhysicalCheck.Payer
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.Payer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.PhysicalCheck.Payer.BuilderA builder for Payer.
-
Method Summary
Modifier and Type Method Description final Stringcontents()The contents of the line. final JsonField<String>_contents()Returns the raw JSON value of contents. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.PhysicalCheck.Payer.BuildertoBuilder()final CheckTransferCreateParams.PhysicalCheck.Payervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.PhysicalCheck.Payer.Builderbuilder()Returns a mutable builder for constructing an instance of Payer. -
-
Method Detail
-
_contents
final JsonField<String> _contents()
Returns the raw JSON value of contents.
Unlike contents, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder toBuilder()
-
validate
final CheckTransferCreateParams.PhysicalCheck.Payer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransferCreateParams.PhysicalCheck.Payer.Builder builder()
Returns a mutable builder for constructing an instance of Payer.
The following fields are required:
.contents()
-
-
-
-