Class CheckTransferCreateParams.PhysicalCheck.Payer.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.Payer.BuilderA builder for Payer.
-
-
Method Summary
Modifier and Type Method Description final CheckTransferCreateParams.PhysicalCheck.Payer.Buildercontents(String contents)The contents of the line. final CheckTransferCreateParams.PhysicalCheck.Payer.Buildercontents(JsonField<String> contents)Sets Builder.contents to an arbitrary JSON value. final CheckTransferCreateParams.PhysicalCheck.Payer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransferCreateParams.PhysicalCheck.Payer.BuilderputAdditionalProperty(String key, JsonValue value)final CheckTransferCreateParams.PhysicalCheck.Payer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransferCreateParams.PhysicalCheck.Payer.BuilderremoveAdditionalProperty(String key)final CheckTransferCreateParams.PhysicalCheck.Payer.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckTransferCreateParams.PhysicalCheck.Payerbuild()Returns an immutable instance of Payer. -
-
Method Detail
-
contents
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder contents(String contents)
The contents of the line.
-
contents
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder contents(JsonField<String> contents)
Sets Builder.contents to an arbitrary JSON value.
You should usually call Builder.contents with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Payer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.PhysicalCheck.Payer build()
Returns an immutable instance of Payer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.contents()
-
-
-
-