Class CheckTransferCreateParams.PhysicalCheck.Signature
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.SignatureThe signature that will appear on the check. If not provided, the check will be printed with 'No Signature Required'. At most one of
textandimage_file_idmay be provided.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.PhysicalCheck.Signature.BuilderA builder for Signature.
-
Method Summary
Modifier and Type Method Description final Optional<String>imageFileId()The ID of a File containing a PNG of the signature. final Optional<String>text()The text that will appear as the signature on the check in cursive font. final JsonField<String>_imageFileId()Returns the raw JSON value of imageFileId. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.PhysicalCheck.Signature.BuildertoBuilder()final CheckTransferCreateParams.PhysicalCheck.Signaturevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.PhysicalCheck.Signature.Builderbuilder()Returns a mutable builder for constructing an instance of Signature. -
-
Method Detail
-
imageFileId
final Optional<String> imageFileId()
The ID of a File containing a PNG of the signature. This must have
purpose: check_signatureand be a 1320x120 pixel PNG.
-
text
final Optional<String> text()
The text that will appear as the signature on the check in cursive font.
-
_imageFileId
final JsonField<String> _imageFileId()
Returns the raw JSON value of imageFileId.
Unlike imageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder toBuilder()
-
validate
final CheckTransferCreateParams.PhysicalCheck.Signature validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransferCreateParams.PhysicalCheck.Signature.Builder builder()
Returns a mutable builder for constructing an instance of Signature.
-
-
-
-