Class CheckTransferCreateParams.PhysicalCheck.Signature.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.PhysicalCheck.Signature.BuilderA builder for Signature.
-
-
Method Summary
-
-
Method Detail
-
imageFileId
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder imageFileId(String imageFileId)
The ID of a File containing a PNG of the signature. This must have
purpose: check_signatureand be a 1320x120 pixel PNG.
-
imageFileId
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder imageFileId(JsonField<String> imageFileId)
Sets Builder.imageFileId to an arbitrary JSON value.
You should usually call Builder.imageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
text
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder text(String text)
The text that will appear as the signature on the check in cursive font.
-
text
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder text(JsonField<String> text)
Sets Builder.text to an arbitrary JSON value.
You should usually call Builder.text with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.PhysicalCheck.Signature.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.PhysicalCheck.Signature build()
Returns an immutable instance of Signature.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-