Class CheckTransferCreateParams.ThirdParty
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.ThirdPartyDetails relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.ThirdParty.BuilderA builder for ThirdParty.
-
Method Summary
Modifier and Type Method Description final Optional<String>recipientName()The pay-to name you will print on the check. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.ThirdParty.BuildertoBuilder()final CheckTransferCreateParams.ThirdPartyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.ThirdParty.Builderbuilder()Returns a mutable builder for constructing an instance of ThirdParty. -
-
Method Detail
-
recipientName
final Optional<String> recipientName()
The pay-to name you will print on the check. If provided, this is used for /documentation/positive-pay. If this is omitted, Increase will be unable to validate the payer name when the check is deposited.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferCreateParams.ThirdParty.Builder toBuilder()
-
validate
final CheckTransferCreateParams.ThirdParty validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckTransferCreateParams.ThirdParty.Builder builder()
Returns a mutable builder for constructing an instance of ThirdParty.
-
-
-
-