Class CheckTransferListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class CheckTransferListPage implements Page<CheckTransfer>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferListPage.BuilderA builder for CheckTransferListPage.
-
Method Summary
Modifier and Type Method Description final List<CheckTransfer>data()Delegates to CheckTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to CheckTransferListPageResponse, but gracefully handles missing data. List<CheckTransfer>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final CheckTransferListParamsnextPageParams()CheckTransferListPagenextPage()Returns the page after this one by making another request. final AutoPager<CheckTransfer>autoPager()final CheckTransferListParamsparams()The parameters that were used to request this page. final CheckTransferListPageResponseresponse()The response that this page was parsed from. final CheckTransferListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferListPage.Builderbuilder()Returns a mutable builder for constructing an instance of CheckTransferListPage. -
-
Method Detail
-
data
final List<CheckTransfer> data()
Delegates to CheckTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to CheckTransferListPageResponse, but gracefully handles missing data.
-
items
List<CheckTransfer> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final CheckTransferListParams nextPageParams()
-
nextPage
CheckTransferListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<CheckTransfer> autoPager()
-
params
final CheckTransferListParams params()
The parameters that were used to request this page.
-
response
final CheckTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final CheckTransferListPage.Builder toBuilder()
-
builder
final static CheckTransferListPage.Builder builder()
Returns a mutable builder for constructing an instance of CheckTransferListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-