Class CheckTransferListParams.Status
-
- All Implemented Interfaces:
public final class CheckTransferListParams.Status
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferListParams.Status.BuilderA builder for Status.
public final classCheckTransferListParams.Status.In
-
Method Summary
Modifier and Type Method Description final Optional<List<CheckTransferListParams.Status.In>>in_()Filter Check Transfers to those that have the specified status. final QueryParams_additionalProperties()Query params to send with the request. final CheckTransferListParams.Status.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferListParams.Status.Builderbuilder()Returns a mutable builder for constructing an instance of Status. -
-
Method Detail
-
in_
final Optional<List<CheckTransferListParams.Status.In>> in_()
Filter Check Transfers to those that have the specified status. For GET requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
-
_additionalProperties
final QueryParams _additionalProperties()
Query params to send with the request.
-
toBuilder
final CheckTransferListParams.Status.Builder toBuilder()
-
builder
final static CheckTransferListParams.Status.Builder builder()
Returns a mutable builder for constructing an instance of Status.
-
-
-
-