Class CheckTransferListResponse
-
- All Implemented Interfaces:
public final class CheckTransferListResponseA list of Check Transfer objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferListResponse.BuilderA builder for CheckTransferListResponse.
-
Method Summary
Modifier and Type Method Description final List<CheckTransfer>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<CheckTransfer>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final CheckTransferListResponse.BuildertoBuilder()final CheckTransferListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CheckTransferListResponse. -
-
Method Detail
-
data
final List<CheckTransfer> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<CheckTransfer>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferListResponse.Builder toBuilder()
-
validate
final CheckTransferListResponse validate()
-
builder
final static CheckTransferListResponse.Builder builder()
Returns a mutable builder for constructing an instance of CheckTransferListResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-