Class CheckTransferStopPaymentParams.Body.Builder
-
- All Implemented Interfaces:
public final class CheckTransferStopPaymentParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final CheckTransferStopPaymentParams.Body.Builderreason(CheckTransferStopPaymentParams.Reason reason)The reason why this transfer should be stopped. final CheckTransferStopPaymentParams.Body.Builderreason(JsonField<CheckTransferStopPaymentParams.Reason> reason)Sets Builder.reason to an arbitrary JSON value. final CheckTransferStopPaymentParams.Body.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransferStopPaymentParams.Body.BuilderputAdditionalProperty(String key, JsonValue value)final CheckTransferStopPaymentParams.Body.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransferStopPaymentParams.Body.BuilderremoveAdditionalProperty(String key)final CheckTransferStopPaymentParams.Body.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckTransferStopPaymentParams.Bodybuild()Returns an immutable instance of Body. -
-
Method Detail
-
reason
final CheckTransferStopPaymentParams.Body.Builder reason(CheckTransferStopPaymentParams.Reason reason)
The reason why this transfer should be stopped.
-
reason
final CheckTransferStopPaymentParams.Body.Builder reason(JsonField<CheckTransferStopPaymentParams.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransferStopPaymentParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferStopPaymentParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferStopPaymentParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferStopPaymentParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferStopPaymentParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferStopPaymentParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-