Class DeclinedTransaction
-
- All Implemented Interfaces:
public final class DeclinedTransactionDeclined Transactions are refused additions and removals of money from your bank account. For example, Declined Transactions are caused when your Account has an insufficient balance or your Limits are triggered.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.BuilderA builder for DeclinedTransaction.
public final classDeclinedTransaction.CurrencyThe ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
public final classDeclinedTransaction.RouteTypeThe type of the route this Declined Transaction came through.
public final classDeclinedTransaction.SourceThis is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
public final classDeclinedTransaction.TypeA constant representing the object's type. For this resource it will always be
declined_transaction.
-
Method Summary
Modifier and Type Method Description final Stringid()The Declined Transaction identifier. final StringaccountId()The identifier for the Account the Declined Transaction belongs to. final Longamount()The Declined Transaction amount in the minor unit of its currency. final OffsetDateTimecreatedAt()The ISO 8601 date on which the Transaction occurred. final DeclinedTransaction.Currencycurrency()The ISO 4217 code for the Declined Transaction's currency. final Stringdescription()This is the description the vendor provides. final Optional<String>routeId()The identifier for the route this Declined Transaction came through. final Optional<DeclinedTransaction.RouteType>routeType()The type of the route this Declined Transaction came through. final DeclinedTransaction.Sourcesource()This is an object giving more details on the network-level event that caused the Declined Transaction. final DeclinedTransaction.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<DeclinedTransaction.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_routeId()Returns the raw JSON value of routeId. final JsonField<DeclinedTransaction.RouteType>_routeType()Returns the raw JSON value of routeType. final JsonField<DeclinedTransaction.Source>_source()Returns the raw JSON value of source. final JsonField<DeclinedTransaction.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.BuildertoBuilder()final DeclinedTransactionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Builderbuilder()Returns a mutable builder for constructing an instance of DeclinedTransaction. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account the Declined Transaction belongs to.
-
amount
final Long amount()
The Declined Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date on which the Transaction occurred.
-
currency
final DeclinedTransaction.Currency currency()
The ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
-
description
final String description()
This is the description the vendor provides.
-
routeId
final Optional<String> routeId()
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
routeType
final Optional<DeclinedTransaction.RouteType> routeType()
The type of the route this Declined Transaction came through.
-
source
final DeclinedTransaction.Source source()
This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
type
final DeclinedTransaction.Type type()
A constant representing the object's type. For this resource it will always be
declined_transaction.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<DeclinedTransaction.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_routeId
final JsonField<String> _routeId()
Returns the raw JSON value of routeId.
Unlike routeId, this method doesn't throw if the JSON field has an unexpected type.
-
_routeType
final JsonField<DeclinedTransaction.RouteType> _routeType()
Returns the raw JSON value of routeType.
Unlike routeType, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<DeclinedTransaction.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DeclinedTransaction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Builder toBuilder()
-
validate
final DeclinedTransaction validate()
-
builder
final static DeclinedTransaction.Builder builder()
Returns a mutable builder for constructing an instance of DeclinedTransaction.
The following fields are required:
.id() .accountId() .amount() .createdAt() .currency() .description() .routeId() .routeType() .source() .type()
-
-
-
-