Class DeclinedTransaction.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.BuilderA builder for DeclinedTransaction.
-
-
Method Summary
-
-
Method Detail
-
id
final DeclinedTransaction.Builder id(String id)
The Declined Transaction identifier.
-
id
final DeclinedTransaction.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final DeclinedTransaction.Builder accountId(String accountId)
The identifier for the Account the Declined Transaction belongs to.
-
accountId
final DeclinedTransaction.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final DeclinedTransaction.Builder amount(Long amount)
The Declined Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final DeclinedTransaction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final DeclinedTransaction.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date on which the Transaction occurred.
-
createdAt
final DeclinedTransaction.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final DeclinedTransaction.Builder currency(DeclinedTransaction.Currency currency)
The ISO 4217 code for the Declined Transaction's currency. This will match the currency on the Declined Transaction's Account.
-
currency
final DeclinedTransaction.Builder currency(JsonField<DeclinedTransaction.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final DeclinedTransaction.Builder description(String description)
This is the description the vendor provides.
-
description
final DeclinedTransaction.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routeId
final DeclinedTransaction.Builder routeId(String routeId)
The identifier for the route this Declined Transaction came through. Routes are things like cards and ACH details.
-
routeId
final DeclinedTransaction.Builder routeId(Optional<String> routeId)
Alias for calling Builder.routeId with
routeId.orElse(null).
-
routeId
final DeclinedTransaction.Builder routeId(JsonField<String> routeId)
Sets Builder.routeId to an arbitrary JSON value.
You should usually call Builder.routeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routeType
final DeclinedTransaction.Builder routeType(DeclinedTransaction.RouteType routeType)
The type of the route this Declined Transaction came through.
-
routeType
final DeclinedTransaction.Builder routeType(Optional<DeclinedTransaction.RouteType> routeType)
Alias for calling Builder.routeType with
routeType.orElse(null).
-
routeType
final DeclinedTransaction.Builder routeType(JsonField<DeclinedTransaction.RouteType> routeType)
Sets Builder.routeType to an arbitrary JSON value.
You should usually call Builder.routeType with a well-typed RouteType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final DeclinedTransaction.Builder source(DeclinedTransaction.Source source)
This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
source
final DeclinedTransaction.Builder source(JsonField<DeclinedTransaction.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final DeclinedTransaction.Builder type(DeclinedTransaction.Type type)
A constant representing the object's type. For this resource it will always be
declined_transaction.
-
type
final DeclinedTransaction.Builder type(JsonField<DeclinedTransaction.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DeclinedTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction build()
Returns an immutable instance of DeclinedTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount() .createdAt() .currency() .description() .routeId() .routeType() .source() .type()
-
-
-
-