Class DeclinedTransaction.Source
-
- All Implemented Interfaces:
public final class DeclinedTransaction.SourceThis is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.BuilderA builder for Source.
public final classDeclinedTransaction.Source.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classDeclinedTransaction.Source.AchDeclineAn ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.public final classDeclinedTransaction.Source.CardDeclineA Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.public final classDeclinedTransaction.Source.CheckDeclineA Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.public final classDeclinedTransaction.Source.CheckDepositRejectionA Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.public final classDeclinedTransaction.Source.InboundFednowTransferDeclineAn Inbound FedNow Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_decline.public final classDeclinedTransaction.Source.InboundRealTimePaymentsTransferDeclineAn Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.public final classDeclinedTransaction.Source.OtherIf the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.public final classDeclinedTransaction.Source.WireDeclineA Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
Method Summary
-
-
Method Detail
-
category
final DeclinedTransaction.Source.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
achDecline
final Optional<DeclinedTransaction.Source.AchDecline> achDecline()
An ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.
-
cardDecline
final Optional<DeclinedTransaction.Source.CardDecline> cardDecline()
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
checkDecline
final Optional<DeclinedTransaction.Source.CheckDecline> checkDecline()
A Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.
-
checkDepositRejection
final Optional<DeclinedTransaction.Source.CheckDepositRejection> checkDepositRejection()
A Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.
-
inboundFednowTransferDecline
final Optional<DeclinedTransaction.Source.InboundFednowTransferDecline> inboundFednowTransferDecline()
An Inbound FedNow Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_decline.
-
inboundRealTimePaymentsTransferDecline
final Optional<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline()
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
other
final Optional<DeclinedTransaction.Source.Other> other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
wireDecline
final Optional<DeclinedTransaction.Source.WireDecline> wireDecline()
A Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
_category
final JsonField<DeclinedTransaction.Source.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_achDecline
final JsonField<DeclinedTransaction.Source.AchDecline> _achDecline()
Returns the raw JSON value of achDecline.
Unlike achDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDecline
final JsonField<DeclinedTransaction.Source.CardDecline> _cardDecline()
Returns the raw JSON value of cardDecline.
Unlike cardDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDecline
final JsonField<DeclinedTransaction.Source.CheckDecline> _checkDecline()
Returns the raw JSON value of checkDecline.
Unlike checkDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositRejection
final JsonField<DeclinedTransaction.Source.CheckDepositRejection> _checkDepositRejection()
Returns the raw JSON value of checkDepositRejection.
Unlike checkDepositRejection, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundFednowTransferDecline
final JsonField<DeclinedTransaction.Source.InboundFednowTransferDecline> _inboundFednowTransferDecline()
Returns the raw JSON value of inboundFednowTransferDecline.
Unlike inboundFednowTransferDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundRealTimePaymentsTransferDecline
final JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline> _inboundRealTimePaymentsTransferDecline()
Returns the raw JSON value of inboundRealTimePaymentsTransferDecline.
Unlike inboundRealTimePaymentsTransferDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_other
final JsonField<DeclinedTransaction.Source.Other> _other()
Returns the raw JSON value of other.
Unlike other, this method doesn't throw if the JSON field has an unexpected type.
-
_wireDecline
final JsonField<DeclinedTransaction.Source.WireDecline> _wireDecline()
Returns the raw JSON value of wireDecline.
Unlike wireDecline, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.Builder toBuilder()
-
validate
final DeclinedTransaction.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DeclinedTransaction.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
The following fields are required:
.category()
-
-
-
-