Class DeclinedTransaction.Source.AchDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.AchDeclineAn ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.AchDecline.BuilderA builder for AchDecline.
public final classDeclinedTransaction.Source.AchDecline.ReasonWhy the ACH transfer was declined.
public final classDeclinedTransaction.Source.AchDecline.TypeA constant representing the object's type. For this resource it will always be
ach_decline.
-
Method Summary
Modifier and Type Method Description final Stringid()The ACH Decline's identifier. final Longamount()The declined amount in USD cents. final StringinboundAchTransferId()The identifier of the Inbound ACH Transfer object associated with this decline. final Optional<String>originatorCompanyDescriptiveDate()The descriptive date of the transfer. final Optional<String>originatorCompanyDiscretionaryData()The additional information included with the transfer. final StringoriginatorCompanyId()The identifier of the company that initiated the transfer. final StringoriginatorCompanyName()The name of the company that initiated the transfer. final DeclinedTransaction.Source.AchDecline.Reasonreason()Why the ACH transfer was declined. final Optional<String>receiverIdNumber()The id of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final StringtraceNumber()The trace number of the transfer. final DeclinedTransaction.Source.AchDecline.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_inboundAchTransferId()Returns the raw JSON value of inboundAchTransferId. final JsonField<String>_originatorCompanyDescriptiveDate()Returns the raw JSON value of originatorCompanyDescriptiveDate. final JsonField<String>_originatorCompanyDiscretionaryData()Returns the raw JSON value of originatorCompanyDiscretionaryData. final JsonField<String>_originatorCompanyId()Returns the raw JSON value of originatorCompanyId. final JsonField<String>_originatorCompanyName()Returns the raw JSON value of originatorCompanyName. final JsonField<DeclinedTransaction.Source.AchDecline.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_receiverIdNumber()Returns the raw JSON value of receiverIdNumber. final JsonField<String>_receiverName()Returns the raw JSON value of receiverName. final JsonField<String>_traceNumber()Returns the raw JSON value of traceNumber. final JsonField<DeclinedTransaction.Source.AchDecline.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.AchDecline.BuildertoBuilder()final DeclinedTransaction.Source.AchDeclinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.AchDecline.Builderbuilder()Returns a mutable builder for constructing an instance of AchDecline. -
-
Method Detail
-
inboundAchTransferId
final String inboundAchTransferId()
The identifier of the Inbound ACH Transfer object associated with this decline.
-
originatorCompanyDescriptiveDate
final Optional<String> originatorCompanyDescriptiveDate()
The descriptive date of the transfer.
-
originatorCompanyDiscretionaryData
final Optional<String> originatorCompanyDiscretionaryData()
The additional information included with the transfer.
-
originatorCompanyId
final String originatorCompanyId()
The identifier of the company that initiated the transfer.
-
originatorCompanyName
final String originatorCompanyName()
The name of the company that initiated the transfer.
-
reason
final DeclinedTransaction.Source.AchDecline.Reason reason()
Why the ACH transfer was declined.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The id of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
traceNumber
final String traceNumber()
The trace number of the transfer.
-
type
final DeclinedTransaction.Source.AchDecline.Type type()
A constant representing the object's type. For this resource it will always be
ach_decline.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundAchTransferId
final JsonField<String> _inboundAchTransferId()
Returns the raw JSON value of inboundAchTransferId.
Unlike inboundAchTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyDescriptiveDate
final JsonField<String> _originatorCompanyDescriptiveDate()
Returns the raw JSON value of originatorCompanyDescriptiveDate.
Unlike originatorCompanyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyDiscretionaryData
final JsonField<String> _originatorCompanyDiscretionaryData()
Returns the raw JSON value of originatorCompanyDiscretionaryData.
Unlike originatorCompanyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyId
final JsonField<String> _originatorCompanyId()
Returns the raw JSON value of originatorCompanyId.
Unlike originatorCompanyId, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyName
final JsonField<String> _originatorCompanyName()
Returns the raw JSON value of originatorCompanyName.
Unlike originatorCompanyName, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DeclinedTransaction.Source.AchDecline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
Returns the raw JSON value of receiverIdNumber.
Unlike receiverIdNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverName
final JsonField<String> _receiverName()
Returns the raw JSON value of receiverName.
Unlike receiverName, this method doesn't throw if the JSON field has an unexpected type.
-
_traceNumber
final JsonField<String> _traceNumber()
Returns the raw JSON value of traceNumber.
Unlike traceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DeclinedTransaction.Source.AchDecline.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.AchDecline.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.AchDecline validate()
-
builder
final static DeclinedTransaction.Source.AchDecline.Builder builder()
Returns a mutable builder for constructing an instance of AchDecline.
The following fields are required:
.id() .amount() .inboundAchTransferId() .originatorCompanyDescriptiveDate() .originatorCompanyDiscretionaryData() .originatorCompanyId() .originatorCompanyName() .reason() .receiverIdNumber() .receiverName() .traceNumber() .type()
-
-
-
-