Class DeclinedTransaction.Source.AchDecline.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.AchDecline.BuilderA builder for AchDecline.
-
-
Method Summary
-
-
Method Detail
-
id
final DeclinedTransaction.Source.AchDecline.Builder id(String id)
The ACH Decline's identifier.
-
id
final DeclinedTransaction.Source.AchDecline.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final DeclinedTransaction.Source.AchDecline.Builder amount(Long amount)
The declined amount in USD cents.
-
amount
final DeclinedTransaction.Source.AchDecline.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundAchTransferId
final DeclinedTransaction.Source.AchDecline.Builder inboundAchTransferId(String inboundAchTransferId)
The identifier of the Inbound ACH Transfer object associated with this decline.
-
inboundAchTransferId
final DeclinedTransaction.Source.AchDecline.Builder inboundAchTransferId(JsonField<String> inboundAchTransferId)
Sets Builder.inboundAchTransferId to an arbitrary JSON value.
You should usually call Builder.inboundAchTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyDescriptiveDate
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDescriptiveDate
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)
Alias for calling Builder.originatorCompanyDescriptiveDate with
originatorCompanyDescriptiveDate.orElse(null).
-
originatorCompanyDescriptiveDate
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)
Sets Builder.originatorCompanyDescriptiveDate to an arbitrary JSON value.
You should usually call Builder.originatorCompanyDescriptiveDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyDiscretionaryData
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyDiscretionaryData
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)
Alias for calling Builder.originatorCompanyDiscretionaryData with
originatorCompanyDiscretionaryData.orElse(null).
-
originatorCompanyDiscretionaryData
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)
Sets Builder.originatorCompanyDiscretionaryData to an arbitrary JSON value.
You should usually call Builder.originatorCompanyDiscretionaryData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyId
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyId(String originatorCompanyId)
The identifier of the company that initiated the transfer.
-
originatorCompanyId
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyId(JsonField<String> originatorCompanyId)
Sets Builder.originatorCompanyId to an arbitrary JSON value.
You should usually call Builder.originatorCompanyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyName
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyName(String originatorCompanyName)
The name of the company that initiated the transfer.
-
originatorCompanyName
final DeclinedTransaction.Source.AchDecline.Builder originatorCompanyName(JsonField<String> originatorCompanyName)
Sets Builder.originatorCompanyName to an arbitrary JSON value.
You should usually call Builder.originatorCompanyName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final DeclinedTransaction.Source.AchDecline.Builder reason(DeclinedTransaction.Source.AchDecline.Reason reason)
Why the ACH transfer was declined.
-
reason
final DeclinedTransaction.Source.AchDecline.Builder reason(JsonField<DeclinedTransaction.Source.AchDecline.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverIdNumber
final DeclinedTransaction.Source.AchDecline.Builder receiverIdNumber(String receiverIdNumber)
The id of the receiver of the transfer.
-
receiverIdNumber
final DeclinedTransaction.Source.AchDecline.Builder receiverIdNumber(Optional<String> receiverIdNumber)
Alias for calling Builder.receiverIdNumber with
receiverIdNumber.orElse(null).
-
receiverIdNumber
final DeclinedTransaction.Source.AchDecline.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
Sets Builder.receiverIdNumber to an arbitrary JSON value.
You should usually call Builder.receiverIdNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverName
final DeclinedTransaction.Source.AchDecline.Builder receiverName(String receiverName)
The name of the receiver of the transfer.
-
receiverName
final DeclinedTransaction.Source.AchDecline.Builder receiverName(Optional<String> receiverName)
Alias for calling Builder.receiverName with
receiverName.orElse(null).
-
receiverName
final DeclinedTransaction.Source.AchDecline.Builder receiverName(JsonField<String> receiverName)
Sets Builder.receiverName to an arbitrary JSON value.
You should usually call Builder.receiverName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
traceNumber
final DeclinedTransaction.Source.AchDecline.Builder traceNumber(String traceNumber)
The trace number of the transfer.
-
traceNumber
final DeclinedTransaction.Source.AchDecline.Builder traceNumber(JsonField<String> traceNumber)
Sets Builder.traceNumber to an arbitrary JSON value.
You should usually call Builder.traceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final DeclinedTransaction.Source.AchDecline.Builder type(DeclinedTransaction.Source.AchDecline.Type type)
A constant representing the object's type. For this resource it will always be
ach_decline.
-
type
final DeclinedTransaction.Source.AchDecline.Builder type(JsonField<DeclinedTransaction.Source.AchDecline.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DeclinedTransaction.Source.AchDecline.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.AchDecline.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.AchDecline.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.AchDecline.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.AchDecline.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source.AchDecline build()
Returns an immutable instance of AchDecline.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .amount() .inboundAchTransferId() .originatorCompanyDescriptiveDate() .originatorCompanyDiscretionaryData() .originatorCompanyId() .originatorCompanyName() .reason() .receiverIdNumber() .receiverName() .traceNumber() .type()
-
-
-
-