Enum DeclinedTransaction.Source.AchDecline.Reason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.AchDecline.Reason.Value extends Enum<DeclinedTransaction.Source.AchDecline.Reason.Value>
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.AchDecline.Reason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACH_ROUTE_CANCELEDThe account number is canceled.
ACH_ROUTE_DISABLEDThe account number is disabled.
BREACHES_LIMITThe transaction would cause an Increase limit to be exceeded.
ENTITY_NOT_ACTIVEThe account's entity is not active.
GROUP_LOCKEDYour account is inactive.
TRANSACTION_NOT_ALLOWEDThe transaction is not allowed per Increase's terms.
USER_INITIATEDYour integration declined this transfer via the API.
INSUFFICIENT_FUNDSYour account contains insufficient funds.
RETURNED_PER_ODFI_REQUESTThe originating financial institution asked for this transfer to be returned. The receiving bank is complying with the request.
AUTHORIZATION_REVOKED_BY_CUSTOMERThe customer no longer authorizes this transaction.
PAYMENT_STOPPEDThe customer asked for the payment to be stopped.
CUSTOMER_ADVISED_UNAUTHORIZED_IMPROPER_INELIGIBLE_OR_INCOMPLETEThe customer advises that the debit was unauthorized.
REPRESENTATIVE_PAYEE_DECEASED_OR_UNABLE_TO_CONTINUE_IN_THAT_CAPACITYThe payee is deceased.
BENEFICIARY_OR_ACCOUNT_HOLDER_DECEASEDThe account holder is deceased.
CREDIT_ENTRY_REFUSED_BY_RECEIVERThe customer refused a credit entry.
DUPLICATE_ENTRYThe account holder identified this transaction as a duplicate.
CORPORATE_CUSTOMER_ADVISED_NOT_AUTHORIZEDThe corporate customer no longer authorizes this transaction.
_UNKNOWNAn enum member indicating that Reason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.AchDecline.Reason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.AchDecline.Reason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.AchDecline.Reason.Value>getEntries()An enum containing Reason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.AchDecline.Reason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.AchDecline.Reason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.AchDecline.Reason.Value> getEntries()
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-