Class DeclinedTransaction.Source.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.BuilderA builder for Source.
-
-
Method Summary
-
-
Method Detail
-
category
final DeclinedTransaction.Source.Builder category(DeclinedTransaction.Source.Category category)
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final DeclinedTransaction.Source.Builder category(JsonField<DeclinedTransaction.Source.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achDecline
final DeclinedTransaction.Source.Builder achDecline(DeclinedTransaction.Source.AchDecline achDecline)
An ACH Decline object. This field will be present in the JSON response if and only if
categoryis equal toach_decline.
-
achDecline
final DeclinedTransaction.Source.Builder achDecline(Optional<DeclinedTransaction.Source.AchDecline> achDecline)
Alias for calling Builder.achDecline with
achDecline.orElse(null).
-
achDecline
final DeclinedTransaction.Source.Builder achDecline(JsonField<DeclinedTransaction.Source.AchDecline> achDecline)
Sets Builder.achDecline to an arbitrary JSON value.
You should usually call Builder.achDecline with a well-typed AchDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDecline
final DeclinedTransaction.Source.Builder cardDecline(DeclinedTransaction.Source.CardDecline cardDecline)
A Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
cardDecline
final DeclinedTransaction.Source.Builder cardDecline(Optional<DeclinedTransaction.Source.CardDecline> cardDecline)
Alias for calling Builder.cardDecline with
cardDecline.orElse(null).
-
cardDecline
final DeclinedTransaction.Source.Builder cardDecline(JsonField<DeclinedTransaction.Source.CardDecline> cardDecline)
Sets Builder.cardDecline to an arbitrary JSON value.
You should usually call Builder.cardDecline with a well-typed CardDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDecline
final DeclinedTransaction.Source.Builder checkDecline(DeclinedTransaction.Source.CheckDecline checkDecline)
A Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.
-
checkDecline
final DeclinedTransaction.Source.Builder checkDecline(Optional<DeclinedTransaction.Source.CheckDecline> checkDecline)
Alias for calling Builder.checkDecline with
checkDecline.orElse(null).
-
checkDecline
final DeclinedTransaction.Source.Builder checkDecline(JsonField<DeclinedTransaction.Source.CheckDecline> checkDecline)
Sets Builder.checkDecline to an arbitrary JSON value.
You should usually call Builder.checkDecline with a well-typed CheckDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositRejection
final DeclinedTransaction.Source.Builder checkDepositRejection(DeclinedTransaction.Source.CheckDepositRejection checkDepositRejection)
A Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.
-
checkDepositRejection
final DeclinedTransaction.Source.Builder checkDepositRejection(Optional<DeclinedTransaction.Source.CheckDepositRejection> checkDepositRejection)
Alias for calling Builder.checkDepositRejection with
checkDepositRejection.orElse(null).
-
checkDepositRejection
final DeclinedTransaction.Source.Builder checkDepositRejection(JsonField<DeclinedTransaction.Source.CheckDepositRejection> checkDepositRejection)
Sets Builder.checkDepositRejection to an arbitrary JSON value.
You should usually call Builder.checkDepositRejection with a well-typed CheckDepositRejection value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundFednowTransferDecline
final DeclinedTransaction.Source.Builder inboundFednowTransferDecline(DeclinedTransaction.Source.InboundFednowTransferDecline inboundFednowTransferDecline)
An Inbound FedNow Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_decline.
-
inboundFednowTransferDecline
final DeclinedTransaction.Source.Builder inboundFednowTransferDecline(Optional<DeclinedTransaction.Source.InboundFednowTransferDecline> inboundFednowTransferDecline)
Alias for calling Builder.inboundFednowTransferDecline with
inboundFednowTransferDecline.orElse(null).
-
inboundFednowTransferDecline
final DeclinedTransaction.Source.Builder inboundFednowTransferDecline(JsonField<DeclinedTransaction.Source.InboundFednowTransferDecline> inboundFednowTransferDecline)
Sets Builder.inboundFednowTransferDecline to an arbitrary JSON value.
You should usually call Builder.inboundFednowTransferDecline with a well-typed InboundFednowTransferDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundRealTimePaymentsTransferDecline
final DeclinedTransaction.Source.Builder inboundRealTimePaymentsTransferDecline(DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline inboundRealTimePaymentsTransferDecline)
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
inboundRealTimePaymentsTransferDecline
final DeclinedTransaction.Source.Builder inboundRealTimePaymentsTransferDecline(Optional<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline)
Alias for calling Builder.inboundRealTimePaymentsTransferDecline with
inboundRealTimePaymentsTransferDecline.orElse(null).
-
inboundRealTimePaymentsTransferDecline
final DeclinedTransaction.Source.Builder inboundRealTimePaymentsTransferDecline(JsonField<DeclinedTransaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline)
Sets Builder.inboundRealTimePaymentsTransferDecline to an arbitrary JSON value.
You should usually call Builder.inboundRealTimePaymentsTransferDecline with a well-typed InboundRealTimePaymentsTransferDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
other
final DeclinedTransaction.Source.Builder other(DeclinedTransaction.Source.Other other)
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
other
final DeclinedTransaction.Source.Builder other(Optional<DeclinedTransaction.Source.Other> other)
Alias for calling Builder.other with
other.orElse(null).
-
other
final DeclinedTransaction.Source.Builder other(JsonField<DeclinedTransaction.Source.Other> other)
Sets Builder.other to an arbitrary JSON value.
You should usually call Builder.other with a well-typed Other value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireDecline
final DeclinedTransaction.Source.Builder wireDecline(DeclinedTransaction.Source.WireDecline wireDecline)
A Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
wireDecline
final DeclinedTransaction.Source.Builder wireDecline(Optional<DeclinedTransaction.Source.WireDecline> wireDecline)
Alias for calling Builder.wireDecline with
wireDecline.orElse(null).
-
wireDecline
final DeclinedTransaction.Source.Builder wireDecline(JsonField<DeclinedTransaction.Source.WireDecline> wireDecline)
Sets Builder.wireDecline to an arbitrary JSON value.
You should usually call Builder.wireDecline with a well-typed WireDecline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DeclinedTransaction.Source.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source build()
Returns an immutable instance of Source.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category()
-
-
-
-