Class DeclinedTransaction.Source.CardDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CardDeclineA Card Decline object. This field will be present in the JSON response if and only if
categoryis equal tocard_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.CardDecline.BuilderA builder for CardDecline.
public final classDeclinedTransaction.Source.CardDecline.ActionerWhether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classDeclinedTransaction.Source.CardDecline.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.public final classDeclinedTransaction.Source.CardDecline.CurrencyThe ISO 4217 code for the destination account currency.
public final classDeclinedTransaction.Source.CardDecline.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classDeclinedTransaction.Source.CardDecline.NetworkDetailsFields specific to the
network.public final classDeclinedTransaction.Source.CardDecline.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classDeclinedTransaction.Source.CardDecline.ProcessingCategoryThe processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
public final classDeclinedTransaction.Source.CardDecline.RealTimeDecisionReasonThis is present if a specific decline reason was given in the real-time decision.
public final classDeclinedTransaction.Source.CardDecline.ReasonWhy the transaction was declined.
public final classDeclinedTransaction.Source.CardDecline.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Decline identifier. final DeclinedTransaction.Source.CardDecline.Actioneractioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final DeclinedTransaction.Source.CardDecline.AdditionalAmountsadditionalAmounts()Additional amounts associated with the card authorization, such as ATM surcharges fees. final Longamount()The declined amount in the minor unit of the destination account currency. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final DeclinedTransaction.Source.CardDecline.Currencycurrency()The ISO 4217 code for the destination account currency. final StringdeclinedTransactionId()The identifier of the declined transaction created for this Card Decline. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final DeclinedTransaction.Source.CardDecline.Directiondirection()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final Optional<String>incrementedCardAuthorizationId()The identifier of the card authorization this request attempted to incrementally authorize. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final DeclinedTransaction.Source.CardDecline.NetworkDetailsnetworkDetails()Fields specific to the network.final DeclinedTransaction.Source.CardDecline.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final LongpresentmentAmount()The declined amount in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final DeclinedTransaction.Source.CardDecline.ProcessingCategoryprocessingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final Optional<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason>realTimeDecisionReason()This is present if a specific decline reason was given in the real-time decision. final DeclinedTransaction.Source.CardDecline.Reasonreason()Why the transaction was declined. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final DeclinedTransaction.Source.CardDecline.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<DeclinedTransaction.Source.CardDecline.Actioner>_actioner()Returns the raw JSON value of actioner. final JsonField<DeclinedTransaction.Source.CardDecline.AdditionalAmounts>_additionalAmounts()Returns the raw JSON value of additionalAmounts. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<DeclinedTransaction.Source.CardDecline.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_declinedTransactionId()Returns the raw JSON value of declinedTransactionId. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<DeclinedTransaction.Source.CardDecline.Direction>_direction()Returns the raw JSON value of direction. final JsonField<String>_incrementedCardAuthorizationId()Returns the raw JSON value of incrementedCardAuthorizationId. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails>_networkDetails()Returns the raw JSON value of networkDetails. final JsonField<DeclinedTransaction.Source.CardDecline.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<Long>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_presentmentCurrency()Returns the raw JSON value of presentmentCurrency. final JsonField<DeclinedTransaction.Source.CardDecline.ProcessingCategory>_processingCategory()Returns the raw JSON value of processingCategory. final JsonField<String>_realTimeDecisionId()Returns the raw JSON value of realTimeDecisionId. final JsonField<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason>_realTimeDecisionReason()Returns the raw JSON value of realTimeDecisionReason. final JsonField<DeclinedTransaction.Source.CardDecline.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final JsonField<DeclinedTransaction.Source.CardDecline.Verification>_verification()Returns the raw JSON value of verification. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.CardDecline.BuildertoBuilder()final DeclinedTransaction.Source.CardDeclinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.CardDecline.Builderbuilder()Returns a mutable builder for constructing an instance of CardDecline. -
-
Method Detail
-
actioner
final DeclinedTransaction.Source.CardDecline.Actioner actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
additionalAmounts
final DeclinedTransaction.Source.CardDecline.AdditionalAmounts additionalAmounts()
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
amount
final Long amount()
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
currency
final DeclinedTransaction.Source.CardDecline.Currency currency()
The ISO 4217 code for the destination account currency.
-
declinedTransactionId
final String declinedTransactionId()
The identifier of the declined transaction created for this Card Decline.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final DeclinedTransaction.Source.CardDecline.Direction direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
incrementedCardAuthorizationId
final Optional<String> incrementedCardAuthorizationId()
The identifier of the card authorization this request attempted to incrementally authorize.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final DeclinedTransaction.Source.CardDecline.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final DeclinedTransaction.Source.CardDecline.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final Long presentmentAmount()
The declined amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
processingCategory
final DeclinedTransaction.Source.CardDecline.ProcessingCategory processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionReason
final Optional<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason> realTimeDecisionReason()
This is present if a specific decline reason was given in the real-time decision.
-
reason
final DeclinedTransaction.Source.CardDecline.Reason reason()
Why the transaction was declined.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
verification
final DeclinedTransaction.Source.CardDecline.Verification verification()
Fields related to verification of cardholder-provided values.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_actioner
final JsonField<DeclinedTransaction.Source.CardDecline.Actioner> _actioner()
Returns the raw JSON value of actioner.
Unlike actioner, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalAmounts
final JsonField<DeclinedTransaction.Source.CardDecline.AdditionalAmounts> _additionalAmounts()
Returns the raw JSON value of additionalAmounts.
Unlike additionalAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<DeclinedTransaction.Source.CardDecline.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
Returns the raw JSON value of declinedTransactionId.
Unlike declinedTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<DeclinedTransaction.Source.CardDecline.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_incrementedCardAuthorizationId
final JsonField<String> _incrementedCardAuthorizationId()
Returns the raw JSON value of incrementedCardAuthorizationId.
Unlike incrementedCardAuthorizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_networkDetails
final JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails> _networkDetails()
Returns the raw JSON value of networkDetails.
Unlike networkDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<DeclinedTransaction.Source.CardDecline.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
Returns the raw JSON value of presentmentCurrency.
Unlike presentmentCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_processingCategory
final JsonField<DeclinedTransaction.Source.CardDecline.ProcessingCategory> _processingCategory()
Returns the raw JSON value of processingCategory.
Unlike processingCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionReason
final JsonField<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason> _realTimeDecisionReason()
Returns the raw JSON value of realTimeDecisionReason.
Unlike realTimeDecisionReason, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DeclinedTransaction.Source.CardDecline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_verification
final JsonField<DeclinedTransaction.Source.CardDecline.Verification> _verification()
Returns the raw JSON value of verification.
Unlike verification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.CardDecline.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.CardDecline validate()
-
builder
final static DeclinedTransaction.Source.CardDecline.Builder builder()
Returns a mutable builder for constructing an instance of CardDecline.
The following fields are required:
.id() .actioner() .additionalAmounts() .amount() .cardPaymentId() .currency() .declinedTransactionId() .digitalWalletTokenId() .direction() .incrementedCardAuthorizationId() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .presentmentAmount() .presentmentCurrency() .processingCategory() .realTimeDecisionId() .realTimeDecisionReason() .reason() .terminalId() .verification()
-
-
-
-