Class DeclinedTransaction.Source.CardDecline.AdditionalAmounts

  • All Implemented Interfaces:

    
    public final class DeclinedTransaction.Source.CardDecline.AdditionalAmounts
    
                        

    Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.