Class DeclinedTransaction.Source.CardDecline.NetworkDetails
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CardDecline.NetworkDetailsFields specific to the
network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.CardDecline.NetworkDetails.BuilderA builder for NetworkDetails.
public final classDeclinedTransaction.Source.CardDecline.NetworkDetails.CategoryThe payment network used to process this card authorization.
public final classDeclinedTransaction.Source.CardDecline.NetworkDetails.PulseFields specific to the
pulsenetwork.public final classDeclinedTransaction.Source.CardDecline.NetworkDetails.VisaFields specific to the
visanetwork.
-
Method Summary
-
-
Method Detail
-
category
final DeclinedTransaction.Source.CardDecline.NetworkDetails.Category category()
The payment network used to process this card authorization.
-
pulse
final Optional<DeclinedTransaction.Source.CardDecline.NetworkDetails.Pulse> pulse()
Fields specific to the
pulsenetwork.
-
visa
final Optional<DeclinedTransaction.Source.CardDecline.NetworkDetails.Visa> visa()
Fields specific to the
visanetwork.
-
_category
final JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_pulse
final JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails.Pulse> _pulse()
Returns the raw JSON value of pulse.
Unlike pulse, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<DeclinedTransaction.Source.CardDecline.NetworkDetails.Visa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.CardDecline.NetworkDetails.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.CardDecline.NetworkDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DeclinedTransaction.Source.CardDecline.NetworkDetails.Builder builder()
Returns a mutable builder for constructing an instance of NetworkDetails.
The following fields are required:
.category() .pulse() .visa()
-
-
-
-