Class DeclinedTransaction.Source.CardDecline.ProcessingCategory

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class DeclinedTransaction.Source.CardDecline.ProcessingCategory
     implements Enum
                        

    The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.