Enum DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value extends Enum<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value>
An enum containing RealTimeDecisionReason's known values, as well as an _UNKNOWN member.
An instance of RealTimeDecisionReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description INSUFFICIENT_FUNDSThe cardholder does not have sufficient funds to cover the transaction. The merchant may attempt to process the transaction again.
TRANSACTION_NEVER_ALLOWEDThis type of transaction is not allowed for this card. This transaction should not be retried.
EXCEEDS_APPROVAL_LIMITThe transaction amount exceeds the cardholder's approval limit. The merchant may attempt to process the transaction again.
CARD_TEMPORARILY_DISABLEDThe card has been temporarily disabled or not yet activated. The merchant may attempt to process the transaction again.
SUSPECTED_FRAUDThe transaction is suspected to be fraudulent. The merchant may attempt to process the transaction again.
OTHERThe transaction was declined for another reason. The merchant may attempt to process the transaction again. This should be used sparingly.
_UNKNOWNAn enum member indicating that RealTimeDecisionReason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value>getEntries()An enum containing RealTimeDecisionReason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.CardDecline.RealTimeDecisionReason.Value> getEntries()
An enum containing RealTimeDecisionReason's known values, as well as an _UNKNOWN member.
An instance of RealTimeDecisionReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-