Enum DeclinedTransaction.Source.CardDecline.Reason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.CardDecline.Reason.Value extends Enum<DeclinedTransaction.Source.CardDecline.Reason.Value>
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.CardDecline.Reason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_CLOSEDThe account has been closed.
CARD_NOT_ACTIVEThe Card was not active.
CARD_CANCELEDThe Card has been canceled.
PHYSICAL_CARD_NOT_ACTIVEThe Physical Card was not active.
ENTITY_NOT_ACTIVEThe account's entity was not active.
GROUP_LOCKEDThe account was inactive.
INSUFFICIENT_FUNDSThe Card's Account did not have a sufficient available balance.
CVV2_MISMATCHThe given CVV2 did not match the card's value.
PIN_MISMATCHThe given PIN did not match the card's value.
CARD_EXPIRATION_MISMATCHThe given expiration date did not match the card's value. Only applies when a CVV2 is present.
TRANSACTION_NOT_ALLOWEDThe attempted card transaction is not allowed per Increase's terms.
BREACHES_LIMITThe transaction was blocked by a Limit.
WEBHOOK_DECLINEDYour application declined the transaction via webhook.
WEBHOOK_TIMED_OUTYour application webhook did not respond without the required timeout.
DECLINED_BY_STAND_IN_PROCESSINGDeclined by stand-in processing.
INVALID_PHYSICAL_CARDThe card read had an invalid CVV or dCVV.
MISSING_ORIGINAL_AUTHORIZATIONThe original card authorization for this incremental authorization does not exist.
INVALID_CRYPTOGRAMThe card's authorization request cryptogram was invalid. The cryptogram can be from a physical card or a Digital Wallet Token purchase.
FAILED_3DS_AUTHENTICATIONThe transaction was declined because the 3DS authentication failed.
SUSPECTED_CARD_TESTINGThe transaction was suspected to be used by a card tester to test for valid card numbers.
SUSPECTED_FRAUDThe transaction was suspected to be fraudulent. Please reach out to [email protected] for more information.
_UNKNOWNAn enum member indicating that Reason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.CardDecline.Reason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.CardDecline.Reason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.CardDecline.Reason.Value>getEntries()An enum containing Reason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.CardDecline.Reason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.CardDecline.Reason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.CardDecline.Reason.Value> getEntries()
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-