Enum DeclinedTransaction.Source.Category.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.Category.Value extends Enum<DeclinedTransaction.Source.Category.Value>
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.Category.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACH_DECLINEACH Decline: details will be under the
ach_declineobject.CARD_DECLINECard Decline: details will be under the
card_declineobject.CHECK_DECLINECheck Decline: details will be under the
check_declineobject.INBOUND_REAL_TIME_PAYMENTS_TRANSFER_DECLINEInbound Real-Time Payments Transfer Decline: details will be under the
inbound_real_time_payments_transfer_declineobject.INBOUND_FEDNOW_TRANSFER_DECLINEInbound FedNow Transfer Decline: details will be under the
inbound_fednow_transfer_declineobject.WIRE_DECLINEWire Decline: details will be under the
wire_declineobject.CHECK_DEPOSIT_REJECTIONCheck Deposit Rejection: details will be under the
check_deposit_rejectionobject.OTHERThe Declined Transaction was made for an undocumented or deprecated reason.
_UNKNOWNAn enum member indicating that Category was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.Category.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.Category.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.Category.Value>getEntries()An enum containing Category's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.Category.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.Category.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.Category.Value> getEntries()
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-