Class DeclinedTransaction.Source.CheckDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDeclineA Check Decline object. This field will be present in the JSON response if and only if
categoryis equal tocheck_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.CheckDecline.BuilderA builder for CheckDecline.
public final classDeclinedTransaction.Source.CheckDecline.ReasonWhy the check was declined.
-
Method Summary
Modifier and Type Method Description final Longamount()The declined amount in USD cents. final Optional<String>auxiliaryOnUs()A computer-readable number printed on the MICR line of business checks, usually the check number. final Optional<String>backImageFileId()The identifier of the API File object containing an image of the back of the declined check. final Optional<String>checkTransferId()The identifier of the Check Transfer object associated with this decline. final Optional<String>frontImageFileId()The identifier of the API File object containing an image of the front of the declined check. final Optional<String>inboundCheckDepositId()The identifier of the Inbound Check Deposit object associated with this decline. final DeclinedTransaction.Source.CheckDecline.Reasonreason()Why the check was declined. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_auxiliaryOnUs()Returns the raw JSON value of auxiliaryOnUs. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_checkTransferId()Returns the raw JSON value of checkTransferId. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_inboundCheckDepositId()Returns the raw JSON value of inboundCheckDepositId. final JsonField<DeclinedTransaction.Source.CheckDecline.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.CheckDecline.BuildertoBuilder()final DeclinedTransaction.Source.CheckDeclinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.CheckDecline.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDecline. -
-
Method Detail
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the API File object containing an image of the back of the declined check.
-
checkTransferId
final Optional<String> checkTransferId()
The identifier of the Check Transfer object associated with this decline.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the API File object containing an image of the front of the declined check.
-
inboundCheckDepositId
final Optional<String> inboundCheckDepositId()
The identifier of the Inbound Check Deposit object associated with this decline.
-
reason
final DeclinedTransaction.Source.CheckDecline.Reason reason()
Why the check was declined.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
Returns the raw JSON value of auxiliaryOnUs.
Unlike auxiliaryOnUs, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_checkTransferId
final JsonField<String> _checkTransferId()
Returns the raw JSON value of checkTransferId.
Unlike checkTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundCheckDepositId
final JsonField<String> _inboundCheckDepositId()
Returns the raw JSON value of inboundCheckDepositId.
Unlike inboundCheckDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DeclinedTransaction.Source.CheckDecline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.CheckDecline.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.CheckDecline validate()
-
builder
final static DeclinedTransaction.Source.CheckDecline.Builder builder()
Returns a mutable builder for constructing an instance of CheckDecline.
The following fields are required:
.amount() .auxiliaryOnUs() .backImageFileId() .checkTransferId() .frontImageFileId() .inboundCheckDepositId() .reason()
-
-
-
-