Class DeclinedTransaction.Source.CheckDecline.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDecline.BuilderA builder for CheckDecline.
-
-
Method Summary
-
-
Method Detail
-
amount
final DeclinedTransaction.Source.CheckDecline.Builder amount(Long amount)
The declined amount in USD cents.
-
amount
final DeclinedTransaction.Source.CheckDecline.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
auxiliaryOnUs
final DeclinedTransaction.Source.CheckDecline.Builder auxiliaryOnUs(String auxiliaryOnUs)
A computer-readable number printed on the MICR line of business checks, usually the check number. This is useful for positive pay checks, but can be unreliably transmitted by the bank of first deposit.
-
auxiliaryOnUs
final DeclinedTransaction.Source.CheckDecline.Builder auxiliaryOnUs(Optional<String> auxiliaryOnUs)
Alias for calling Builder.auxiliaryOnUs with
auxiliaryOnUs.orElse(null).
-
auxiliaryOnUs
final DeclinedTransaction.Source.CheckDecline.Builder auxiliaryOnUs(JsonField<String> auxiliaryOnUs)
Sets Builder.auxiliaryOnUs to an arbitrary JSON value.
You should usually call Builder.auxiliaryOnUs with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder backImageFileId(String backImageFileId)
The identifier of the API File object containing an image of the back of the declined check.
-
backImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder backImageFileId(Optional<String> backImageFileId)
Alias for calling Builder.backImageFileId with
backImageFileId.orElse(null).
-
backImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkTransferId
final DeclinedTransaction.Source.CheckDecline.Builder checkTransferId(String checkTransferId)
The identifier of the Check Transfer object associated with this decline.
-
checkTransferId
final DeclinedTransaction.Source.CheckDecline.Builder checkTransferId(Optional<String> checkTransferId)
Alias for calling Builder.checkTransferId with
checkTransferId.orElse(null).
-
checkTransferId
final DeclinedTransaction.Source.CheckDecline.Builder checkTransferId(JsonField<String> checkTransferId)
Sets Builder.checkTransferId to an arbitrary JSON value.
You should usually call Builder.checkTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder frontImageFileId(String frontImageFileId)
The identifier of the API File object containing an image of the front of the declined check.
-
frontImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder frontImageFileId(Optional<String> frontImageFileId)
Alias for calling Builder.frontImageFileId with
frontImageFileId.orElse(null).
-
frontImageFileId
final DeclinedTransaction.Source.CheckDecline.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundCheckDepositId
final DeclinedTransaction.Source.CheckDecline.Builder inboundCheckDepositId(String inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this decline.
-
inboundCheckDepositId
final DeclinedTransaction.Source.CheckDecline.Builder inboundCheckDepositId(Optional<String> inboundCheckDepositId)
Alias for calling Builder.inboundCheckDepositId with
inboundCheckDepositId.orElse(null).
-
inboundCheckDepositId
final DeclinedTransaction.Source.CheckDecline.Builder inboundCheckDepositId(JsonField<String> inboundCheckDepositId)
Sets Builder.inboundCheckDepositId to an arbitrary JSON value.
You should usually call Builder.inboundCheckDepositId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final DeclinedTransaction.Source.CheckDecline.Builder reason(DeclinedTransaction.Source.CheckDecline.Reason reason)
Why the check was declined.
-
reason
final DeclinedTransaction.Source.CheckDecline.Builder reason(JsonField<DeclinedTransaction.Source.CheckDecline.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DeclinedTransaction.Source.CheckDecline.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.CheckDecline.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.CheckDecline.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.CheckDecline.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.CheckDecline.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source.CheckDecline build()
Returns an immutable instance of CheckDecline.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .auxiliaryOnUs() .backImageFileId() .checkTransferId() .frontImageFileId() .inboundCheckDepositId() .reason()
-
-
-
-