Enum DeclinedTransaction.Source.CheckDecline.Reason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.CheckDecline.Reason.Value extends Enum<DeclinedTransaction.Source.CheckDecline.Reason.Value>
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.CheckDecline.Reason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACH_ROUTE_DISABLEDThe account number is disabled.
ACH_ROUTE_CANCELEDThe account number is canceled.
ALTERED_OR_FICTITIOUSThe deposited check was altered or fictitious.
BREACHES_LIMITThe transaction would cause a limit to be exceeded.
ENDORSEMENT_IRREGULARThe check was not endorsed by the payee.
ENTITY_NOT_ACTIVEThe account's entity is not active.
GROUP_LOCKEDYour account is inactive.
INSUFFICIENT_FUNDSYour account contains insufficient funds.
STOP_PAYMENT_REQUESTEDStop payment requested for this check.
DUPLICATE_PRESENTMENTThe check was a duplicate deposit.
NOT_AUTHORIZEDThe check was not authorized.
AMOUNT_MISMATCHThe amount the receiving bank is attempting to deposit does not match the amount on the check.
NOT_OUR_ITEMThe check attempting to be deposited does not belong to Increase.
NO_ACCOUNT_NUMBER_FOUNDThe account number on the check does not exist at Increase.
REFER_TO_IMAGEThe check is not readable. Please refer to the image.
UNABLE_TO_PROCESSThe check cannot be processed. This is rare: please contact support.
UNUSABLE_IMAGEThe check image is unusable.
USER_INITIATEDYour integration declined this check via the API.
_UNKNOWNAn enum member indicating that Reason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.CheckDecline.Reason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.CheckDecline.Reason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.CheckDecline.Reason.Value>getEntries()An enum containing Reason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.CheckDecline.Reason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.CheckDecline.Reason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.CheckDecline.Reason.Value> getEntries()
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-