Class DeclinedTransaction.Source.CheckDepositRejection.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDepositRejection.BuilderA builder for CheckDepositRejection.
-
-
Method Summary
-
-
Method Detail
-
amount
final DeclinedTransaction.Source.CheckDepositRejection.Builder amount(Long amount)
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
amount
final DeclinedTransaction.Source.CheckDepositRejection.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositId
final DeclinedTransaction.Source.CheckDepositRejection.Builder checkDepositId(String checkDepositId)
The identifier of the Check Deposit that was rejected.
-
checkDepositId
final DeclinedTransaction.Source.CheckDepositRejection.Builder checkDepositId(JsonField<String> checkDepositId)
Sets Builder.checkDepositId to an arbitrary JSON value.
You should usually call Builder.checkDepositId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final DeclinedTransaction.Source.CheckDepositRejection.Builder currency(DeclinedTransaction.Source.CheckDepositRejection.Currency currency)
The ISO 4217 code for the check's currency.
-
currency
final DeclinedTransaction.Source.CheckDepositRejection.Builder currency(JsonField<DeclinedTransaction.Source.CheckDepositRejection.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declinedTransactionId
final DeclinedTransaction.Source.CheckDepositRejection.Builder declinedTransactionId(String declinedTransactionId)
The identifier of the associated declined transaction.
-
declinedTransactionId
final DeclinedTransaction.Source.CheckDepositRejection.Builder declinedTransactionId(JsonField<String> declinedTransactionId)
Sets Builder.declinedTransactionId to an arbitrary JSON value.
You should usually call Builder.declinedTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final DeclinedTransaction.Source.CheckDepositRejection.Builder reason(DeclinedTransaction.Source.CheckDepositRejection.Reason reason)
Why the check deposit was rejected.
-
reason
final DeclinedTransaction.Source.CheckDepositRejection.Builder reason(JsonField<DeclinedTransaction.Source.CheckDepositRejection.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rejectedAt
final DeclinedTransaction.Source.CheckDepositRejection.Builder rejectedAt(OffsetDateTime rejectedAt)
The ISO 8601 date and time at which the check deposit was rejected.
-
rejectedAt
final DeclinedTransaction.Source.CheckDepositRejection.Builder rejectedAt(JsonField<OffsetDateTime> rejectedAt)
Sets Builder.rejectedAt to an arbitrary JSON value.
You should usually call Builder.rejectedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DeclinedTransaction.Source.CheckDepositRejection.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DeclinedTransaction.Source.CheckDepositRejection.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DeclinedTransaction.Source.CheckDepositRejection.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DeclinedTransaction.Source.CheckDepositRejection.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DeclinedTransaction.Source.CheckDepositRejection.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DeclinedTransaction.Source.CheckDepositRejection build()
Returns an immutable instance of CheckDepositRejection.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .checkDepositId() .currency() .declinedTransactionId() .reason() .rejectedAt()
-
-
-
-