Enum DeclinedTransaction.Source.CheckDepositRejection.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.CheckDepositRejection.Reason.Known extends Enum<DeclinedTransaction.Source.CheckDepositRejection.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.CheckDepositRejection.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description INCOMPLETE_IMAGEThe check's image is incomplete.
DUPLICATEThis is a duplicate check submission.
POOR_IMAGE_QUALITYThis check has poor image quality.
INCORRECT_AMOUNTThe check was deposited with the incorrect amount.
INCORRECT_RECIPIENTThe check is made out to someone other than the account holder.
NOT_ELIGIBLE_FOR_MOBILE_DEPOSITThis check was not eligible for mobile deposit.
MISSING_REQUIRED_DATA_ELEMENTSThis check is missing at least one required field.
SUSPECTED_FRAUDThis check is suspected to be fraudulent.
DEPOSIT_WINDOW_EXPIREDThis check's deposit window has expired.
REQUESTED_BY_USERThe check was rejected at the user's request.
INTERNATIONALThe check is not a U.S. domestic check and cannot be processed.
UNKNOWNThe check was rejected for an unknown reason.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.CheckDepositRejection.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.CheckDepositRejection.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.CheckDepositRejection.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.CheckDepositRejection.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.CheckDepositRejection.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.CheckDepositRejection.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-