Class DeclinedTransaction.Source.InboundFednowTransferDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.InboundFednowTransferDeclineAn Inbound FedNow Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.InboundFednowTransferDecline.BuilderA builder for InboundFednowTransferDecline.
public final classDeclinedTransaction.Source.InboundFednowTransferDecline.ReasonWhy the transfer was declined.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.InboundFednowTransferDecline.Reasonreason()Why the transfer was declined. final StringtransferId()The identifier of the FedNow Transfer that led to this declined transaction. final JsonField<DeclinedTransaction.Source.InboundFednowTransferDecline.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.InboundFednowTransferDecline.BuildertoBuilder()final DeclinedTransaction.Source.InboundFednowTransferDeclinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.InboundFednowTransferDecline.Builderbuilder()Returns a mutable builder for constructing an instance of InboundFednowTransferDecline. -
-
Method Detail
-
reason
final DeclinedTransaction.Source.InboundFednowTransferDecline.Reason reason()
Why the transfer was declined.
-
transferId
final String transferId()
The identifier of the FedNow Transfer that led to this declined transaction.
-
_reason
final JsonField<DeclinedTransaction.Source.InboundFednowTransferDecline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.InboundFednowTransferDecline.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.InboundFednowTransferDecline validate()
-
builder
final static DeclinedTransaction.Source.InboundFednowTransferDecline.Builder builder()
Returns a mutable builder for constructing an instance of InboundFednowTransferDecline.
The following fields are required:
.reason() .transferId()
-
-
-
-