Class DeclinedTransaction.Source.WireDecline
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.WireDeclineA Wire Decline object. This field will be present in the JSON response if and only if
categoryis equal towire_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.WireDecline.BuilderA builder for WireDecline.
public final classDeclinedTransaction.Source.WireDecline.ReasonWhy the wire transfer was declined.
-
Method Summary
Modifier and Type Method Description final StringinboundWireTransferId()The identifier of the Inbound Wire Transfer that was declined. final DeclinedTransaction.Source.WireDecline.Reasonreason()Why the wire transfer was declined. final JsonField<String>_inboundWireTransferId()Returns the raw JSON value of inboundWireTransferId. final JsonField<DeclinedTransaction.Source.WireDecline.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final DeclinedTransaction.Source.WireDecline.BuildertoBuilder()final DeclinedTransaction.Source.WireDeclinevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransaction.Source.WireDecline.Builderbuilder()Returns a mutable builder for constructing an instance of WireDecline. -
-
Method Detail
-
inboundWireTransferId
final String inboundWireTransferId()
The identifier of the Inbound Wire Transfer that was declined.
-
reason
final DeclinedTransaction.Source.WireDecline.Reason reason()
Why the wire transfer was declined.
-
_inboundWireTransferId
final JsonField<String> _inboundWireTransferId()
Returns the raw JSON value of inboundWireTransferId.
Unlike inboundWireTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DeclinedTransaction.Source.WireDecline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.WireDecline.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.WireDecline validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DeclinedTransaction.Source.WireDecline.Builder builder()
Returns a mutable builder for constructing an instance of WireDecline.
The following fields are required:
.inboundWireTransferId() .reason()
-
-
-
-