Enum DeclinedTransaction.Source.WireDecline.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DeclinedTransaction.Source.WireDecline.Reason.Known extends Enum<DeclinedTransaction.Source.WireDecline.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DeclinedTransaction.Source.WireDecline.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_NUMBER_CANCELEDThe account number is canceled.
ACCOUNT_NUMBER_DISABLEDThe account number is disabled.
ENTITY_NOT_ACTIVEThe account's entity is not active.
GROUP_LOCKEDYour account is inactive.
NO_ACCOUNT_NUMBERThe beneficiary account number does not exist.
TRANSACTION_NOT_ALLOWEDThe transaction is not allowed per Increase's terms.
-
Method Summary
Modifier and Type Method Description final DeclinedTransaction.Source.WireDecline.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DeclinedTransaction.Source.WireDecline.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DeclinedTransaction.Source.WireDecline.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final DeclinedTransaction.Source.WireDecline.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DeclinedTransaction.Source.WireDecline.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DeclinedTransaction.Source.WireDecline.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-