Class DeclinedTransactionListPage.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransactionListPage.BuilderA builder for DeclinedTransactionListPage.
-
-
Method Summary
Modifier and Type Method Description final DeclinedTransactionListPage.Builderservice(DeclinedTransactionService service)final DeclinedTransactionListPage.Builderparams(DeclinedTransactionListParams params)The parameters that were used to request this page. final DeclinedTransactionListPage.Builderresponse(DeclinedTransactionListPageResponse response)The response that this page was parsed from. final DeclinedTransactionListPagebuild()Returns an immutable instance of DeclinedTransactionListPage. -
-
Method Detail
-
service
final DeclinedTransactionListPage.Builder service(DeclinedTransactionService service)
-
params
final DeclinedTransactionListPage.Builder params(DeclinedTransactionListParams params)
The parameters that were used to request this page.
-
response
final DeclinedTransactionListPage.Builder response(DeclinedTransactionListPageResponse response)
The response that this page was parsed from.
-
build
final DeclinedTransactionListPage build()
Returns an immutable instance of DeclinedTransactionListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-