Class DeclinedTransactionListPageAsync
-
- All Implemented Interfaces:
public final class DeclinedTransactionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransactionListPageAsync.BuilderA builder for DeclinedTransactionListPageAsync.
public final classDeclinedTransactionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<DeclinedTransaction>data()Delegates to DeclinedTransactionListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DeclinedTransactionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<DeclinedTransactionListParams>getNextPageParams()final CompletableFuture<Optional<DeclinedTransactionListPageAsync>>getNextPage()final DeclinedTransactionListPageAsync.AutoPagerautoPager()final DeclinedTransactionListParamsparams()The parameters that were used to request this page. final DeclinedTransactionListPageResponseresponse()The response that this page was parsed from. final DeclinedTransactionListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DeclinedTransactionListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of DeclinedTransactionListPageAsync. -
-
Method Detail
-
data
final List<DeclinedTransaction> data()
Delegates to DeclinedTransactionListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DeclinedTransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<DeclinedTransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<DeclinedTransactionListPageAsync>> getNextPage()
-
autoPager
final DeclinedTransactionListPageAsync.AutoPager autoPager()
-
params
final DeclinedTransactionListParams params()
The parameters that were used to request this page.
-
response
final DeclinedTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DeclinedTransactionListPageAsync.Builder toBuilder()
-
builder
final static DeclinedTransactionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of DeclinedTransactionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-