Class DeclinedTransactionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class DeclinedTransactionListPageAsync.BuilderA builder for DeclinedTransactionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final DeclinedTransactionListPageAsync.Builderservice(DeclinedTransactionServiceAsync service)final DeclinedTransactionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final DeclinedTransactionListPageAsync.Builderparams(DeclinedTransactionListParams params)The parameters that were used to request this page. final DeclinedTransactionListPageAsync.Builderresponse(DeclinedTransactionListPageResponse response)The response that this page was parsed from. final DeclinedTransactionListPageAsyncbuild()Returns an immutable instance of DeclinedTransactionListPageAsync. -
-
Method Detail
-
service
final DeclinedTransactionListPageAsync.Builder service(DeclinedTransactionServiceAsync service)
-
streamHandlerExecutor
final DeclinedTransactionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final DeclinedTransactionListPageAsync.Builder params(DeclinedTransactionListParams params)
The parameters that were used to request this page.
-
response
final DeclinedTransactionListPageAsync.Builder response(DeclinedTransactionListPageResponse response)
The response that this page was parsed from.
-
build
final DeclinedTransactionListPageAsync build()
Returns an immutable instance of DeclinedTransactionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-