Class DigitalCardProfile
-
- All Implemented Interfaces:
public final class DigitalCardProfileThis contains artwork and metadata relating to a Card's appearance in digital wallet apps like Apple Pay and Google Pay. For more information, see our guide on digital card artwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfile.BuilderA builder for DigitalCardProfile.
public final classDigitalCardProfile.StatusThe status of the Card Profile.
public final classDigitalCardProfile.TextColorThe Card's text color, specified as an RGB triple.
public final classDigitalCardProfile.TypeA constant representing the object's type. For this resource it will always be
digital_card_profile.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Profile identifier. final StringappIconFileId()The identifier of the File containing the card's icon image. final StringbackgroundImageFileId()The identifier of the File containing the card's front image. final StringcardDescription()A user-facing description for the card itself. final Optional<String>contactEmail()An email address the user can contact to receive support for their card. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>contactWebsite()A website the user can visit to view and receive support for their card. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Digital Card Profile was created. final Stringdescription()A description you can use to identify the Card Profile. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringissuerName()A user-facing description for whoever is issuing the card. final DigitalCardProfile.Statusstatus()The status of the Card Profile. final DigitalCardProfile.TextColortextColor()The Card's text color, specified as an RGB triple. final DigitalCardProfile.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_appIconFileId()Returns the raw JSON value of appIconFileId. final JsonField<String>_backgroundImageFileId()Returns the raw JSON value of backgroundImageFileId. final JsonField<String>_cardDescription()Returns the raw JSON value of cardDescription. final JsonField<String>_contactEmail()Returns the raw JSON value of contactEmail. final JsonField<String>_contactPhone()Returns the raw JSON value of contactPhone. final JsonField<String>_contactWebsite()Returns the raw JSON value of contactWebsite. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_issuerName()Returns the raw JSON value of issuerName. final JsonField<DigitalCardProfile.Status>_status()Returns the raw JSON value of status. final JsonField<DigitalCardProfile.TextColor>_textColor()Returns the raw JSON value of textColor. final JsonField<DigitalCardProfile.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final DigitalCardProfile.BuildertoBuilder()final DigitalCardProfilevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfile.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalCardProfile. -
-
Method Detail
-
appIconFileId
final String appIconFileId()
The identifier of the File containing the card's icon image.
-
backgroundImageFileId
final String backgroundImageFileId()
The identifier of the File containing the card's front image.
-
cardDescription
final String cardDescription()
A user-facing description for the card itself.
-
contactEmail
final Optional<String> contactEmail()
An email address the user can contact to receive support for their card.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
contactWebsite
final Optional<String> contactWebsite()
A website the user can visit to view and receive support for their card.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Digital Card Profile was created.
-
description
final String description()
A description you can use to identify the Card Profile.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
issuerName
final String issuerName()
A user-facing description for whoever is issuing the card.
-
status
final DigitalCardProfile.Status status()
The status of the Card Profile.
-
textColor
final DigitalCardProfile.TextColor textColor()
The Card's text color, specified as an RGB triple.
-
type
final DigitalCardProfile.Type type()
A constant representing the object's type. For this resource it will always be
digital_card_profile.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_appIconFileId
final JsonField<String> _appIconFileId()
Returns the raw JSON value of appIconFileId.
Unlike appIconFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_backgroundImageFileId
final JsonField<String> _backgroundImageFileId()
Returns the raw JSON value of backgroundImageFileId.
Unlike backgroundImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDescription
final JsonField<String> _cardDescription()
Returns the raw JSON value of cardDescription.
Unlike cardDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_contactEmail
final JsonField<String> _contactEmail()
Returns the raw JSON value of contactEmail.
Unlike contactEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_contactPhone
final JsonField<String> _contactPhone()
Returns the raw JSON value of contactPhone.
Unlike contactPhone, this method doesn't throw if the JSON field has an unexpected type.
-
_contactWebsite
final JsonField<String> _contactWebsite()
Returns the raw JSON value of contactWebsite.
Unlike contactWebsite, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_issuerName
final JsonField<String> _issuerName()
Returns the raw JSON value of issuerName.
Unlike issuerName, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<DigitalCardProfile.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_textColor
final JsonField<DigitalCardProfile.TextColor> _textColor()
Returns the raw JSON value of textColor.
Unlike textColor, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DigitalCardProfile.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalCardProfile.Builder toBuilder()
-
validate
final DigitalCardProfile validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DigitalCardProfile.Builder builder()
Returns a mutable builder for constructing an instance of DigitalCardProfile.
The following fields are required:
.id() .appIconFileId() .backgroundImageFileId() .cardDescription() .contactEmail() .contactPhone() .contactWebsite() .createdAt() .description() .idempotencyKey() .issuerName() .status() .textColor() .type()
-
-
-
-