Class DigitalCardProfile.Builder
-
- All Implemented Interfaces:
public final class DigitalCardProfile.BuilderA builder for DigitalCardProfile.
-
-
Method Summary
Modifier and Type Method Description final DigitalCardProfile.Builderid(String id)The Card Profile identifier. final DigitalCardProfile.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final DigitalCardProfile.BuilderappIconFileId(String appIconFileId)The identifier of the File containing the card's icon image. final DigitalCardProfile.BuilderappIconFileId(JsonField<String> appIconFileId)Sets Builder.appIconFileId to an arbitrary JSON value. final DigitalCardProfile.BuilderbackgroundImageFileId(String backgroundImageFileId)The identifier of the File containing the card's front image. final DigitalCardProfile.BuilderbackgroundImageFileId(JsonField<String> backgroundImageFileId)Sets Builder.backgroundImageFileId to an arbitrary JSON value. final DigitalCardProfile.BuildercardDescription(String cardDescription)A user-facing description for the card itself. final DigitalCardProfile.BuildercardDescription(JsonField<String> cardDescription)Sets Builder.cardDescription to an arbitrary JSON value. final DigitalCardProfile.BuildercontactEmail(String contactEmail)An email address the user can contact to receive support for their card. final DigitalCardProfile.BuildercontactEmail(Optional<String> contactEmail)Alias for calling Builder.contactEmail with contactEmail.orElse(null).final DigitalCardProfile.BuildercontactEmail(JsonField<String> contactEmail)Sets Builder.contactEmail to an arbitrary JSON value. final DigitalCardProfile.BuildercontactPhone(String contactPhone)A phone number the user can contact to receive support for their card. final DigitalCardProfile.BuildercontactPhone(Optional<String> contactPhone)Alias for calling Builder.contactPhone with contactPhone.orElse(null).final DigitalCardProfile.BuildercontactPhone(JsonField<String> contactPhone)Sets Builder.contactPhone to an arbitrary JSON value. final DigitalCardProfile.BuildercontactWebsite(String contactWebsite)A website the user can visit to view and receive support for their card. final DigitalCardProfile.BuildercontactWebsite(Optional<String> contactWebsite)Alias for calling Builder.contactWebsite with contactWebsite.orElse(null).final DigitalCardProfile.BuildercontactWebsite(JsonField<String> contactWebsite)Sets Builder.contactWebsite to an arbitrary JSON value. final DigitalCardProfile.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the Digital Card Profile was created. final DigitalCardProfile.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final DigitalCardProfile.Builderdescription(String description)A description you can use to identify the Card Profile. final DigitalCardProfile.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final DigitalCardProfile.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final DigitalCardProfile.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final DigitalCardProfile.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final DigitalCardProfile.BuilderissuerName(String issuerName)A user-facing description for whoever is issuing the card. final DigitalCardProfile.BuilderissuerName(JsonField<String> issuerName)Sets Builder.issuerName to an arbitrary JSON value. final DigitalCardProfile.Builderstatus(DigitalCardProfile.Status status)The status of the Card Profile. final DigitalCardProfile.Builderstatus(JsonField<DigitalCardProfile.Status> status)Sets Builder.status to an arbitrary JSON value. final DigitalCardProfile.BuildertextColor(DigitalCardProfile.TextColor textColor)The Card's text color, specified as an RGB triple. final DigitalCardProfile.BuildertextColor(JsonField<DigitalCardProfile.TextColor> textColor)Sets Builder.textColor to an arbitrary JSON value. final DigitalCardProfile.Buildertype(DigitalCardProfile.Type type)A constant representing the object's type. final DigitalCardProfile.Buildertype(JsonField<DigitalCardProfile.Type> type)Sets Builder.type to an arbitrary JSON value. final DigitalCardProfile.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final DigitalCardProfile.BuilderputAdditionalProperty(String key, JsonValue value)final DigitalCardProfile.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final DigitalCardProfile.BuilderremoveAdditionalProperty(String key)final DigitalCardProfile.BuilderremoveAllAdditionalProperties(Set<String> keys)final DigitalCardProfilebuild()Returns an immutable instance of DigitalCardProfile. -
-
Method Detail
-
id
final DigitalCardProfile.Builder id(String id)
The Card Profile identifier.
-
id
final DigitalCardProfile.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
appIconFileId
final DigitalCardProfile.Builder appIconFileId(String appIconFileId)
The identifier of the File containing the card's icon image.
-
appIconFileId
final DigitalCardProfile.Builder appIconFileId(JsonField<String> appIconFileId)
Sets Builder.appIconFileId to an arbitrary JSON value.
You should usually call Builder.appIconFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backgroundImageFileId
final DigitalCardProfile.Builder backgroundImageFileId(String backgroundImageFileId)
The identifier of the File containing the card's front image.
-
backgroundImageFileId
final DigitalCardProfile.Builder backgroundImageFileId(JsonField<String> backgroundImageFileId)
Sets Builder.backgroundImageFileId to an arbitrary JSON value.
You should usually call Builder.backgroundImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDescription
final DigitalCardProfile.Builder cardDescription(String cardDescription)
A user-facing description for the card itself.
-
cardDescription
final DigitalCardProfile.Builder cardDescription(JsonField<String> cardDescription)
Sets Builder.cardDescription to an arbitrary JSON value.
You should usually call Builder.cardDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactEmail
final DigitalCardProfile.Builder contactEmail(String contactEmail)
An email address the user can contact to receive support for their card.
-
contactEmail
final DigitalCardProfile.Builder contactEmail(Optional<String> contactEmail)
Alias for calling Builder.contactEmail with
contactEmail.orElse(null).
-
contactEmail
final DigitalCardProfile.Builder contactEmail(JsonField<String> contactEmail)
Sets Builder.contactEmail to an arbitrary JSON value.
You should usually call Builder.contactEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactPhone
final DigitalCardProfile.Builder contactPhone(String contactPhone)
A phone number the user can contact to receive support for their card.
-
contactPhone
final DigitalCardProfile.Builder contactPhone(Optional<String> contactPhone)
Alias for calling Builder.contactPhone with
contactPhone.orElse(null).
-
contactPhone
final DigitalCardProfile.Builder contactPhone(JsonField<String> contactPhone)
Sets Builder.contactPhone to an arbitrary JSON value.
You should usually call Builder.contactPhone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactWebsite
final DigitalCardProfile.Builder contactWebsite(String contactWebsite)
A website the user can visit to view and receive support for their card.
-
contactWebsite
final DigitalCardProfile.Builder contactWebsite(Optional<String> contactWebsite)
Alias for calling Builder.contactWebsite with
contactWebsite.orElse(null).
-
contactWebsite
final DigitalCardProfile.Builder contactWebsite(JsonField<String> contactWebsite)
Sets Builder.contactWebsite to an arbitrary JSON value.
You should usually call Builder.contactWebsite with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final DigitalCardProfile.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Digital Card Profile was created.
-
createdAt
final DigitalCardProfile.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final DigitalCardProfile.Builder description(String description)
A description you can use to identify the Card Profile.
-
description
final DigitalCardProfile.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final DigitalCardProfile.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final DigitalCardProfile.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final DigitalCardProfile.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
issuerName
final DigitalCardProfile.Builder issuerName(String issuerName)
A user-facing description for whoever is issuing the card.
-
issuerName
final DigitalCardProfile.Builder issuerName(JsonField<String> issuerName)
Sets Builder.issuerName to an arbitrary JSON value.
You should usually call Builder.issuerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final DigitalCardProfile.Builder status(DigitalCardProfile.Status status)
The status of the Card Profile.
-
status
final DigitalCardProfile.Builder status(JsonField<DigitalCardProfile.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
textColor
final DigitalCardProfile.Builder textColor(DigitalCardProfile.TextColor textColor)
The Card's text color, specified as an RGB triple.
-
textColor
final DigitalCardProfile.Builder textColor(JsonField<DigitalCardProfile.TextColor> textColor)
Sets Builder.textColor to an arbitrary JSON value.
You should usually call Builder.textColor with a well-typed TextColor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final DigitalCardProfile.Builder type(DigitalCardProfile.Type type)
A constant representing the object's type. For this resource it will always be
digital_card_profile.
-
type
final DigitalCardProfile.Builder type(JsonField<DigitalCardProfile.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalCardProfile.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalCardProfile.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalCardProfile.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalCardProfile.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalCardProfile.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalCardProfile build()
Returns an immutable instance of DigitalCardProfile.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .appIconFileId() .backgroundImageFileId() .cardDescription() .contactEmail() .contactPhone() .contactWebsite() .createdAt() .description() .idempotencyKey() .issuerName() .status() .textColor() .type()
-
-
-
-