Enum DigitalCardProfile.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum DigitalCardProfile.Status.Known extends Enum<DigitalCardProfile.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<DigitalCardProfile.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDINGThe Card Profile is awaiting review from Increase and/or processing by card networks.
REJECTEDThere is an issue with the Card Profile preventing it from use.
ACTIVEThe Card Profile can be assigned to Cards.
ARCHIVEDThe Card Profile is no longer in use.
-
Method Summary
Modifier and Type Method Description final DigitalCardProfile.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<DigitalCardProfile.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<DigitalCardProfile.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final DigitalCardProfile.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<DigitalCardProfile.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<DigitalCardProfile.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-