Enum DigitalCardProfile.Status.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum DigitalCardProfile.Status.Value
    extends Enum<DigitalCardProfile.Status.Value>
                        

    An enum containing Status's known values, as well as an _UNKNOWN member.

    An instance of Status can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      PENDING

      The Card Profile is awaiting review from Increase and/or processing by card networks.

      REJECTED

      There is an issue with the Card Profile preventing it from use.

      ACTIVE

      The Card Profile can be assigned to Cards.

      ARCHIVED

      The Card Profile is no longer in use.

      _UNKNOWN

      An enum member indicating that Status was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final DigitalCardProfile.Status.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<DigitalCardProfile.Status.Value> getEntries()

        An enum containing Status's known values, as well as an _UNKNOWN member.

        An instance of Status can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.