Class DigitalCardProfileCloneParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class DigitalCardProfileCloneParams implements Params
Clones a Digital Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileCloneParams.BuilderA builder for DigitalCardProfileCloneParams.
public final classDigitalCardProfileCloneParams.Bodypublic final classDigitalCardProfileCloneParams.TextColorThe Card's text color, specified as an RGB triple. The default is white.
-
Method Summary
Modifier and Type Method Description final Optional<String>digitalCardProfileId()The identifier of the Digital Card Profile to clone. final Optional<String>appIconFileId()The identifier of the File containing the card's icon image. final Optional<String>backgroundImageFileId()The identifier of the File containing the card's front image. final Optional<String>cardDescription()A user-facing description for the card itself. final Optional<String>contactEmail()An email address the user can contact to receive support for their card. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>contactWebsite()A website the user can visit to view and receive support for their card. final Optional<String>description()A description you can use to identify the Card Profile. final Optional<String>issuerName()A user-facing description for whoever is issuing the card. final Optional<DigitalCardProfileCloneParams.TextColor>textColor()The Card's text color, specified as an RGB triple. final JsonField<String>_appIconFileId()Returns the raw JSON value of appIconFileId. final JsonField<String>_backgroundImageFileId()Returns the raw JSON value of backgroundImageFileId. final JsonField<String>_cardDescription()Returns the raw JSON value of cardDescription. final JsonField<String>_contactEmail()Returns the raw JSON value of contactEmail. final JsonField<String>_contactPhone()Returns the raw JSON value of contactPhone. final JsonField<String>_contactWebsite()Returns the raw JSON value of contactWebsite. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_issuerName()Returns the raw JSON value of issuerName. final JsonField<DigitalCardProfileCloneParams.TextColor>_textColor()Returns the raw JSON value of textColor. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DigitalCardProfileCloneParams.BuildertoBuilder()final DigitalCardProfileCloneParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileCloneParamsnone()final static DigitalCardProfileCloneParams.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalCardProfileCloneParams. -
-
Method Detail
-
digitalCardProfileId
final Optional<String> digitalCardProfileId()
The identifier of the Digital Card Profile to clone.
-
appIconFileId
final Optional<String> appIconFileId()
The identifier of the File containing the card's icon image.
-
backgroundImageFileId
final Optional<String> backgroundImageFileId()
The identifier of the File containing the card's front image.
-
cardDescription
final Optional<String> cardDescription()
A user-facing description for the card itself.
-
contactEmail
final Optional<String> contactEmail()
An email address the user can contact to receive support for their card.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
contactWebsite
final Optional<String> contactWebsite()
A website the user can visit to view and receive support for their card.
-
description
final Optional<String> description()
A description you can use to identify the Card Profile.
-
issuerName
final Optional<String> issuerName()
A user-facing description for whoever is issuing the card.
-
textColor
final Optional<DigitalCardProfileCloneParams.TextColor> textColor()
The Card's text color, specified as an RGB triple. The default is white.
-
_appIconFileId
final JsonField<String> _appIconFileId()
Returns the raw JSON value of appIconFileId.
Unlike appIconFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_backgroundImageFileId
final JsonField<String> _backgroundImageFileId()
Returns the raw JSON value of backgroundImageFileId.
Unlike backgroundImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDescription
final JsonField<String> _cardDescription()
Returns the raw JSON value of cardDescription.
Unlike cardDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_contactEmail
final JsonField<String> _contactEmail()
Returns the raw JSON value of contactEmail.
Unlike contactEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_contactPhone
final JsonField<String> _contactPhone()
Returns the raw JSON value of contactPhone.
Unlike contactPhone, this method doesn't throw if the JSON field has an unexpected type.
-
_contactWebsite
final JsonField<String> _contactWebsite()
Returns the raw JSON value of contactWebsite.
Unlike contactWebsite, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_issuerName
final JsonField<String> _issuerName()
Returns the raw JSON value of issuerName.
Unlike issuerName, this method doesn't throw if the JSON field has an unexpected type.
-
_textColor
final JsonField<DigitalCardProfileCloneParams.TextColor> _textColor()
Returns the raw JSON value of textColor.
Unlike textColor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DigitalCardProfileCloneParams.Builder toBuilder()
-
_body
final DigitalCardProfileCloneParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static DigitalCardProfileCloneParams none()
-
builder
final static DigitalCardProfileCloneParams.Builder builder()
Returns a mutable builder for constructing an instance of DigitalCardProfileCloneParams.
-
-
-
-