Class DigitalCardProfileCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class DigitalCardProfileCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
appIconFileId
final DigitalCardProfileCreateParams.Body.Builder appIconFileId(String appIconFileId)
The identifier of the File containing the card's icon image.
-
appIconFileId
final DigitalCardProfileCreateParams.Body.Builder appIconFileId(JsonField<String> appIconFileId)
Sets Builder.appIconFileId to an arbitrary JSON value.
You should usually call Builder.appIconFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backgroundImageFileId
final DigitalCardProfileCreateParams.Body.Builder backgroundImageFileId(String backgroundImageFileId)
The identifier of the File containing the card's front image.
-
backgroundImageFileId
final DigitalCardProfileCreateParams.Body.Builder backgroundImageFileId(JsonField<String> backgroundImageFileId)
Sets Builder.backgroundImageFileId to an arbitrary JSON value.
You should usually call Builder.backgroundImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDescription
final DigitalCardProfileCreateParams.Body.Builder cardDescription(String cardDescription)
A user-facing description for the card itself.
-
cardDescription
final DigitalCardProfileCreateParams.Body.Builder cardDescription(JsonField<String> cardDescription)
Sets Builder.cardDescription to an arbitrary JSON value.
You should usually call Builder.cardDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final DigitalCardProfileCreateParams.Body.Builder description(String description)
A description you can use to identify the Card Profile.
-
description
final DigitalCardProfileCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
issuerName
final DigitalCardProfileCreateParams.Body.Builder issuerName(String issuerName)
A user-facing description for whoever is issuing the card.
-
issuerName
final DigitalCardProfileCreateParams.Body.Builder issuerName(JsonField<String> issuerName)
Sets Builder.issuerName to an arbitrary JSON value.
You should usually call Builder.issuerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactEmail
final DigitalCardProfileCreateParams.Body.Builder contactEmail(String contactEmail)
An email address the user can contact to receive support for their card.
-
contactEmail
final DigitalCardProfileCreateParams.Body.Builder contactEmail(JsonField<String> contactEmail)
Sets Builder.contactEmail to an arbitrary JSON value.
You should usually call Builder.contactEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactPhone
final DigitalCardProfileCreateParams.Body.Builder contactPhone(String contactPhone)
A phone number the user can contact to receive support for their card.
-
contactPhone
final DigitalCardProfileCreateParams.Body.Builder contactPhone(JsonField<String> contactPhone)
Sets Builder.contactPhone to an arbitrary JSON value.
You should usually call Builder.contactPhone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactWebsite
final DigitalCardProfileCreateParams.Body.Builder contactWebsite(String contactWebsite)
A website the user can visit to view and receive support for their card.
-
contactWebsite
final DigitalCardProfileCreateParams.Body.Builder contactWebsite(JsonField<String> contactWebsite)
Sets Builder.contactWebsite to an arbitrary JSON value.
You should usually call Builder.contactWebsite with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
textColor
final DigitalCardProfileCreateParams.Body.Builder textColor(DigitalCardProfileCreateParams.TextColor textColor)
The Card's text color, specified as an RGB triple. The default is white.
-
textColor
final DigitalCardProfileCreateParams.Body.Builder textColor(JsonField<DigitalCardProfileCreateParams.TextColor> textColor)
Sets Builder.textColor to an arbitrary JSON value.
You should usually call Builder.textColor with a well-typed TextColor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalCardProfileCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalCardProfileCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalCardProfileCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalCardProfileCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalCardProfileCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalCardProfileCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.appIconFileId() .backgroundImageFileId() .cardDescription() .description() .issuerName()
-
-
-
-