Class DigitalCardProfileListPage
-
- All Implemented Interfaces:
public final class DigitalCardProfileListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileListPage.BuilderA builder for DigitalCardProfileListPage.
public final classDigitalCardProfileListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<DigitalCardProfile>data()Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<DigitalCardProfileListParams>getNextPageParams()final Optional<DigitalCardProfileListPage>getNextPage()final DigitalCardProfileListPage.AutoPagerautoPager()final DigitalCardProfileListParamsparams()The parameters that were used to request this page. final DigitalCardProfileListPageResponseresponse()The response that this page was parsed from. final DigitalCardProfileListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileListPage.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalCardProfileListPage. -
-
Method Detail
-
data
final List<DigitalCardProfile> data()
Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<DigitalCardProfileListParams> getNextPageParams()
-
getNextPage
final Optional<DigitalCardProfileListPage> getNextPage()
-
autoPager
final DigitalCardProfileListPage.AutoPager autoPager()
-
params
final DigitalCardProfileListParams params()
The parameters that were used to request this page.
-
response
final DigitalCardProfileListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DigitalCardProfileListPage.Builder toBuilder()
-
builder
final static DigitalCardProfileListPage.Builder builder()
Returns a mutable builder for constructing an instance of DigitalCardProfileListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-