Class DigitalCardProfileListPage.Builder
-
- All Implemented Interfaces:
public final class DigitalCardProfileListPage.BuilderA builder for DigitalCardProfileListPage.
-
-
Method Summary
Modifier and Type Method Description final DigitalCardProfileListPage.Builderservice(DigitalCardProfileService service)final DigitalCardProfileListPage.Builderparams(DigitalCardProfileListParams params)The parameters that were used to request this page. final DigitalCardProfileListPage.Builderresponse(DigitalCardProfileListPageResponse response)The response that this page was parsed from. final DigitalCardProfileListPagebuild()Returns an immutable instance of DigitalCardProfileListPage. -
-
Method Detail
-
service
final DigitalCardProfileListPage.Builder service(DigitalCardProfileService service)
-
params
final DigitalCardProfileListPage.Builder params(DigitalCardProfileListParams params)
The parameters that were used to request this page.
-
response
final DigitalCardProfileListPage.Builder response(DigitalCardProfileListPageResponse response)
The response that this page was parsed from.
-
build
final DigitalCardProfileListPage build()
Returns an immutable instance of DigitalCardProfileListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-