Class DigitalCardProfileListPageAsync
-
- All Implemented Interfaces:
public final class DigitalCardProfileListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileListPageAsync.BuilderA builder for DigitalCardProfileListPageAsync.
public final classDigitalCardProfileListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<DigitalCardProfile>data()Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<DigitalCardProfileListParams>getNextPageParams()final CompletableFuture<Optional<DigitalCardProfileListPageAsync>>getNextPage()final DigitalCardProfileListPageAsync.AutoPagerautoPager()final DigitalCardProfileListParamsparams()The parameters that were used to request this page. final DigitalCardProfileListPageResponseresponse()The response that this page was parsed from. final DigitalCardProfileListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalCardProfileListPageAsync. -
-
Method Detail
-
data
final List<DigitalCardProfile> data()
Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DigitalCardProfileListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<DigitalCardProfileListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<DigitalCardProfileListPageAsync>> getNextPage()
-
autoPager
final DigitalCardProfileListPageAsync.AutoPager autoPager()
-
params
final DigitalCardProfileListParams params()
The parameters that were used to request this page.
-
response
final DigitalCardProfileListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DigitalCardProfileListPageAsync.Builder toBuilder()
-
builder
final static DigitalCardProfileListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of DigitalCardProfileListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-