Class DigitalCardProfileListPageAsync.Builder
-
- All Implemented Interfaces:
public final class DigitalCardProfileListPageAsync.BuilderA builder for DigitalCardProfileListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final DigitalCardProfileListPageAsync.Builderservice(DigitalCardProfileServiceAsync service)final DigitalCardProfileListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final DigitalCardProfileListPageAsync.Builderparams(DigitalCardProfileListParams params)The parameters that were used to request this page. final DigitalCardProfileListPageAsync.Builderresponse(DigitalCardProfileListPageResponse response)The response that this page was parsed from. final DigitalCardProfileListPageAsyncbuild()Returns an immutable instance of DigitalCardProfileListPageAsync. -
-
Method Detail
-
service
final DigitalCardProfileListPageAsync.Builder service(DigitalCardProfileServiceAsync service)
-
streamHandlerExecutor
final DigitalCardProfileListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final DigitalCardProfileListPageAsync.Builder params(DigitalCardProfileListParams params)
The parameters that were used to request this page.
-
response
final DigitalCardProfileListPageAsync.Builder response(DigitalCardProfileListPageResponse response)
The response that this page was parsed from.
-
build
final DigitalCardProfileListPageAsync build()
Returns an immutable instance of DigitalCardProfileListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-