Class DigitalCardProfileListPageResponse
-
- All Implemented Interfaces:
public final class DigitalCardProfileListPageResponseA list of Digital Card Profile objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileListPageResponse.BuilderA builder for DigitalCardProfileListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<DigitalCardProfile>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<DigitalCardProfile>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final DigitalCardProfileListPageResponse.BuildertoBuilder()final DigitalCardProfileListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalCardProfileListPageResponse. -
-
Method Detail
-
data
final List<DigitalCardProfile> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<DigitalCardProfile>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalCardProfileListPageResponse.Builder toBuilder()
-
validate
final DigitalCardProfileListPageResponse validate()
-
builder
final static DigitalCardProfileListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of DigitalCardProfileListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-