Class DigitalCardProfileListPageResponse.Builder
-
- All Implemented Interfaces:
public final class DigitalCardProfileListPageResponse.BuilderA builder for DigitalCardProfileListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final DigitalCardProfileListPageResponse.Builder data(List<DigitalCardProfile> data)
The contents of the list.
-
data
final DigitalCardProfileListPageResponse.Builder data(JsonField<List<DigitalCardProfile>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<DigitalCardProfile>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final DigitalCardProfileListPageResponse.Builder addData(DigitalCardProfile data)
Adds a single DigitalCardProfile to Builder.data.
-
nextCursor
final DigitalCardProfileListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final DigitalCardProfileListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final DigitalCardProfileListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalCardProfileListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalCardProfileListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalCardProfileListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalCardProfileListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalCardProfileListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalCardProfileListPageResponse build()
Returns an immutable instance of DigitalCardProfileListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-