Class DigitalCardProfileListParams.Status
-
- All Implemented Interfaces:
public final class DigitalCardProfileListParams.Status
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileListParams.Status.BuilderA builder for Status.
public final classDigitalCardProfileListParams.Status.In
-
Method Summary
Modifier and Type Method Description final Optional<List<DigitalCardProfileListParams.Status.In>>in_()Filter Digital Card Profiles for those with the specified digital wallet status or statuses. final QueryParams_additionalProperties()Query params to send with the request. final DigitalCardProfileListParams.Status.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalCardProfileListParams.Status.Builderbuilder()Returns a mutable builder for constructing an instance of Status. -
-
Method Detail
-
in_
final Optional<List<DigitalCardProfileListParams.Status.In>> in_()
Filter Digital Card Profiles for those with the specified digital wallet status or statuses. For GET requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
-
_additionalProperties
final QueryParams _additionalProperties()
Query params to send with the request.
-
toBuilder
final DigitalCardProfileListParams.Status.Builder toBuilder()
-
builder
final static DigitalCardProfileListParams.Status.Builder builder()
Returns a mutable builder for constructing an instance of Status.
-
-
-
-