Class DigitalWalletToken
-
- All Implemented Interfaces:
public final class DigitalWalletTokenA Digital Wallet Token is created when a user adds a Card to their Apple Pay or Google Pay app. The Digital Wallet Token can be used for purchases just like a Card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletToken.BuilderA builder for DigitalWalletToken.
public final classDigitalWalletToken.CardholderThe cardholder information given when the Digital Wallet Token was created.
public final classDigitalWalletToken.DeviceThe device that was used to create the Digital Wallet Token.
public final classDigitalWalletToken.StatusThis indicates if payments can be made with the Digital Wallet Token.
public final classDigitalWalletToken.TokenRequestorThe digital wallet app being used.
public final classDigitalWalletToken.TypeA constant representing the object's type. For this resource it will always be
digital_wallet_token.public final classDigitalWalletToken.Update
-
Method Summary
Modifier and Type Method Description final Stringid()The Digital Wallet Token identifier. final StringcardId()The identifier for the Card this Digital Wallet Token belongs to. final DigitalWalletToken.Cardholdercardholder()The cardholder information given when the Digital Wallet Token was created. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Digital Wallet Token was created. final DigitalWalletToken.Devicedevice()The device that was used to create the Digital Wallet Token. final DigitalWalletToken.Statusstatus()This indicates if payments can be made with the Digital Wallet Token. final DigitalWalletToken.TokenRequestortokenRequestor()The digital wallet app being used. final DigitalWalletToken.Typetype()A constant representing the object's type. final List<DigitalWalletToken.Update>updates()Updates to the Digital Wallet Token. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<DigitalWalletToken.Cardholder>_cardholder()Returns the raw JSON value of cardholder. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<DigitalWalletToken.Device>_device()Returns the raw JSON value of device. final JsonField<DigitalWalletToken.Status>_status()Returns the raw JSON value of status. final JsonField<DigitalWalletToken.TokenRequestor>_tokenRequestor()Returns the raw JSON value of tokenRequestor. final JsonField<DigitalWalletToken.Type>_type()Returns the raw JSON value of type. final JsonField<List<DigitalWalletToken.Update>>_updates()Returns the raw JSON value of updates. final Map<String, JsonValue>_additionalProperties()final DigitalWalletToken.BuildertoBuilder()final DigitalWalletTokenvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletToken.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalWalletToken. -
-
Method Detail
-
cardholder
final DigitalWalletToken.Cardholder cardholder()
The cardholder information given when the Digital Wallet Token was created.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Digital Wallet Token was created.
-
device
final DigitalWalletToken.Device device()
The device that was used to create the Digital Wallet Token.
-
status
final DigitalWalletToken.Status status()
This indicates if payments can be made with the Digital Wallet Token.
-
tokenRequestor
final DigitalWalletToken.TokenRequestor tokenRequestor()
The digital wallet app being used.
-
type
final DigitalWalletToken.Type type()
A constant representing the object's type. For this resource it will always be
digital_wallet_token.
-
updates
final List<DigitalWalletToken.Update> updates()
Updates to the Digital Wallet Token.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<DigitalWalletToken.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_device
final JsonField<DigitalWalletToken.Device> _device()
Returns the raw JSON value of device.
Unlike device, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<DigitalWalletToken.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenRequestor
final JsonField<DigitalWalletToken.TokenRequestor> _tokenRequestor()
Returns the raw JSON value of tokenRequestor.
Unlike tokenRequestor, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DigitalWalletToken.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updates
final JsonField<List<DigitalWalletToken.Update>> _updates()
Returns the raw JSON value of updates.
Unlike updates, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletToken.Builder toBuilder()
-
validate
final DigitalWalletToken validate()
-
builder
final static DigitalWalletToken.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletToken.
The following fields are required:
.id() .cardId() .cardholder() .createdAt() .device() .status() .tokenRequestor() .type() .updates()
-
-
-
-