Class DigitalWalletToken.Device
-
- All Implemented Interfaces:
public final class DigitalWalletToken.DeviceThe device that was used to create the Digital Wallet Token.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletToken.Device.BuilderA builder for Device.
public final classDigitalWalletToken.Device.DeviceTypeDevice type.
-
Method Summary
Modifier and Type Method Description final Optional<DigitalWalletToken.Device.DeviceType>deviceType()Device type. final Optional<String>identifier()ID assigned to the device by the digital wallet provider. final Optional<String>ipAddress()IP address of the device. final Optional<String>name()Name of the device, for example "My Work Phone". final JsonField<DigitalWalletToken.Device.DeviceType>_deviceType()Returns the raw JSON value of deviceType. final JsonField<String>_identifier()Returns the raw JSON value of identifier. final JsonField<String>_ipAddress()Returns the raw JSON value of ipAddress. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final DigitalWalletToken.Device.BuildertoBuilder()final DigitalWalletToken.Devicevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletToken.Device.Builderbuilder()Returns a mutable builder for constructing an instance of Device. -
-
Method Detail
-
deviceType
final Optional<DigitalWalletToken.Device.DeviceType> deviceType()
Device type.
-
identifier
final Optional<String> identifier()
ID assigned to the device by the digital wallet provider.
-
_deviceType
final JsonField<DigitalWalletToken.Device.DeviceType> _deviceType()
Returns the raw JSON value of deviceType.
Unlike deviceType, this method doesn't throw if the JSON field has an unexpected type.
-
_identifier
final JsonField<String> _identifier()
Returns the raw JSON value of identifier.
Unlike identifier, this method doesn't throw if the JSON field has an unexpected type.
-
_ipAddress
final JsonField<String> _ipAddress()
Returns the raw JSON value of ipAddress.
Unlike ipAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletToken.Device.Builder toBuilder()
-
validate
final DigitalWalletToken.Device validate()
-
builder
final static DigitalWalletToken.Device.Builder builder()
Returns a mutable builder for constructing an instance of Device.
The following fields are required:
.deviceType() .identifier() .ipAddress() .name()
-
-
-
-