Class Document
-
- All Implemented Interfaces:
public final class DocumentIncrease generates certain documents / forms automatically for your application; they can be listed here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocument.BuilderA builder for Document.
public final classDocument.AccountVerificationLetterProperties of an account verification letter document.
public final classDocument.CategoryThe type of document.
public final classDocument.FundingInstructionsProperties of a funding instructions document.
public final classDocument.TypeA constant representing the object's type. For this resource it will always be
document.
-
Method Summary
Modifier and Type Method Description final Stringid()The Document identifier. final Optional<Document.AccountVerificationLetter>accountVerificationLetter()Properties of an account verification letter document. final Document.Categorycategory()The type of document. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Document was created. final Optional<String>entityId()The identifier of the Entity the document was generated for. final StringfileId()The identifier of the File containing the Document's contents. final Optional<Document.FundingInstructions>fundingInstructions()Properties of a funding instructions document. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Document.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Document.AccountVerificationLetter>_accountVerificationLetter()Returns the raw JSON value of accountVerificationLetter. final JsonField<Document.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<Document.FundingInstructions>_fundingInstructions()Returns the raw JSON value of fundingInstructions. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<Document.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Document.BuildertoBuilder()final Documentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Document.Builderbuilder()Returns a mutable builder for constructing an instance of Document. -
-
Method Detail
-
accountVerificationLetter
final Optional<Document.AccountVerificationLetter> accountVerificationLetter()
Properties of an account verification letter document.
-
category
final Document.Category category()
The type of document.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Document was created.
-
entityId
final Optional<String> entityId()
The identifier of the Entity the document was generated for.
-
fundingInstructions
final Optional<Document.FundingInstructions> fundingInstructions()
Properties of a funding instructions document.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final Document.Type type()
A constant representing the object's type. For this resource it will always be
document.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountVerificationLetter
final JsonField<Document.AccountVerificationLetter> _accountVerificationLetter()
Returns the raw JSON value of accountVerificationLetter.
Unlike accountVerificationLetter, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Document.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_fundingInstructions
final JsonField<Document.FundingInstructions> _fundingInstructions()
Returns the raw JSON value of fundingInstructions.
Unlike fundingInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Document.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Document.Builder toBuilder()
-
builder
final static Document.Builder builder()
Returns a mutable builder for constructing an instance of Document.
The following fields are required:
.id() .accountVerificationLetter() .category() .createdAt() .entityId() .fileId() .fundingInstructions() .idempotencyKey() .type()
-
-
-
-