Enum Document.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Document.Category.Known extends Enum<Document.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Document.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FORM_1099_INTInternal Revenue Service Form 1099-INT.
FORM_1099_MISCInternal Revenue Service Form 1099-MISC.
PROOF_OF_AUTHORIZATIONA document submitted in response to a proof of authorization request for an ACH transfer.
COMPANY_INFORMATIONCompany information, such a policies or procedures, typically submitted during our due diligence process.
ACCOUNT_VERIFICATION_LETTERAn account verification letter.
FUNDING_INSTRUCTIONSFunding instructions.
-
Method Summary
Modifier and Type Method Description final Document.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Document.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Document.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final Document.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Document.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Document.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-