Enum Document.Category.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Document.Category.Value extends Enum<Document.Category.Value>
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Document.Category.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FORM_1099_INTInternal Revenue Service Form 1099-INT.
FORM_1099_MISCInternal Revenue Service Form 1099-MISC.
PROOF_OF_AUTHORIZATIONA document submitted in response to a proof of authorization request for an ACH transfer.
COMPANY_INFORMATIONCompany information, such a policies or procedures, typically submitted during our due diligence process.
ACCOUNT_VERIFICATION_LETTERAn account verification letter.
FUNDING_INSTRUCTIONSFunding instructions.
_UNKNOWNAn enum member indicating that Category was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Document.Category.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Document.Category.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Document.Category.Value>getEntries()An enum containing Category's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Document.Category.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Document.Category.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Document.Category.Value> getEntries()
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-