Class DocumentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class DocumentCreateParams implements Params
Create a Document
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentCreateParams.BuilderA builder for DocumentCreateParams.
public final classDocumentCreateParams.Bodypublic final classDocumentCreateParams.CategoryThe type of document to create.
public final classDocumentCreateParams.AccountVerificationLetterAn account verification letter. Required if and only if
categoryisaccount_verification_letter.public final classDocumentCreateParams.FundingInstructionsFunding instructions. Required if and only if
categoryisfunding_instructions.
-
Method Summary
-
-
Method Detail
-
category
final DocumentCreateParams.Category category()
The type of document to create.
-
accountVerificationLetter
final Optional<DocumentCreateParams.AccountVerificationLetter> accountVerificationLetter()
An account verification letter. Required if and only if
categoryisaccount_verification_letter.
-
fundingInstructions
final Optional<DocumentCreateParams.FundingInstructions> fundingInstructions()
Funding instructions. Required if and only if
categoryisfunding_instructions.
-
_category
final JsonField<DocumentCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_accountVerificationLetter
final JsonField<DocumentCreateParams.AccountVerificationLetter> _accountVerificationLetter()
Returns the raw JSON value of accountVerificationLetter.
Unlike accountVerificationLetter, this method doesn't throw if the JSON field has an unexpected type.
-
_fundingInstructions
final JsonField<DocumentCreateParams.FundingInstructions> _fundingInstructions()
Returns the raw JSON value of fundingInstructions.
Unlike fundingInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DocumentCreateParams.Builder toBuilder()
-
_body
final DocumentCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static DocumentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of DocumentCreateParams.
The following fields are required:
.category()
-
-
-
-