Class DocumentCreateParams.AccountVerificationLetter
-
- All Implemented Interfaces:
public final class DocumentCreateParams.AccountVerificationLetterAn account verification letter.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentCreateParams.AccountVerificationLetter.BuilderA builder for AccountVerificationLetter.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number the bank letter should be generated for. final Optional<LocalDate>balanceDate()If provided, the letter will include the Account's balance as of the date. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<LocalDate>_balanceDate()Returns the raw JSON value of balanceDate. final Map<String, JsonValue>_additionalProperties()final DocumentCreateParams.AccountVerificationLetter.BuildertoBuilder()final DocumentCreateParams.AccountVerificationLettervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentCreateParams.AccountVerificationLetter.Builderbuilder()Returns a mutable builder for constructing an instance of AccountVerificationLetter. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number the bank letter should be generated for.
-
balanceDate
final Optional<LocalDate> balanceDate()
If provided, the letter will include the Account's balance as of the date.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_balanceDate
final JsonField<LocalDate> _balanceDate()
Returns the raw JSON value of balanceDate.
Unlike balanceDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocumentCreateParams.AccountVerificationLetter.Builder toBuilder()
-
validate
final DocumentCreateParams.AccountVerificationLetter validate()
-
builder
final static DocumentCreateParams.AccountVerificationLetter.Builder builder()
Returns a mutable builder for constructing an instance of AccountVerificationLetter.
The following fields are required:
.accountNumberId()
-
-
-
-