Class DocumentCreateParams.AccountVerificationLetter.Builder
-
- All Implemented Interfaces:
public final class DocumentCreateParams.AccountVerificationLetter.BuilderA builder for AccountVerificationLetter.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final DocumentCreateParams.AccountVerificationLetter.Builder accountNumberId(String accountNumberId)
The Account Number the bank letter should be generated for.
-
accountNumberId
final DocumentCreateParams.AccountVerificationLetter.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balanceDate
final DocumentCreateParams.AccountVerificationLetter.Builder balanceDate(LocalDate balanceDate)
If provided, the letter will include the Account's balance as of the date.
-
balanceDate
final DocumentCreateParams.AccountVerificationLetter.Builder balanceDate(JsonField<LocalDate> balanceDate)
Sets Builder.balanceDate to an arbitrary JSON value.
You should usually call Builder.balanceDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DocumentCreateParams.AccountVerificationLetter.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DocumentCreateParams.AccountVerificationLetter.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DocumentCreateParams.AccountVerificationLetter.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DocumentCreateParams.AccountVerificationLetter.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DocumentCreateParams.AccountVerificationLetter.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DocumentCreateParams.AccountVerificationLetter build()
Returns an immutable instance of AccountVerificationLetter.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId()
-
-
-
-