Class DocumentCreateParams.Body
-
- All Implemented Interfaces:
public final class DocumentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
category
final DocumentCreateParams.Category category()
The type of document to create.
-
accountVerificationLetter
final Optional<DocumentCreateParams.AccountVerificationLetter> accountVerificationLetter()
An account verification letter.
-
fundingInstructions
final Optional<DocumentCreateParams.FundingInstructions> fundingInstructions()
Funding instructions.
-
_category
final JsonField<DocumentCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_accountVerificationLetter
final JsonField<DocumentCreateParams.AccountVerificationLetter> _accountVerificationLetter()
Returns the raw JSON value of accountVerificationLetter.
Unlike accountVerificationLetter, this method doesn't throw if the JSON field has an unexpected type.
-
_fundingInstructions
final JsonField<DocumentCreateParams.FundingInstructions> _fundingInstructions()
Returns the raw JSON value of fundingInstructions.
Unlike fundingInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocumentCreateParams.Body.Builder toBuilder()
-
validate
final DocumentCreateParams.Body validate()
-
builder
final static DocumentCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.category()
-
-
-
-