Class DocumentCreateParams.FundingInstructions
-
- All Implemented Interfaces:
public final class DocumentCreateParams.FundingInstructionsFunding instructions. Required if and only if
categoryisfunding_instructions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentCreateParams.FundingInstructions.BuilderA builder for FundingInstructions.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number the funding instructions should be generated for. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final Map<String, JsonValue>_additionalProperties()final DocumentCreateParams.FundingInstructions.BuildertoBuilder()final DocumentCreateParams.FundingInstructionsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentCreateParams.FundingInstructions.Builderbuilder()Returns a mutable builder for constructing an instance of FundingInstructions. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number the funding instructions should be generated for.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocumentCreateParams.FundingInstructions.Builder toBuilder()
-
validate
final DocumentCreateParams.FundingInstructions validate()
-
builder
final static DocumentCreateParams.FundingInstructions.Builder builder()
Returns a mutable builder for constructing an instance of FundingInstructions.
The following fields are required:
.accountNumberId()
-
-
-
-