Class DocumentListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class DocumentListPage implements Page<Document>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentListPage.BuilderA builder for DocumentListPage.
-
Method Summary
Modifier and Type Method Description final List<Document>data()Delegates to DocumentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DocumentListPageResponse, but gracefully handles missing data. List<Document>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final DocumentListParamsnextPageParams()DocumentListPagenextPage()Returns the page after this one by making another request. final AutoPager<Document>autoPager()final DocumentListParamsparams()The parameters that were used to request this page. final DocumentListPageResponseresponse()The response that this page was parsed from. final DocumentListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentListPage.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentListPage. -
-
Method Detail
-
data
final List<Document> data()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final DocumentListParams nextPageParams()
-
nextPage
DocumentListPage nextPage()
Returns the page after this one by making another request.
-
params
final DocumentListParams params()
The parameters that were used to request this page.
-
response
final DocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DocumentListPage.Builder toBuilder()
-
builder
final static DocumentListPage.Builder builder()
Returns a mutable builder for constructing an instance of DocumentListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-