Class DocumentListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class DocumentListPageAsync implements PageAsync<Document>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentListPageAsync.BuilderA builder for DocumentListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<Document>data()Delegates to DocumentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DocumentListPageResponse, but gracefully handles missing data. List<Document>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final DocumentListParamsnextPageParams()CompletableFuture<DocumentListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Document>autoPager()final DocumentListParamsparams()The parameters that were used to request this page. final DocumentListPageResponseresponse()The response that this page was parsed from. final DocumentListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentListPageAsync. -
-
Method Detail
-
data
final List<Document> data()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final DocumentListParams nextPageParams()
-
nextPage
CompletableFuture<DocumentListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Document> autoPager()
-
params
final DocumentListParams params()
The parameters that were used to request this page.
-
response
final DocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DocumentListPageAsync.Builder toBuilder()
-
builder
final static DocumentListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of DocumentListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-