Class DocumentListPageAsync.Builder
-
- All Implemented Interfaces:
public final class DocumentListPageAsync.BuilderA builder for DocumentListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final DocumentListPageAsync.Builderservice(DocumentServiceAsync service)final DocumentListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final DocumentListPageAsync.Builderparams(DocumentListParams params)The parameters that were used to request this page. final DocumentListPageAsync.Builderresponse(DocumentListPageResponse response)The response that this page was parsed from. final DocumentListPageAsyncbuild()Returns an immutable instance of DocumentListPageAsync. -
-
Method Detail
-
service
final DocumentListPageAsync.Builder service(DocumentServiceAsync service)
-
streamHandlerExecutor
final DocumentListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final DocumentListPageAsync.Builder params(DocumentListParams params)
The parameters that were used to request this page.
-
response
final DocumentListPageAsync.Builder response(DocumentListPageResponse response)
The response that this page was parsed from.
-
build
final DocumentListPageAsync build()
Returns an immutable instance of DocumentListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-