Class DocumentListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class DocumentListParams implements Params
List Documents
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentListParams.BuilderA builder for DocumentListParams.
public final classDocumentListParams.Categorypublic final classDocumentListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<DocumentListParams.Category>category()final Optional<DocumentListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<String>entityId()Filter Documents to ones belonging to the specified Entity. final Optional<String>idempotencyKey()Filter records to the one with the specified idempotency_keyyou chose for that object.final Optional<Long>limit()Limit the size of the list that is returned. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DocumentListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentListParamsnone()final static DocumentListParams.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentListParams. -
-
Method Detail
-
category
final Optional<DocumentListParams.Category> category()
-
createdAt
final Optional<DocumentListParams.CreatedAt> createdAt()
-
entityId
final Optional<String> entityId()
Filter Documents to ones belonging to the specified Entity.
-
idempotencyKey
final Optional<String> idempotencyKey()
Filter records to the one with the specified
idempotency_keyyou chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DocumentListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static DocumentListParams none()
-
builder
final static DocumentListParams.Builder builder()
Returns a mutable builder for constructing an instance of DocumentListParams.
-
-
-
-