Class Entity
-
- All Implemented Interfaces:
public final class EntityEntities are the legal entities that own accounts. They can be people, corporations, partnerships, government authorities, or trusts. To learn more, see /documentation/entities.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.BuilderA builder for Entity.
public final classEntity.CorporationDetails of the corporation entity. Will be present if
structureis equal tocorporation.public final classEntity.GovernmentAuthorityDetails of the government authority entity. Will be present if
structureis equal togovernment_authority.public final classEntity.JointDetails of the joint entity. Will be present if
structureis equal tojoint.public final classEntity.NaturalPersonDetails of the natural person entity. Will be present if
structureis equal tonatural_person.public final classEntity.RiskRatingAn assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
public final classEntity.StatusThe status of the entity.
public final classEntity.StructureThe entity's legal structure.
public final classEntity.TermsAgreementpublic final classEntity.ThirdPartyVerificationIf you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
public final classEntity.TrustDetails of the trust entity. Will be present if
structureis equal totrust.public final classEntity.TypeA constant representing the object's type. For this resource it will always be
entity.public final classEntity.ValidationThe validation results for the entity. Learn more about /documentation/entity-validation.
-
Method Summary
Modifier and Type Method Description final Stringid()The entity's identifier. final Optional<Entity.Corporation>corporation()Details of the corporation entity. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Entity was created. final Optional<String>description()The entity's description for display purposes. final Optional<OffsetDateTime>detailsConfirmedAt()The ISO 8601 time at which the Entity's details were most recently confirmed. final Optional<Entity.GovernmentAuthority>governmentAuthority()Details of the government authority entity. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<Entity.Joint>joint()Details of the joint entity. final Optional<Entity.NaturalPerson>naturalPerson()Details of the natural person entity. final Optional<Entity.RiskRating>riskRating()An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering. final Entity.Statusstatus()The status of the entity. final Entity.Structurestructure()The entity's legal structure. final List<EntitySupplementalDocument>supplementalDocuments()Additional documentation associated with the entity. final List<Entity.TermsAgreement>termsAgreements()The terms that the Entity agreed to. final Optional<Entity.ThirdPartyVerification>thirdPartyVerification()If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service. final Optional<Entity.Trust>trust()Details of the trust entity. final Entity.Typetype()A constant representing the object's type. final Optional<Entity.Validation>validation()The validation results for the entity. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Entity.Corporation>_corporation()Returns the raw JSON value of corporation. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<OffsetDateTime>_detailsConfirmedAt()Returns the raw JSON value of detailsConfirmedAt. final JsonField<Entity.GovernmentAuthority>_governmentAuthority()Returns the raw JSON value of governmentAuthority. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<Entity.Joint>_joint()Returns the raw JSON value of joint. final JsonField<Entity.NaturalPerson>_naturalPerson()Returns the raw JSON value of naturalPerson. final JsonField<Entity.RiskRating>_riskRating()Returns the raw JSON value of riskRating. final JsonField<Entity.Status>_status()Returns the raw JSON value of status. final JsonField<Entity.Structure>_structure()Returns the raw JSON value of structure. final JsonField<List<EntitySupplementalDocument>>_supplementalDocuments()Returns the raw JSON value of supplementalDocuments. final JsonField<List<Entity.TermsAgreement>>_termsAgreements()Returns the raw JSON value of termsAgreements. final JsonField<Entity.ThirdPartyVerification>_thirdPartyVerification()Returns the raw JSON value of thirdPartyVerification. final JsonField<Entity.Trust>_trust()Returns the raw JSON value of trust. final JsonField<Entity.Type>_type()Returns the raw JSON value of type. final JsonField<Entity.Validation>_validation()Returns the raw JSON value of validation. final Map<String, JsonValue>_additionalProperties()final Entity.BuildertoBuilder()final Entityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Builderbuilder()Returns a mutable builder for constructing an instance of Entity. -
-
Method Detail
-
corporation
final Optional<Entity.Corporation> corporation()
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Entity was created.
-
description
final Optional<String> description()
The entity's description for display purposes.
-
detailsConfirmedAt
final Optional<OffsetDateTime> detailsConfirmedAt()
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
governmentAuthority
final Optional<Entity.GovernmentAuthority> governmentAuthority()
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
joint
final Optional<Entity.Joint> joint()
Details of the joint entity. Will be present if
structureis equal tojoint.
-
naturalPerson
final Optional<Entity.NaturalPerson> naturalPerson()
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
riskRating
final Optional<Entity.RiskRating> riskRating()
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
status
final Entity.Status status()
The status of the entity.
-
structure
final Entity.Structure structure()
The entity's legal structure.
-
supplementalDocuments
final List<EntitySupplementalDocument> supplementalDocuments()
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
termsAgreements
final List<Entity.TermsAgreement> termsAgreements()
The terms that the Entity agreed to. Not all programs are required to submit this data.
-
thirdPartyVerification
final Optional<Entity.ThirdPartyVerification> thirdPartyVerification()
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
trust
final Optional<Entity.Trust> trust()
Details of the trust entity. Will be present if
structureis equal totrust.
-
type
final Entity.Type type()
A constant representing the object's type. For this resource it will always be
entity.
-
validation
final Optional<Entity.Validation> validation()
The validation results for the entity. Learn more about /documentation/entity-validation.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_corporation
final JsonField<Entity.Corporation> _corporation()
Returns the raw JSON value of corporation.
Unlike corporation, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_detailsConfirmedAt
final JsonField<OffsetDateTime> _detailsConfirmedAt()
Returns the raw JSON value of detailsConfirmedAt.
Unlike detailsConfirmedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentAuthority
final JsonField<Entity.GovernmentAuthority> _governmentAuthority()
Returns the raw JSON value of governmentAuthority.
Unlike governmentAuthority, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_joint
final JsonField<Entity.Joint> _joint()
Returns the raw JSON value of joint.
Unlike joint, this method doesn't throw if the JSON field has an unexpected type.
-
_naturalPerson
final JsonField<Entity.NaturalPerson> _naturalPerson()
Returns the raw JSON value of naturalPerson.
Unlike naturalPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_riskRating
final JsonField<Entity.RiskRating> _riskRating()
Returns the raw JSON value of riskRating.
Unlike riskRating, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Entity.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_structure
final JsonField<Entity.Structure> _structure()
Returns the raw JSON value of structure.
Unlike structure, this method doesn't throw if the JSON field has an unexpected type.
-
_supplementalDocuments
final JsonField<List<EntitySupplementalDocument>> _supplementalDocuments()
Returns the raw JSON value of supplementalDocuments.
Unlike supplementalDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_termsAgreements
final JsonField<List<Entity.TermsAgreement>> _termsAgreements()
Returns the raw JSON value of termsAgreements.
Unlike termsAgreements, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdPartyVerification
final JsonField<Entity.ThirdPartyVerification> _thirdPartyVerification()
Returns the raw JSON value of thirdPartyVerification.
Unlike thirdPartyVerification, this method doesn't throw if the JSON field has an unexpected type.
-
_trust
final JsonField<Entity.Trust> _trust()
Returns the raw JSON value of trust.
Unlike trust, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Entity.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_validation
final JsonField<Entity.Validation> _validation()
Returns the raw JSON value of validation.
Unlike validation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Builder toBuilder()
-
builder
final static Entity.Builder builder()
Returns a mutable builder for constructing an instance of Entity.
The following fields are required:
.id() .corporation() .createdAt() .description() .detailsConfirmedAt() .governmentAuthority() .idempotencyKey() .joint() .naturalPerson() .riskRating() .status() .structure() .supplementalDocuments() .termsAgreements() .thirdPartyVerification() .trust() .type() .validation()
-
-
-
-