Class Entity.Builder
-
- All Implemented Interfaces:
public final class Entity.BuilderA builder for Entity.
-
-
Method Summary
Modifier and Type Method Description final Entity.Builderid(String id)The entity's identifier. final Entity.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Entity.Buildercorporation(Entity.Corporation corporation)Details of the corporation entity. final Entity.Buildercorporation(Optional<Entity.Corporation> corporation)Alias for calling Builder.corporation with corporation.orElse(null).final Entity.Buildercorporation(JsonField<Entity.Corporation> corporation)Sets Builder.corporation to an arbitrary JSON value. final Entity.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Entity was created. final Entity.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Entity.BuildercreatingEntityOnboardingSessionId(String creatingEntityOnboardingSessionId)The identifier of the Entity Onboarding Session that was used to create this Entity, if any. final Entity.BuildercreatingEntityOnboardingSessionId(Optional<String> creatingEntityOnboardingSessionId)Alias for calling Builder.creatingEntityOnboardingSessionId with creatingEntityOnboardingSessionId.orElse(null).final Entity.BuildercreatingEntityOnboardingSessionId(JsonField<String> creatingEntityOnboardingSessionId)Sets Builder.creatingEntityOnboardingSessionId to an arbitrary JSON value. final Entity.Builderdescription(String description)The entity's description for display purposes. final Entity.Builderdescription(Optional<String> description)Alias for calling Builder.description with description.orElse(null).final Entity.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final Entity.BuilderdetailsConfirmedAt(OffsetDateTime detailsConfirmedAt)The ISO 8601 time at which the Entity's details were most recently confirmed. final Entity.BuilderdetailsConfirmedAt(Optional<OffsetDateTime> detailsConfirmedAt)Alias for calling Builder.detailsConfirmedAt with detailsConfirmedAt.orElse(null).final Entity.BuilderdetailsConfirmedAt(JsonField<OffsetDateTime> detailsConfirmedAt)Sets Builder.detailsConfirmedAt to an arbitrary JSON value. final Entity.BuildergovernmentAuthority(Entity.GovernmentAuthority governmentAuthority)Details of the government authority entity. final Entity.BuildergovernmentAuthority(Optional<Entity.GovernmentAuthority> governmentAuthority)Alias for calling Builder.governmentAuthority with governmentAuthority.orElse(null).final Entity.BuildergovernmentAuthority(JsonField<Entity.GovernmentAuthority> governmentAuthority)Sets Builder.governmentAuthority to an arbitrary JSON value. final Entity.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Entity.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final Entity.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final Entity.Builderjoint(Entity.Joint joint)Details of the joint entity. final Entity.Builderjoint(Optional<Entity.Joint> joint)Alias for calling Builder.joint with joint.orElse(null).final Entity.Builderjoint(JsonField<Entity.Joint> joint)Sets Builder.joint to an arbitrary JSON value. final Entity.BuildernaturalPerson(Entity.NaturalPerson naturalPerson)Details of the natural person entity. final Entity.BuildernaturalPerson(Optional<Entity.NaturalPerson> naturalPerson)Alias for calling Builder.naturalPerson with naturalPerson.orElse(null).final Entity.BuildernaturalPerson(JsonField<Entity.NaturalPerson> naturalPerson)Sets Builder.naturalPerson to an arbitrary JSON value. final Entity.BuilderriskRating(Entity.RiskRating riskRating)An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering. final Entity.BuilderriskRating(Optional<Entity.RiskRating> riskRating)Alias for calling Builder.riskRating with riskRating.orElse(null).final Entity.BuilderriskRating(JsonField<Entity.RiskRating> riskRating)Sets Builder.riskRating to an arbitrary JSON value. final Entity.Builderstatus(Entity.Status status)The status of the entity. final Entity.Builderstatus(JsonField<Entity.Status> status)Sets Builder.status to an arbitrary JSON value. final Entity.Builderstructure(Entity.Structure structure)The entity's legal structure. final Entity.Builderstructure(JsonField<Entity.Structure> structure)Sets Builder.structure to an arbitrary JSON value. final Entity.BuildersupplementalDocuments(List<EntitySupplementalDocument> supplementalDocuments)Additional documentation associated with the entity. final Entity.BuildersupplementalDocuments(JsonField<List<EntitySupplementalDocument>> supplementalDocuments)Sets Builder.supplementalDocuments to an arbitrary JSON value. final Entity.BuilderaddSupplementalDocument(EntitySupplementalDocument supplementalDocument)Adds a single EntitySupplementalDocument to supplementalDocuments. final Entity.BuildertermsAgreements(List<Entity.TermsAgreement> termsAgreements)The terms that the Entity agreed to. final Entity.BuildertermsAgreements(JsonField<List<Entity.TermsAgreement>> termsAgreements)Sets Builder.termsAgreements to an arbitrary JSON value. final Entity.BuilderaddTermsAgreement(Entity.TermsAgreement termsAgreement)Adds a single TermsAgreement to termsAgreements. final Entity.BuilderthirdPartyVerification(Entity.ThirdPartyVerification thirdPartyVerification)If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service. final Entity.BuilderthirdPartyVerification(Optional<Entity.ThirdPartyVerification> thirdPartyVerification)Alias for calling Builder.thirdPartyVerification with thirdPartyVerification.orElse(null).final Entity.BuilderthirdPartyVerification(JsonField<Entity.ThirdPartyVerification> thirdPartyVerification)Sets Builder.thirdPartyVerification to an arbitrary JSON value. final Entity.Buildertrust(Entity.Trust trust)Details of the trust entity. final Entity.Buildertrust(Optional<Entity.Trust> trust)Alias for calling Builder.trust with trust.orElse(null).final Entity.Buildertrust(JsonField<Entity.Trust> trust)Sets Builder.trust to an arbitrary JSON value. final Entity.Buildertype(Entity.Type type)A constant representing the object's type. final Entity.Buildertype(JsonField<Entity.Type> type)Sets Builder.type to an arbitrary JSON value. final Entity.Buildervalidation(Entity.Validation validation)The validation results for the entity. final Entity.Buildervalidation(Optional<Entity.Validation> validation)Alias for calling Builder.validation with validation.orElse(null).final Entity.Buildervalidation(JsonField<Entity.Validation> validation)Sets Builder.validation to an arbitrary JSON value. final Entity.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.BuilderputAdditionalProperty(String key, JsonValue value)final Entity.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.BuilderremoveAdditionalProperty(String key)final Entity.BuilderremoveAllAdditionalProperties(Set<String> keys)final Entitybuild()Returns an immutable instance of Entity. -
-
Method Detail
-
id
final Entity.Builder id(String id)
The entity's identifier.
-
id
final Entity.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
corporation
final Entity.Builder corporation(Entity.Corporation corporation)
Details of the corporation entity. Will be present if
structureis equal tocorporation.
-
corporation
final Entity.Builder corporation(Optional<Entity.Corporation> corporation)
Alias for calling Builder.corporation with
corporation.orElse(null).
-
corporation
final Entity.Builder corporation(JsonField<Entity.Corporation> corporation)
Sets Builder.corporation to an arbitrary JSON value.
You should usually call Builder.corporation with a well-typed Corporation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Entity.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Entity was created.
-
createdAt
final Entity.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creatingEntityOnboardingSessionId
final Entity.Builder creatingEntityOnboardingSessionId(String creatingEntityOnboardingSessionId)
The identifier of the Entity Onboarding Session that was used to create this Entity, if any.
-
creatingEntityOnboardingSessionId
final Entity.Builder creatingEntityOnboardingSessionId(Optional<String> creatingEntityOnboardingSessionId)
Alias for calling Builder.creatingEntityOnboardingSessionId with
creatingEntityOnboardingSessionId.orElse(null).
-
creatingEntityOnboardingSessionId
final Entity.Builder creatingEntityOnboardingSessionId(JsonField<String> creatingEntityOnboardingSessionId)
Sets Builder.creatingEntityOnboardingSessionId to an arbitrary JSON value.
You should usually call Builder.creatingEntityOnboardingSessionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Entity.Builder description(String description)
The entity's description for display purposes.
-
description
final Entity.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final Entity.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
detailsConfirmedAt
final Entity.Builder detailsConfirmedAt(OffsetDateTime detailsConfirmedAt)
The ISO 8601 time at which the Entity's details were most recently confirmed.
-
detailsConfirmedAt
final Entity.Builder detailsConfirmedAt(Optional<OffsetDateTime> detailsConfirmedAt)
Alias for calling Builder.detailsConfirmedAt with
detailsConfirmedAt.orElse(null).
-
detailsConfirmedAt
final Entity.Builder detailsConfirmedAt(JsonField<OffsetDateTime> detailsConfirmedAt)
Sets Builder.detailsConfirmedAt to an arbitrary JSON value.
You should usually call Builder.detailsConfirmedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentAuthority
final Entity.Builder governmentAuthority(Entity.GovernmentAuthority governmentAuthority)
Details of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
governmentAuthority
final Entity.Builder governmentAuthority(Optional<Entity.GovernmentAuthority> governmentAuthority)
Alias for calling Builder.governmentAuthority with
governmentAuthority.orElse(null).
-
governmentAuthority
final Entity.Builder governmentAuthority(JsonField<Entity.GovernmentAuthority> governmentAuthority)
Sets Builder.governmentAuthority to an arbitrary JSON value.
You should usually call Builder.governmentAuthority with a well-typed GovernmentAuthority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final Entity.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Entity.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final Entity.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
joint
final Entity.Builder joint(Entity.Joint joint)
Details of the joint entity. Will be present if
structureis equal tojoint.
-
joint
final Entity.Builder joint(Optional<Entity.Joint> joint)
Alias for calling Builder.joint with
joint.orElse(null).
-
joint
final Entity.Builder joint(JsonField<Entity.Joint> joint)
Sets Builder.joint to an arbitrary JSON value.
You should usually call Builder.joint with a well-typed Joint value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naturalPerson
final Entity.Builder naturalPerson(Entity.NaturalPerson naturalPerson)
Details of the natural person entity. Will be present if
structureis equal tonatural_person.
-
naturalPerson
final Entity.Builder naturalPerson(Optional<Entity.NaturalPerson> naturalPerson)
Alias for calling Builder.naturalPerson with
naturalPerson.orElse(null).
-
naturalPerson
final Entity.Builder naturalPerson(JsonField<Entity.NaturalPerson> naturalPerson)
Sets Builder.naturalPerson to an arbitrary JSON value.
You should usually call Builder.naturalPerson with a well-typed NaturalPerson value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
riskRating
final Entity.Builder riskRating(Entity.RiskRating riskRating)
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
riskRating
final Entity.Builder riskRating(Optional<Entity.RiskRating> riskRating)
Alias for calling Builder.riskRating with
riskRating.orElse(null).
-
riskRating
final Entity.Builder riskRating(JsonField<Entity.RiskRating> riskRating)
Sets Builder.riskRating to an arbitrary JSON value.
You should usually call Builder.riskRating with a well-typed RiskRating value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Entity.Builder status(Entity.Status status)
The status of the entity.
-
status
final Entity.Builder status(JsonField<Entity.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
structure
final Entity.Builder structure(Entity.Structure structure)
The entity's legal structure.
-
structure
final Entity.Builder structure(JsonField<Entity.Structure> structure)
Sets Builder.structure to an arbitrary JSON value.
You should usually call Builder.structure with a well-typed Structure value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supplementalDocuments
final Entity.Builder supplementalDocuments(List<EntitySupplementalDocument> supplementalDocuments)
Additional documentation associated with the entity. This is limited to the first 10 documents for an entity. If an entity has more than 10 documents, use the GET /entity_supplemental_documents list endpoint to retrieve them.
-
supplementalDocuments
final Entity.Builder supplementalDocuments(JsonField<List<EntitySupplementalDocument>> supplementalDocuments)
Sets Builder.supplementalDocuments to an arbitrary JSON value.
You should usually call Builder.supplementalDocuments with a well-typed
List<EntitySupplementalDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSupplementalDocument
final Entity.Builder addSupplementalDocument(EntitySupplementalDocument supplementalDocument)
Adds a single EntitySupplementalDocument to supplementalDocuments.
-
termsAgreements
final Entity.Builder termsAgreements(List<Entity.TermsAgreement> termsAgreements)
The terms that the Entity agreed to. Not all programs are required to submit this data.
-
termsAgreements
final Entity.Builder termsAgreements(JsonField<List<Entity.TermsAgreement>> termsAgreements)
Sets Builder.termsAgreements to an arbitrary JSON value.
You should usually call Builder.termsAgreements with a well-typed
List<TermsAgreement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTermsAgreement
final Entity.Builder addTermsAgreement(Entity.TermsAgreement termsAgreement)
Adds a single TermsAgreement to termsAgreements.
-
thirdPartyVerification
final Entity.Builder thirdPartyVerification(Entity.ThirdPartyVerification thirdPartyVerification)
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
thirdPartyVerification
final Entity.Builder thirdPartyVerification(Optional<Entity.ThirdPartyVerification> thirdPartyVerification)
Alias for calling Builder.thirdPartyVerification with
thirdPartyVerification.orElse(null).
-
thirdPartyVerification
final Entity.Builder thirdPartyVerification(JsonField<Entity.ThirdPartyVerification> thirdPartyVerification)
Sets Builder.thirdPartyVerification to an arbitrary JSON value.
You should usually call Builder.thirdPartyVerification with a well-typed ThirdPartyVerification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trust
final Entity.Builder trust(Entity.Trust trust)
Details of the trust entity. Will be present if
structureis equal totrust.
-
trust
final Entity.Builder trust(Optional<Entity.Trust> trust)
Alias for calling Builder.trust with
trust.orElse(null).
-
trust
final Entity.Builder trust(JsonField<Entity.Trust> trust)
Sets Builder.trust to an arbitrary JSON value.
You should usually call Builder.trust with a well-typed Trust value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Entity.Builder type(Entity.Type type)
A constant representing the object's type. For this resource it will always be
entity.
-
type
final Entity.Builder type(JsonField<Entity.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
validation
final Entity.Builder validation(Entity.Validation validation)
The validation results for the entity. Learn more about /documentation/entity-validation.
-
validation
final Entity.Builder validation(Optional<Entity.Validation> validation)
Alias for calling Builder.validation with
validation.orElse(null).
-
validation
final Entity.Builder validation(JsonField<Entity.Validation> validation)
Sets Builder.validation to an arbitrary JSON value.
You should usually call Builder.validation with a well-typed Validation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity build()
Returns an immutable instance of Entity.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .corporation() .createdAt() .creatingEntityOnboardingSessionId() .description() .detailsConfirmedAt() .governmentAuthority() .idempotencyKey() .joint() .naturalPerson() .riskRating() .status() .structure() .supplementalDocuments() .termsAgreements() .thirdPartyVerification() .trust() .type() .validation()
-
-
-
-