Class Entity.Corporation
-
- All Implemented Interfaces:
public final class Entity.CorporationDetails of the corporation entity. Will be present if
structureis equal tocorporation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Corporation.BuilderA builder for Corporation.
public final classEntity.Corporation.AddressThe corporation's address.
public final classEntity.Corporation.BeneficialOwnerpublic final classEntity.Corporation.LegalIdentifierThe legal identifier of the corporation.
-
Method Summary
Modifier and Type Method Description final Entity.Corporation.Addressaddress()The corporation's address. final List<Entity.Corporation.BeneficialOwner>beneficialOwners()The identifying details of anyone controlling or owning 25% or more of the corporation. final Optional<String>email()An email address for the business. final Optional<String>incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final Optional<String>industryCode()The numeric North American Industry Classification System (NAICS) code submitted for the corporation. final Optional<Entity.Corporation.LegalIdentifier>legalIdentifier()The legal identifier of the corporation. final Stringname()The legal name of the corporation. final Optional<String>website()The website of the corporation. final JsonField<Entity.Corporation.Address>_address()Returns the raw JSON value of address. final JsonField<List<Entity.Corporation.BeneficialOwner>>_beneficialOwners()Returns the raw JSON value of beneficialOwners. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_incorporationState()Returns the raw JSON value of incorporationState. final JsonField<String>_industryCode()Returns the raw JSON value of industryCode. final JsonField<Entity.Corporation.LegalIdentifier>_legalIdentifier()Returns the raw JSON value of legalIdentifier. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_website()Returns the raw JSON value of website. final Map<String, JsonValue>_additionalProperties()final Entity.Corporation.BuildertoBuilder()final Entity.Corporationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Corporation.Builderbuilder()Returns a mutable builder for constructing an instance of Corporation. -
-
Method Detail
-
address
final Entity.Corporation.Address address()
The corporation's address.
-
beneficialOwners
final List<Entity.Corporation.BeneficialOwner> beneficialOwners()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
incorporationState
final Optional<String> incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
industryCode
final Optional<String> industryCode()
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
-
legalIdentifier
final Optional<Entity.Corporation.LegalIdentifier> legalIdentifier()
The legal identifier of the corporation.
-
_address
final JsonField<Entity.Corporation.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwners
final JsonField<List<Entity.Corporation.BeneficialOwner>> _beneficialOwners()
Returns the raw JSON value of beneficialOwners.
Unlike beneficialOwners, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_incorporationState
final JsonField<String> _incorporationState()
Returns the raw JSON value of incorporationState.
Unlike incorporationState, this method doesn't throw if the JSON field has an unexpected type.
-
_industryCode
final JsonField<String> _industryCode()
Returns the raw JSON value of industryCode.
Unlike industryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_legalIdentifier
final JsonField<Entity.Corporation.LegalIdentifier> _legalIdentifier()
Returns the raw JSON value of legalIdentifier.
Unlike legalIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_website
final JsonField<String> _website()
Returns the raw JSON value of website.
Unlike website, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Corporation.Builder toBuilder()
-
validate
final Entity.Corporation validate()
-
builder
final static Entity.Corporation.Builder builder()
Returns a mutable builder for constructing an instance of Corporation.
The following fields are required:
.address() .beneficialOwners() .email() .incorporationState() .industryCode() .legalIdentifier() .name() .website()
-
-
-
-