Class Entity.Corporation.Builder
-
- All Implemented Interfaces:
public final class Entity.Corporation.BuilderA builder for Corporation.
-
-
Method Summary
-
-
Method Detail
-
address
final Entity.Corporation.Builder address(Entity.Corporation.Address address)
The corporation's address.
-
address
final Entity.Corporation.Builder address(JsonField<Entity.Corporation.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwners
final Entity.Corporation.Builder beneficialOwners(List<Entity.Corporation.BeneficialOwner> beneficialOwners)
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
beneficialOwners
final Entity.Corporation.Builder beneficialOwners(JsonField<List<Entity.Corporation.BeneficialOwner>> beneficialOwners)
Sets Builder.beneficialOwners to an arbitrary JSON value.
You should usually call Builder.beneficialOwners with a well-typed
List<BeneficialOwner>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBeneficialOwner
final Entity.Corporation.Builder addBeneficialOwner(Entity.Corporation.BeneficialOwner beneficialOwner)
Adds a single BeneficialOwner to beneficialOwners.
-
incorporationState
final Entity.Corporation.Builder incorporationState(String incorporationState)
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
incorporationState
final Entity.Corporation.Builder incorporationState(Optional<String> incorporationState)
Alias for calling Builder.incorporationState with
incorporationState.orElse(null).
-
incorporationState
final Entity.Corporation.Builder incorporationState(JsonField<String> incorporationState)
Sets Builder.incorporationState to an arbitrary JSON value.
You should usually call Builder.incorporationState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
industryCode
final Entity.Corporation.Builder industryCode(String industryCode)
The numeric North American Industry Classification System (NAICS) code submitted for the corporation.
-
industryCode
final Entity.Corporation.Builder industryCode(Optional<String> industryCode)
Alias for calling Builder.industryCode with
industryCode.orElse(null).
-
industryCode
final Entity.Corporation.Builder industryCode(JsonField<String> industryCode)
Sets Builder.industryCode to an arbitrary JSON value.
You should usually call Builder.industryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Entity.Corporation.Builder name(String name)
The legal name of the corporation.
-
name
final Entity.Corporation.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final Entity.Corporation.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the corporation.
-
taxIdentifier
final Entity.Corporation.Builder taxIdentifier(Optional<String> taxIdentifier)
Alias for calling Builder.taxIdentifier with
taxIdentifier.orElse(null).
-
taxIdentifier
final Entity.Corporation.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
website
final Entity.Corporation.Builder website(String website)
The website of the corporation.
-
website
final Entity.Corporation.Builder website(Optional<String> website)
Alias for calling Builder.website with
website.orElse(null).
-
website
final Entity.Corporation.Builder website(JsonField<String> website)
Sets Builder.website to an arbitrary JSON value.
You should usually call Builder.website with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.Corporation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Corporation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Corporation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Corporation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Corporation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Corporation build()
Returns an immutable instance of Corporation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .beneficialOwners() .incorporationState() .industryCode() .name() .taxIdentifier() .website()
-
-
-
-