Class Entity.GovernmentAuthority
-
- All Implemented Interfaces:
public final class Entity.GovernmentAuthorityDetails of the government authority entity. Will be present if
structureis equal togovernment_authority.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
public final classEntity.GovernmentAuthority.AddressThe government authority's address.
public final classEntity.GovernmentAuthority.AuthorizedPersonpublic final classEntity.GovernmentAuthority.CategoryThe category of the government authority.
-
Method Summary
Modifier and Type Method Description final Entity.GovernmentAuthority.Addressaddress()The government authority's address. final List<Entity.GovernmentAuthority.AuthorizedPerson>authorizedPersons()The identifying details of authorized persons of the government authority. final Entity.GovernmentAuthority.Categorycategory()The category of the government authority. final Stringname()The government authority's name. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) of the government authority. final Optional<String>website()The government authority's website. final JsonField<Entity.GovernmentAuthority.Address>_address()Returns the raw JSON value of address. final JsonField<List<Entity.GovernmentAuthority.AuthorizedPerson>>_authorizedPersons()Returns the raw JSON value of authorizedPersons. final JsonField<Entity.GovernmentAuthority.Category>_category()Returns the raw JSON value of category. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_taxIdentifier()Returns the raw JSON value of taxIdentifier. final JsonField<String>_website()Returns the raw JSON value of website. final Map<String, JsonValue>_additionalProperties()final Entity.GovernmentAuthority.BuildertoBuilder()final Entity.GovernmentAuthorityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.GovernmentAuthority.Builderbuilder()Returns a mutable builder for constructing an instance of GovernmentAuthority. -
-
Method Detail
-
address
final Entity.GovernmentAuthority.Address address()
The government authority's address.
-
authorizedPersons
final List<Entity.GovernmentAuthority.AuthorizedPerson> authorizedPersons()
The identifying details of authorized persons of the government authority.
-
category
final Entity.GovernmentAuthority.Category category()
The category of the government authority.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) of the government authority.
-
_address
final JsonField<Entity.GovernmentAuthority.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizedPersons
final JsonField<List<Entity.GovernmentAuthority.AuthorizedPerson>> _authorizedPersons()
Returns the raw JSON value of authorizedPersons.
Unlike authorizedPersons, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Entity.GovernmentAuthority.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
Returns the raw JSON value of taxIdentifier.
Unlike taxIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_website
final JsonField<String> _website()
Returns the raw JSON value of website.
Unlike website, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.GovernmentAuthority.Builder toBuilder()
-
validate
final Entity.GovernmentAuthority validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.GovernmentAuthority.Builder builder()
Returns a mutable builder for constructing an instance of GovernmentAuthority.
The following fields are required:
.address() .authorizedPersons() .category() .name() .taxIdentifier() .website()
-
-
-
-