Class Entity.GovernmentAuthority.Builder
-
- All Implemented Interfaces:
public final class Entity.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
-
-
Method Summary
-
-
Method Detail
-
address
final Entity.GovernmentAuthority.Builder address(Entity.GovernmentAuthority.Address address)
The government authority's address.
-
address
final Entity.GovernmentAuthority.Builder address(JsonField<Entity.GovernmentAuthority.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizedPersons
final Entity.GovernmentAuthority.Builder authorizedPersons(List<Entity.GovernmentAuthority.AuthorizedPerson> authorizedPersons)
The identifying details of authorized persons of the government authority.
-
authorizedPersons
final Entity.GovernmentAuthority.Builder authorizedPersons(JsonField<List<Entity.GovernmentAuthority.AuthorizedPerson>> authorizedPersons)
Sets Builder.authorizedPersons to an arbitrary JSON value.
You should usually call Builder.authorizedPersons with a well-typed
List<AuthorizedPerson>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthorizedPerson
final Entity.GovernmentAuthority.Builder addAuthorizedPerson(Entity.GovernmentAuthority.AuthorizedPerson authorizedPerson)
Adds a single AuthorizedPerson to authorizedPersons.
-
category
final Entity.GovernmentAuthority.Builder category(Entity.GovernmentAuthority.Category category)
The category of the government authority.
-
category
final Entity.GovernmentAuthority.Builder category(JsonField<Entity.GovernmentAuthority.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Entity.GovernmentAuthority.Builder name(String name)
The government authority's name.
-
name
final Entity.GovernmentAuthority.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final Entity.GovernmentAuthority.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) of the government authority.
-
taxIdentifier
final Entity.GovernmentAuthority.Builder taxIdentifier(Optional<String> taxIdentifier)
Alias for calling Builder.taxIdentifier with
taxIdentifier.orElse(null).
-
taxIdentifier
final Entity.GovernmentAuthority.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
website
final Entity.GovernmentAuthority.Builder website(String website)
The government authority's website.
-
website
final Entity.GovernmentAuthority.Builder website(Optional<String> website)
Alias for calling Builder.website with
website.orElse(null).
-
website
final Entity.GovernmentAuthority.Builder website(JsonField<String> website)
Sets Builder.website to an arbitrary JSON value.
You should usually call Builder.website with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.GovernmentAuthority.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.GovernmentAuthority.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.GovernmentAuthority.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.GovernmentAuthority.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.GovernmentAuthority.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.GovernmentAuthority build()
Returns an immutable instance of GovernmentAuthority.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .authorizedPersons() .category() .name() .taxIdentifier() .website()
-
-
-
-