Package com.increase.api.models.entities
Class Entity.Joint
-
- All Implemented Interfaces:
public final class Entity.JointDetails of the joint entity. Will be present if
structureis equal tojoint.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Joint.BuilderA builder for Joint.
public final classEntity.Joint.Individual
-
Method Summary
Modifier and Type Method Description final List<Entity.Joint.Individual>individuals()The two individuals that share control of the entity. final Stringname()The entity's name. final JsonField<List<Entity.Joint.Individual>>_individuals()Returns the raw JSON value of individuals. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final Entity.Joint.BuildertoBuilder()final Entity.Jointvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Joint.Builderbuilder()Returns a mutable builder for constructing an instance of Joint. -
-
Method Detail
-
individuals
final List<Entity.Joint.Individual> individuals()
The two individuals that share control of the entity.
-
_individuals
final JsonField<List<Entity.Joint.Individual>> _individuals()
Returns the raw JSON value of individuals.
Unlike individuals, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Joint.Builder toBuilder()
-
validate
final Entity.Joint validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.Joint.Builder builder()
Returns a mutable builder for constructing an instance of Joint.
The following fields are required:
.individuals() .name()
-
-
-
-