Class Entity.Joint.Individual.Address
-
- All Implemented Interfaces:
public final class Entity.Joint.Individual.AddressThe person's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Joint.Individual.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the address. final Stringline1()The first line of the address. final Optional<String>line2()The second line of the address. final Stringstate()The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final Stringzip()The ZIP code of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_zip()Returns the raw JSON value of zip. final Map<String, JsonValue>_additionalProperties()final Entity.Joint.Individual.Address.BuildertoBuilder()final Entity.Joint.Individual.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Joint.Individual.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
state
final String state()
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_zip
final JsonField<String> _zip()
Returns the raw JSON value of zip.
Unlike zip, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Joint.Individual.Address.Builder toBuilder()
-
validate
final Entity.Joint.Individual.Address validate()
-
builder
final static Entity.Joint.Individual.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .line1() .line2() .state() .zip()
-
-
-
-