Class Entity.Joint.Individual.Identification
-
- All Implemented Interfaces:
public final class Entity.Joint.Individual.IdentificationA means of verifying the person's identity.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Joint.Individual.Identification.BuilderA builder for Identification.
public final classEntity.Joint.Individual.Identification.MethodA method that can be used to verify the individual's identity.
-
Method Summary
Modifier and Type Method Description final Entity.Joint.Individual.Identification.Methodmethod()A method that can be used to verify the individual's identity. final StringnumberLast4()The last 4 digits of the identification number that can be used to verify the individual's identity. final JsonField<Entity.Joint.Individual.Identification.Method>_method()Returns the raw JSON value of method. final JsonField<String>_numberLast4()Returns the raw JSON value of numberLast4. final Map<String, JsonValue>_additionalProperties()final Entity.Joint.Individual.Identification.BuildertoBuilder()final Entity.Joint.Individual.Identificationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Joint.Individual.Identification.Builderbuilder()Returns a mutable builder for constructing an instance of Identification. -
-
Method Detail
-
method
final Entity.Joint.Individual.Identification.Method method()
A method that can be used to verify the individual's identity.
-
numberLast4
final String numberLast4()
The last 4 digits of the identification number that can be used to verify the individual's identity.
-
_method
final JsonField<Entity.Joint.Individual.Identification.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_numberLast4
final JsonField<String> _numberLast4()
Returns the raw JSON value of numberLast4.
Unlike numberLast4, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Joint.Individual.Identification.Builder toBuilder()
-
validate
final Entity.Joint.Individual.Identification validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.Joint.Individual.Identification.Builder builder()
Returns a mutable builder for constructing an instance of Identification.
The following fields are required:
.method() .numberLast4()
-
-
-
-