Class Entity.NaturalPerson
-
- All Implemented Interfaces:
public final class Entity.NaturalPersonDetails of the natural person entity. Will be present if
structureis equal tonatural_person.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.NaturalPerson.BuilderA builder for NaturalPerson.
public final classEntity.NaturalPerson.AddressThe person's address.
public final classEntity.NaturalPerson.IdentificationA means of verifying the person's identity.
-
Method Summary
Modifier and Type Method Description final Entity.NaturalPerson.Addressaddress()The person's address. final LocalDatedateOfBirth()The person's date of birth in YYYY-MM-DD format. final Entity.NaturalPerson.Identificationidentification()A means of verifying the person's identity. final Stringname()The person's legal name. final JsonField<Entity.NaturalPerson.Address>_address()Returns the raw JSON value of address. final JsonField<LocalDate>_dateOfBirth()Returns the raw JSON value of dateOfBirth. final JsonField<Entity.NaturalPerson.Identification>_identification()Returns the raw JSON value of identification. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final Entity.NaturalPerson.BuildertoBuilder()final Entity.NaturalPersonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.NaturalPerson.Builderbuilder()Returns a mutable builder for constructing an instance of NaturalPerson. -
-
Method Detail
-
address
final Entity.NaturalPerson.Address address()
The person's address.
-
dateOfBirth
final LocalDate dateOfBirth()
The person's date of birth in YYYY-MM-DD format.
-
identification
final Entity.NaturalPerson.Identification identification()
A means of verifying the person's identity.
-
_address
final JsonField<Entity.NaturalPerson.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfBirth
final JsonField<LocalDate> _dateOfBirth()
Returns the raw JSON value of dateOfBirth.
Unlike dateOfBirth, this method doesn't throw if the JSON field has an unexpected type.
-
_identification
final JsonField<Entity.NaturalPerson.Identification> _identification()
Returns the raw JSON value of identification.
Unlike identification, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.NaturalPerson.Builder toBuilder()
-
validate
final Entity.NaturalPerson validate()
-
builder
final static Entity.NaturalPerson.Builder builder()
Returns a mutable builder for constructing an instance of NaturalPerson.
The following fields are required:
.address() .dateOfBirth() .identification() .name()
-
-
-
-