Class Entity.NaturalPerson.Address
-
- All Implemented Interfaces:
public final class Entity.NaturalPerson.AddressThe person's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.NaturalPerson.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Optional<String>city()The city, district, town, or village of the address. final Stringcountry()The two-letter ISO 3166-1 alpha-2 code for the country of the address. final Stringline1()The first line of the address. final Optional<String>line2()The second line of the address. final Optional<String>state()The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. final Optional<String>zip()The ZIP or postal code of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_zip()Returns the raw JSON value of zip. final Map<String, JsonValue>_additionalProperties()final Entity.NaturalPerson.Address.BuildertoBuilder()final Entity.NaturalPerson.Addressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.NaturalPerson.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
country
final String country()
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
state
final Optional<String> state()
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_zip
final JsonField<String> _zip()
Returns the raw JSON value of zip.
Unlike zip, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.NaturalPerson.Address.Builder toBuilder()
-
validate
final Entity.NaturalPerson.Address validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.NaturalPerson.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .country() .line1() .line2() .state() .zip()
-
-
-
-