Package com.increase.api.models.entities
Class Entity.NaturalPerson.Identification
-
- All Implemented Interfaces:
public final class Entity.NaturalPerson.IdentificationA means of verifying the person's identity.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.NaturalPerson.Identification.BuilderA builder for Identification.
public final classEntity.NaturalPerson.Identification.MethodA method that can be used to verify the individual's identity.
-
Method Summary
Modifier and Type Method Description final Entity.NaturalPerson.Identification.Methodmethod()A method that can be used to verify the individual's identity. final StringnumberLast4()The last 4 digits of the identification number that can be used to verify the individual's identity. final JsonField<Entity.NaturalPerson.Identification.Method>_method()Returns the raw JSON value of method. final JsonField<String>_numberLast4()Returns the raw JSON value of numberLast4. final Map<String, JsonValue>_additionalProperties()final Entity.NaturalPerson.Identification.BuildertoBuilder()final Entity.NaturalPerson.Identificationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.NaturalPerson.Identification.Builderbuilder()Returns a mutable builder for constructing an instance of Identification. -
-
Method Detail
-
method
final Entity.NaturalPerson.Identification.Method method()
A method that can be used to verify the individual's identity.
-
numberLast4
final String numberLast4()
The last 4 digits of the identification number that can be used to verify the individual's identity.
-
_method
final JsonField<Entity.NaturalPerson.Identification.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_numberLast4
final JsonField<String> _numberLast4()
Returns the raw JSON value of numberLast4.
Unlike numberLast4, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.NaturalPerson.Identification.Builder toBuilder()
-
validate
final Entity.NaturalPerson.Identification validate()
-
builder
final static Entity.NaturalPerson.Identification.Builder builder()
Returns a mutable builder for constructing an instance of Identification.
The following fields are required:
.method() .numberLast4()
-
-
-
-