Class Entity.NaturalPerson.Identification.Builder
-
- All Implemented Interfaces:
public final class Entity.NaturalPerson.Identification.BuilderA builder for Identification.
-
-
Method Summary
-
-
Method Detail
-
method
final Entity.NaturalPerson.Identification.Builder method(Entity.NaturalPerson.Identification.Method method)
A method that can be used to verify the individual's identity.
-
method
final Entity.NaturalPerson.Identification.Builder method(JsonField<Entity.NaturalPerson.Identification.Method> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed Method value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
numberLast4
final Entity.NaturalPerson.Identification.Builder numberLast4(String numberLast4)
The last 4 digits of the identification number that can be used to verify the individual's identity.
-
numberLast4
final Entity.NaturalPerson.Identification.Builder numberLast4(JsonField<String> numberLast4)
Sets Builder.numberLast4 to an arbitrary JSON value.
You should usually call Builder.numberLast4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.NaturalPerson.Identification.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.NaturalPerson.Identification.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.NaturalPerson.Identification.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.NaturalPerson.Identification.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.NaturalPerson.Identification.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.NaturalPerson.Identification build()
Returns an immutable instance of Identification.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.method() .numberLast4()
-
-
-
-