Class Entity.RiskRating
-
- All Implemented Interfaces:
public final class Entity.RiskRatingAn assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.RiskRating.BuilderA builder for RiskRating.
public final classEntity.RiskRating.RatingThe rating given to this entity.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeratedAt()The ISO 8601 time at which the risk rating was performed. final Entity.RiskRating.Ratingrating()The rating given to this entity. final JsonField<OffsetDateTime>_ratedAt()Returns the raw JSON value of ratedAt. final JsonField<Entity.RiskRating.Rating>_rating()Returns the raw JSON value of rating. final Map<String, JsonValue>_additionalProperties()final Entity.RiskRating.BuildertoBuilder()final Entity.RiskRatingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.RiskRating.Builderbuilder()Returns a mutable builder for constructing an instance of RiskRating. -
-
Method Detail
-
ratedAt
final OffsetDateTime ratedAt()
The ISO 8601 time at which the risk rating was performed.
-
rating
final Entity.RiskRating.Rating rating()
The rating given to this entity.
-
_ratedAt
final JsonField<OffsetDateTime> _ratedAt()
Returns the raw JSON value of ratedAt.
Unlike ratedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_rating
final JsonField<Entity.RiskRating.Rating> _rating()
Returns the raw JSON value of rating.
Unlike rating, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.RiskRating.Builder toBuilder()
-
validate
final Entity.RiskRating validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.RiskRating.Builder builder()
Returns a mutable builder for constructing an instance of RiskRating.
The following fields are required:
.ratedAt() .rating()
-
-
-
-