Class Entity.TermsAgreement.Builder
-
- All Implemented Interfaces:
public final class Entity.TermsAgreement.BuilderA builder for TermsAgreement.
-
-
Method Summary
-
-
Method Detail
-
agreedAt
final Entity.TermsAgreement.Builder agreedAt(OffsetDateTime agreedAt)
The timestamp of when the Entity agreed to the terms.
-
agreedAt
final Entity.TermsAgreement.Builder agreedAt(JsonField<OffsetDateTime> agreedAt)
Sets Builder.agreedAt to an arbitrary JSON value.
You should usually call Builder.agreedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
ipAddress
final Entity.TermsAgreement.Builder ipAddress(String ipAddress)
The IP address the Entity accessed reviewed the terms from.
-
ipAddress
final Entity.TermsAgreement.Builder ipAddress(JsonField<String> ipAddress)
Sets Builder.ipAddress to an arbitrary JSON value.
You should usually call Builder.ipAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
termsUrl
final Entity.TermsAgreement.Builder termsUrl(String termsUrl)
The URL of the terms agreement. This link will be provided by your bank partner.
-
termsUrl
final Entity.TermsAgreement.Builder termsUrl(JsonField<String> termsUrl)
Sets Builder.termsUrl to an arbitrary JSON value.
You should usually call Builder.termsUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.TermsAgreement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.TermsAgreement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.TermsAgreement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.TermsAgreement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.TermsAgreement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.TermsAgreement build()
Returns an immutable instance of TermsAgreement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.agreedAt() .ipAddress() .termsUrl()
-
-
-
-