Class Entity.ThirdPartyVerification.Builder
-
- All Implemented Interfaces:
public final class Entity.ThirdPartyVerification.BuilderA builder for ThirdPartyVerification.
-
-
Method Summary
-
-
Method Detail
-
reference
final Entity.ThirdPartyVerification.Builder reference(String reference)
The reference identifier for the third party verification.
-
reference
final Entity.ThirdPartyVerification.Builder reference(JsonField<String> reference)
Sets Builder.reference to an arbitrary JSON value.
You should usually call Builder.reference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vendor
final Entity.ThirdPartyVerification.Builder vendor(Entity.ThirdPartyVerification.Vendor vendor)
The vendor that was used to perform the verification.
-
vendor
final Entity.ThirdPartyVerification.Builder vendor(JsonField<Entity.ThirdPartyVerification.Vendor> vendor)
Sets Builder.vendor to an arbitrary JSON value.
You should usually call Builder.vendor with a well-typed Vendor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.ThirdPartyVerification.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.ThirdPartyVerification.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.ThirdPartyVerification.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.ThirdPartyVerification.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.ThirdPartyVerification.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.ThirdPartyVerification build()
Returns an immutable instance of ThirdPartyVerification.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.reference() .vendor()
-
-
-
-