Class Entity.Trust
-
- All Implemented Interfaces:
public final class Entity.TrustDetails of the trust entity. Will be present if
structureis equal totrust.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Trust.BuilderA builder for Trust.
public final classEntity.Trust.AddressThe trust's address.
public final classEntity.Trust.CategoryWhether the trust is
revocableorirrevocable.public final classEntity.Trust.GrantorThe grantor of the trust. Will be present if the
categoryisrevocable.public final classEntity.Trust.Trustee
-
Method Summary
Modifier and Type Method Description final Entity.Trust.Addressaddress()The trust's address. final Entity.Trust.Categorycategory()Whether the trust is revocableorirrevocable.final Optional<String>formationDocumentFileId()The ID for the File containing the formation document of the trust. final Optional<String>formationState()The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Optional<Entity.Trust.Grantor>grantor()The grantor of the trust. final Stringname()The trust's name. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) of the trust itself. final List<Entity.Trust.Trustee>trustees()The trustees of the trust. final JsonField<Entity.Trust.Address>_address()Returns the raw JSON value of address. final JsonField<Entity.Trust.Category>_category()Returns the raw JSON value of category. final JsonField<String>_formationDocumentFileId()Returns the raw JSON value of formationDocumentFileId. final JsonField<String>_formationState()Returns the raw JSON value of formationState. final JsonField<Entity.Trust.Grantor>_grantor()Returns the raw JSON value of grantor. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_taxIdentifier()Returns the raw JSON value of taxIdentifier. final JsonField<List<Entity.Trust.Trustee>>_trustees()Returns the raw JSON value of trustees. final Map<String, JsonValue>_additionalProperties()final Entity.Trust.BuildertoBuilder()final Entity.Trustvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Trust.Builderbuilder()Returns a mutable builder for constructing an instance of Trust. -
-
Method Detail
-
address
final Entity.Trust.Address address()
The trust's address.
-
category
final Entity.Trust.Category category()
Whether the trust is
revocableorirrevocable.
-
formationDocumentFileId
final Optional<String> formationDocumentFileId()
The ID for the File containing the formation document of the trust.
-
formationState
final Optional<String> formationState()
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
grantor
final Optional<Entity.Trust.Grantor> grantor()
The grantor of the trust. Will be present if the
categoryisrevocable.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) of the trust itself.
-
trustees
final List<Entity.Trust.Trustee> trustees()
The trustees of the trust.
-
_address
final JsonField<Entity.Trust.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Entity.Trust.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_formationDocumentFileId
final JsonField<String> _formationDocumentFileId()
Returns the raw JSON value of formationDocumentFileId.
Unlike formationDocumentFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_formationState
final JsonField<String> _formationState()
Returns the raw JSON value of formationState.
Unlike formationState, this method doesn't throw if the JSON field has an unexpected type.
-
_grantor
final JsonField<Entity.Trust.Grantor> _grantor()
Returns the raw JSON value of grantor.
Unlike grantor, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
Returns the raw JSON value of taxIdentifier.
Unlike taxIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_trustees
final JsonField<List<Entity.Trust.Trustee>> _trustees()
Returns the raw JSON value of trustees.
Unlike trustees, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Trust.Builder toBuilder()
-
validate
final Entity.Trust validate()
-
builder
final static Entity.Trust.Builder builder()
Returns a mutable builder for constructing an instance of Trust.
The following fields are required:
.address() .category() .formationDocumentFileId() .formationState() .grantor() .name() .taxIdentifier() .trustees()
-
-
-
-