Class Entity.Trust.Address.Builder
-
- All Implemented Interfaces:
public final class Entity.Trust.Address.BuilderA builder for Address.
-
-
Method Summary
Modifier and Type Method Description final Entity.Trust.Address.Buildercity(String city)The city, district, town, or village of the address. final Entity.Trust.Address.Buildercity(Optional<String> city)Alias for calling Builder.city with city.orElse(null).final Entity.Trust.Address.Buildercity(JsonField<String> city)Sets Builder.city to an arbitrary JSON value. final Entity.Trust.Address.Buildercountry(String country)The two-letter ISO 3166-1 alpha-2 code for the country of the address. final Entity.Trust.Address.Buildercountry(JsonField<String> country)Sets Builder.country to an arbitrary JSON value. final Entity.Trust.Address.Builderline1(String line1)The first line of the address. final Entity.Trust.Address.Builderline1(JsonField<String> line1)Sets Builder.line1 to an arbitrary JSON value. final Entity.Trust.Address.Builderline2(String line2)The second line of the address. final Entity.Trust.Address.Builderline2(Optional<String> line2)Alias for calling Builder.line2 with line2.orElse(null).final Entity.Trust.Address.Builderline2(JsonField<String> line2)Sets Builder.line2 to an arbitrary JSON value. final Entity.Trust.Address.Builderstate(String state)The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. final Entity.Trust.Address.Builderstate(Optional<String> state)Alias for calling Builder.state with state.orElse(null).final Entity.Trust.Address.Builderstate(JsonField<String> state)Sets Builder.state to an arbitrary JSON value. final Entity.Trust.Address.Builderzip(String zip)The ZIP or postal code of the address. final Entity.Trust.Address.Builderzip(Optional<String> zip)Alias for calling Builder.zip with zip.orElse(null).final Entity.Trust.Address.Builderzip(JsonField<String> zip)Sets Builder.zip to an arbitrary JSON value. final Entity.Trust.Address.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.Trust.Address.BuilderputAdditionalProperty(String key, JsonValue value)final Entity.Trust.Address.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Entity.Trust.Address.BuilderremoveAdditionalProperty(String key)final Entity.Trust.Address.BuilderremoveAllAdditionalProperties(Set<String> keys)final Entity.Trust.Addressbuild()Returns an immutable instance of Address. -
-
Method Detail
-
city
final Entity.Trust.Address.Builder city(String city)
The city, district, town, or village of the address.
-
city
final Entity.Trust.Address.Builder city(Optional<String> city)
Alias for calling Builder.city with
city.orElse(null).
-
city
final Entity.Trust.Address.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final Entity.Trust.Address.Builder country(String country)
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
country
final Entity.Trust.Address.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final Entity.Trust.Address.Builder line1(String line1)
The first line of the address.
-
line1
final Entity.Trust.Address.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final Entity.Trust.Address.Builder line2(String line2)
The second line of the address.
-
line2
final Entity.Trust.Address.Builder line2(Optional<String> line2)
Alias for calling Builder.line2 with
line2.orElse(null).
-
line2
final Entity.Trust.Address.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Entity.Trust.Address.Builder state(String state)
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address.
-
state
final Entity.Trust.Address.Builder state(Optional<String> state)
Alias for calling Builder.state with
state.orElse(null).
-
state
final Entity.Trust.Address.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
zip
final Entity.Trust.Address.Builder zip(String zip)
The ZIP or postal code of the address.
-
zip
final Entity.Trust.Address.Builder zip(Optional<String> zip)
Alias for calling Builder.zip with
zip.orElse(null).
-
zip
final Entity.Trust.Address.Builder zip(JsonField<String> zip)
Sets Builder.zip to an arbitrary JSON value.
You should usually call Builder.zip with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.Trust.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Trust.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Trust.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Trust.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Trust.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Trust.Address build()
Returns an immutable instance of Address.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .country() .line1() .line2() .state() .zip()
-
-
-
-