Class Entity.Trust.Builder
-
- All Implemented Interfaces:
public final class Entity.Trust.BuilderA builder for Trust.
-
-
Method Summary
-
-
Method Detail
-
address
final Entity.Trust.Builder address(Entity.Trust.Address address)
The trust's address.
-
address
final Entity.Trust.Builder address(JsonField<Entity.Trust.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Entity.Trust.Builder category(Entity.Trust.Category category)
Whether the trust is
revocableorirrevocable.
-
category
final Entity.Trust.Builder category(JsonField<Entity.Trust.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
formationDocumentFileId
final Entity.Trust.Builder formationDocumentFileId(String formationDocumentFileId)
The ID for the File containing the formation document of the trust.
-
formationDocumentFileId
final Entity.Trust.Builder formationDocumentFileId(Optional<String> formationDocumentFileId)
Alias for calling Builder.formationDocumentFileId with
formationDocumentFileId.orElse(null).
-
formationDocumentFileId
final Entity.Trust.Builder formationDocumentFileId(JsonField<String> formationDocumentFileId)
Sets Builder.formationDocumentFileId to an arbitrary JSON value.
You should usually call Builder.formationDocumentFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
formationState
final Entity.Trust.Builder formationState(String formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
formationState
final Entity.Trust.Builder formationState(Optional<String> formationState)
Alias for calling Builder.formationState with
formationState.orElse(null).
-
formationState
final Entity.Trust.Builder formationState(JsonField<String> formationState)
Sets Builder.formationState to an arbitrary JSON value.
You should usually call Builder.formationState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
grantor
final Entity.Trust.Builder grantor(Entity.Trust.Grantor grantor)
The grantor of the trust. Will be present if the
categoryisrevocable.
-
grantor
final Entity.Trust.Builder grantor(Optional<Entity.Trust.Grantor> grantor)
Alias for calling Builder.grantor with
grantor.orElse(null).
-
grantor
final Entity.Trust.Builder grantor(JsonField<Entity.Trust.Grantor> grantor)
Sets Builder.grantor to an arbitrary JSON value.
You should usually call Builder.grantor with a well-typed Grantor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Entity.Trust.Builder name(String name)
The trust's name.
-
name
final Entity.Trust.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final Entity.Trust.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) of the trust itself.
-
taxIdentifier
final Entity.Trust.Builder taxIdentifier(Optional<String> taxIdentifier)
Alias for calling Builder.taxIdentifier with
taxIdentifier.orElse(null).
-
taxIdentifier
final Entity.Trust.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trustees
final Entity.Trust.Builder trustees(List<Entity.Trust.Trustee> trustees)
The trustees of the trust.
-
trustees
final Entity.Trust.Builder trustees(JsonField<List<Entity.Trust.Trustee>> trustees)
Sets Builder.trustees to an arbitrary JSON value.
You should usually call Builder.trustees with a well-typed
List<Trustee>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTrustee
final Entity.Trust.Builder addTrustee(Entity.Trust.Trustee trustee)
-
additionalProperties
final Entity.Trust.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Trust.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Trust.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Trust.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Trust.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Trust build()
Returns an immutable instance of Trust.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .category() .formationDocumentFileId() .formationState() .grantor() .name() .taxIdentifier() .trustees()
-
-
-
-