Class Entity.Trust.Grantor
-
- All Implemented Interfaces:
public final class Entity.Trust.GrantorThe grantor of the trust. Will be present if the
categoryisrevocable.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Trust.Grantor.BuilderA builder for Grantor.
public final classEntity.Trust.Grantor.AddressThe person's address.
public final classEntity.Trust.Grantor.IdentificationA means of verifying the person's identity.
-
Method Summary
Modifier and Type Method Description final Entity.Trust.Grantor.Addressaddress()The person's address. final LocalDatedateOfBirth()The person's date of birth in YYYY-MM-DD format. final Entity.Trust.Grantor.Identificationidentification()A means of verifying the person's identity. final Stringname()The person's legal name. final JsonField<Entity.Trust.Grantor.Address>_address()Returns the raw JSON value of address. final JsonField<LocalDate>_dateOfBirth()Returns the raw JSON value of dateOfBirth. final JsonField<Entity.Trust.Grantor.Identification>_identification()Returns the raw JSON value of identification. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final Entity.Trust.Grantor.BuildertoBuilder()final Entity.Trust.Grantorvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Trust.Grantor.Builderbuilder()Returns a mutable builder for constructing an instance of Grantor. -
-
Method Detail
-
address
final Entity.Trust.Grantor.Address address()
The person's address.
-
dateOfBirth
final LocalDate dateOfBirth()
The person's date of birth in YYYY-MM-DD format.
-
identification
final Entity.Trust.Grantor.Identification identification()
A means of verifying the person's identity.
-
_address
final JsonField<Entity.Trust.Grantor.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfBirth
final JsonField<LocalDate> _dateOfBirth()
Returns the raw JSON value of dateOfBirth.
Unlike dateOfBirth, this method doesn't throw if the JSON field has an unexpected type.
-
_identification
final JsonField<Entity.Trust.Grantor.Identification> _identification()
Returns the raw JSON value of identification.
Unlike identification, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Trust.Grantor.Builder toBuilder()
-
validate
final Entity.Trust.Grantor validate()
-
builder
final static Entity.Trust.Grantor.Builder builder()
Returns a mutable builder for constructing an instance of Grantor.
The following fields are required:
.address() .dateOfBirth() .identification() .name()
-
-
-
-