Class Entity.Trust.Trustee
-
- All Implemented Interfaces:
public final class Entity.Trust.Trustee
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Trust.Trustee.BuilderA builder for Trustee.
public final classEntity.Trust.Trustee.IndividualThe individual trustee of the trust. Will be present if the trustee's
structureis equal toindividual.public final classEntity.Trust.Trustee.StructureThe structure of the trustee. Will always be equal to
individual.
-
Method Summary
Modifier and Type Method Description final Optional<Entity.Trust.Trustee.Individual>individual()The individual trustee of the trust. final Entity.Trust.Trustee.Structurestructure()The structure of the trustee. final JsonField<Entity.Trust.Trustee.Individual>_individual()Returns the raw JSON value of individual. final JsonField<Entity.Trust.Trustee.Structure>_structure()Returns the raw JSON value of structure. final Map<String, JsonValue>_additionalProperties()final Entity.Trust.Trustee.BuildertoBuilder()final Entity.Trust.Trusteevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Trust.Trustee.Builderbuilder()Returns a mutable builder for constructing an instance of Trustee. -
-
Method Detail
-
individual
final Optional<Entity.Trust.Trustee.Individual> individual()
The individual trustee of the trust. Will be present if the trustee's
structureis equal toindividual.
-
structure
final Entity.Trust.Trustee.Structure structure()
The structure of the trustee. Will always be equal to
individual.
-
_individual
final JsonField<Entity.Trust.Trustee.Individual> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_structure
final JsonField<Entity.Trust.Trustee.Structure> _structure()
Returns the raw JSON value of structure.
Unlike structure, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Trust.Trustee.Builder toBuilder()
-
validate
final Entity.Trust.Trustee validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.Trust.Trustee.Builder builder()
Returns a mutable builder for constructing an instance of Trustee.
The following fields are required:
.individual() .structure()
-
-
-
-