Class Entity.Trust.Trustee.Builder
-
- All Implemented Interfaces:
public final class Entity.Trust.Trustee.BuilderA builder for Trustee.
-
-
Method Summary
-
-
Method Detail
-
individual
final Entity.Trust.Trustee.Builder individual(Entity.Trust.Trustee.Individual individual)
The individual trustee of the trust. Will be present if the trustee's
structureis equal toindividual.
-
individual
final Entity.Trust.Trustee.Builder individual(Optional<Entity.Trust.Trustee.Individual> individual)
Alias for calling Builder.individual with
individual.orElse(null).
-
individual
final Entity.Trust.Trustee.Builder individual(JsonField<Entity.Trust.Trustee.Individual> individual)
Sets Builder.individual to an arbitrary JSON value.
You should usually call Builder.individual with a well-typed Individual value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
structure
final Entity.Trust.Trustee.Builder structure(Entity.Trust.Trustee.Structure structure)
The structure of the trustee. Will always be equal to
individual.
-
structure
final Entity.Trust.Trustee.Builder structure(JsonField<Entity.Trust.Trustee.Structure> structure)
Sets Builder.structure to an arbitrary JSON value.
You should usually call Builder.structure with a well-typed Structure value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.Trust.Trustee.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Trust.Trustee.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Trust.Trustee.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Trust.Trustee.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Trust.Trustee.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Trust.Trustee build()
Returns an immutable instance of Trustee.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.individual() .structure()
-
-
-
-