Class Entity.Validation.Issue
-
- All Implemented Interfaces:
public final class Entity.Validation.Issue
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Validation.Issue.BuilderA builder for Issue.
public final classEntity.Validation.Issue.BeneficialOwnerAddressDetails when the issue is with a beneficial owner's address.
public final classEntity.Validation.Issue.BeneficialOwnerIdentityDetails when the issue is with a beneficial owner's identity verification.
public final classEntity.Validation.Issue.CategoryThe type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classEntity.Validation.Issue.EntityAddressDetails when the issue is with the entity's address.
public final classEntity.Validation.Issue.EntityTaxIdentifierDetails when the issue is with the entity's tax ID.
-
Method Summary
-
-
Method Detail
-
beneficialOwnerAddress
final Optional<Entity.Validation.Issue.BeneficialOwnerAddress> beneficialOwnerAddress()
Details when the issue is with a beneficial owner's address.
-
beneficialOwnerIdentity
final Optional<Entity.Validation.Issue.BeneficialOwnerIdentity> beneficialOwnerIdentity()
Details when the issue is with a beneficial owner's identity verification.
-
category
final Entity.Validation.Issue.Category category()
The type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
entityAddress
final Optional<Entity.Validation.Issue.EntityAddress> entityAddress()
Details when the issue is with the entity's address.
-
entityTaxIdentifier
final Optional<Entity.Validation.Issue.EntityTaxIdentifier> entityTaxIdentifier()
Details when the issue is with the entity's tax ID.
-
_beneficialOwnerAddress
final JsonField<Entity.Validation.Issue.BeneficialOwnerAddress> _beneficialOwnerAddress()
Returns the raw JSON value of beneficialOwnerAddress.
Unlike beneficialOwnerAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwnerIdentity
final JsonField<Entity.Validation.Issue.BeneficialOwnerIdentity> _beneficialOwnerIdentity()
Returns the raw JSON value of beneficialOwnerIdentity.
Unlike beneficialOwnerIdentity, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Entity.Validation.Issue.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_entityAddress
final JsonField<Entity.Validation.Issue.EntityAddress> _entityAddress()
Returns the raw JSON value of entityAddress.
Unlike entityAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_entityTaxIdentifier
final JsonField<Entity.Validation.Issue.EntityTaxIdentifier> _entityTaxIdentifier()
Returns the raw JSON value of entityTaxIdentifier.
Unlike entityTaxIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Validation.Issue.Builder toBuilder()
-
validate
final Entity.Validation.Issue validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.Validation.Issue.Builder builder()
Returns a mutable builder for constructing an instance of Issue.
The following fields are required:
.beneficialOwnerAddress() .beneficialOwnerIdentity() .category() .entityAddress() .entityTaxIdentifier()
-
-
-
-