Class Entity.Validation.Issue.BeneficialOwnerAddress
-
- All Implemented Interfaces:
public final class Entity.Validation.Issue.BeneficialOwnerAddressDetails when the issue is with a beneficial owner's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Validation.Issue.BeneficialOwnerAddress.BuilderA builder for BeneficialOwnerAddress.
public final classEntity.Validation.Issue.BeneficialOwnerAddress.ReasonThe reason the address is invalid.
-
Method Summary
Modifier and Type Method Description final StringbeneficialOwnerId()The ID of the beneficial owner. final Entity.Validation.Issue.BeneficialOwnerAddress.Reasonreason()The reason the address is invalid. final JsonField<String>_beneficialOwnerId()Returns the raw JSON value of beneficialOwnerId. final JsonField<Entity.Validation.Issue.BeneficialOwnerAddress.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final Entity.Validation.Issue.BeneficialOwnerAddress.BuildertoBuilder()final Entity.Validation.Issue.BeneficialOwnerAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Validation.Issue.BeneficialOwnerAddress.Builderbuilder()Returns a mutable builder for constructing an instance of BeneficialOwnerAddress. -
-
Method Detail
-
beneficialOwnerId
final String beneficialOwnerId()
The ID of the beneficial owner.
-
reason
final Entity.Validation.Issue.BeneficialOwnerAddress.Reason reason()
The reason the address is invalid.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
Returns the raw JSON value of beneficialOwnerId.
Unlike beneficialOwnerId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<Entity.Validation.Issue.BeneficialOwnerAddress.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Validation.Issue.BeneficialOwnerAddress.Builder toBuilder()
-
validate
final Entity.Validation.Issue.BeneficialOwnerAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.Validation.Issue.BeneficialOwnerAddress.Builder builder()
Returns a mutable builder for constructing an instance of BeneficialOwnerAddress.
The following fields are required:
.beneficialOwnerId() .reason()
-
-
-
-