Package com.increase.api.models.entities
Class Entity.Validation.Issue.BeneficialOwnerIdentity.Builder
-
- All Implemented Interfaces:
public final class Entity.Validation.Issue.BeneficialOwnerIdentity.BuilderA builder for BeneficialOwnerIdentity.
-
-
Method Summary
-
-
Method Detail
-
beneficialOwnerId
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder beneficialOwnerId(String beneficialOwnerId)
The ID of the beneficial owner.
-
beneficialOwnerId
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder beneficialOwnerId(JsonField<String> beneficialOwnerId)
Sets Builder.beneficialOwnerId to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Validation.Issue.BeneficialOwnerIdentity build()
Returns an immutable instance of BeneficialOwnerIdentity.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.beneficialOwnerId()
-
-
-
-