Class Entity.Validation.Issue.Builder
-
- All Implemented Interfaces:
public final class Entity.Validation.Issue.BuilderA builder for Issue.
-
-
Method Summary
-
-
Method Detail
-
beneficialOwnerAddress
final Entity.Validation.Issue.Builder beneficialOwnerAddress(Entity.Validation.Issue.BeneficialOwnerAddress beneficialOwnerAddress)
Details when the issue is with a beneficial owner's address.
-
beneficialOwnerAddress
final Entity.Validation.Issue.Builder beneficialOwnerAddress(Optional<Entity.Validation.Issue.BeneficialOwnerAddress> beneficialOwnerAddress)
Alias for calling Builder.beneficialOwnerAddress with
beneficialOwnerAddress.orElse(null).
-
beneficialOwnerAddress
final Entity.Validation.Issue.Builder beneficialOwnerAddress(JsonField<Entity.Validation.Issue.BeneficialOwnerAddress> beneficialOwnerAddress)
Sets Builder.beneficialOwnerAddress to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerAddress with a well-typed BeneficialOwnerAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwnerIdentity
final Entity.Validation.Issue.Builder beneficialOwnerIdentity(Entity.Validation.Issue.BeneficialOwnerIdentity beneficialOwnerIdentity)
Details when the issue is with a beneficial owner's identity verification.
-
beneficialOwnerIdentity
final Entity.Validation.Issue.Builder beneficialOwnerIdentity(Optional<Entity.Validation.Issue.BeneficialOwnerIdentity> beneficialOwnerIdentity)
Alias for calling Builder.beneficialOwnerIdentity with
beneficialOwnerIdentity.orElse(null).
-
beneficialOwnerIdentity
final Entity.Validation.Issue.Builder beneficialOwnerIdentity(JsonField<Entity.Validation.Issue.BeneficialOwnerIdentity> beneficialOwnerIdentity)
Sets Builder.beneficialOwnerIdentity to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerIdentity with a well-typed BeneficialOwnerIdentity value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Entity.Validation.Issue.Builder category(Entity.Validation.Issue.Category category)
The type of issue. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final Entity.Validation.Issue.Builder category(JsonField<Entity.Validation.Issue.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityAddress
final Entity.Validation.Issue.Builder entityAddress(Entity.Validation.Issue.EntityAddress entityAddress)
Details when the issue is with the entity's address.
-
entityAddress
final Entity.Validation.Issue.Builder entityAddress(Optional<Entity.Validation.Issue.EntityAddress> entityAddress)
Alias for calling Builder.entityAddress with
entityAddress.orElse(null).
-
entityAddress
final Entity.Validation.Issue.Builder entityAddress(JsonField<Entity.Validation.Issue.EntityAddress> entityAddress)
Sets Builder.entityAddress to an arbitrary JSON value.
You should usually call Builder.entityAddress with a well-typed EntityAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityTaxIdentifier
final Entity.Validation.Issue.Builder entityTaxIdentifier(Entity.Validation.Issue.EntityTaxIdentifier entityTaxIdentifier)
Details when the issue is with the entity's tax ID.
-
entityTaxIdentifier
final Entity.Validation.Issue.Builder entityTaxIdentifier(Optional<Entity.Validation.Issue.EntityTaxIdentifier> entityTaxIdentifier)
Alias for calling Builder.entityTaxIdentifier with
entityTaxIdentifier.orElse(null).
-
entityTaxIdentifier
final Entity.Validation.Issue.Builder entityTaxIdentifier(JsonField<Entity.Validation.Issue.EntityTaxIdentifier> entityTaxIdentifier)
Sets Builder.entityTaxIdentifier to an arbitrary JSON value.
You should usually call Builder.entityTaxIdentifier with a well-typed EntityTaxIdentifier value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Entity.Validation.Issue.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Entity.Validation.Issue.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Entity.Validation.Issue.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Entity.Validation.Issue.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Entity.Validation.Issue.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Entity.Validation.Issue build()
Returns an immutable instance of Issue.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.beneficialOwnerAddress() .beneficialOwnerIdentity() .category() .entityAddress() .entityTaxIdentifier()
-
-
-
-