Package com.increase.api.models.entities
Class Entity.Validation.Issue.EntityAddress
-
- All Implemented Interfaces:
public final class Entity.Validation.Issue.EntityAddressDetails when the issue is with the entity's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Validation.Issue.EntityAddress.BuilderA builder for EntityAddress.
public final classEntity.Validation.Issue.EntityAddress.ReasonThe reason the address is invalid.
-
Method Summary
Modifier and Type Method Description final Entity.Validation.Issue.EntityAddress.Reasonreason()The reason the address is invalid. final JsonField<Entity.Validation.Issue.EntityAddress.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final Entity.Validation.Issue.EntityAddress.BuildertoBuilder()final Entity.Validation.Issue.EntityAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Validation.Issue.EntityAddress.Builderbuilder()Returns a mutable builder for constructing an instance of EntityAddress. -
-
Method Detail
-
reason
final Entity.Validation.Issue.EntityAddress.Reason reason()
The reason the address is invalid.
-
_reason
final JsonField<Entity.Validation.Issue.EntityAddress.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Validation.Issue.EntityAddress.Builder toBuilder()
-
validate
final Entity.Validation.Issue.EntityAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Entity.Validation.Issue.EntityAddress.Builder builder()
Returns a mutable builder for constructing an instance of EntityAddress.
The following fields are required:
.reason()
-
-
-
-