Package com.increase.api.models.entities
Class EntityArchiveBeneficialOwnerParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityArchiveBeneficialOwnerParams implements Params
Archive a beneficial owner for a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityArchiveBeneficialOwnerParams.BuilderA builder for EntityArchiveBeneficialOwnerParams.
public final classEntityArchiveBeneficialOwnerParams.Body
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity associated with the Beneficial Owner that is being archived. final StringbeneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<String>_beneficialOwnerId()Returns the raw JSON value of beneficialOwnerId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final EntityArchiveBeneficialOwnerParams.BuildertoBuilder()final EntityArchiveBeneficialOwnerParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityArchiveBeneficialOwnerParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityArchiveBeneficialOwnerParams. -
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity associated with the Beneficial Owner that is being archived.
-
beneficialOwnerId
final String beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
Returns the raw JSON value of beneficialOwnerId.
Unlike beneficialOwnerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final EntityArchiveBeneficialOwnerParams.Builder toBuilder()
-
_body
final EntityArchiveBeneficialOwnerParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityArchiveBeneficialOwnerParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityArchiveBeneficialOwnerParams.
The following fields are required:
.entityId() .beneficialOwnerId()
-
-
-
-