Package com.increase.api.models.entities
Class EntityArchiveBeneficialOwnerParams.Body
-
- All Implemented Interfaces:
public final class EntityArchiveBeneficialOwnerParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityArchiveBeneficialOwnerParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringbeneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<String>_beneficialOwnerId()Returns the raw JSON value of beneficialOwnerId. final Map<String, JsonValue>_additionalProperties()final EntityArchiveBeneficialOwnerParams.Body.BuildertoBuilder()final EntityArchiveBeneficialOwnerParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityArchiveBeneficialOwnerParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
beneficialOwnerId
final String beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
Returns the raw JSON value of beneficialOwnerId.
Unlike beneficialOwnerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityArchiveBeneficialOwnerParams.Body.Builder toBuilder()
-
validate
final EntityArchiveBeneficialOwnerParams.Body validate()
-
builder
final static EntityArchiveBeneficialOwnerParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.beneficialOwnerId()
-
-
-
-