Class EntityCreateBeneficialOwnerParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityCreateBeneficialOwnerParams implements Params
Create a beneficial owner for a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateBeneficialOwnerParams.BuilderA builder for EntityCreateBeneficialOwnerParams.
public final classEntityCreateBeneficialOwnerParams.Bodypublic final classEntityCreateBeneficialOwnerParams.BeneficialOwnerThe identifying details of anyone controlling or owning 25% or more of the corporation.
-
Method Summary
Modifier and Type Method Description final Optional<String>entityId()The identifier of the Entity to associate with the new Beneficial Owner. final EntityCreateBeneficialOwnerParams.BeneficialOwnerbeneficialOwner()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner>_beneficialOwner()Returns the raw JSON value of beneficialOwner. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityCreateBeneficialOwnerParams.BuildertoBuilder()final EntityCreateBeneficialOwnerParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateBeneficialOwnerParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityCreateBeneficialOwnerParams. -
-
Method Detail
-
entityId
final Optional<String> entityId()
The identifier of the Entity to associate with the new Beneficial Owner.
-
beneficialOwner
final EntityCreateBeneficialOwnerParams.BeneficialOwner beneficialOwner()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwner
final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner> _beneficialOwner()
Returns the raw JSON value of beneficialOwner.
Unlike beneficialOwner, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityCreateBeneficialOwnerParams.Builder toBuilder()
-
_body
final EntityCreateBeneficialOwnerParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityCreateBeneficialOwnerParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityCreateBeneficialOwnerParams.
The following fields are required:
.beneficialOwner()
-
-
-
-