Class EntityCreateBeneficialOwnerParams.BeneficialOwner
-
- All Implemented Interfaces:
public final class EntityCreateBeneficialOwnerParams.BeneficialOwnerThe identifying details of anyone controlling or owning 25% or more of the corporation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateBeneficialOwnerParams.BeneficialOwner.BuilderA builder for BeneficialOwner.
public final classEntityCreateBeneficialOwnerParams.BeneficialOwner.IndividualPersonal details for the beneficial owner.
public final classEntityCreateBeneficialOwnerParams.BeneficialOwner.Prong
-
Method Summary
-
-
Method Detail
-
individual
final EntityCreateBeneficialOwnerParams.BeneficialOwner.Individual individual()
Personal details for the beneficial owner.
-
prongs
final List<EntityCreateBeneficialOwnerParams.BeneficialOwner.Prong> prongs()
Why this person is considered a beneficial owner of the entity. At least one option is required, if a person is both a control person and owner, submit an array containing both.
-
companyTitle
final Optional<String> companyTitle()
This person's role or title within the entity.
-
_individual
final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner.Individual> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_prongs
final JsonField<List<EntityCreateBeneficialOwnerParams.BeneficialOwner.Prong>> _prongs()
Returns the raw JSON value of prongs.
Unlike prongs, this method doesn't throw if the JSON field has an unexpected type.
-
_companyTitle
final JsonField<String> _companyTitle()
Returns the raw JSON value of companyTitle.
Unlike companyTitle, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateBeneficialOwnerParams.BeneficialOwner.Builder toBuilder()
-
validate
final EntityCreateBeneficialOwnerParams.BeneficialOwner validate()
-
builder
final static EntityCreateBeneficialOwnerParams.BeneficialOwner.Builder builder()
Returns a mutable builder for constructing an instance of BeneficialOwner.
The following fields are required:
.individual() .prongs()
-
-
-
-