Package com.increase.api.models.entities
Class EntityCreateBeneficialOwnerParams.Body
-
- All Implemented Interfaces:
public final class EntityCreateBeneficialOwnerParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateBeneficialOwnerParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final EntityCreateBeneficialOwnerParams.BeneficialOwnerbeneficialOwner()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner>_beneficialOwner()Returns the raw JSON value of beneficialOwner. final Map<String, JsonValue>_additionalProperties()final EntityCreateBeneficialOwnerParams.Body.BuildertoBuilder()final EntityCreateBeneficialOwnerParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateBeneficialOwnerParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
beneficialOwner
final EntityCreateBeneficialOwnerParams.BeneficialOwner beneficialOwner()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_beneficialOwner
final JsonField<EntityCreateBeneficialOwnerParams.BeneficialOwner> _beneficialOwner()
Returns the raw JSON value of beneficialOwner.
Unlike beneficialOwner, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateBeneficialOwnerParams.Body.Builder toBuilder()
-
validate
final EntityCreateBeneficialOwnerParams.Body validate()
-
builder
final static EntityCreateBeneficialOwnerParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.beneficialOwner()
-
-
-
-