Class EntityCreateParams.Body
-
- All Implemented Interfaces:
public final class EntityCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Structurestructure()The type of Entity to create. final Optional<EntityCreateParams.Corporation>corporation()Details of the corporation entity to create. final Optional<String>description()The description you choose to give the entity. final Optional<EntityCreateParams.GovernmentAuthority>governmentAuthority()Details of the Government Authority entity to create. final Optional<EntityCreateParams.Joint>joint()Details of the joint entity to create. final Optional<EntityCreateParams.NaturalPerson>naturalPerson()Details of the natural person entity to create. final Optional<EntityCreateParams.RiskRating>riskRating()An assessment of the entity's potential risk of involvement in financial crimes, such as money laundering. final Optional<List<EntityCreateParams.SupplementalDocument>>supplementalDocuments()Additional documentation associated with the entity. final Optional<List<EntityCreateParams.TermsAgreement>>termsAgreements()The terms that the Entity agreed to. final Optional<EntityCreateParams.ThirdPartyVerification>thirdPartyVerification()If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service. final Optional<EntityCreateParams.Trust>trust()Details of the trust entity to create. final JsonField<EntityCreateParams.Structure>_structure()Returns the raw JSON value of structure. final JsonField<EntityCreateParams.Corporation>_corporation()Returns the raw JSON value of corporation. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<EntityCreateParams.GovernmentAuthority>_governmentAuthority()Returns the raw JSON value of governmentAuthority. final JsonField<EntityCreateParams.Joint>_joint()Returns the raw JSON value of joint. final JsonField<EntityCreateParams.NaturalPerson>_naturalPerson()Returns the raw JSON value of naturalPerson. final JsonField<EntityCreateParams.RiskRating>_riskRating()Returns the raw JSON value of riskRating. final JsonField<List<EntityCreateParams.SupplementalDocument>>_supplementalDocuments()Returns the raw JSON value of supplementalDocuments. final JsonField<List<EntityCreateParams.TermsAgreement>>_termsAgreements()Returns the raw JSON value of termsAgreements. final JsonField<EntityCreateParams.ThirdPartyVerification>_thirdPartyVerification()Returns the raw JSON value of thirdPartyVerification. final JsonField<EntityCreateParams.Trust>_trust()Returns the raw JSON value of trust. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Body.BuildertoBuilder()final EntityCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
structure
final EntityCreateParams.Structure structure()
The type of Entity to create.
-
corporation
final Optional<EntityCreateParams.Corporation> corporation()
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
description
final Optional<String> description()
The description you choose to give the entity.
-
governmentAuthority
final Optional<EntityCreateParams.GovernmentAuthority> governmentAuthority()
Details of the Government Authority entity to create. Required if
structureis equal togovernment_authority.
-
joint
final Optional<EntityCreateParams.Joint> joint()
Details of the joint entity to create. Required if
structureis equal tojoint.
-
naturalPerson
final Optional<EntityCreateParams.NaturalPerson> naturalPerson()
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
riskRating
final Optional<EntityCreateParams.RiskRating> riskRating()
An assessment of the entity's potential risk of involvement in financial crimes, such as money laundering.
-
supplementalDocuments
final Optional<List<EntityCreateParams.SupplementalDocument>> supplementalDocuments()
Additional documentation associated with the entity.
-
termsAgreements
final Optional<List<EntityCreateParams.TermsAgreement>> termsAgreements()
The terms that the Entity agreed to. Not all programs are required to submit this data.
-
thirdPartyVerification
final Optional<EntityCreateParams.ThirdPartyVerification> thirdPartyVerification()
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
trust
final Optional<EntityCreateParams.Trust> trust()
Details of the trust entity to create. Required if
structureis equal totrust.
-
_structure
final JsonField<EntityCreateParams.Structure> _structure()
Returns the raw JSON value of structure.
Unlike structure, this method doesn't throw if the JSON field has an unexpected type.
-
_corporation
final JsonField<EntityCreateParams.Corporation> _corporation()
Returns the raw JSON value of corporation.
Unlike corporation, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentAuthority
final JsonField<EntityCreateParams.GovernmentAuthority> _governmentAuthority()
Returns the raw JSON value of governmentAuthority.
Unlike governmentAuthority, this method doesn't throw if the JSON field has an unexpected type.
-
_joint
final JsonField<EntityCreateParams.Joint> _joint()
Returns the raw JSON value of joint.
Unlike joint, this method doesn't throw if the JSON field has an unexpected type.
-
_naturalPerson
final JsonField<EntityCreateParams.NaturalPerson> _naturalPerson()
Returns the raw JSON value of naturalPerson.
Unlike naturalPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_riskRating
final JsonField<EntityCreateParams.RiskRating> _riskRating()
Returns the raw JSON value of riskRating.
Unlike riskRating, this method doesn't throw if the JSON field has an unexpected type.
-
_supplementalDocuments
final JsonField<List<EntityCreateParams.SupplementalDocument>> _supplementalDocuments()
Returns the raw JSON value of supplementalDocuments.
Unlike supplementalDocuments, this method doesn't throw if the JSON field has an unexpected type.
-
_termsAgreements
final JsonField<List<EntityCreateParams.TermsAgreement>> _termsAgreements()
Returns the raw JSON value of termsAgreements.
Unlike termsAgreements, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdPartyVerification
final JsonField<EntityCreateParams.ThirdPartyVerification> _thirdPartyVerification()
Returns the raw JSON value of thirdPartyVerification.
Unlike thirdPartyVerification, this method doesn't throw if the JSON field has an unexpected type.
-
_trust
final JsonField<EntityCreateParams.Trust> _trust()
Returns the raw JSON value of trust.
Unlike trust, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Body.Builder toBuilder()
-
validate
final EntityCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.structure()
-
-
-
-