Class EntityCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
structure
final EntityCreateParams.Body.Builder structure(EntityCreateParams.Structure structure)
The type of Entity to create.
-
structure
final EntityCreateParams.Body.Builder structure(JsonField<EntityCreateParams.Structure> structure)
Sets Builder.structure to an arbitrary JSON value.
You should usually call Builder.structure with a well-typed Structure value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
corporation
final EntityCreateParams.Body.Builder corporation(EntityCreateParams.Corporation corporation)
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
corporation
final EntityCreateParams.Body.Builder corporation(JsonField<EntityCreateParams.Corporation> corporation)
Sets Builder.corporation to an arbitrary JSON value.
You should usually call Builder.corporation with a well-typed Corporation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final EntityCreateParams.Body.Builder description(String description)
The description you choose to give the entity.
-
description
final EntityCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentAuthority
final EntityCreateParams.Body.Builder governmentAuthority(EntityCreateParams.GovernmentAuthority governmentAuthority)
Details of the Government Authority entity to create. Required if
structureis equal togovernment_authority.
-
governmentAuthority
final EntityCreateParams.Body.Builder governmentAuthority(JsonField<EntityCreateParams.GovernmentAuthority> governmentAuthority)
Sets Builder.governmentAuthority to an arbitrary JSON value.
You should usually call Builder.governmentAuthority with a well-typed GovernmentAuthority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
joint
final EntityCreateParams.Body.Builder joint(EntityCreateParams.Joint joint)
Details of the joint entity to create. Required if
structureis equal tojoint.
-
joint
final EntityCreateParams.Body.Builder joint(JsonField<EntityCreateParams.Joint> joint)
Sets Builder.joint to an arbitrary JSON value.
You should usually call Builder.joint with a well-typed Joint value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naturalPerson
final EntityCreateParams.Body.Builder naturalPerson(EntityCreateParams.NaturalPerson naturalPerson)
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
naturalPerson
final EntityCreateParams.Body.Builder naturalPerson(JsonField<EntityCreateParams.NaturalPerson> naturalPerson)
Sets Builder.naturalPerson to an arbitrary JSON value.
You should usually call Builder.naturalPerson with a well-typed NaturalPerson value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
riskRating
final EntityCreateParams.Body.Builder riskRating(EntityCreateParams.RiskRating riskRating)
An assessment of the entity's potential risk of involvement in financial crimes, such as money laundering.
-
riskRating
final EntityCreateParams.Body.Builder riskRating(JsonField<EntityCreateParams.RiskRating> riskRating)
Sets Builder.riskRating to an arbitrary JSON value.
You should usually call Builder.riskRating with a well-typed RiskRating value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supplementalDocuments
final EntityCreateParams.Body.Builder supplementalDocuments(List<EntityCreateParams.SupplementalDocument> supplementalDocuments)
Additional documentation associated with the entity.
-
supplementalDocuments
final EntityCreateParams.Body.Builder supplementalDocuments(JsonField<List<EntityCreateParams.SupplementalDocument>> supplementalDocuments)
Sets Builder.supplementalDocuments to an arbitrary JSON value.
You should usually call Builder.supplementalDocuments with a well-typed
List<SupplementalDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSupplementalDocument
final EntityCreateParams.Body.Builder addSupplementalDocument(EntityCreateParams.SupplementalDocument supplementalDocument)
Adds a single SupplementalDocument to supplementalDocuments.
-
termsAgreements
final EntityCreateParams.Body.Builder termsAgreements(List<EntityCreateParams.TermsAgreement> termsAgreements)
The terms that the Entity agreed to. Not all programs are required to submit this data.
-
termsAgreements
final EntityCreateParams.Body.Builder termsAgreements(JsonField<List<EntityCreateParams.TermsAgreement>> termsAgreements)
Sets Builder.termsAgreements to an arbitrary JSON value.
You should usually call Builder.termsAgreements with a well-typed
List<TermsAgreement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTermsAgreement
final EntityCreateParams.Body.Builder addTermsAgreement(EntityCreateParams.TermsAgreement termsAgreement)
Adds a single TermsAgreement to termsAgreements.
-
thirdPartyVerification
final EntityCreateParams.Body.Builder thirdPartyVerification(EntityCreateParams.ThirdPartyVerification thirdPartyVerification)
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
thirdPartyVerification
final EntityCreateParams.Body.Builder thirdPartyVerification(JsonField<EntityCreateParams.ThirdPartyVerification> thirdPartyVerification)
Sets Builder.thirdPartyVerification to an arbitrary JSON value.
You should usually call Builder.thirdPartyVerification with a well-typed ThirdPartyVerification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trust
final EntityCreateParams.Body.Builder trust(EntityCreateParams.Trust trust)
Details of the trust entity to create. Required if
structureis equal totrust.
-
trust
final EntityCreateParams.Body.Builder trust(JsonField<EntityCreateParams.Trust> trust)
Sets Builder.trust to an arbitrary JSON value.
You should usually call Builder.trust with a well-typed Trust value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.structure()
-
-
-
-