Class EntityCreateParams.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.BuilderA builder for EntityCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final EntityCreateParams.Builder body(EntityCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
structure
final EntityCreateParams.Builder structure(EntityCreateParams.Structure structure)
The type of Entity to create.
-
structure
final EntityCreateParams.Builder structure(JsonField<EntityCreateParams.Structure> structure)
Sets Builder.structure to an arbitrary JSON value.
You should usually call Builder.structure with a well-typed Structure value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
corporation
final EntityCreateParams.Builder corporation(EntityCreateParams.Corporation corporation)
Details of the corporation entity to create. Required if
structureis equal tocorporation.
-
corporation
final EntityCreateParams.Builder corporation(JsonField<EntityCreateParams.Corporation> corporation)
Sets Builder.corporation to an arbitrary JSON value.
You should usually call Builder.corporation with a well-typed Corporation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final EntityCreateParams.Builder description(String description)
The description you choose to give the entity.
-
description
final EntityCreateParams.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentAuthority
final EntityCreateParams.Builder governmentAuthority(EntityCreateParams.GovernmentAuthority governmentAuthority)
Details of the Government Authority entity to create. Required if
structureis equal togovernment_authority.
-
governmentAuthority
final EntityCreateParams.Builder governmentAuthority(JsonField<EntityCreateParams.GovernmentAuthority> governmentAuthority)
Sets Builder.governmentAuthority to an arbitrary JSON value.
You should usually call Builder.governmentAuthority with a well-typed GovernmentAuthority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
joint
final EntityCreateParams.Builder joint(EntityCreateParams.Joint joint)
Details of the joint entity to create. Required if
structureis equal tojoint.
-
joint
final EntityCreateParams.Builder joint(JsonField<EntityCreateParams.Joint> joint)
Sets Builder.joint to an arbitrary JSON value.
You should usually call Builder.joint with a well-typed Joint value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naturalPerson
final EntityCreateParams.Builder naturalPerson(EntityCreateParams.NaturalPerson naturalPerson)
Details of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
naturalPerson
final EntityCreateParams.Builder naturalPerson(JsonField<EntityCreateParams.NaturalPerson> naturalPerson)
Sets Builder.naturalPerson to an arbitrary JSON value.
You should usually call Builder.naturalPerson with a well-typed NaturalPerson value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
riskRating
final EntityCreateParams.Builder riskRating(EntityCreateParams.RiskRating riskRating)
An assessment of the entity's potential risk of involvement in financial crimes, such as money laundering.
-
riskRating
final EntityCreateParams.Builder riskRating(JsonField<EntityCreateParams.RiskRating> riskRating)
Sets Builder.riskRating to an arbitrary JSON value.
You should usually call Builder.riskRating with a well-typed RiskRating value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
supplementalDocuments
final EntityCreateParams.Builder supplementalDocuments(List<EntityCreateParams.SupplementalDocument> supplementalDocuments)
Additional documentation associated with the entity.
-
supplementalDocuments
final EntityCreateParams.Builder supplementalDocuments(JsonField<List<EntityCreateParams.SupplementalDocument>> supplementalDocuments)
Sets Builder.supplementalDocuments to an arbitrary JSON value.
You should usually call Builder.supplementalDocuments with a well-typed
List<SupplementalDocument>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSupplementalDocument
final EntityCreateParams.Builder addSupplementalDocument(EntityCreateParams.SupplementalDocument supplementalDocument)
Adds a single SupplementalDocument to supplementalDocuments.
-
termsAgreements
final EntityCreateParams.Builder termsAgreements(List<EntityCreateParams.TermsAgreement> termsAgreements)
The terms that the Entity agreed to. Not all programs are required to submit this data.
-
termsAgreements
final EntityCreateParams.Builder termsAgreements(JsonField<List<EntityCreateParams.TermsAgreement>> termsAgreements)
Sets Builder.termsAgreements to an arbitrary JSON value.
You should usually call Builder.termsAgreements with a well-typed
List<TermsAgreement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTermsAgreement
final EntityCreateParams.Builder addTermsAgreement(EntityCreateParams.TermsAgreement termsAgreement)
Adds a single TermsAgreement to termsAgreements.
-
thirdPartyVerification
final EntityCreateParams.Builder thirdPartyVerification(EntityCreateParams.ThirdPartyVerification thirdPartyVerification)
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
thirdPartyVerification
final EntityCreateParams.Builder thirdPartyVerification(JsonField<EntityCreateParams.ThirdPartyVerification> thirdPartyVerification)
Sets Builder.thirdPartyVerification to an arbitrary JSON value.
You should usually call Builder.thirdPartyVerification with a well-typed ThirdPartyVerification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trust
final EntityCreateParams.Builder trust(EntityCreateParams.Trust trust)
Details of the trust entity to create. Required if
structureis equal totrust.
-
trust
final EntityCreateParams.Builder trust(JsonField<EntityCreateParams.Trust> trust)
Sets Builder.trust to an arbitrary JSON value.
You should usually call Builder.trust with a well-typed Trust value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final EntityCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final EntityCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final EntityCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final EntityCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final EntityCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final EntityCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final EntityCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final EntityCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final EntityCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final EntityCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final EntityCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final EntityCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final EntityCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final EntityCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final EntityCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final EntityCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final EntityCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final EntityCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final EntityCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final EntityCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final EntityCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final EntityCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final EntityCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final EntityCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final EntityCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final EntityCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final EntityCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final EntityCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final EntityCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final EntityCreateParams build()
Returns an immutable instance of EntityCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.structure()
-
-
-
-