Class EntityCreateParams.Corporation
-
- All Implemented Interfaces:
public final class EntityCreateParams.CorporationDetails of the corporation entity to create. Required if
structureis equal tocorporation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Corporation.BuilderA builder for Corporation.
public final classEntityCreateParams.Corporation.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.Corporation.BeneficialOwnerpublic final classEntityCreateParams.Corporation.LegalIdentifierThe legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
public final classEntityCreateParams.Corporation.BeneficialOwnershipExemptionReasonIf the entity is exempt from the requirement to submit beneficial owners, provide the justification. If a reason is provided, you do not need to submit a list of beneficial owners.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Corporation.Addressaddress()The entity's physical address. final List<EntityCreateParams.Corporation.BeneficialOwner>beneficialOwners()The identifying details of each person who owns 25% or more of the business and one control person, like the CEO, CFO, or other executive. final EntityCreateParams.Corporation.LegalIdentifierlegalIdentifier()The legal identifier of the corporation. final Stringname()The legal name of the corporation. final Optional<EntityCreateParams.Corporation.BeneficialOwnershipExemptionReason>beneficialOwnershipExemptionReason()If the entity is exempt from the requirement to submit beneficial owners, provide the justification. final Optional<String>email()An email address for the business. final Optional<String>incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final Optional<String>industryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final Optional<String>website()The website of the corporation. final JsonField<EntityCreateParams.Corporation.Address>_address()Returns the raw JSON value of address. final JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>>_beneficialOwners()Returns the raw JSON value of beneficialOwners. final JsonField<EntityCreateParams.Corporation.LegalIdentifier>_legalIdentifier()Returns the raw JSON value of legalIdentifier. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<EntityCreateParams.Corporation.BeneficialOwnershipExemptionReason>_beneficialOwnershipExemptionReason()Returns the raw JSON value of beneficialOwnershipExemptionReason. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_incorporationState()Returns the raw JSON value of incorporationState. final JsonField<String>_industryCode()Returns the raw JSON value of industryCode. final JsonField<String>_website()Returns the raw JSON value of website. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Corporation.BuildertoBuilder()final EntityCreateParams.Corporationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Corporation.Builderbuilder()Returns a mutable builder for constructing an instance of Corporation. -
-
Method Detail
-
address
final EntityCreateParams.Corporation.Address address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
beneficialOwners
final List<EntityCreateParams.Corporation.BeneficialOwner> beneficialOwners()
The identifying details of each person who owns 25% or more of the business and one control person, like the CEO, CFO, or other executive. You can submit between 1 and 5 people to this list.
-
legalIdentifier
final EntityCreateParams.Corporation.LegalIdentifier legalIdentifier()
The legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
-
beneficialOwnershipExemptionReason
final Optional<EntityCreateParams.Corporation.BeneficialOwnershipExemptionReason> beneficialOwnershipExemptionReason()
If the entity is exempt from the requirement to submit beneficial owners, provide the justification. If a reason is provided, you do not need to submit a list of beneficial owners.
-
email
final Optional<String> email()
An email address for the business. Not every program requires an email for submitted Entities.
-
incorporationState
final Optional<String> incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
industryCode
final Optional<String> industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_address
final JsonField<EntityCreateParams.Corporation.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwners
final JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>> _beneficialOwners()
Returns the raw JSON value of beneficialOwners.
Unlike beneficialOwners, this method doesn't throw if the JSON field has an unexpected type.
-
_legalIdentifier
final JsonField<EntityCreateParams.Corporation.LegalIdentifier> _legalIdentifier()
Returns the raw JSON value of legalIdentifier.
Unlike legalIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwnershipExemptionReason
final JsonField<EntityCreateParams.Corporation.BeneficialOwnershipExemptionReason> _beneficialOwnershipExemptionReason()
Returns the raw JSON value of beneficialOwnershipExemptionReason.
Unlike beneficialOwnershipExemptionReason, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_incorporationState
final JsonField<String> _incorporationState()
Returns the raw JSON value of incorporationState.
Unlike incorporationState, this method doesn't throw if the JSON field has an unexpected type.
-
_industryCode
final JsonField<String> _industryCode()
Returns the raw JSON value of industryCode.
Unlike industryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_website
final JsonField<String> _website()
Returns the raw JSON value of website.
Unlike website, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Corporation.Builder toBuilder()
-
validate
final EntityCreateParams.Corporation validate()
-
builder
final static EntityCreateParams.Corporation.Builder builder()
Returns a mutable builder for constructing an instance of Corporation.
The following fields are required:
.address() .beneficialOwners() .legalIdentifier() .name()
-
-
-
-