Class EntityCreateParams.Corporation.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Corporation.BuilderA builder for Corporation.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityCreateParams.Corporation.Builder address(EntityCreateParams.Corporation.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.Corporation.Builder address(JsonField<EntityCreateParams.Corporation.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwners
final EntityCreateParams.Corporation.Builder beneficialOwners(List<EntityCreateParams.Corporation.BeneficialOwner> beneficialOwners)
The identifying details of each person who owns 25% or more of the business and one control person, like the CEO, CFO, or other executive. You can submit between 1 and 5 people to this list.
-
beneficialOwners
final EntityCreateParams.Corporation.Builder beneficialOwners(JsonField<List<EntityCreateParams.Corporation.BeneficialOwner>> beneficialOwners)
Sets Builder.beneficialOwners to an arbitrary JSON value.
You should usually call Builder.beneficialOwners with a well-typed
List<BeneficialOwner>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBeneficialOwner
final EntityCreateParams.Corporation.Builder addBeneficialOwner(EntityCreateParams.Corporation.BeneficialOwner beneficialOwner)
Adds a single BeneficialOwner to beneficialOwners.
-
name
final EntityCreateParams.Corporation.Builder name(String name)
The legal name of the corporation.
-
name
final EntityCreateParams.Corporation.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final EntityCreateParams.Corporation.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the corporation.
-
taxIdentifier
final EntityCreateParams.Corporation.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwnershipExemptionReason
final EntityCreateParams.Corporation.Builder beneficialOwnershipExemptionReason(EntityCreateParams.Corporation.BeneficialOwnershipExemptionReason beneficialOwnershipExemptionReason)
If the entity is exempt from the requirement to submit beneficial owners, provide the justification. If a reason is provided, you do not need to submit a list of beneficial owners.
-
beneficialOwnershipExemptionReason
final EntityCreateParams.Corporation.Builder beneficialOwnershipExemptionReason(JsonField<EntityCreateParams.Corporation.BeneficialOwnershipExemptionReason> beneficialOwnershipExemptionReason)
Sets Builder.beneficialOwnershipExemptionReason to an arbitrary JSON value.
You should usually call Builder.beneficialOwnershipExemptionReason with a well-typed BeneficialOwnershipExemptionReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final EntityCreateParams.Corporation.Builder email(String email)
An email address for the business. Not every program requires an email for submitted Entities.
-
email
final EntityCreateParams.Corporation.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
incorporationState
final EntityCreateParams.Corporation.Builder incorporationState(String incorporationState)
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
incorporationState
final EntityCreateParams.Corporation.Builder incorporationState(JsonField<String> incorporationState)
Sets Builder.incorporationState to an arbitrary JSON value.
You should usually call Builder.incorporationState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
industryCode
final EntityCreateParams.Corporation.Builder industryCode(String industryCode)
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
industryCode
final EntityCreateParams.Corporation.Builder industryCode(JsonField<String> industryCode)
Sets Builder.industryCode to an arbitrary JSON value.
You should usually call Builder.industryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
website
final EntityCreateParams.Corporation.Builder website(String website)
The website of the corporation.
-
website
final EntityCreateParams.Corporation.Builder website(JsonField<String> website)
Sets Builder.website to an arbitrary JSON value.
You should usually call Builder.website with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Corporation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Corporation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Corporation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Corporation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Corporation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Corporation build()
Returns an immutable instance of Corporation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .beneficialOwners() .name() .taxIdentifier()
-
-
-
-