Class EntityCreateParams.Corporation.LegalIdentifier
-
- All Implemented Interfaces:
public final class EntityCreateParams.Corporation.LegalIdentifierThe legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Corporation.LegalIdentifier.BuilderA builder for LegalIdentifier.
public final classEntityCreateParams.Corporation.LegalIdentifier.CategoryThe category of the legal identifier. If not provided, the default is
us_employer_identification_number.
-
Method Summary
Modifier and Type Method Description final Stringvalue()The legal identifier. final Optional<EntityCreateParams.Corporation.LegalIdentifier.Category>category()The category of the legal identifier. final JsonField<String>_value()Returns the raw JSON value of value. final JsonField<EntityCreateParams.Corporation.LegalIdentifier.Category>_category()Returns the raw JSON value of category. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Corporation.LegalIdentifier.BuildertoBuilder()final EntityCreateParams.Corporation.LegalIdentifiervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Corporation.LegalIdentifier.Builderbuilder()Returns a mutable builder for constructing an instance of LegalIdentifier. -
-
Method Detail
-
value
final String value()
The legal identifier. For US Employer Identification Numbers, submit nine digits with no dashes or other separators.
-
category
final Optional<EntityCreateParams.Corporation.LegalIdentifier.Category> category()
The category of the legal identifier. If not provided, the default is
us_employer_identification_number.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<EntityCreateParams.Corporation.LegalIdentifier.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Corporation.LegalIdentifier.Builder toBuilder()
-
validate
final EntityCreateParams.Corporation.LegalIdentifier validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.Corporation.LegalIdentifier.Builder builder()
Returns a mutable builder for constructing an instance of LegalIdentifier.
The following fields are required:
.value()
-
-
-
-