Class EntityCreateParams.GovernmentAuthority
-
- All Implemented Interfaces:
public final class EntityCreateParams.GovernmentAuthorityDetails of the Government Authority entity to create. Required if
structureis equal togovernment_authority.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
public final classEntityCreateParams.GovernmentAuthority.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.GovernmentAuthority.AuthorizedPersonpublic final classEntityCreateParams.GovernmentAuthority.CategoryThe category of the government authority.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.GovernmentAuthority.Addressaddress()The entity's physical address. final List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>authorizedPersons()The identifying details of authorized officials acting on the entity's behalf. final EntityCreateParams.GovernmentAuthority.Categorycategory()The category of the government authority. final Stringname()The legal name of the government authority. final StringtaxIdentifier()The Employer Identification Number (EIN) for the government authority. final Optional<String>website()A website for the government authority. final JsonField<EntityCreateParams.GovernmentAuthority.Address>_address()Returns the raw JSON value of address. final JsonField<List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>>_authorizedPersons()Returns the raw JSON value of authorizedPersons. final JsonField<EntityCreateParams.GovernmentAuthority.Category>_category()Returns the raw JSON value of category. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_taxIdentifier()Returns the raw JSON value of taxIdentifier. final JsonField<String>_website()Returns the raw JSON value of website. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.GovernmentAuthority.BuildertoBuilder()final EntityCreateParams.GovernmentAuthorityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.GovernmentAuthority.Builderbuilder()Returns a mutable builder for constructing an instance of GovernmentAuthority. -
-
Method Detail
-
address
final EntityCreateParams.GovernmentAuthority.Address address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
authorizedPersons
final List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson> authorizedPersons()
The identifying details of authorized officials acting on the entity's behalf.
-
category
final EntityCreateParams.GovernmentAuthority.Category category()
The category of the government authority.
-
taxIdentifier
final String taxIdentifier()
The Employer Identification Number (EIN) for the government authority. Submit nine digits with no dashes or other separators.
-
website
final Optional<String> website()
A website for the government authority. Not every program requires a website for submitted Entities.
-
_address
final JsonField<EntityCreateParams.GovernmentAuthority.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizedPersons
final JsonField<List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>> _authorizedPersons()
Returns the raw JSON value of authorizedPersons.
Unlike authorizedPersons, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<EntityCreateParams.GovernmentAuthority.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
Returns the raw JSON value of taxIdentifier.
Unlike taxIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_website
final JsonField<String> _website()
Returns the raw JSON value of website.
Unlike website, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.GovernmentAuthority.Builder toBuilder()
-
validate
final EntityCreateParams.GovernmentAuthority validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.GovernmentAuthority.Builder builder()
Returns a mutable builder for constructing an instance of GovernmentAuthority.
The following fields are required:
.address() .authorizedPersons() .category() .name() .taxIdentifier()
-
-
-
-