Package com.increase.api.models.entities
Class EntityCreateParams.GovernmentAuthority.AuthorizedPerson
-
- All Implemented Interfaces:
public final class EntityCreateParams.GovernmentAuthority.AuthorizedPerson
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.GovernmentAuthority.AuthorizedPerson.BuilderA builder for AuthorizedPerson.
-
Method Summary
Modifier and Type Method Description final Stringname()The person's legal name. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.GovernmentAuthority.AuthorizedPerson.BuildertoBuilder()final EntityCreateParams.GovernmentAuthority.AuthorizedPersonvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.GovernmentAuthority.AuthorizedPerson.Builderbuilder()Returns a mutable builder for constructing an instance of AuthorizedPerson. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.GovernmentAuthority.AuthorizedPerson.Builder toBuilder()
-
validate
final EntityCreateParams.GovernmentAuthority.AuthorizedPerson validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.GovernmentAuthority.AuthorizedPerson.Builder builder()
Returns a mutable builder for constructing an instance of AuthorizedPerson.
The following fields are required:
.name()
-
-
-
-