Class EntityCreateParams.GovernmentAuthority.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityCreateParams.GovernmentAuthority.Builder address(EntityCreateParams.GovernmentAuthority.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.GovernmentAuthority.Builder address(JsonField<EntityCreateParams.GovernmentAuthority.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizedPersons
final EntityCreateParams.GovernmentAuthority.Builder authorizedPersons(List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson> authorizedPersons)
The identifying details of authorized officials acting on the entity's behalf.
-
authorizedPersons
final EntityCreateParams.GovernmentAuthority.Builder authorizedPersons(JsonField<List<EntityCreateParams.GovernmentAuthority.AuthorizedPerson>> authorizedPersons)
Sets Builder.authorizedPersons to an arbitrary JSON value.
You should usually call Builder.authorizedPersons with a well-typed
List<AuthorizedPerson>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAuthorizedPerson
final EntityCreateParams.GovernmentAuthority.Builder addAuthorizedPerson(EntityCreateParams.GovernmentAuthority.AuthorizedPerson authorizedPerson)
Adds a single AuthorizedPerson to authorizedPersons.
-
category
final EntityCreateParams.GovernmentAuthority.Builder category(EntityCreateParams.GovernmentAuthority.Category category)
The category of the government authority.
-
category
final EntityCreateParams.GovernmentAuthority.Builder category(JsonField<EntityCreateParams.GovernmentAuthority.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EntityCreateParams.GovernmentAuthority.Builder name(String name)
The legal name of the government authority.
-
name
final EntityCreateParams.GovernmentAuthority.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final EntityCreateParams.GovernmentAuthority.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the government authority.
-
taxIdentifier
final EntityCreateParams.GovernmentAuthority.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
website
final EntityCreateParams.GovernmentAuthority.Builder website(String website)
The website of the government authority.
-
website
final EntityCreateParams.GovernmentAuthority.Builder website(JsonField<String> website)
Sets Builder.website to an arbitrary JSON value.
You should usually call Builder.website with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.GovernmentAuthority.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.GovernmentAuthority.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.GovernmentAuthority.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.GovernmentAuthority.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.GovernmentAuthority.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.GovernmentAuthority build()
Returns an immutable instance of GovernmentAuthority.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .authorizedPersons() .category() .name() .taxIdentifier()
-
-
-
-