Class EntityCreateParams.Joint.Individual
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Joint.Individual.BuilderA builder for Individual.
public final classEntityCreateParams.Joint.Individual.AddressThe individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.Joint.Individual.IdentificationA means of verifying the person's identity.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Joint.Individual.Addressaddress()The individual's physical address. final LocalDatedateOfBirth()The person's date of birth in YYYY-MM-DD format. final EntityCreateParams.Joint.Individual.Identificationidentification()A means of verifying the person's identity. final Stringname()The person's legal name. final Optional<Boolean>confirmedNoUsTaxId()The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number). final JsonField<EntityCreateParams.Joint.Individual.Address>_address()Returns the raw JSON value of address. final JsonField<LocalDate>_dateOfBirth()Returns the raw JSON value of dateOfBirth. final JsonField<EntityCreateParams.Joint.Individual.Identification>_identification()Returns the raw JSON value of identification. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Boolean>_confirmedNoUsTaxId()Returns the raw JSON value of confirmedNoUsTaxId. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Joint.Individual.BuildertoBuilder()final EntityCreateParams.Joint.Individualvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Joint.Individual.Builderbuilder()Returns a mutable builder for constructing an instance of Individual. -
-
Method Detail
-
address
final EntityCreateParams.Joint.Individual.Address address()
The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
dateOfBirth
final LocalDate dateOfBirth()
The person's date of birth in YYYY-MM-DD format.
-
identification
final EntityCreateParams.Joint.Individual.Identification identification()
A means of verifying the person's identity.
-
confirmedNoUsTaxId
final Optional<Boolean> confirmedNoUsTaxId()
The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
_address
final JsonField<EntityCreateParams.Joint.Individual.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfBirth
final JsonField<LocalDate> _dateOfBirth()
Returns the raw JSON value of dateOfBirth.
Unlike dateOfBirth, this method doesn't throw if the JSON field has an unexpected type.
-
_identification
final JsonField<EntityCreateParams.Joint.Individual.Identification> _identification()
Returns the raw JSON value of identification.
Unlike identification, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_confirmedNoUsTaxId
final JsonField<Boolean> _confirmedNoUsTaxId()
Returns the raw JSON value of confirmedNoUsTaxId.
Unlike confirmedNoUsTaxId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Joint.Individual.Builder toBuilder()
-
validate
final EntityCreateParams.Joint.Individual validate()
-
builder
final static EntityCreateParams.Joint.Individual.Builder builder()
Returns a mutable builder for constructing an instance of Individual.
The following fields are required:
.address() .dateOfBirth() .identification() .name()
-
-
-
-