Class EntityCreateParams.Joint.Individual.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual.BuilderA builder for Individual.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityCreateParams.Joint.Individual.Builder address(EntityCreateParams.Joint.Individual.Address address)
The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.Joint.Individual.Builder address(JsonField<EntityCreateParams.Joint.Individual.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dateOfBirth
final EntityCreateParams.Joint.Individual.Builder dateOfBirth(LocalDate dateOfBirth)
The person's date of birth in YYYY-MM-DD format.
-
dateOfBirth
final EntityCreateParams.Joint.Individual.Builder dateOfBirth(JsonField<LocalDate> dateOfBirth)
Sets Builder.dateOfBirth to an arbitrary JSON value.
You should usually call Builder.dateOfBirth with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
identification
final EntityCreateParams.Joint.Individual.Builder identification(EntityCreateParams.Joint.Individual.Identification identification)
A means of verifying the person's identity.
-
identification
final EntityCreateParams.Joint.Individual.Builder identification(JsonField<EntityCreateParams.Joint.Individual.Identification> identification)
Sets Builder.identification to an arbitrary JSON value.
You should usually call Builder.identification with a well-typed Identification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EntityCreateParams.Joint.Individual.Builder name(String name)
The person's legal name.
-
name
final EntityCreateParams.Joint.Individual.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
confirmedNoUsTaxId
final EntityCreateParams.Joint.Individual.Builder confirmedNoUsTaxId(Boolean confirmedNoUsTaxId)
The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
confirmedNoUsTaxId
final EntityCreateParams.Joint.Individual.Builder confirmedNoUsTaxId(JsonField<Boolean> confirmedNoUsTaxId)
Sets Builder.confirmedNoUsTaxId to an arbitrary JSON value.
You should usually call Builder.confirmedNoUsTaxId with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Joint.Individual.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Joint.Individual.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Joint.Individual.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Joint.Individual.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Joint.Individual.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Joint.Individual build()
Returns an immutable instance of Individual.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .dateOfBirth() .identification() .name()
-
-
-
-