Class EntityCreateParams.Joint.Individual.Identification.DriversLicense
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual.Identification.DriversLicenseInformation about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Joint.Individual.Identification.DriversLicense.BuilderA builder for DriversLicense.
-
Method Summary
Modifier and Type Method Description final LocalDateexpirationDate()The driver's license's expiration date in YYYY-MM-DD format. final StringfileId()The identifier of the File containing the front of the driver's license. final Stringstate()The state that issued the provided driver's license. final Optional<String>backFileId()The identifier of the File containing the back of the driver's license. final JsonField<LocalDate>_expirationDate()Returns the raw JSON value of expirationDate. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_backFileId()Returns the raw JSON value of backFileId. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Joint.Individual.Identification.DriversLicense.BuildertoBuilder()final EntityCreateParams.Joint.Individual.Identification.DriversLicensevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Joint.Individual.Identification.DriversLicense.Builderbuilder()Returns a mutable builder for constructing an instance of DriversLicense. -
-
Method Detail
-
expirationDate
final LocalDate expirationDate()
The driver's license's expiration date in YYYY-MM-DD format.
-
fileId
final String fileId()
The identifier of the File containing the front of the driver's license.
-
backFileId
final Optional<String> backFileId()
The identifier of the File containing the back of the driver's license.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
Returns the raw JSON value of expirationDate.
Unlike expirationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_backFileId
final JsonField<String> _backFileId()
Returns the raw JSON value of backFileId.
Unlike backFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Joint.Individual.Identification.DriversLicense.Builder toBuilder()
-
validate
final EntityCreateParams.Joint.Individual.Identification.DriversLicense validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.Joint.Individual.Identification.DriversLicense.Builder builder()
Returns a mutable builder for constructing an instance of DriversLicense.
The following fields are required:
.expirationDate() .fileId() .state()
-
-
-
-