Package com.increase.api.models.entities
Enum EntityCreateParams.Joint.Individual.Identification.Method.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum EntityCreateParams.Joint.Individual.Identification.Method.Known extends Enum<EntityCreateParams.Joint.Individual.Identification.Method.Known>
An enum containing Method's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<EntityCreateParams.Joint.Individual.Identification.Method.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description SOCIAL_SECURITY_NUMBERA social security number.
INDIVIDUAL_TAXPAYER_IDENTIFICATION_NUMBERAn individual taxpayer identification number (ITIN).
PASSPORTA passport number.
DRIVERS_LICENSEA driver's license number.
OTHERAnother identifying document.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Joint.Individual.Identification.Method.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<EntityCreateParams.Joint.Individual.Identification.Method.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<EntityCreateParams.Joint.Individual.Identification.Method.Known>getEntries()An enum containing Method's known values. -
-
Method Detail
-
valueOf
final EntityCreateParams.Joint.Individual.Identification.Method.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<EntityCreateParams.Joint.Individual.Identification.Method.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<EntityCreateParams.Joint.Individual.Identification.Method.Known> getEntries()
An enum containing Method's known values.
-
-
-
-