Class EntityCreateParams.Joint.Individual.Identification.Other
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual.Identification.OtherInformation about the identification document provided. Required if
methodis equal toother.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Joint.Individual.Identification.Other.BuilderA builder for Other.
-
Method Summary
Modifier and Type Method Description final Stringcountry()The two-character ISO 3166-1 code representing the country that issued the document (e.g. final Stringdescription()A description of the document submitted. final StringfileId()The identifier of the File containing the front of the document. final Optional<String>backFileId()The identifier of the File containing the back of the document. final Optional<LocalDate>expirationDate()The document's expiration date in YYYY-MM-DD format. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_backFileId()Returns the raw JSON value of backFileId. final JsonField<LocalDate>_expirationDate()Returns the raw JSON value of expirationDate. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Joint.Individual.Identification.Other.BuildertoBuilder()final EntityCreateParams.Joint.Individual.Identification.Othervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Joint.Individual.Identification.Other.Builderbuilder()Returns a mutable builder for constructing an instance of Other. -
-
Method Detail
-
country
final String country()
The two-character ISO 3166-1 code representing the country that issued the document (e.g.,
US).
-
description
final String description()
A description of the document submitted.
-
backFileId
final Optional<String> backFileId()
The identifier of the File containing the back of the document. Not every document has a reverse side.
-
expirationDate
final Optional<LocalDate> expirationDate()
The document's expiration date in YYYY-MM-DD format.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_backFileId
final JsonField<String> _backFileId()
Returns the raw JSON value of backFileId.
Unlike backFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
Returns the raw JSON value of expirationDate.
Unlike expirationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Joint.Individual.Identification.Other.Builder toBuilder()
-
validate
final EntityCreateParams.Joint.Individual.Identification.Other validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.Joint.Individual.Identification.Other.Builder builder()
Returns a mutable builder for constructing an instance of Other.
The following fields are required:
.country() .description() .fileId()
-
-
-
-