Class EntityCreateParams.Joint.Individual.Identification.Other.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual.Identification.Other.BuilderA builder for Other.
-
-
Method Summary
-
-
Method Detail
-
country
final EntityCreateParams.Joint.Individual.Identification.Other.Builder country(String country)
The two-character ISO 3166-1 code representing the country that issued the document (e.g.,
US).
-
country
final EntityCreateParams.Joint.Individual.Identification.Other.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final EntityCreateParams.Joint.Individual.Identification.Other.Builder description(String description)
A description of the document submitted.
-
description
final EntityCreateParams.Joint.Individual.Identification.Other.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final EntityCreateParams.Joint.Individual.Identification.Other.Builder fileId(String fileId)
The identifier of the File containing the front of the document.
-
fileId
final EntityCreateParams.Joint.Individual.Identification.Other.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backFileId
final EntityCreateParams.Joint.Individual.Identification.Other.Builder backFileId(String backFileId)
The identifier of the File containing the back of the document. Not every document has a reverse side.
-
backFileId
final EntityCreateParams.Joint.Individual.Identification.Other.Builder backFileId(JsonField<String> backFileId)
Sets Builder.backFileId to an arbitrary JSON value.
You should usually call Builder.backFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationDate
final EntityCreateParams.Joint.Individual.Identification.Other.Builder expirationDate(LocalDate expirationDate)
The document's expiration date in YYYY-MM-DD format.
-
expirationDate
final EntityCreateParams.Joint.Individual.Identification.Other.Builder expirationDate(JsonField<LocalDate> expirationDate)
Sets Builder.expirationDate to an arbitrary JSON value.
You should usually call Builder.expirationDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Joint.Individual.Identification.Other.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Joint.Individual.Identification.Other.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Joint.Individual.Identification.Other.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Joint.Individual.Identification.Other.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Joint.Individual.Identification.Other.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Joint.Individual.Identification.Other build()
Returns an immutable instance of Other.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.country() .description() .fileId()
-
-
-
-