Class EntityCreateParams.Joint.Individual.Identification.Passport.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Joint.Individual.Identification.Passport.BuilderA builder for Passport.
-
-
Method Summary
-
-
Method Detail
-
country
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder country(String country)
The country that issued the passport.
-
country
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expirationDate
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder expirationDate(LocalDate expirationDate)
The passport's expiration date in YYYY-MM-DD format.
-
expirationDate
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder expirationDate(JsonField<LocalDate> expirationDate)
Sets Builder.expirationDate to an arbitrary JSON value.
You should usually call Builder.expirationDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder fileId(String fileId)
The identifier of the File containing the passport.
-
fileId
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Joint.Individual.Identification.Passport.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Joint.Individual.Identification.Passport build()
Returns an immutable instance of Passport.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.country() .expirationDate() .fileId()
-
-
-
-