Class EntityCreateParams.NaturalPerson
-
- All Implemented Interfaces:
public final class EntityCreateParams.NaturalPersonDetails of the natural person entity to create. Required if
structureis equal tonatural_person. Natural people entities should be submitted withsocial_security_numberorindividual_taxpayer_identification_numberidentification methods.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.NaturalPerson.BuilderA builder for NaturalPerson.
public final classEntityCreateParams.NaturalPerson.AddressThe individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.NaturalPerson.IdentificationA means of verifying the person's identity.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.NaturalPerson.Addressaddress()The individual's physical address. final LocalDatedateOfBirth()The person's date of birth in YYYY-MM-DD format. final EntityCreateParams.NaturalPerson.Identificationidentification()A means of verifying the person's identity. final Stringname()The person's legal name. final Optional<Boolean>confirmedNoUsTaxId()The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number). final JsonField<EntityCreateParams.NaturalPerson.Address>_address()Returns the raw JSON value of address. final JsonField<LocalDate>_dateOfBirth()Returns the raw JSON value of dateOfBirth. final JsonField<EntityCreateParams.NaturalPerson.Identification>_identification()Returns the raw JSON value of identification. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Boolean>_confirmedNoUsTaxId()Returns the raw JSON value of confirmedNoUsTaxId. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.NaturalPerson.BuildertoBuilder()final EntityCreateParams.NaturalPersonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.NaturalPerson.Builderbuilder()Returns a mutable builder for constructing an instance of NaturalPerson. -
-
Method Detail
-
address
final EntityCreateParams.NaturalPerson.Address address()
The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
dateOfBirth
final LocalDate dateOfBirth()
The person's date of birth in YYYY-MM-DD format.
-
identification
final EntityCreateParams.NaturalPerson.Identification identification()
A means of verifying the person's identity.
-
confirmedNoUsTaxId
final Optional<Boolean> confirmedNoUsTaxId()
The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
_address
final JsonField<EntityCreateParams.NaturalPerson.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfBirth
final JsonField<LocalDate> _dateOfBirth()
Returns the raw JSON value of dateOfBirth.
Unlike dateOfBirth, this method doesn't throw if the JSON field has an unexpected type.
-
_identification
final JsonField<EntityCreateParams.NaturalPerson.Identification> _identification()
Returns the raw JSON value of identification.
Unlike identification, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_confirmedNoUsTaxId
final JsonField<Boolean> _confirmedNoUsTaxId()
Returns the raw JSON value of confirmedNoUsTaxId.
Unlike confirmedNoUsTaxId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.NaturalPerson.Builder toBuilder()
-
validate
final EntityCreateParams.NaturalPerson validate()
-
builder
final static EntityCreateParams.NaturalPerson.Builder builder()
Returns a mutable builder for constructing an instance of NaturalPerson.
The following fields are required:
.address() .dateOfBirth() .identification() .name()
-
-
-
-