Class EntityCreateParams.NaturalPerson.Identification
-
- All Implemented Interfaces:
public final class EntityCreateParams.NaturalPerson.IdentificationA means of verifying the person's identity.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.NaturalPerson.Identification.BuilderA builder for Identification.
public final classEntityCreateParams.NaturalPerson.Identification.MethodA method that can be used to verify the individual's identity.
public final classEntityCreateParams.NaturalPerson.Identification.DriversLicenseInformation about the United States driver's license used for identification. Required if
methodis equal todrivers_license.public final classEntityCreateParams.NaturalPerson.Identification.OtherInformation about the identification document provided. Required if
methodis equal toother.public final classEntityCreateParams.NaturalPerson.Identification.PassportInformation about the passport used for identification. Required if
methodis equal topassport.
-
Method Summary
-
-
Method Detail
-
method
final EntityCreateParams.NaturalPerson.Identification.Method method()
A method that can be used to verify the individual's identity.
-
number
final String number()
An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators.
-
driversLicense
final Optional<EntityCreateParams.NaturalPerson.Identification.DriversLicense> driversLicense()
Information about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
other
final Optional<EntityCreateParams.NaturalPerson.Identification.Other> other()
Information about the identification document provided. Required if
methodis equal toother.
-
passport
final Optional<EntityCreateParams.NaturalPerson.Identification.Passport> passport()
Information about the passport used for identification. Required if
methodis equal topassport.
-
_method
final JsonField<EntityCreateParams.NaturalPerson.Identification.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_number
final JsonField<String> _number()
Returns the raw JSON value of number.
Unlike number, this method doesn't throw if the JSON field has an unexpected type.
-
_driversLicense
final JsonField<EntityCreateParams.NaturalPerson.Identification.DriversLicense> _driversLicense()
Returns the raw JSON value of driversLicense.
Unlike driversLicense, this method doesn't throw if the JSON field has an unexpected type.
-
_other
final JsonField<EntityCreateParams.NaturalPerson.Identification.Other> _other()
Returns the raw JSON value of other.
Unlike other, this method doesn't throw if the JSON field has an unexpected type.
-
_passport
final JsonField<EntityCreateParams.NaturalPerson.Identification.Passport> _passport()
Returns the raw JSON value of passport.
Unlike passport, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.NaturalPerson.Identification.Builder toBuilder()
-
validate
final EntityCreateParams.NaturalPerson.Identification validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.NaturalPerson.Identification.Builder builder()
Returns a mutable builder for constructing an instance of Identification.
The following fields are required:
.method() .number()
-
-
-
-