Class EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.NaturalPerson.Identification.DriversLicense.BuilderA builder for DriversLicense.
-
-
Method Summary
-
-
Method Detail
-
expirationDate
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder expirationDate(LocalDate expirationDate)
The driver's license's expiration date in YYYY-MM-DD format.
-
expirationDate
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder expirationDate(JsonField<LocalDate> expirationDate)
Sets Builder.expirationDate to an arbitrary JSON value.
You should usually call Builder.expirationDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder fileId(String fileId)
The identifier of the File containing the front of the driver's license.
-
fileId
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder state(String state)
The state that issued the provided driver's license.
-
state
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backFileId
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder backFileId(String backFileId)
The identifier of the File containing the back of the driver's license.
-
backFileId
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder backFileId(JsonField<String> backFileId)
Sets Builder.backFileId to an arbitrary JSON value.
You should usually call Builder.backFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.NaturalPerson.Identification.DriversLicense.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.NaturalPerson.Identification.DriversLicense build()
Returns an immutable instance of DriversLicense.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.expirationDate() .fileId() .state()
-
-
-
-