Package com.increase.api.models.entities
Class EntityCreateParams.RiskRating
-
- All Implemented Interfaces:
public final class EntityCreateParams.RiskRatingAn assessment of the entity's potential risk of involvement in financial crimes, such as money laundering.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.RiskRating.BuilderA builder for RiskRating.
public final classEntityCreateParams.RiskRating.RatingThe rating given to this entity.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeratedAt()The ISO 8601 time at which the risk rating was performed. final EntityCreateParams.RiskRating.Ratingrating()The rating given to this entity. final JsonField<OffsetDateTime>_ratedAt()Returns the raw JSON value of ratedAt. final JsonField<EntityCreateParams.RiskRating.Rating>_rating()Returns the raw JSON value of rating. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.RiskRating.BuildertoBuilder()final EntityCreateParams.RiskRatingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.RiskRating.Builderbuilder()Returns a mutable builder for constructing an instance of RiskRating. -
-
Method Detail
-
ratedAt
final OffsetDateTime ratedAt()
The ISO 8601 time at which the risk rating was performed.
-
rating
final EntityCreateParams.RiskRating.Rating rating()
The rating given to this entity.
-
_ratedAt
final JsonField<OffsetDateTime> _ratedAt()
Returns the raw JSON value of ratedAt.
Unlike ratedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_rating
final JsonField<EntityCreateParams.RiskRating.Rating> _rating()
Returns the raw JSON value of rating.
Unlike rating, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.RiskRating.Builder toBuilder()
-
validate
final EntityCreateParams.RiskRating validate()
-
builder
final static EntityCreateParams.RiskRating.Builder builder()
Returns a mutable builder for constructing an instance of RiskRating.
The following fields are required:
.ratedAt() .rating()
-
-
-
-