Package com.increase.api.models.entities
Class EntityCreateParams.SupplementalDocument.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.SupplementalDocument.BuilderA builder for SupplementalDocument.
-
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.SupplementalDocument.BuilderfileId(String fileId)The identifier of the File containing the document. final EntityCreateParams.SupplementalDocument.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final EntityCreateParams.SupplementalDocument.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final EntityCreateParams.SupplementalDocument.BuilderputAdditionalProperty(String key, JsonValue value)final EntityCreateParams.SupplementalDocument.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final EntityCreateParams.SupplementalDocument.BuilderremoveAdditionalProperty(String key)final EntityCreateParams.SupplementalDocument.BuilderremoveAllAdditionalProperties(Set<String> keys)final EntityCreateParams.SupplementalDocumentbuild()Returns an immutable instance of SupplementalDocument. -
-
Method Detail
-
fileId
final EntityCreateParams.SupplementalDocument.Builder fileId(String fileId)
The identifier of the File containing the document.
-
fileId
final EntityCreateParams.SupplementalDocument.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.SupplementalDocument.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.SupplementalDocument.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.SupplementalDocument.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.SupplementalDocument.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.SupplementalDocument.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.SupplementalDocument build()
Returns an immutable instance of SupplementalDocument.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.fileId()
-
-
-
-