Class EntityCreateParams.TermsAgreement
-
- All Implemented Interfaces:
public final class EntityCreateParams.TermsAgreement
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.TermsAgreement.BuilderA builder for TermsAgreement.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeagreedAt()The timestamp of when the Entity agreed to the terms. final StringipAddress()The IP address the Entity accessed reviewed the terms from. final StringtermsUrl()The URL of the terms agreement. final JsonField<OffsetDateTime>_agreedAt()Returns the raw JSON value of agreedAt. final JsonField<String>_ipAddress()Returns the raw JSON value of ipAddress. final JsonField<String>_termsUrl()Returns the raw JSON value of termsUrl. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.TermsAgreement.BuildertoBuilder()final EntityCreateParams.TermsAgreementvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.TermsAgreement.Builderbuilder()Returns a mutable builder for constructing an instance of TermsAgreement. -
-
Method Detail
-
agreedAt
final OffsetDateTime agreedAt()
The timestamp of when the Entity agreed to the terms.
-
termsUrl
final String termsUrl()
The URL of the terms agreement. This link will be provided by your bank partner.
-
_agreedAt
final JsonField<OffsetDateTime> _agreedAt()
Returns the raw JSON value of agreedAt.
Unlike agreedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_ipAddress
final JsonField<String> _ipAddress()
Returns the raw JSON value of ipAddress.
Unlike ipAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_termsUrl
final JsonField<String> _termsUrl()
Returns the raw JSON value of termsUrl.
Unlike termsUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.TermsAgreement.Builder toBuilder()
-
validate
final EntityCreateParams.TermsAgreement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityCreateParams.TermsAgreement.Builder builder()
Returns a mutable builder for constructing an instance of TermsAgreement.
The following fields are required:
.agreedAt() .ipAddress() .termsUrl()
-
-
-
-