Class EntityCreateParams.Trust
-
- All Implemented Interfaces:
public final class EntityCreateParams.TrustDetails of the trust entity to create. Required if
structureis equal totrust.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Trust.BuilderA builder for Trust.
public final classEntityCreateParams.Trust.AddressThe trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityCreateParams.Trust.CategoryWhether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.public final classEntityCreateParams.Trust.Trusteepublic final classEntityCreateParams.Trust.GrantorThe grantor of the trust. Required if
categoryis equal torevocable.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Trust.Addressaddress()The trust's physical address. final EntityCreateParams.Trust.Categorycategory()Whether the trust is revocableorirrevocable.final Stringname()The legal name of the trust. final List<EntityCreateParams.Trust.Trustee>trustees()The trustees of the trust. final Optional<String>formationDocumentFileId()The identifier of the File containing the formation document of the trust. final Optional<String>formationState()The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed. final Optional<EntityCreateParams.Trust.Grantor>grantor()The grantor of the trust. final Optional<String>taxIdentifier()The Employer Identification Number (EIN) for the trust. final JsonField<EntityCreateParams.Trust.Address>_address()Returns the raw JSON value of address. final JsonField<EntityCreateParams.Trust.Category>_category()Returns the raw JSON value of category. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<List<EntityCreateParams.Trust.Trustee>>_trustees()Returns the raw JSON value of trustees. final JsonField<String>_formationDocumentFileId()Returns the raw JSON value of formationDocumentFileId. final JsonField<String>_formationState()Returns the raw JSON value of formationState. final JsonField<EntityCreateParams.Trust.Grantor>_grantor()Returns the raw JSON value of grantor. final JsonField<String>_taxIdentifier()Returns the raw JSON value of taxIdentifier. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Trust.BuildertoBuilder()final EntityCreateParams.Trustvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Trust.Builderbuilder()Returns a mutable builder for constructing an instance of Trust. -
-
Method Detail
-
address
final EntityCreateParams.Trust.Address address()
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
category
final EntityCreateParams.Trust.Category category()
Whether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.
-
trustees
final List<EntityCreateParams.Trust.Trustee> trustees()
The trustees of the trust.
-
formationDocumentFileId
final Optional<String> formationDocumentFileId()
The identifier of the File containing the formation document of the trust.
-
formationState
final Optional<String> formationState()
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
grantor
final Optional<EntityCreateParams.Trust.Grantor> grantor()
The grantor of the trust. Required if
categoryis equal torevocable.
-
taxIdentifier
final Optional<String> taxIdentifier()
The Employer Identification Number (EIN) for the trust. Submit nine digits with no dashes or other separators. Required if
categoryis equal toirrevocable.
-
_address
final JsonField<EntityCreateParams.Trust.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<EntityCreateParams.Trust.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_trustees
final JsonField<List<EntityCreateParams.Trust.Trustee>> _trustees()
Returns the raw JSON value of trustees.
Unlike trustees, this method doesn't throw if the JSON field has an unexpected type.
-
_formationDocumentFileId
final JsonField<String> _formationDocumentFileId()
Returns the raw JSON value of formationDocumentFileId.
Unlike formationDocumentFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_formationState
final JsonField<String> _formationState()
Returns the raw JSON value of formationState.
Unlike formationState, this method doesn't throw if the JSON field has an unexpected type.
-
_grantor
final JsonField<EntityCreateParams.Trust.Grantor> _grantor()
Returns the raw JSON value of grantor.
Unlike grantor, this method doesn't throw if the JSON field has an unexpected type.
-
_taxIdentifier
final JsonField<String> _taxIdentifier()
Returns the raw JSON value of taxIdentifier.
Unlike taxIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Trust.Builder toBuilder()
-
validate
final EntityCreateParams.Trust validate()
-
builder
final static EntityCreateParams.Trust.Builder builder()
Returns a mutable builder for constructing an instance of Trust.
The following fields are required:
.address() .category() .name() .trustees()
-
-
-
-