Class EntityCreateParams.Trust.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Trust.BuilderA builder for Trust.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityCreateParams.Trust.Builder address(EntityCreateParams.Trust.Address address)
The trust's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityCreateParams.Trust.Builder address(JsonField<EntityCreateParams.Trust.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final EntityCreateParams.Trust.Builder category(EntityCreateParams.Trust.Category category)
Whether the trust is
revocableorirrevocable. Irrevocable trusts require their own Employer Identification Number. Revocable trusts require information about the individualgrantorwho created the trust.
-
category
final EntityCreateParams.Trust.Builder category(JsonField<EntityCreateParams.Trust.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EntityCreateParams.Trust.Builder name(String name)
The legal name of the trust.
-
name
final EntityCreateParams.Trust.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trustees
final EntityCreateParams.Trust.Builder trustees(List<EntityCreateParams.Trust.Trustee> trustees)
The trustees of the trust.
-
trustees
final EntityCreateParams.Trust.Builder trustees(JsonField<List<EntityCreateParams.Trust.Trustee>> trustees)
Sets Builder.trustees to an arbitrary JSON value.
You should usually call Builder.trustees with a well-typed
List<Trustee>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTrustee
final EntityCreateParams.Trust.Builder addTrustee(EntityCreateParams.Trust.Trustee trustee)
-
formationDocumentFileId
final EntityCreateParams.Trust.Builder formationDocumentFileId(String formationDocumentFileId)
The identifier of the File containing the formation document of the trust.
-
formationDocumentFileId
final EntityCreateParams.Trust.Builder formationDocumentFileId(JsonField<String> formationDocumentFileId)
Sets Builder.formationDocumentFileId to an arbitrary JSON value.
You should usually call Builder.formationDocumentFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
formationState
final EntityCreateParams.Trust.Builder formationState(String formationState)
The two-letter United States Postal Service (USPS) abbreviation for the state in which the trust was formed.
-
formationState
final EntityCreateParams.Trust.Builder formationState(JsonField<String> formationState)
Sets Builder.formationState to an arbitrary JSON value.
You should usually call Builder.formationState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
grantor
final EntityCreateParams.Trust.Builder grantor(EntityCreateParams.Trust.Grantor grantor)
The grantor of the trust. Required if
categoryis equal torevocable.
-
grantor
final EntityCreateParams.Trust.Builder grantor(JsonField<EntityCreateParams.Trust.Grantor> grantor)
Sets Builder.grantor to an arbitrary JSON value.
You should usually call Builder.grantor with a well-typed Grantor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final EntityCreateParams.Trust.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the trust. Required if
categoryis equal toirrevocable.
-
taxIdentifier
final EntityCreateParams.Trust.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Trust.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Trust.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Trust.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Trust.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Trust.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Trust build()
Returns an immutable instance of Trust.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .category() .name() .trustees()
-
-
-
-