Class EntityCreateParams.Trust.Trustee.Builder
-
- All Implemented Interfaces:
public final class EntityCreateParams.Trust.Trustee.BuilderA builder for Trustee.
-
-
Method Summary
-
-
Method Detail
-
structure
final EntityCreateParams.Trust.Trustee.Builder structure(EntityCreateParams.Trust.Trustee.Structure structure)
The structure of the trustee.
-
structure
final EntityCreateParams.Trust.Trustee.Builder structure(JsonField<EntityCreateParams.Trust.Trustee.Structure> structure)
Sets Builder.structure to an arbitrary JSON value.
You should usually call Builder.structure with a well-typed Structure value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individual
final EntityCreateParams.Trust.Trustee.Builder individual(EntityCreateParams.Trust.Trustee.Individual individual)
Details of the individual trustee. Within the trustee object, this is required if
structureis equal toindividual.
-
individual
final EntityCreateParams.Trust.Trustee.Builder individual(JsonField<EntityCreateParams.Trust.Trustee.Individual> individual)
Sets Builder.individual to an arbitrary JSON value.
You should usually call Builder.individual with a well-typed Individual value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityCreateParams.Trust.Trustee.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityCreateParams.Trust.Trustee.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityCreateParams.Trust.Trustee.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityCreateParams.Trust.Trustee.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityCreateParams.Trust.Trustee.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityCreateParams.Trust.Trustee build()
Returns an immutable instance of Trustee.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.structure()
-
-
-
-