Package com.increase.api.models.entities
Class EntityListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class EntityListPage implements Page<Entity>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityListPage.BuilderA builder for EntityListPage.
-
Method Summary
Modifier and Type Method Description final List<Entity>data()Delegates to EntityListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to EntityListPageResponse, but gracefully handles missing data. List<Entity>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final EntityListParamsnextPageParams()EntityListPagenextPage()Returns the page after this one by making another request. final AutoPager<Entity>autoPager()final EntityListParamsparams()The parameters that were used to request this page. final EntityListPageResponseresponse()The response that this page was parsed from. final EntityListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityListPage.Builderbuilder()Returns a mutable builder for constructing an instance of EntityListPage. -
-
Method Detail
-
data
final List<Entity> data()
Delegates to EntityListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to EntityListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final EntityListParams nextPageParams()
-
nextPage
EntityListPage nextPage()
Returns the page after this one by making another request.
-
params
final EntityListParams params()
The parameters that were used to request this page.
-
response
final EntityListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EntityListPage.Builder toBuilder()
-
builder
final static EntityListPage.Builder builder()
Returns a mutable builder for constructing an instance of EntityListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-