Package com.increase.api.models.entities
Class EntityListPage.Builder
-
- All Implemented Interfaces:
public final class EntityListPage.BuilderA builder for EntityListPage.
-
-
Method Summary
Modifier and Type Method Description final EntityListPage.Builderservice(EntityService service)final EntityListPage.Builderparams(EntityListParams params)The parameters that were used to request this page. final EntityListPage.Builderresponse(EntityListPageResponse response)The response that this page was parsed from. final EntityListPagebuild()Returns an immutable instance of EntityListPage. -
-
Method Detail
-
service
final EntityListPage.Builder service(EntityService service)
-
params
final EntityListPage.Builder params(EntityListParams params)
The parameters that were used to request this page.
-
response
final EntityListPage.Builder response(EntityListPageResponse response)
The response that this page was parsed from.
-
build
final EntityListPage build()
Returns an immutable instance of EntityListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-