Package com.increase.api.models.entities
Class EntityListPageAsync
-
- All Implemented Interfaces:
public final class EntityListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityListPageAsync.BuilderA builder for EntityListPageAsync.
public final classEntityListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Entity>data()Delegates to EntityListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to EntityListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<EntityListParams>getNextPageParams()final CompletableFuture<Optional<EntityListPageAsync>>getNextPage()final EntityListPageAsync.AutoPagerautoPager()final EntityListParamsparams()The parameters that were used to request this page. final EntityListPageResponseresponse()The response that this page was parsed from. final EntityListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of EntityListPageAsync. -
-
Method Detail
-
data
final List<Entity> data()
Delegates to EntityListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to EntityListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<EntityListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<EntityListPageAsync>> getNextPage()
-
autoPager
final EntityListPageAsync.AutoPager autoPager()
-
params
final EntityListParams params()
The parameters that were used to request this page.
-
response
final EntityListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EntityListPageAsync.Builder toBuilder()
-
builder
final static EntityListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of EntityListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-