Package com.increase.api.models.entities
Class EntityListPageAsync.Builder
-
- All Implemented Interfaces:
public final class EntityListPageAsync.BuilderA builder for EntityListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final EntityListPageAsync.Builderservice(EntityServiceAsync service)final EntityListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final EntityListPageAsync.Builderparams(EntityListParams params)The parameters that were used to request this page. final EntityListPageAsync.Builderresponse(EntityListPageResponse response)The response that this page was parsed from. final EntityListPageAsyncbuild()Returns an immutable instance of EntityListPageAsync. -
-
Method Detail
-
service
final EntityListPageAsync.Builder service(EntityServiceAsync service)
-
streamHandlerExecutor
final EntityListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final EntityListPageAsync.Builder params(EntityListParams params)
The parameters that were used to request this page.
-
response
final EntityListPageAsync.Builder response(EntityListPageResponse response)
The response that this page was parsed from.
-
build
final EntityListPageAsync build()
Returns an immutable instance of EntityListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-