Enum EntityListParams.Status.In.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum EntityListParams.Status.In.Value
    extends Enum<EntityListParams.Status.In.Value>
                        

    An enum containing In's known values, as well as an _UNKNOWN member.

    An instance of In can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      ACTIVE

      The entity is active.

      ARCHIVED

      The entity is archived, and can no longer be used to create accounts.

      DISABLED

      The entity is temporarily disabled and cannot be used for financial activity.

      _UNKNOWN

      An enum member indicating that In was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final EntityListParams.Status.In.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<EntityListParams.Status.In.Value> getEntries()

        An enum containing In's known values, as well as an _UNKNOWN member.

        An instance of In can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.