Class EntityUpdateAddressParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityUpdateAddressParams implements Params
Update a Natural Person or Corporation's address
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateAddressParams.BuilderA builder for EntityUpdateAddressParams.
public final classEntityUpdateAddressParams.Bodypublic final classEntityUpdateAddressParams.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
Method Summary
Modifier and Type Method Description final Optional<String>entityId()The identifier of the Entity whose address is being updated. final EntityUpdateAddressParams.Addressaddress()The entity's physical address. final JsonField<EntityUpdateAddressParams.Address>_address()Returns the raw JSON value of address. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityUpdateAddressParams.BuildertoBuilder()final EntityUpdateAddressParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateAddressParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityUpdateAddressParams. -
-
Method Detail
-
entityId
final Optional<String> entityId()
The identifier of the Entity whose address is being updated.
-
address
final EntityUpdateAddressParams.Address address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
_address
final JsonField<EntityUpdateAddressParams.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityUpdateAddressParams.Builder toBuilder()
-
_body
final EntityUpdateAddressParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityUpdateAddressParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityUpdateAddressParams.
The following fields are required:
.address()
-
-
-
-