Class EntityUpdateBeneficialOwnerAddressParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityUpdateBeneficialOwnerAddressParams implements Params
Update the address for a beneficial owner belonging to a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateBeneficialOwnerAddressParams.BuilderA builder for EntityUpdateBeneficialOwnerAddressParams.
public final classEntityUpdateBeneficialOwnerAddressParams.Bodypublic final classEntityUpdateBeneficialOwnerAddressParams.AddressThe individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
Method Summary
Modifier and Type Method Description final Optional<String>entityId()The identifier of the Entity associated with the Beneficial Owner whose address is being updated. final EntityUpdateBeneficialOwnerAddressParams.Addressaddress()The individual's physical address. final StringbeneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<EntityUpdateBeneficialOwnerAddressParams.Address>_address()Returns the raw JSON value of address. final JsonField<String>_beneficialOwnerId()Returns the raw JSON value of beneficialOwnerId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityUpdateBeneficialOwnerAddressParams.BuildertoBuilder()final EntityUpdateBeneficialOwnerAddressParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateBeneficialOwnerAddressParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityUpdateBeneficialOwnerAddressParams. -
-
Method Detail
-
entityId
final Optional<String> entityId()
The identifier of the Entity associated with the Beneficial Owner whose address is being updated.
-
address
final EntityUpdateBeneficialOwnerAddressParams.Address address()
The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
beneficialOwnerId
final String beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_address
final JsonField<EntityUpdateBeneficialOwnerAddressParams.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
Returns the raw JSON value of beneficialOwnerId.
Unlike beneficialOwnerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityUpdateBeneficialOwnerAddressParams.Builder toBuilder()
-
_body
final EntityUpdateBeneficialOwnerAddressParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityUpdateBeneficialOwnerAddressParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityUpdateBeneficialOwnerAddressParams.
The following fields are required:
.address() .beneficialOwnerId()
-
-
-
-