Package com.increase.api.models.entities
Class EntityUpdateBeneficialOwnerAddressParams.Body
-
- All Implemented Interfaces:
public final class EntityUpdateBeneficialOwnerAddressParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateBeneficialOwnerAddressParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final EntityUpdateBeneficialOwnerAddressParams.Addressaddress()The individual's physical address. final StringbeneficialOwnerId()The identifying details of anyone controlling or owning 25% or more of the corporation. final JsonField<EntityUpdateBeneficialOwnerAddressParams.Address>_address()Returns the raw JSON value of address. final JsonField<String>_beneficialOwnerId()Returns the raw JSON value of beneficialOwnerId. final Map<String, JsonValue>_additionalProperties()final EntityUpdateBeneficialOwnerAddressParams.Body.BuildertoBuilder()final EntityUpdateBeneficialOwnerAddressParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateBeneficialOwnerAddressParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
address
final EntityUpdateBeneficialOwnerAddressParams.Address address()
The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
beneficialOwnerId
final String beneficialOwnerId()
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
_address
final JsonField<EntityUpdateBeneficialOwnerAddressParams.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
Returns the raw JSON value of beneficialOwnerId.
Unlike beneficialOwnerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder toBuilder()
-
validate
final EntityUpdateBeneficialOwnerAddressParams.Body validate()
-
builder
final static EntityUpdateBeneficialOwnerAddressParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.address() .beneficialOwnerId()
-
-
-
-