Class EntityUpdateBeneficialOwnerAddressParams.Body.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateBeneficialOwnerAddressParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder address(EntityUpdateBeneficialOwnerAddressParams.Address address)
The individual's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder address(JsonField<EntityUpdateBeneficialOwnerAddressParams.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficialOwnerId
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder beneficialOwnerId(String beneficialOwnerId)
The identifying details of anyone controlling or owning 25% or more of the corporation.
-
beneficialOwnerId
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder beneficialOwnerId(JsonField<String> beneficialOwnerId)
Sets Builder.beneficialOwnerId to an arbitrary JSON value.
You should usually call Builder.beneficialOwnerId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateBeneficialOwnerAddressParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateBeneficialOwnerAddressParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .beneficialOwnerId()
-
-
-
-