Package com.increase.api.models.entities
Class EntityUpdateIndustryCodeParams.Body
-
- All Implemented Interfaces:
public final class EntityUpdateIndustryCodeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateIndustryCodeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringindustryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final JsonField<String>_industryCode()Returns the raw JSON value of industryCode. final Map<String, JsonValue>_additionalProperties()final EntityUpdateIndustryCodeParams.Body.BuildertoBuilder()final EntityUpdateIndustryCodeParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateIndustryCodeParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
industryCode
final String industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_industryCode
final JsonField<String> _industryCode()
Returns the raw JSON value of industryCode.
Unlike industryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateIndustryCodeParams.Body.Builder toBuilder()
-
validate
final EntityUpdateIndustryCodeParams.Body validate()
-
builder
final static EntityUpdateIndustryCodeParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.industryCode()
-
-
-
-