Class EntityUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityUpdateParams implements Params
Update an Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.BuilderA builder for EntityUpdateParams.
public final classEntityUpdateParams.Bodypublic final classEntityUpdateParams.CorporationDetails of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
public final classEntityUpdateParams.GovernmentAuthorityDetails of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
public final classEntityUpdateParams.NaturalPersonDetails of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
public final classEntityUpdateParams.RiskRatingAn assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
public final classEntityUpdateParams.ThirdPartyVerificationIf you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
public final classEntityUpdateParams.TrustDetails of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
Method Summary
Modifier and Type Method Description final Optional<String>entityId()The entity identifier. final Optional<EntityUpdateParams.Corporation>corporation()Details of the corporation entity to update. final Optional<OffsetDateTime>detailsConfirmedAt()When your user last confirmed the Entity's details. final Optional<EntityUpdateParams.GovernmentAuthority>governmentAuthority()Details of the government authority entity to update. final Optional<EntityUpdateParams.NaturalPerson>naturalPerson()Details of the natural person entity to update. final Optional<EntityUpdateParams.RiskRating>riskRating()An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering. final Optional<EntityUpdateParams.ThirdPartyVerification>thirdPartyVerification()If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service. final Optional<EntityUpdateParams.Trust>trust()Details of the trust entity to update. final JsonField<EntityUpdateParams.Corporation>_corporation()Returns the raw JSON value of corporation. final JsonField<OffsetDateTime>_detailsConfirmedAt()Returns the raw JSON value of detailsConfirmedAt. final JsonField<EntityUpdateParams.GovernmentAuthority>_governmentAuthority()Returns the raw JSON value of governmentAuthority. final JsonField<EntityUpdateParams.NaturalPerson>_naturalPerson()Returns the raw JSON value of naturalPerson. final JsonField<EntityUpdateParams.RiskRating>_riskRating()Returns the raw JSON value of riskRating. final JsonField<EntityUpdateParams.ThirdPartyVerification>_thirdPartyVerification()Returns the raw JSON value of thirdPartyVerification. final JsonField<EntityUpdateParams.Trust>_trust()Returns the raw JSON value of trust. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityUpdateParams.BuildertoBuilder()final EntityUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParamsnone()final static EntityUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityUpdateParams. -
-
Method Detail
-
corporation
final Optional<EntityUpdateParams.Corporation> corporation()
Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
-
detailsConfirmedAt
final Optional<OffsetDateTime> detailsConfirmedAt()
When your user last confirmed the Entity's details. Depending on your program, you may be required to affirmatively confirm details with your users on an annual basis.
-
governmentAuthority
final Optional<EntityUpdateParams.GovernmentAuthority> governmentAuthority()
Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
-
naturalPerson
final Optional<EntityUpdateParams.NaturalPerson> naturalPerson()
Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
riskRating
final Optional<EntityUpdateParams.RiskRating> riskRating()
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
thirdPartyVerification
final Optional<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification()
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
trust
final Optional<EntityUpdateParams.Trust> trust()
Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
_corporation
final JsonField<EntityUpdateParams.Corporation> _corporation()
Returns the raw JSON value of corporation.
Unlike corporation, this method doesn't throw if the JSON field has an unexpected type.
-
_detailsConfirmedAt
final JsonField<OffsetDateTime> _detailsConfirmedAt()
Returns the raw JSON value of detailsConfirmedAt.
Unlike detailsConfirmedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentAuthority
final JsonField<EntityUpdateParams.GovernmentAuthority> _governmentAuthority()
Returns the raw JSON value of governmentAuthority.
Unlike governmentAuthority, this method doesn't throw if the JSON field has an unexpected type.
-
_naturalPerson
final JsonField<EntityUpdateParams.NaturalPerson> _naturalPerson()
Returns the raw JSON value of naturalPerson.
Unlike naturalPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_riskRating
final JsonField<EntityUpdateParams.RiskRating> _riskRating()
Returns the raw JSON value of riskRating.
Unlike riskRating, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdPartyVerification
final JsonField<EntityUpdateParams.ThirdPartyVerification> _thirdPartyVerification()
Returns the raw JSON value of thirdPartyVerification.
Unlike thirdPartyVerification, this method doesn't throw if the JSON field has an unexpected type.
-
_trust
final JsonField<EntityUpdateParams.Trust> _trust()
Returns the raw JSON value of trust.
Unlike trust, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityUpdateParams.Builder toBuilder()
-
_body
final EntityUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EntityUpdateParams none()
-
builder
final static EntityUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityUpdateParams.
-
-
-
-