Class EntityUpdateParams.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.BuilderA builder for EntityUpdateParams.
-
-
Method Summary
-
-
Method Detail
-
entityId
final EntityUpdateParams.Builder entityId(String entityId)
The entity identifier.
-
entityId
final EntityUpdateParams.Builder entityId(Optional<String> entityId)
Alias for calling Builder.entityId with
entityId.orElse(null).
-
body
final EntityUpdateParams.Builder body(EntityUpdateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
corporation
final EntityUpdateParams.Builder corporation(EntityUpdateParams.Corporation corporation)
Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
-
corporation
final EntityUpdateParams.Builder corporation(JsonField<EntityUpdateParams.Corporation> corporation)
Sets Builder.corporation to an arbitrary JSON value.
You should usually call Builder.corporation with a well-typed Corporation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
detailsConfirmedAt
final EntityUpdateParams.Builder detailsConfirmedAt(OffsetDateTime detailsConfirmedAt)
When your user last confirmed the Entity's details. Depending on your program, you may be required to affirmatively confirm details with your users on an annual basis.
-
detailsConfirmedAt
final EntityUpdateParams.Builder detailsConfirmedAt(JsonField<OffsetDateTime> detailsConfirmedAt)
Sets Builder.detailsConfirmedAt to an arbitrary JSON value.
You should usually call Builder.detailsConfirmedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentAuthority
final EntityUpdateParams.Builder governmentAuthority(EntityUpdateParams.GovernmentAuthority governmentAuthority)
Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
-
governmentAuthority
final EntityUpdateParams.Builder governmentAuthority(JsonField<EntityUpdateParams.GovernmentAuthority> governmentAuthority)
Sets Builder.governmentAuthority to an arbitrary JSON value.
You should usually call Builder.governmentAuthority with a well-typed GovernmentAuthority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naturalPerson
final EntityUpdateParams.Builder naturalPerson(EntityUpdateParams.NaturalPerson naturalPerson)
Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
naturalPerson
final EntityUpdateParams.Builder naturalPerson(JsonField<EntityUpdateParams.NaturalPerson> naturalPerson)
Sets Builder.naturalPerson to an arbitrary JSON value.
You should usually call Builder.naturalPerson with a well-typed NaturalPerson value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
riskRating
final EntityUpdateParams.Builder riskRating(EntityUpdateParams.RiskRating riskRating)
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
riskRating
final EntityUpdateParams.Builder riskRating(JsonField<EntityUpdateParams.RiskRating> riskRating)
Sets Builder.riskRating to an arbitrary JSON value.
You should usually call Builder.riskRating with a well-typed RiskRating value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
termsAgreements
final EntityUpdateParams.Builder termsAgreements(List<EntityUpdateParams.TermsAgreement> termsAgreements)
New terms that the Entity agreed to. Not all programs are required to submit this data. This will not archive previously submitted terms.
-
termsAgreements
final EntityUpdateParams.Builder termsAgreements(JsonField<List<EntityUpdateParams.TermsAgreement>> termsAgreements)
Sets Builder.termsAgreements to an arbitrary JSON value.
You should usually call Builder.termsAgreements with a well-typed
List<TermsAgreement>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTermsAgreement
final EntityUpdateParams.Builder addTermsAgreement(EntityUpdateParams.TermsAgreement termsAgreement)
Adds a single TermsAgreement to termsAgreements.
-
thirdPartyVerification
final EntityUpdateParams.Builder thirdPartyVerification(EntityUpdateParams.ThirdPartyVerification thirdPartyVerification)
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
thirdPartyVerification
final EntityUpdateParams.Builder thirdPartyVerification(JsonField<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification)
Sets Builder.thirdPartyVerification to an arbitrary JSON value.
You should usually call Builder.thirdPartyVerification with a well-typed ThirdPartyVerification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trust
final EntityUpdateParams.Builder trust(EntityUpdateParams.Trust trust)
Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
trust
final EntityUpdateParams.Builder trust(JsonField<EntityUpdateParams.Trust> trust)
Sets Builder.trust to an arbitrary JSON value.
You should usually call Builder.trust with a well-typed Trust value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final EntityUpdateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final EntityUpdateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final EntityUpdateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final EntityUpdateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final EntityUpdateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final EntityUpdateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final EntityUpdateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final EntityUpdateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final EntityUpdateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final EntityUpdateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final EntityUpdateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final EntityUpdateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final EntityUpdateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final EntityUpdateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final EntityUpdateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final EntityUpdateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final EntityUpdateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final EntityUpdateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final EntityUpdateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final EntityUpdateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final EntityUpdateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final EntityUpdateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final EntityUpdateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final EntityUpdateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final EntityUpdateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final EntityUpdateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final EntityUpdateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final EntityUpdateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final EntityUpdateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final EntityUpdateParams build()
Returns an immutable instance of EntityUpdateParams.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-