Class EntityUpdateParams.Corporation
-
- All Implemented Interfaces:
public final class EntityUpdateParams.CorporationDetails of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.Corporation.BuilderA builder for Corporation.
public final classEntityUpdateParams.Corporation.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityUpdateParams.Corporation.LegalIdentifierThe legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
-
Method Summary
Modifier and Type Method Description final Optional<EntityUpdateParams.Corporation.Address>address()The entity's physical address. final Optional<String>email()An email address for the business. final Optional<String>incorporationState()The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation. final Optional<String>industryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final Optional<EntityUpdateParams.Corporation.LegalIdentifier>legalIdentifier()The legal identifier of the corporation. final Optional<String>name()The legal name of the corporation. final JsonField<EntityUpdateParams.Corporation.Address>_address()Returns the raw JSON value of address. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_incorporationState()Returns the raw JSON value of incorporationState. final JsonField<String>_industryCode()Returns the raw JSON value of industryCode. final JsonField<EntityUpdateParams.Corporation.LegalIdentifier>_legalIdentifier()Returns the raw JSON value of legalIdentifier. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.Corporation.BuildertoBuilder()final EntityUpdateParams.Corporationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.Corporation.Builderbuilder()Returns a mutable builder for constructing an instance of Corporation. -
-
Method Detail
-
address
final Optional<EntityUpdateParams.Corporation.Address> address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
email
final Optional<String> email()
An email address for the business. Not every program requires an email for submitted Entities.
-
incorporationState
final Optional<String> incorporationState()
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
industryCode
final Optional<String> industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
legalIdentifier
final Optional<EntityUpdateParams.Corporation.LegalIdentifier> legalIdentifier()
The legal identifier of the corporation. This is usually the Employer Identification Number (EIN).
-
_address
final JsonField<EntityUpdateParams.Corporation.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_incorporationState
final JsonField<String> _incorporationState()
Returns the raw JSON value of incorporationState.
Unlike incorporationState, this method doesn't throw if the JSON field has an unexpected type.
-
_industryCode
final JsonField<String> _industryCode()
Returns the raw JSON value of industryCode.
Unlike industryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_legalIdentifier
final JsonField<EntityUpdateParams.Corporation.LegalIdentifier> _legalIdentifier()
Returns the raw JSON value of legalIdentifier.
Unlike legalIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.Corporation.Builder toBuilder()
-
validate
final EntityUpdateParams.Corporation validate()
-
builder
final static EntityUpdateParams.Corporation.Builder builder()
Returns a mutable builder for constructing an instance of Corporation.
-
-
-
-