Class EntityUpdateParams.Corporation.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Corporation.BuilderA builder for Corporation.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityUpdateParams.Corporation.Builder address(EntityUpdateParams.Corporation.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityUpdateParams.Corporation.Builder address(JsonField<EntityUpdateParams.Corporation.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final EntityUpdateParams.Corporation.Builder email(String email)
An email address for the business. Not every program requires an email for submitted Entities.
-
email
final EntityUpdateParams.Corporation.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
incorporationState
final EntityUpdateParams.Corporation.Builder incorporationState(String incorporationState)
The two-letter United States Postal Service (USPS) abbreviation for the corporation's state of incorporation.
-
incorporationState
final EntityUpdateParams.Corporation.Builder incorporationState(JsonField<String> incorporationState)
Sets Builder.incorporationState to an arbitrary JSON value.
You should usually call Builder.incorporationState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
industryCode
final EntityUpdateParams.Corporation.Builder industryCode(String industryCode)
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
industryCode
final EntityUpdateParams.Corporation.Builder industryCode(JsonField<String> industryCode)
Sets Builder.industryCode to an arbitrary JSON value.
You should usually call Builder.industryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EntityUpdateParams.Corporation.Builder name(String name)
The legal name of the corporation.
-
name
final EntityUpdateParams.Corporation.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
taxIdentifier
final EntityUpdateParams.Corporation.Builder taxIdentifier(String taxIdentifier)
The Employer Identification Number (EIN) for the corporation.
-
taxIdentifier
final EntityUpdateParams.Corporation.Builder taxIdentifier(JsonField<String> taxIdentifier)
Sets Builder.taxIdentifier to an arbitrary JSON value.
You should usually call Builder.taxIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.Corporation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.Corporation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.Corporation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.Corporation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.Corporation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.Corporation build()
Returns an immutable instance of Corporation.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-