Class EntityUpdateParams.NaturalPerson
-
- All Implemented Interfaces:
public final class EntityUpdateParams.NaturalPersonDetails of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.NaturalPerson.BuilderA builder for NaturalPerson.
public final classEntityUpdateParams.NaturalPerson.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
public final classEntityUpdateParams.NaturalPerson.IdentificationA means of verifying the person's identity.
-
Method Summary
Modifier and Type Method Description final Optional<EntityUpdateParams.NaturalPerson.Address>address()The entity's physical address. final Optional<Boolean>confirmedNoUsTaxId()The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number). final Optional<EntityUpdateParams.NaturalPerson.Identification>identification()A means of verifying the person's identity. final Optional<String>name()The legal name of the natural person. final JsonField<EntityUpdateParams.NaturalPerson.Address>_address()Returns the raw JSON value of address. final JsonField<Boolean>_confirmedNoUsTaxId()Returns the raw JSON value of confirmedNoUsTaxId. final JsonField<EntityUpdateParams.NaturalPerson.Identification>_identification()Returns the raw JSON value of identification. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.NaturalPerson.BuildertoBuilder()final EntityUpdateParams.NaturalPersonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.NaturalPerson.Builderbuilder()Returns a mutable builder for constructing an instance of NaturalPerson. -
-
Method Detail
-
address
final Optional<EntityUpdateParams.NaturalPerson.Address> address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
confirmedNoUsTaxId
final Optional<Boolean> confirmedNoUsTaxId()
The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
identification
final Optional<EntityUpdateParams.NaturalPerson.Identification> identification()
A means of verifying the person's identity.
-
_address
final JsonField<EntityUpdateParams.NaturalPerson.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_confirmedNoUsTaxId
final JsonField<Boolean> _confirmedNoUsTaxId()
Returns the raw JSON value of confirmedNoUsTaxId.
Unlike confirmedNoUsTaxId, this method doesn't throw if the JSON field has an unexpected type.
-
_identification
final JsonField<EntityUpdateParams.NaturalPerson.Identification> _identification()
Returns the raw JSON value of identification.
Unlike identification, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.NaturalPerson.Builder toBuilder()
-
validate
final EntityUpdateParams.NaturalPerson validate()
-
builder
final static EntityUpdateParams.NaturalPerson.Builder builder()
Returns a mutable builder for constructing an instance of NaturalPerson.
-
-
-
-