Class EntityUpdateParams.NaturalPerson.Address
-
- All Implemented Interfaces:
public final class EntityUpdateParams.NaturalPerson.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.NaturalPerson.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city, district, town, or village of the address. final Stringcountry()The two-letter ISO 3166-1 alpha-2 code for the country of the address. final Stringline1()The first line of the address. final Optional<String>line2()The second line of the address. final Optional<String>state()The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. final Optional<String>zip()The ZIP or postal code of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_zip()Returns the raw JSON value of zip. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.NaturalPerson.Address.BuildertoBuilder()final EntityUpdateParams.NaturalPerson.Addressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.NaturalPerson.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
country
final String country()
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
line1
final String line1()
The first line of the address. This is usually the street number and street.
-
line2
final Optional<String> line2()
The second line of the address. This might be the floor or room number.
-
state
final Optional<String> state()
The two-letter United States Postal Service (USPS) abbreviation for the US state, province, or region of the address. Required in certain countries.
-
zip
final Optional<String> zip()
The ZIP or postal code of the address. Required in certain countries.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_zip
final JsonField<String> _zip()
Returns the raw JSON value of zip.
Unlike zip, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.NaturalPerson.Address.Builder toBuilder()
-
validate
final EntityUpdateParams.NaturalPerson.Address validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityUpdateParams.NaturalPerson.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .country() .line1()
-
-
-
-