Class EntityUpdateParams.NaturalPerson.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.NaturalPerson.BuilderA builder for NaturalPerson.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityUpdateParams.NaturalPerson.Builder address(EntityUpdateParams.NaturalPerson.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityUpdateParams.NaturalPerson.Builder address(JsonField<EntityUpdateParams.NaturalPerson.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
confirmedNoUsTaxId
final EntityUpdateParams.NaturalPerson.Builder confirmedNoUsTaxId(Boolean confirmedNoUsTaxId)
The identification method for an individual can only be a passport, driver's license, or other document if you've confirmed the individual does not have a US tax id (either a Social Security Number or Individual Taxpayer Identification Number).
-
confirmedNoUsTaxId
final EntityUpdateParams.NaturalPerson.Builder confirmedNoUsTaxId(JsonField<Boolean> confirmedNoUsTaxId)
Sets Builder.confirmedNoUsTaxId to an arbitrary JSON value.
You should usually call Builder.confirmedNoUsTaxId with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
identification
final EntityUpdateParams.NaturalPerson.Builder identification(EntityUpdateParams.NaturalPerson.Identification identification)
A means of verifying the person's identity.
-
identification
final EntityUpdateParams.NaturalPerson.Builder identification(JsonField<EntityUpdateParams.NaturalPerson.Identification> identification)
Sets Builder.identification to an arbitrary JSON value.
You should usually call Builder.identification with a well-typed Identification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EntityUpdateParams.NaturalPerson.Builder name(String name)
The legal name of the natural person.
-
name
final EntityUpdateParams.NaturalPerson.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.NaturalPerson.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.NaturalPerson.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.NaturalPerson.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.NaturalPerson.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.NaturalPerson.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.NaturalPerson build()
Returns an immutable instance of NaturalPerson.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-