Class EntityUpdateParams.NaturalPerson.Identification.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.NaturalPerson.Identification.BuilderA builder for Identification.
-
-
Method Summary
-
-
Method Detail
-
method
final EntityUpdateParams.NaturalPerson.Identification.Builder method(EntityUpdateParams.NaturalPerson.Identification.Method method)
A method that can be used to verify the individual's identity.
-
method
final EntityUpdateParams.NaturalPerson.Identification.Builder method(JsonField<EntityUpdateParams.NaturalPerson.Identification.Method> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed Method value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
number
final EntityUpdateParams.NaturalPerson.Identification.Builder number(String number)
An identification number that can be used to verify the individual's identity, such as a social security number. For Social Security Numbers and Individual Taxpayer Identification Numbers, submit nine digits with no dashes or other separators. When testing in sandbox, use one of our sandbox test values.
-
number
final EntityUpdateParams.NaturalPerson.Identification.Builder number(JsonField<String> number)
Sets Builder.number to an arbitrary JSON value.
You should usually call Builder.number with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
driversLicense
final EntityUpdateParams.NaturalPerson.Identification.Builder driversLicense(EntityUpdateParams.NaturalPerson.Identification.DriversLicense driversLicense)
Information about the United States driver's license used for identification. Required if
methodis equal todrivers_license.
-
driversLicense
final EntityUpdateParams.NaturalPerson.Identification.Builder driversLicense(JsonField<EntityUpdateParams.NaturalPerson.Identification.DriversLicense> driversLicense)
Sets Builder.driversLicense to an arbitrary JSON value.
You should usually call Builder.driversLicense with a well-typed DriversLicense value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
other
final EntityUpdateParams.NaturalPerson.Identification.Builder other(EntityUpdateParams.NaturalPerson.Identification.Other other)
Information about the identification document provided. Required if
methodis equal toother.
-
other
final EntityUpdateParams.NaturalPerson.Identification.Builder other(JsonField<EntityUpdateParams.NaturalPerson.Identification.Other> other)
Sets Builder.other to an arbitrary JSON value.
You should usually call Builder.other with a well-typed Other value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
passport
final EntityUpdateParams.NaturalPerson.Identification.Builder passport(EntityUpdateParams.NaturalPerson.Identification.Passport passport)
Information about the passport used for identification. Required if
methodis equal topassport.
-
passport
final EntityUpdateParams.NaturalPerson.Identification.Builder passport(JsonField<EntityUpdateParams.NaturalPerson.Identification.Passport> passport)
Sets Builder.passport to an arbitrary JSON value.
You should usually call Builder.passport with a well-typed Passport value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.NaturalPerson.Identification.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.NaturalPerson.Identification.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.NaturalPerson.Identification.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.NaturalPerson.Identification.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.NaturalPerson.Identification.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.NaturalPerson.Identification build()
Returns an immutable instance of Identification.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.method() .number()
-
-
-
-