Class EntityUpdateParams.NaturalPerson.Identification.Passport
-
- All Implemented Interfaces:
public final class EntityUpdateParams.NaturalPerson.Identification.PassportInformation about the passport used for identification. Required if
methodis equal topassport.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.NaturalPerson.Identification.Passport.BuilderA builder for Passport.
-
Method Summary
Modifier and Type Method Description final Stringcountry()The two-character ISO 3166-1 code representing the country that issued the document (e.g. final LocalDateexpirationDate()The passport's expiration date in YYYY-MM-DD format. final StringfileId()The identifier of the File containing the passport. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<LocalDate>_expirationDate()Returns the raw JSON value of expirationDate. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.NaturalPerson.Identification.Passport.BuildertoBuilder()final EntityUpdateParams.NaturalPerson.Identification.Passportvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.NaturalPerson.Identification.Passport.Builderbuilder()Returns a mutable builder for constructing an instance of Passport. -
-
Method Detail
-
country
final String country()
The two-character ISO 3166-1 code representing the country that issued the document (e.g.,
US).
-
expirationDate
final LocalDate expirationDate()
The passport's expiration date in YYYY-MM-DD format.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
Returns the raw JSON value of expirationDate.
Unlike expirationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.NaturalPerson.Identification.Passport.Builder toBuilder()
-
validate
final EntityUpdateParams.NaturalPerson.Identification.Passport validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityUpdateParams.NaturalPerson.Identification.Passport.Builder builder()
Returns a mutable builder for constructing an instance of Passport.
The following fields are required:
.country() .expirationDate() .fileId()
-
-
-
-