Class EntityUpdateParams.Trust.Address
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Trust.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.Trust.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the address. final Stringline1()The first line of the address. final Stringstate()The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final Stringzip()The ZIP code of the address. final Optional<String>line2()The second line of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_zip()Returns the raw JSON value of zip. final JsonField<String>_line2()Returns the raw JSON value of line2. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.Trust.Address.BuildertoBuilder()final EntityUpdateParams.Trust.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.Trust.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
line1
final String line1()
The first line of the address. This is usually the street number and street.
-
state
final String state()
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
line2
final Optional<String> line2()
The second line of the address. This might be the floor or room number.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_zip
final JsonField<String> _zip()
Returns the raw JSON value of zip.
Unlike zip, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.Trust.Address.Builder toBuilder()
-
validate
final EntityUpdateParams.Trust.Address validate()
-
builder
final static EntityUpdateParams.Trust.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .line1() .state() .zip()
-
-
-
-