Class EntityUpdateParams.Trust.Address.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Trust.Address.BuilderA builder for Address.
-
-
Method Summary
-
-
Method Detail
-
city
final EntityUpdateParams.Trust.Address.Builder city(String city)
The city of the address.
-
city
final EntityUpdateParams.Trust.Address.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final EntityUpdateParams.Trust.Address.Builder line1(String line1)
The first line of the address. This is usually the street number and street.
-
line1
final EntityUpdateParams.Trust.Address.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final EntityUpdateParams.Trust.Address.Builder state(String state)
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
state
final EntityUpdateParams.Trust.Address.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
zip
final EntityUpdateParams.Trust.Address.Builder zip(String zip)
The ZIP code of the address.
-
zip
final EntityUpdateParams.Trust.Address.Builder zip(JsonField<String> zip)
Sets Builder.zip to an arbitrary JSON value.
You should usually call Builder.zip with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final EntityUpdateParams.Trust.Address.Builder line2(String line2)
The second line of the address. This might be the floor or room number.
-
line2
final EntityUpdateParams.Trust.Address.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.Trust.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.Trust.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.Trust.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.Trust.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.Trust.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.Trust.Address build()
Returns an immutable instance of Address.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .line1() .state() .zip()
-
-
-
-