Package com.increase.api.models.entities
Class EntityUpdateParams.Trust.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Trust.BuilderA builder for Trust.
-
-
Method Summary
-
-
Method Detail
-
address
final EntityUpdateParams.Trust.Builder address(EntityUpdateParams.Trust.Address address)
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
address
final EntityUpdateParams.Trust.Builder address(JsonField<EntityUpdateParams.Trust.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final EntityUpdateParams.Trust.Builder name(String name)
The legal name of the trust.
-
name
final EntityUpdateParams.Trust.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.Trust.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.Trust.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.Trust.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.Trust.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.Trust.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.Trust build()
Returns an immutable instance of Trust.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-