Class EntityOnboardingSession
-
- All Implemented Interfaces:
public final class EntityOnboardingSessionEntity Onboarding Sessions let your customers onboard themselves by completing Increase-hosted forms. Create a session and redirect your customer to the returned URL. When they're done, they'll be redirected back to your site. This API is used for /documentation/hosted-onboarding.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityOnboardingSession.BuilderA builder for EntityOnboardingSession.
public final classEntityOnboardingSession.StatusThe status of the onboarding session.
public final classEntityOnboardingSession.TypeA constant representing the object's type. For this resource it will always be
entity_onboarding_session.
-
Method Summary
Modifier and Type Method Description final Stringid()The Entity Onboarding Session's identifier. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Entity Onboarding Session was created. final Optional<String>entityId()The identifier of the Entity associated with this session, if one has been created or was provided when creating the session. final OffsetDateTimeexpiresAt()The ISO 8601 date and time at which the Entity Onboarding Session will expire. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringprogramId()The identifier of the Program the Entity will be onboarded to. final StringredirectUrl()The URL to redirect to after the onboarding session is complete. final Optional<String>sessionUrl()The URL containing the onboarding form. final EntityOnboardingSession.Statusstatus()The status of the onboarding session. final EntityOnboardingSession.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_programId()Returns the raw JSON value of programId. final JsonField<String>_redirectUrl()Returns the raw JSON value of redirectUrl. final JsonField<String>_sessionUrl()Returns the raw JSON value of sessionUrl. final JsonField<EntityOnboardingSession.Status>_status()Returns the raw JSON value of status. final JsonField<EntityOnboardingSession.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final EntityOnboardingSession.BuildertoBuilder()final EntityOnboardingSessionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityOnboardingSession.Builderbuilder()Returns a mutable builder for constructing an instance of EntityOnboardingSession. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Entity Onboarding Session was created.
-
entityId
final Optional<String> entityId()
The identifier of the Entity associated with this session, if one has been created or was provided when creating the session.
-
expiresAt
final OffsetDateTime expiresAt()
The ISO 8601 date and time at which the Entity Onboarding Session will expire.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
redirectUrl
final String redirectUrl()
The URL to redirect to after the onboarding session is complete. Increase will include the query parameters
entity_onboarding_session_idandentity_idwhen redirecting.
-
sessionUrl
final Optional<String> sessionUrl()
The URL containing the onboarding form. You should share this link with your customer. Only present when the session is active.
-
status
final EntityOnboardingSession.Status status()
The status of the onboarding session.
-
type
final EntityOnboardingSession.Type type()
A constant representing the object's type. For this resource it will always be
entity_onboarding_session.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUrl
final JsonField<String> _redirectUrl()
Returns the raw JSON value of redirectUrl.
Unlike redirectUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_sessionUrl
final JsonField<String> _sessionUrl()
Returns the raw JSON value of sessionUrl.
Unlike sessionUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EntityOnboardingSession.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<EntityOnboardingSession.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityOnboardingSession.Builder toBuilder()
-
validate
final EntityOnboardingSession validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityOnboardingSession.Builder builder()
Returns a mutable builder for constructing an instance of EntityOnboardingSession.
The following fields are required:
.id() .createdAt() .entityId() .expiresAt() .idempotencyKey() .programId() .redirectUrl() .sessionUrl() .status() .type()
-
-
-
-