Class EntityOnboardingSession.Builder
-
- All Implemented Interfaces:
public final class EntityOnboardingSession.BuilderA builder for EntityOnboardingSession.
-
-
Method Summary
-
-
Method Detail
-
id
final EntityOnboardingSession.Builder id(String id)
The Entity Onboarding Session's identifier.
-
id
final EntityOnboardingSession.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final EntityOnboardingSession.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Entity Onboarding Session was created.
-
createdAt
final EntityOnboardingSession.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final EntityOnboardingSession.Builder entityId(String entityId)
The identifier of the Entity associated with this session, if one has been created or was provided when creating the session.
-
entityId
final EntityOnboardingSession.Builder entityId(Optional<String> entityId)
Alias for calling Builder.entityId with
entityId.orElse(null).
-
entityId
final EntityOnboardingSession.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresAt
final EntityOnboardingSession.Builder expiresAt(OffsetDateTime expiresAt)
The ISO 8601 date and time at which the Entity Onboarding Session will expire.
-
expiresAt
final EntityOnboardingSession.Builder expiresAt(JsonField<OffsetDateTime> expiresAt)
Sets Builder.expiresAt to an arbitrary JSON value.
You should usually call Builder.expiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final EntityOnboardingSession.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final EntityOnboardingSession.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final EntityOnboardingSession.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final EntityOnboardingSession.Builder programId(String programId)
The identifier of the Program the Entity will be onboarded to.
-
programId
final EntityOnboardingSession.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
redirectUrl
final EntityOnboardingSession.Builder redirectUrl(String redirectUrl)
The URL to redirect to after the onboarding session is complete. Increase will include the query parameters
entity_onboarding_session_idandentity_idwhen redirecting.
-
redirectUrl
final EntityOnboardingSession.Builder redirectUrl(JsonField<String> redirectUrl)
Sets Builder.redirectUrl to an arbitrary JSON value.
You should usually call Builder.redirectUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sessionUrl
final EntityOnboardingSession.Builder sessionUrl(String sessionUrl)
The URL containing the onboarding form. You should share this link with your customer. Only present when the session is active.
-
sessionUrl
final EntityOnboardingSession.Builder sessionUrl(Optional<String> sessionUrl)
Alias for calling Builder.sessionUrl with
sessionUrl.orElse(null).
-
sessionUrl
final EntityOnboardingSession.Builder sessionUrl(JsonField<String> sessionUrl)
Sets Builder.sessionUrl to an arbitrary JSON value.
You should usually call Builder.sessionUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final EntityOnboardingSession.Builder status(EntityOnboardingSession.Status status)
The status of the onboarding session.
-
status
final EntityOnboardingSession.Builder status(JsonField<EntityOnboardingSession.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final EntityOnboardingSession.Builder type(EntityOnboardingSession.Type type)
A constant representing the object's type. For this resource it will always be
entity_onboarding_session.
-
type
final EntityOnboardingSession.Builder type(JsonField<EntityOnboardingSession.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityOnboardingSession.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityOnboardingSession.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityOnboardingSession.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityOnboardingSession.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityOnboardingSession.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityOnboardingSession build()
Returns an immutable instance of EntityOnboardingSession.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .entityId() .expiresAt() .idempotencyKey() .programId() .redirectUrl() .sessionUrl() .status() .type()
-
-
-
-