Class EntityOnboardingSessionCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityOnboardingSessionCreateParams implements Params
Create an Entity Onboarding Session
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityOnboardingSessionCreateParams.BuilderA builder for EntityOnboardingSessionCreateParams.
public final classEntityOnboardingSessionCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringprogramId()The identifier of the Program the Entity will be onboarded to. final StringredirectUrl()The URL to redirect the customer to after they complete the onboarding form. final Optional<String>entityId()The identifier of an existing Entity to associate with the onboarding session. final JsonField<String>_programId()Returns the raw JSON value of programId. final JsonField<String>_redirectUrl()Returns the raw JSON value of redirectUrl. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityOnboardingSessionCreateParams.BuildertoBuilder()final EntityOnboardingSessionCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityOnboardingSessionCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityOnboardingSessionCreateParams. -
-
Method Detail
-
redirectUrl
final String redirectUrl()
The URL to redirect the customer to after they complete the onboarding form. The redirect will include
entity_onboarding_session_idandentity_idquery parameters.
-
entityId
final Optional<String> entityId()
The identifier of an existing Entity to associate with the onboarding session. If provided, the onboarding form will display any outstanding tasks required to complete the Entity's onboarding.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUrl
final JsonField<String> _redirectUrl()
Returns the raw JSON value of redirectUrl.
Unlike redirectUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityOnboardingSessionCreateParams.Builder toBuilder()
-
_body
final EntityOnboardingSessionCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityOnboardingSessionCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityOnboardingSessionCreateParams.
The following fields are required:
.programId() .redirectUrl()
-
-
-
-