Class EntityOnboardingSessionCreateParams.Body
-
- All Implemented Interfaces:
public final class EntityOnboardingSessionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityOnboardingSessionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringprogramId()The identifier of the Program the Entity will be onboarded to. final StringredirectUrl()The URL to redirect the customer to after they complete the onboarding form. final Optional<String>entityId()The identifier of an existing Entity to associate with the onboarding session. final JsonField<String>_programId()Returns the raw JSON value of programId. final JsonField<String>_redirectUrl()Returns the raw JSON value of redirectUrl. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalProperties()final EntityOnboardingSessionCreateParams.Body.BuildertoBuilder()final EntityOnboardingSessionCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityOnboardingSessionCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
redirectUrl
final String redirectUrl()
The URL to redirect the customer to after they complete the onboarding form. The redirect will include
entity_onboarding_session_idandentity_idquery parameters.
-
entityId
final Optional<String> entityId()
The identifier of an existing Entity to associate with the onboarding session. If provided, the onboarding form will display any outstanding tasks required to complete the Entity's onboarding.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_redirectUrl
final JsonField<String> _redirectUrl()
Returns the raw JSON value of redirectUrl.
Unlike redirectUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityOnboardingSessionCreateParams.Body.Builder toBuilder()
-
validate
final EntityOnboardingSessionCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityOnboardingSessionCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.programId() .redirectUrl()
-
-
-
-