Class EntityOnboardingSessionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EntityOnboardingSessionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
programId
final EntityOnboardingSessionCreateParams.Body.Builder programId(String programId)
The identifier of the Program the Entity will be onboarded to.
-
programId
final EntityOnboardingSessionCreateParams.Body.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
redirectUrl
final EntityOnboardingSessionCreateParams.Body.Builder redirectUrl(String redirectUrl)
The URL to redirect the customer to after they complete the onboarding form. The redirect will include
entity_onboarding_session_idandentity_idquery parameters.
-
redirectUrl
final EntityOnboardingSessionCreateParams.Body.Builder redirectUrl(JsonField<String> redirectUrl)
Sets Builder.redirectUrl to an arbitrary JSON value.
You should usually call Builder.redirectUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final EntityOnboardingSessionCreateParams.Body.Builder entityId(String entityId)
The identifier of an existing Entity to associate with the onboarding session. If provided, the onboarding form will display any outstanding tasks required to complete the Entity's onboarding.
-
entityId
final EntityOnboardingSessionCreateParams.Body.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityOnboardingSessionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityOnboardingSessionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityOnboardingSessionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityOnboardingSessionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityOnboardingSessionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityOnboardingSessionCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.programId() .redirectUrl()
-
-
-
-