Class EntityOnboardingSessionListPage.Builder
-
- All Implemented Interfaces:
public final class EntityOnboardingSessionListPage.BuilderA builder for EntityOnboardingSessionListPage.
-
-
Method Summary
Modifier and Type Method Description final EntityOnboardingSessionListPage.Builderservice(EntityOnboardingSessionService service)final EntityOnboardingSessionListPage.Builderparams(EntityOnboardingSessionListParams params)The parameters that were used to request this page. final EntityOnboardingSessionListPage.Builderresponse(EntityOnboardingSessionListPageResponse response)The response that this page was parsed from. final EntityOnboardingSessionListPagebuild()Returns an immutable instance of EntityOnboardingSessionListPage. -
-
Method Detail
-
service
final EntityOnboardingSessionListPage.Builder service(EntityOnboardingSessionService service)
-
params
final EntityOnboardingSessionListPage.Builder params(EntityOnboardingSessionListParams params)
The parameters that were used to request this page.
-
response
final EntityOnboardingSessionListPage.Builder response(EntityOnboardingSessionListPageResponse response)
The response that this page was parsed from.
-
build
final EntityOnboardingSessionListPage build()
Returns an immutable instance of EntityOnboardingSessionListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-