Class EntityOnboardingSessionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class EntityOnboardingSessionListPageAsync.BuilderA builder for EntityOnboardingSessionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final EntityOnboardingSessionListPageAsync.Builderservice(EntityOnboardingSessionServiceAsync service)final EntityOnboardingSessionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final EntityOnboardingSessionListPageAsync.Builderparams(EntityOnboardingSessionListParams params)The parameters that were used to request this page. final EntityOnboardingSessionListPageAsync.Builderresponse(EntityOnboardingSessionListPageResponse response)The response that this page was parsed from. final EntityOnboardingSessionListPageAsyncbuild()Returns an immutable instance of EntityOnboardingSessionListPageAsync. -
-
Method Detail
-
service
final EntityOnboardingSessionListPageAsync.Builder service(EntityOnboardingSessionServiceAsync service)
-
streamHandlerExecutor
final EntityOnboardingSessionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final EntityOnboardingSessionListPageAsync.Builder params(EntityOnboardingSessionListParams params)
The parameters that were used to request this page.
-
response
final EntityOnboardingSessionListPageAsync.Builder response(EntityOnboardingSessionListPageResponse response)
The response that this page was parsed from.
-
build
final EntityOnboardingSessionListPageAsync build()
Returns an immutable instance of EntityOnboardingSessionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-