Class Event
-
- All Implemented Interfaces:
public final class EventEvents are records of things that happened to objects at Increase. Events are accessible via the List Events endpoint and can be delivered to your application via webhooks. For more information, see our webhooks guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEvent.BuilderA builder for Event.
public final classEvent.CategoryThe category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classEvent.TypeA constant representing the object's type. For this resource it will always be
event.
-
Method Summary
Modifier and Type Method Description final Stringid()The Event identifier. final StringassociatedObjectId()The identifier of the object that generated this Event. final StringassociatedObjectType()The type of the object that generated this Event. final Event.Categorycategory()The category of the Event. final OffsetDateTimecreatedAt()The time the Event was created. final Event.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_associatedObjectId()Returns the raw JSON value of associatedObjectId. final JsonField<String>_associatedObjectType()Returns the raw JSON value of associatedObjectType. final JsonField<Event.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Event.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Event.BuildertoBuilder()final Eventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Event.Builderbuilder()Returns a mutable builder for constructing an instance of Event. -
-
Method Detail
-
associatedObjectId
final String associatedObjectId()
The identifier of the object that generated this Event.
-
associatedObjectType
final String associatedObjectType()
The type of the object that generated this Event.
-
category
final Event.Category category()
The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
createdAt
final OffsetDateTime createdAt()
The time the Event was created.
-
type
final Event.Type type()
A constant representing the object's type. For this resource it will always be
event.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_associatedObjectId
final JsonField<String> _associatedObjectId()
Returns the raw JSON value of associatedObjectId.
Unlike associatedObjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_associatedObjectType
final JsonField<String> _associatedObjectType()
Returns the raw JSON value of associatedObjectType.
Unlike associatedObjectType, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Event.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Event.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Event.Builder toBuilder()
-
builder
final static Event.Builder builder()
Returns a mutable builder for constructing an instance of Event.
The following fields are required:
.id() .associatedObjectId() .associatedObjectType() .category() .createdAt() .type()
-
-
-
-