Class Event.Builder
-
- All Implemented Interfaces:
public final class Event.BuilderA builder for Event.
-
-
Method Summary
Modifier and Type Method Description final Event.Builderid(String id)The Event identifier. final Event.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Event.BuilderassociatedObjectId(String associatedObjectId)The identifier of the object that generated this Event. final Event.BuilderassociatedObjectId(JsonField<String> associatedObjectId)Sets Builder.associatedObjectId to an arbitrary JSON value. final Event.BuilderassociatedObjectType(String associatedObjectType)The type of the object that generated this Event. final Event.BuilderassociatedObjectType(JsonField<String> associatedObjectType)Sets Builder.associatedObjectType to an arbitrary JSON value. final Event.Buildercategory(Event.Category category)The category of the Event. final Event.Buildercategory(JsonField<Event.Category> category)Sets Builder.category to an arbitrary JSON value. final Event.BuildercreatedAt(OffsetDateTime createdAt)The time the Event was created. final Event.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Event.Buildertype(Event.Type type)A constant representing the object's type. final Event.Buildertype(JsonField<Event.Type> type)Sets Builder.type to an arbitrary JSON value. final Event.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Event.BuilderputAdditionalProperty(String key, JsonValue value)final Event.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Event.BuilderremoveAdditionalProperty(String key)final Event.BuilderremoveAllAdditionalProperties(Set<String> keys)final Eventbuild()Returns an immutable instance of Event. -
-
Method Detail
-
id
final Event.Builder id(String id)
The Event identifier.
-
id
final Event.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
associatedObjectId
final Event.Builder associatedObjectId(String associatedObjectId)
The identifier of the object that generated this Event.
-
associatedObjectId
final Event.Builder associatedObjectId(JsonField<String> associatedObjectId)
Sets Builder.associatedObjectId to an arbitrary JSON value.
You should usually call Builder.associatedObjectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
associatedObjectType
final Event.Builder associatedObjectType(String associatedObjectType)
The type of the object that generated this Event.
-
associatedObjectType
final Event.Builder associatedObjectType(JsonField<String> associatedObjectType)
Sets Builder.associatedObjectType to an arbitrary JSON value.
You should usually call Builder.associatedObjectType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Event.Builder category(Event.Category category)
The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final Event.Builder category(JsonField<Event.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Event.Builder createdAt(OffsetDateTime createdAt)
The time the Event was created.
-
createdAt
final Event.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Event.Builder type(Event.Type type)
A constant representing the object's type. For this resource it will always be
event.
-
type
final Event.Builder type(JsonField<Event.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Event.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Event.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Event.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Event.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Event.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-