Enum Event.Category.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Event.Category.Value extends Enum<Event.Category.Value>
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Event.Category.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_CREATEDOccurs whenever an Account is created.
ACCOUNT_UPDATEDOccurs whenever an Account is updated.
ACCOUNT_NUMBER_CREATEDOccurs whenever an Account Number is created.
ACCOUNT_NUMBER_UPDATEDOccurs whenever an Account Number is updated.
ACCOUNT_STATEMENT_CREATEDOccurs whenever an Account Statement is created.
ACCOUNT_TRANSFER_CREATEDOccurs whenever an Account Transfer is created.
ACCOUNT_TRANSFER_UPDATEDOccurs whenever an Account Transfer is updated.
ACH_PRENOTIFICATION_CREATEDOccurs whenever an ACH Prenotification is created.
ACH_PRENOTIFICATION_UPDATEDOccurs whenever an ACH Prenotification is updated.
ACH_TRANSFER_CREATEDOccurs whenever an ACH Transfer is created.
ACH_TRANSFER_UPDATEDOccurs whenever an ACH Transfer is updated.
BLOCKCHAIN_ADDRESS_CREATEDOccurs whenever a Blockchain Address is created.
BLOCKCHAIN_ADDRESS_UPDATEDOccurs whenever a Blockchain Address is updated.
BLOCKCHAIN_OFFRAMP_TRANSFER_CREATEDOccurs whenever a Blockchain Off-Ramp Transfer is created.
BLOCKCHAIN_OFFRAMP_TRANSFER_UPDATEDOccurs whenever a Blockchain Off-Ramp Transfer is updated.
BLOCKCHAIN_ONRAMP_TRANSFER_CREATEDOccurs whenever a Blockchain On-Ramp Transfer is created.
BLOCKCHAIN_ONRAMP_TRANSFER_UPDATEDOccurs whenever a Blockchain On-Ramp Transfer is updated.
BOOKKEEPING_ACCOUNT_CREATEDOccurs whenever a Bookkeeping Account is created.
BOOKKEEPING_ACCOUNT_UPDATEDOccurs whenever a Bookkeeping Account is updated.
BOOKKEEPING_ENTRY_SET_UPDATEDOccurs whenever a Bookkeeping Entry Set is created.
CARD_CREATEDOccurs whenever a Card is created.
CARD_UPDATEDOccurs whenever a Card is updated.
CARD_PAYMENT_CREATEDOccurs whenever a Card Payment is created.
CARD_PAYMENT_UPDATEDOccurs whenever a Card Payment is updated.
CARD_PURCHASE_SUPPLEMENT_CREATEDOccurs whenever a Card Purchase Supplement is created.
CARD_PROFILE_CREATEDOccurs whenever a Card Profile is created.
CARD_PROFILE_UPDATEDOccurs whenever a Card Profile is updated.
CARD_DISPUTE_CREATEDOccurs whenever a Card Dispute is created.
CARD_DISPUTE_UPDATEDOccurs whenever a Card Dispute is updated.
CHECK_DEPOSIT_CREATEDOccurs whenever a Check Deposit is created.
CHECK_DEPOSIT_UPDATEDOccurs whenever a Check Deposit is updated.
CHECK_TRANSFER_CREATEDOccurs whenever a Check Transfer is created.
CHECK_TRANSFER_UPDATEDOccurs whenever a Check Transfer is updated.
DECLINED_TRANSACTION_CREATEDOccurs whenever a Declined Transaction is created.
DIGITAL_CARD_PROFILE_CREATEDOccurs whenever a Digital Card Profile is created.
DIGITAL_CARD_PROFILE_UPDATEDOccurs whenever a Digital Card Profile is updated.
DIGITAL_WALLET_TOKEN_CREATEDOccurs whenever a Digital Wallet Token is created.
DIGITAL_WALLET_TOKEN_UPDATEDOccurs whenever a Digital Wallet Token is updated.
DOCUMENT_CREATEDOccurs whenever a Document is created.
ENTITY_CREATEDOccurs whenever an Entity is created.
ENTITY_UPDATEDOccurs whenever an Entity is updated.
EVENT_SUBSCRIPTION_CREATEDOccurs whenever an Event Subscription is created.
EVENT_SUBSCRIPTION_UPDATEDOccurs whenever an Event Subscription is updated.
EXPORT_CREATEDOccurs whenever an Export is created.
EXPORT_UPDATEDOccurs whenever an Export is updated.
EXTERNAL_ACCOUNT_CREATEDOccurs whenever an External Account is created.
EXTERNAL_ACCOUNT_UPDATEDOccurs whenever an External Account is updated.
FEDNOW_TRANSFER_CREATEDOccurs whenever a FedNow Transfer is created.
FEDNOW_TRANSFER_UPDATEDOccurs whenever a FedNow Transfer is updated.
FILE_CREATEDOccurs whenever a File is created.
GROUP_UPDATEDOccurs whenever a Group is updated.
GROUP_HEARTBEATIncrease may send webhooks with this category to see if a webhook endpoint is working properly.
INBOUND_ACH_TRANSFER_CREATEDOccurs whenever an Inbound ACH Transfer is created.
INBOUND_ACH_TRANSFER_UPDATEDOccurs whenever an Inbound ACH Transfer is updated.
INBOUND_ACH_TRANSFER_RETURN_CREATEDOccurs whenever an Inbound ACH Transfer Return is created.
INBOUND_ACH_TRANSFER_RETURN_UPDATEDOccurs whenever an Inbound ACH Transfer Return is updated.
INBOUND_CHECK_DEPOSIT_CREATEDOccurs whenever an Inbound Check Deposit is created.
INBOUND_CHECK_DEPOSIT_UPDATEDOccurs whenever an Inbound Check Deposit is updated.
INBOUND_FEDNOW_TRANSFER_CREATEDOccurs whenever an Inbound FedNow Transfer is created.
INBOUND_FEDNOW_TRANSFER_UPDATEDOccurs whenever an Inbound FedNow Transfer is updated.
INBOUND_MAIL_ITEM_CREATEDOccurs whenever an Inbound Mail Item is created.
INBOUND_MAIL_ITEM_UPDATEDOccurs whenever an Inbound Mail Item is updated.
INBOUND_REAL_TIME_PAYMENTS_TRANSFER_CREATEDOccurs whenever an Inbound Real-Time Payments Transfer is created.
INBOUND_REAL_TIME_PAYMENTS_TRANSFER_UPDATEDOccurs whenever an Inbound Real-Time Payments Transfer is updated.
INBOUND_WIRE_DRAWDOWN_REQUEST_CREATEDOccurs whenever an Inbound Wire Drawdown Request is created.
INBOUND_WIRE_TRANSFER_CREATEDOccurs whenever an Inbound Wire Transfer is created.
INBOUND_WIRE_TRANSFER_UPDATEDOccurs whenever an Inbound Wire Transfer is updated.
INTRAFI_ACCOUNT_ENROLLMENT_CREATEDOccurs whenever an IntraFi Account Enrollment is created.
INTRAFI_ACCOUNT_ENROLLMENT_UPDATEDOccurs whenever an IntraFi Account Enrollment is updated.
INTRAFI_EXCLUSION_CREATEDOccurs whenever an IntraFi Exclusion is created.
INTRAFI_EXCLUSION_UPDATEDOccurs whenever an IntraFi Exclusion is updated.
LEGACY_CARD_DISPUTE_CREATEDOccurs whenever a Legacy Card Dispute is created.
LEGACY_CARD_DISPUTE_UPDATEDOccurs whenever a Legacy Card Dispute is updated.
LOCKBOX_CREATEDOccurs whenever a Lockbox is created.
LOCKBOX_UPDATEDOccurs whenever a Lockbox is updated.
OAUTH_CONNECTION_CREATEDOccurs whenever an OAuth Connection is created.
OAUTH_CONNECTION_DEACTIVATEDOccurs whenever an OAuth Connection is deactivated.
CARD_PUSH_TRANSFER_CREATEDOccurs whenever a Card Push Transfer is created.
CARD_PUSH_TRANSFER_UPDATEDOccurs whenever a Card Push Transfer is updated.
CARD_VALIDATION_CREATEDOccurs whenever a Card Validation is created.
CARD_VALIDATION_UPDATEDOccurs whenever a Card Validation is updated.
PENDING_TRANSACTION_CREATEDOccurs whenever a Pending Transaction is created.
PENDING_TRANSACTION_UPDATEDOccurs whenever a Pending Transaction is updated.
PHYSICAL_CARD_CREATEDOccurs whenever a Physical Card is created.
PHYSICAL_CARD_UPDATEDOccurs whenever a Physical Card is updated.
PHYSICAL_CARD_PROFILE_CREATEDOccurs whenever a Physical Card Profile is created.
PHYSICAL_CARD_PROFILE_UPDATEDOccurs whenever a Physical Card Profile is updated.
PHYSICAL_CHECK_CREATEDOccurs whenever a Physical Check is created.
PHYSICAL_CHECK_UPDATEDOccurs whenever a Physical Check is updated.
PROGRAM_CREATEDOccurs whenever a Program is created.
PROGRAM_UPDATEDOccurs whenever a Program is updated.
PROOF_OF_AUTHORIZATION_REQUEST_CREATEDOccurs whenever a Proof of Authorization Request is created.
PROOF_OF_AUTHORIZATION_REQUEST_UPDATEDOccurs whenever a Proof of Authorization Request is updated.
REAL_TIME_DECISION_CARD_AUTHORIZATION_REQUESTEDOccurs whenever a Real-Time Decision is created in response to a card authorization.
REAL_TIME_DECISION_CARD_BALANCE_INQUIRY_REQUESTEDOccurs whenever a Real-Time Decision is created in response to a card balance inquiry.
REAL_TIME_DECISION_DIGITAL_WALLET_TOKEN_REQUESTEDOccurs whenever a Real-Time Decision is created in response to a digital wallet provisioning attempt.
REAL_TIME_DECISION_DIGITAL_WALLET_AUTHENTICATION_REQUESTEDOccurs whenever a Real-Time Decision is created in response to a digital wallet requiring two-factor authentication.
REAL_TIME_DECISION_CARD_AUTHENTICATION_REQUESTEDOccurs whenever a Real-Time Decision is created in response to 3DS authentication.
REAL_TIME_DECISION_CARD_AUTHENTICATION_CHALLENGE_REQUESTEDOccurs whenever a Real-Time Decision is created in response to 3DS authentication challenges.
REAL_TIME_PAYMENTS_TRANSFER_CREATEDOccurs whenever a Real-Time Payments Transfer is created.
REAL_TIME_PAYMENTS_TRANSFER_UPDATEDOccurs whenever a Real-Time Payments Transfer is updated.
REAL_TIME_PAYMENTS_REQUEST_FOR_PAYMENT_CREATEDOccurs whenever a Real-Time Payments Request for Payment is created.
REAL_TIME_PAYMENTS_REQUEST_FOR_PAYMENT_UPDATEDOccurs whenever a Real-Time Payments Request for Payment is updated.
SWIFT_TRANSFER_CREATEDOccurs whenever a Swift Transfer is created.
SWIFT_TRANSFER_UPDATEDOccurs whenever a Swift Transfer is updated.
TRANSACTION_CREATEDOccurs whenever a Transaction is created.
WIRE_DRAWDOWN_REQUEST_CREATEDOccurs whenever a Wire Drawdown Request is created.
WIRE_DRAWDOWN_REQUEST_UPDATEDOccurs whenever a Wire Drawdown Request is updated.
WIRE_TRANSFER_CREATEDOccurs whenever a Wire Transfer is created.
WIRE_TRANSFER_UPDATEDOccurs whenever a Wire Transfer is updated.
_UNKNOWNAn enum member indicating that Category was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Event.Category.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Event.Category.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Event.Category.Value>getEntries()An enum containing Category's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Event.Category.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Event.Category.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Event.Category.Value> getEntries()
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-