Package com.increase.api.models.events
Class EventListPage.Builder
-
- All Implemented Interfaces:
public final class EventListPage.BuilderA builder for EventListPage.
-
-
Method Summary
Modifier and Type Method Description final EventListPage.Builderservice(EventService service)final EventListPage.Builderparams(EventListParams params)The parameters that were used to request this page. final EventListPage.Builderresponse(EventListPageResponse response)The response that this page was parsed from. final EventListPagebuild()Returns an immutable instance of EventListPage. -
-
Method Detail
-
service
final EventListPage.Builder service(EventService service)
-
params
final EventListPage.Builder params(EventListParams params)
The parameters that were used to request this page.
-
response
final EventListPage.Builder response(EventListPageResponse response)
The response that this page was parsed from.
-
build
final EventListPage build()
Returns an immutable instance of EventListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-