Class EventListPageResponse
-
- All Implemented Interfaces:
public final class EventListPageResponseA list of Event objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventListPageResponse.BuilderA builder for EventListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Event>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<Event>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final EventListPageResponse.BuildertoBuilder()final EventListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EventListPageResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
_data
final JsonField<List<Event>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventListPageResponse.Builder toBuilder()
-
validate
final EventListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EventListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of EventListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-