Package com.increase.api.models.events
Class EventListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EventListParams implements Params
List Events
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventListParams.BuilderA builder for EventListParams.
public final classEventListParams.Categorypublic final classEventListParams.CreatedAtpublic final classEventListParams.OrderBy
-
Method Summary
Modifier and Type Method Description final Optional<String>associatedObjectId()Filter Events to those belonging to the object with the provided identifier. final Optional<EventListParams.Category>category()final Optional<EventListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Optional<EventListParams.OrderBy>orderBy()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EventListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventListParamsnone()final static EventListParams.Builderbuilder()Returns a mutable builder for constructing an instance of EventListParams. -
-
Method Detail
-
associatedObjectId
final Optional<String> associatedObjectId()
Filter Events to those belonging to the object with the provided identifier.
-
category
final Optional<EventListParams.Category> category()
-
createdAt
final Optional<EventListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
orderBy
final Optional<EventListParams.OrderBy> orderBy()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EventListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EventListParams none()
-
builder
final static EventListParams.Builder builder()
Returns a mutable builder for constructing an instance of EventListParams.
-
-
-
-