Package com.increase.api.models.events
Class EventListParams.OrderBy
-
- All Implemented Interfaces:
public final class EventListParams.OrderBy
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventListParams.OrderBy.BuilderA builder for OrderBy.
public final classEventListParams.OrderBy.DirectionThe direction to order in.
public final classEventListParams.OrderBy.FieldThe field to order by.
-
Method Summary
Modifier and Type Method Description final Optional<EventListParams.OrderBy.Direction>direction()The direction to order in. final Optional<EventListParams.OrderBy.Field>field()The field to order by. final QueryParams_additionalProperties()Query params to send with the request. final EventListParams.OrderBy.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventListParams.OrderBy.Builderbuilder()Returns a mutable builder for constructing an instance of OrderBy. -
-
Method Detail
-
direction
final Optional<EventListParams.OrderBy.Direction> direction()
The direction to order in.
-
field
final Optional<EventListParams.OrderBy.Field> field()
The field to order by.
-
_additionalProperties
final QueryParams _additionalProperties()
Query params to send with the request.
-
toBuilder
final EventListParams.OrderBy.Builder toBuilder()
-
builder
final static EventListParams.OrderBy.Builder builder()
Returns a mutable builder for constructing an instance of OrderBy.
-
-
-
-