Class UnwrapWebhookEvent
-
- All Implemented Interfaces:
public final class UnwrapWebhookEventEvents are records of things that happened to objects at Increase. Events are accessible via the List Events endpoint and can be delivered to your application via webhooks. For more information, see our webhooks guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUnwrapWebhookEvent.BuilderA builder for UnwrapWebhookEvent.
public final classUnwrapWebhookEvent.CategoryThe category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classUnwrapWebhookEvent.TypeA constant representing the object's type. For this resource it will always be
event.
-
Method Summary
Modifier and Type Method Description final Stringid()The Event identifier. final StringassociatedObjectId()The identifier of the object that generated this Event. final StringassociatedObjectType()The type of the object that generated this Event. final UnwrapWebhookEvent.Categorycategory()The category of the Event. final OffsetDateTimecreatedAt()The time the Event was created. final UnwrapWebhookEvent.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_associatedObjectId()Returns the raw JSON value of associatedObjectId. final JsonField<String>_associatedObjectType()Returns the raw JSON value of associatedObjectType. final JsonField<UnwrapWebhookEvent.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<UnwrapWebhookEvent.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final UnwrapWebhookEvent.BuildertoBuilder()final UnwrapWebhookEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UnwrapWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of UnwrapWebhookEvent. -
-
Method Detail
-
associatedObjectId
final String associatedObjectId()
The identifier of the object that generated this Event.
-
associatedObjectType
final String associatedObjectType()
The type of the object that generated this Event.
-
category
final UnwrapWebhookEvent.Category category()
The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
createdAt
final OffsetDateTime createdAt()
The time the Event was created.
-
type
final UnwrapWebhookEvent.Type type()
A constant representing the object's type. For this resource it will always be
event.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_associatedObjectId
final JsonField<String> _associatedObjectId()
Returns the raw JSON value of associatedObjectId.
Unlike associatedObjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_associatedObjectType
final JsonField<String> _associatedObjectType()
Returns the raw JSON value of associatedObjectType.
Unlike associatedObjectType, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<UnwrapWebhookEvent.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<UnwrapWebhookEvent.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UnwrapWebhookEvent.Builder toBuilder()
-
validate
final UnwrapWebhookEvent validate()
-
builder
final static UnwrapWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of UnwrapWebhookEvent.
The following fields are required:
.id() .associatedObjectId() .associatedObjectType() .category() .createdAt() .type()
-
-
-
-