Class UnwrapWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class UnwrapWebhookEvent.BuilderA builder for UnwrapWebhookEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final UnwrapWebhookEvent.Builder id(String id)
The Event identifier.
-
id
final UnwrapWebhookEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
associatedObjectId
final UnwrapWebhookEvent.Builder associatedObjectId(String associatedObjectId)
The identifier of the object that generated this Event.
-
associatedObjectId
final UnwrapWebhookEvent.Builder associatedObjectId(JsonField<String> associatedObjectId)
Sets Builder.associatedObjectId to an arbitrary JSON value.
You should usually call Builder.associatedObjectId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
associatedObjectType
final UnwrapWebhookEvent.Builder associatedObjectType(String associatedObjectType)
The type of the object that generated this Event.
-
associatedObjectType
final UnwrapWebhookEvent.Builder associatedObjectType(JsonField<String> associatedObjectType)
Sets Builder.associatedObjectType to an arbitrary JSON value.
You should usually call Builder.associatedObjectType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final UnwrapWebhookEvent.Builder category(UnwrapWebhookEvent.Category category)
The category of the Event. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final UnwrapWebhookEvent.Builder category(JsonField<UnwrapWebhookEvent.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final UnwrapWebhookEvent.Builder createdAt(OffsetDateTime createdAt)
The time the Event was created.
-
createdAt
final UnwrapWebhookEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final UnwrapWebhookEvent.Builder type(UnwrapWebhookEvent.Type type)
A constant representing the object's type. For this resource it will always be
event.
-
type
final UnwrapWebhookEvent.Builder type(JsonField<UnwrapWebhookEvent.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UnwrapWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UnwrapWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UnwrapWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UnwrapWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UnwrapWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UnwrapWebhookEvent build()
Returns an immutable instance of UnwrapWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .associatedObjectId() .associatedObjectType() .category() .createdAt() .type()
-
-
-
-