Class EventSubscription
-
- All Implemented Interfaces:
public final class EventSubscriptionWebhooks are event notifications we send to you by HTTPS POST requests. Event Subscriptions are how you configure your application to listen for them. You can create an Event Subscription through your developer dashboard or the API. For more information, see our webhooks guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscription.BuilderA builder for EventSubscription.
public final classEventSubscription.SelectedEventCategorypublic final classEventSubscription.StatusThis indicates if we'll send notifications to this subscription.
public final classEventSubscription.TypeA constant representing the object's type. For this resource it will always be
event_subscription.
-
Method Summary
Modifier and Type Method Description final Stringid()The event subscription identifier. final OffsetDateTimecreatedAt()The time the event subscription was created. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection. final Optional<List<EventSubscription.SelectedEventCategory>>selectedEventCategories()If specified, this subscription will only receive webhooks for Events with the specified category.final EventSubscription.Statusstatus()This indicates if we'll send notifications to this subscription. final EventSubscription.Typetype()A constant representing the object's type. final Stringurl()The webhook url where we'll send notifications. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_oauthConnectionId()Returns the raw JSON value of oauthConnectionId. final JsonField<List<EventSubscription.SelectedEventCategory>>_selectedEventCategories()Returns the raw JSON value of selectedEventCategories. final JsonField<EventSubscription.Status>_status()Returns the raw JSON value of status. final JsonField<EventSubscription.Type>_type()Returns the raw JSON value of type. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final EventSubscription.BuildertoBuilder()final EventSubscriptionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscription.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscription. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The time the event subscription was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
oauthConnectionId
final Optional<String> oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
selectedEventCategories
final Optional<List<EventSubscription.SelectedEventCategory>> selectedEventCategories()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
status
final EventSubscription.Status status()
This indicates if we'll send notifications to this subscription.
-
type
final EventSubscription.Type type()
A constant representing the object's type. For this resource it will always be
event_subscription.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthConnectionId
final JsonField<String> _oauthConnectionId()
Returns the raw JSON value of oauthConnectionId.
Unlike oauthConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_selectedEventCategories
final JsonField<List<EventSubscription.SelectedEventCategory>> _selectedEventCategories()
Returns the raw JSON value of selectedEventCategories.
Unlike selectedEventCategories, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EventSubscription.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<EventSubscription.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscription.Builder toBuilder()
-
validate
final EventSubscription validate()
-
builder
final static EventSubscription.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscription.
The following fields are required:
.id() .createdAt() .idempotencyKey() .oauthConnectionId() .selectedEventCategories() .status() .type() .url()
-
-
-
-