Class EventSubscription.Builder
-
- All Implemented Interfaces:
public final class EventSubscription.BuilderA builder for EventSubscription.
-
-
Method Summary
-
-
Method Detail
-
id
final EventSubscription.Builder id(String id)
The event subscription identifier.
-
id
final EventSubscription.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final EventSubscription.Builder createdAt(OffsetDateTime createdAt)
The time the event subscription was created.
-
createdAt
final EventSubscription.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final EventSubscription.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final EventSubscription.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final EventSubscription.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
oauthConnectionId
final EventSubscription.Builder oauthConnectionId(String oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with this OAuth Connection.
-
oauthConnectionId
final EventSubscription.Builder oauthConnectionId(Optional<String> oauthConnectionId)
Alias for calling Builder.oauthConnectionId with
oauthConnectionId.orElse(null).
-
oauthConnectionId
final EventSubscription.Builder oauthConnectionId(JsonField<String> oauthConnectionId)
Sets Builder.oauthConnectionId to an arbitrary JSON value.
You should usually call Builder.oauthConnectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
selectedEventCategories
final EventSubscription.Builder selectedEventCategories(List<EventSubscription.SelectedEventCategory> selectedEventCategories)
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
selectedEventCategories
final EventSubscription.Builder selectedEventCategories(Optional<List<EventSubscription.SelectedEventCategory>> selectedEventCategories)
Alias for calling Builder.selectedEventCategories with
selectedEventCategories.orElse(null).
-
selectedEventCategories
final EventSubscription.Builder selectedEventCategories(JsonField<List<EventSubscription.SelectedEventCategory>> selectedEventCategories)
Sets Builder.selectedEventCategories to an arbitrary JSON value.
You should usually call Builder.selectedEventCategories with a well-typed
List<SelectedEventCategory>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSelectedEventCategory
final EventSubscription.Builder addSelectedEventCategory(EventSubscription.SelectedEventCategory selectedEventCategory)
Adds a single SelectedEventCategory to selectedEventCategories.
-
status
final EventSubscription.Builder status(EventSubscription.Status status)
This indicates if we'll send notifications to this subscription.
-
status
final EventSubscription.Builder status(JsonField<EventSubscription.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final EventSubscription.Builder type(EventSubscription.Type type)
A constant representing the object's type. For this resource it will always be
event_subscription.
-
type
final EventSubscription.Builder type(JsonField<EventSubscription.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final EventSubscription.Builder url(String url)
The webhook url where we'll send notifications.
-
url
final EventSubscription.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EventSubscription.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EventSubscription.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EventSubscription.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EventSubscription.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EventSubscription.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EventSubscription build()
Returns an immutable instance of EventSubscription.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .idempotencyKey() .oauthConnectionId() .selectedEventCategories() .status() .type() .url()
-
-
-
-