Class EventSubscription.SelectedEventCategory
-
- All Implemented Interfaces:
public final class EventSubscription.SelectedEventCategory
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscription.SelectedEventCategory.BuilderA builder for SelectedEventCategory.
public final classEventSubscription.SelectedEventCategory.EventCategoryThe category of the Event.
-
Method Summary
Modifier and Type Method Description final Optional<EventSubscription.SelectedEventCategory.EventCategory>eventCategory()The category of the Event. final JsonField<EventSubscription.SelectedEventCategory.EventCategory>_eventCategory()Returns the raw JSON value of eventCategory. final Map<String, JsonValue>_additionalProperties()final EventSubscription.SelectedEventCategory.BuildertoBuilder()final EventSubscription.SelectedEventCategoryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscription.SelectedEventCategory.Builderbuilder()Returns a mutable builder for constructing an instance of SelectedEventCategory. -
-
Method Detail
-
eventCategory
final Optional<EventSubscription.SelectedEventCategory.EventCategory> eventCategory()
The category of the Event.
-
_eventCategory
final JsonField<EventSubscription.SelectedEventCategory.EventCategory> _eventCategory()
Returns the raw JSON value of eventCategory.
Unlike eventCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscription.SelectedEventCategory.Builder toBuilder()
-
validate
final EventSubscription.SelectedEventCategory validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EventSubscription.SelectedEventCategory.Builder builder()
Returns a mutable builder for constructing an instance of SelectedEventCategory.
The following fields are required:
.eventCategory()
-
-
-
-