Class EventSubscriptionCreateParams.Body
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringurl()The URL you'd like us to send webhooks to. final Optional<String>oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection. final Optional<List<EventSubscriptionCreateParams.SelectedEventCategory>>selectedEventCategories()If specified, this subscription will only receive webhooks for Events with the specified category.final Optional<String>sharedSecret()The key that will be used to sign webhooks. final Optional<EventSubscriptionCreateParams.Status>status()The status of the event subscription. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_oauthConnectionId()Returns the raw JSON value of oauthConnectionId. final JsonField<List<EventSubscriptionCreateParams.SelectedEventCategory>>_selectedEventCategories()Returns the raw JSON value of selectedEventCategories. final JsonField<String>_sharedSecret()Returns the raw JSON value of sharedSecret. final JsonField<EventSubscriptionCreateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionCreateParams.Body.BuildertoBuilder()final EventSubscriptionCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
oauthConnectionId
final Optional<String> oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
selectedEventCategories
final Optional<List<EventSubscriptionCreateParams.SelectedEventCategory>> selectedEventCategories()
If specified, this subscription will only receive webhooks for Events with the specified
category. If specifying a Real-Time Decision event category, only one Event Category can be specified for the Event Subscription.
-
sharedSecret
final Optional<String> sharedSecret()
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
status
final Optional<EventSubscriptionCreateParams.Status> status()
The status of the event subscription. Defaults to
activeif not specified.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthConnectionId
final JsonField<String> _oauthConnectionId()
Returns the raw JSON value of oauthConnectionId.
Unlike oauthConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_selectedEventCategories
final JsonField<List<EventSubscriptionCreateParams.SelectedEventCategory>> _selectedEventCategories()
Returns the raw JSON value of selectedEventCategories.
Unlike selectedEventCategories, this method doesn't throw if the JSON field has an unexpected type.
-
_sharedSecret
final JsonField<String> _sharedSecret()
Returns the raw JSON value of sharedSecret.
Unlike sharedSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EventSubscriptionCreateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionCreateParams.Body.Builder toBuilder()
-
validate
final EventSubscriptionCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EventSubscriptionCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.url()
-
-
-
-