Class EventSubscriptionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
url
final EventSubscriptionCreateParams.Body.Builder url(String url)
The URL you'd like us to send webhooks to.
-
url
final EventSubscriptionCreateParams.Body.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
oauthConnectionId
final EventSubscriptionCreateParams.Body.Builder oauthConnectionId(String oauthConnectionId)
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
oauthConnectionId
final EventSubscriptionCreateParams.Body.Builder oauthConnectionId(JsonField<String> oauthConnectionId)
Sets Builder.oauthConnectionId to an arbitrary JSON value.
You should usually call Builder.oauthConnectionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
selectedEventCategories
final EventSubscriptionCreateParams.Body.Builder selectedEventCategories(List<EventSubscriptionCreateParams.SelectedEventCategory> selectedEventCategories)
If specified, this subscription will only receive webhooks for Events with the specified
category. If specifying a Real-Time Decision event category, only one Event Category can be specified for the Event Subscription.
-
selectedEventCategories
final EventSubscriptionCreateParams.Body.Builder selectedEventCategories(JsonField<List<EventSubscriptionCreateParams.SelectedEventCategory>> selectedEventCategories)
Sets Builder.selectedEventCategories to an arbitrary JSON value.
You should usually call Builder.selectedEventCategories with a well-typed
List<SelectedEventCategory>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSelectedEventCategory
final EventSubscriptionCreateParams.Body.Builder addSelectedEventCategory(EventSubscriptionCreateParams.SelectedEventCategory selectedEventCategory)
Adds a single SelectedEventCategory to selectedEventCategories.
-
sharedSecret
final EventSubscriptionCreateParams.Body.Builder sharedSecret(String sharedSecret)
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
sharedSecret
final EventSubscriptionCreateParams.Body.Builder sharedSecret(JsonField<String> sharedSecret)
Sets Builder.sharedSecret to an arbitrary JSON value.
You should usually call Builder.sharedSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final EventSubscriptionCreateParams.Body.Builder status(EventSubscriptionCreateParams.Status status)
The status of the event subscription. Defaults to
activeif not specified.
-
status
final EventSubscriptionCreateParams.Body.Builder status(JsonField<EventSubscriptionCreateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EventSubscriptionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EventSubscriptionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EventSubscriptionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EventSubscriptionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EventSubscriptionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EventSubscriptionCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.url()
-
-
-
-