Class EventSubscriptionCreateParams.SelectedEventCategory.Builder
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.SelectedEventCategory.BuilderA builder for SelectedEventCategory.
-
-
Method Summary
-
-
Method Detail
-
eventCategory
final EventSubscriptionCreateParams.SelectedEventCategory.Builder eventCategory(EventSubscriptionCreateParams.SelectedEventCategory.EventCategory eventCategory)
The category of the Event to subscribe to.
-
eventCategory
final EventSubscriptionCreateParams.SelectedEventCategory.Builder eventCategory(JsonField<EventSubscriptionCreateParams.SelectedEventCategory.EventCategory> eventCategory)
Sets Builder.eventCategory to an arbitrary JSON value.
You should usually call Builder.eventCategory with a well-typed EventCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EventSubscriptionCreateParams.SelectedEventCategory.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EventSubscriptionCreateParams.SelectedEventCategory.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EventSubscriptionCreateParams.SelectedEventCategory.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EventSubscriptionCreateParams.SelectedEventCategory.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EventSubscriptionCreateParams.SelectedEventCategory.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EventSubscriptionCreateParams.SelectedEventCategory build()
Returns an immutable instance of SelectedEventCategory.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.eventCategory()
-
-
-
-