Class EventSubscriptionListResponse
-
- All Implemented Interfaces:
public final class EventSubscriptionListResponseA list of Event Subscription objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionListResponse.BuilderA builder for EventSubscriptionListResponse.
-
Method Summary
Modifier and Type Method Description final List<EventSubscription>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<EventSubscription>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionListResponse.BuildertoBuilder()final EventSubscriptionListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscriptionListResponse. -
-
Method Detail
-
data
final List<EventSubscription> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<EventSubscription>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionListResponse.Builder toBuilder()
-
validate
final EventSubscriptionListResponse validate()
-
builder
final static EventSubscriptionListResponse.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscriptionListResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-