Class EventSubscriptionUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EventSubscriptionUpdateParams implements Params
Update an Event Subscription
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionUpdateParams.BuilderA builder for EventSubscriptionUpdateParams.
public final classEventSubscriptionUpdateParams.Bodypublic final classEventSubscriptionUpdateParams.StatusThe status to update the Event Subscription with.
-
Method Summary
Modifier and Type Method Description final Optional<String>eventSubscriptionId()The identifier of the Event Subscription. final Optional<EventSubscriptionUpdateParams.Status>status()The status to update the Event Subscription with. final JsonField<EventSubscriptionUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EventSubscriptionUpdateParams.BuildertoBuilder()final EventSubscriptionUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionUpdateParamsnone()final static EventSubscriptionUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscriptionUpdateParams. -
-
Method Detail
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription.
-
status
final Optional<EventSubscriptionUpdateParams.Status> status()
The status to update the Event Subscription with.
-
_status
final JsonField<EventSubscriptionUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EventSubscriptionUpdateParams.Builder toBuilder()
-
_body
final EventSubscriptionUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EventSubscriptionUpdateParams none()
-
builder
final static EventSubscriptionUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscriptionUpdateParams.
-
-
-
-