Class Export
-
- All Implemented Interfaces:
public final class ExportExports are generated files. Some exports can contain a lot of data, like a CSV of your transactions. Others can be a single document, like a tax form. Since they can take a while, they are generated asynchronously. We send a webhook when they are ready. For more information, please read our Exports documentation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.BuilderA builder for Export.
public final classExport.AccountStatementBai2Details of the account statement BAI2 export. This field will be present when the
categoryis equal toaccount_statement_bai2.public final classExport.AccountStatementOfxDetails of the account statement OFX export. This field will be present when the
categoryis equal toaccount_statement_ofx.public final classExport.AccountVerificationLetterDetails of the account verification letter export. This field will be present when the
categoryis equal toaccount_verification_letter.public final classExport.BalanceCsvDetails of the balance CSV export. This field will be present when the
categoryis equal tobalance_csv.public final classExport.BookkeepingAccountBalanceCsvDetails of the bookkeeping account balance CSV export. This field will be present when the
categoryis equal tobookkeeping_account_balance_csv.public final classExport.CategoryThe category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
public final classExport.DailyAccountBalanceCsvDetails of the daily account balance CSV export. This field will be present when the
categoryis equal todaily_account_balance_csv.public final classExport.DashboardTableCsvDetails of the dashboard table CSV export. This field will be present when the
categoryis equal todashboard_table_csv.public final classExport.EntityCsvDetails of the entity CSV export. This field will be present when the
categoryis equal toentity_csv.public final classExport.FeeCsvDetails of the fee CSV export. This field will be present when the
categoryis equal tofee_csv.public final classExport.Form1099IntDetails of the Form 1099-INT export. This field will be present when the
categoryis equal toform_1099_int.public final classExport.Form1099MiscDetails of the Form 1099-MISC export. This field will be present when the
categoryis equal toform_1099_misc.public final classExport.FundingInstructionsDetails of the funding instructions export. This field will be present when the
categoryis equal tofunding_instructions.public final classExport.ResultThe result of the Export. This will be present when the Export's status transitions to
complete.public final classExport.StatusThe status of the Export.
public final classExport.TransactionCsvDetails of the transaction CSV export. This field will be present when the
categoryis equal totransaction_csv.public final classExport.TypeA constant representing the object's type. For this resource it will always be
export.public final classExport.VendorCsvDetails of the vendor CSV export. This field will be present when the
categoryis equal tovendor_csv.public final classExport.VoidedCheckDetails of the voided check export. This field will be present when the
categoryis equal tovoided_check.
-
Method Summary
Modifier and Type Method Description final Stringid()The Export identifier. final Optional<Export.AccountStatementBai2>accountStatementBai2()Details of the account statement BAI2 export. final Optional<Export.AccountStatementOfx>accountStatementOfx()Details of the account statement OFX export. final Optional<Export.AccountVerificationLetter>accountVerificationLetter()Details of the account verification letter export. final Optional<Export.BalanceCsv>balanceCsv()Details of the balance CSV export. final Optional<Export.BookkeepingAccountBalanceCsv>bookkeepingAccountBalanceCsv()Details of the bookkeeping account balance CSV export. final Export.Categorycategory()The category of the Export. final OffsetDateTimecreatedAt()The time the Export was created. final Optional<Export.DailyAccountBalanceCsv>dailyAccountBalanceCsv()Details of the daily account balance CSV export. final Optional<Export.DashboardTableCsv>dashboardTableCsv()Details of the dashboard table CSV export. final Optional<Export.EntityCsv>entityCsv()Details of the entity CSV export. final Optional<Export.FeeCsv>feeCsv()Details of the fee CSV export. final Optional<Export.Form1099Int>form1099Int()Details of the Form 1099-INT export. final Optional<Export.Form1099Misc>form1099Misc()Details of the Form 1099-MISC export. final Optional<Export.FundingInstructions>fundingInstructions()Details of the funding instructions export. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<Export.Result>result()The result of the Export. final Export.Statusstatus()The status of the Export. final Optional<Export.TransactionCsv>transactionCsv()Details of the transaction CSV export. final Export.Typetype()A constant representing the object's type. final Optional<Export.VendorCsv>vendorCsv()Details of the vendor CSV export. final Optional<Export.VoidedCheck>voidedCheck()Details of the voided check export. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Export.AccountStatementBai2>_accountStatementBai2()Returns the raw JSON value of accountStatementBai2. final JsonField<Export.AccountStatementOfx>_accountStatementOfx()Returns the raw JSON value of accountStatementOfx. final JsonField<Export.AccountVerificationLetter>_accountVerificationLetter()Returns the raw JSON value of accountVerificationLetter. final JsonField<Export.BalanceCsv>_balanceCsv()Returns the raw JSON value of balanceCsv. final JsonField<Export.BookkeepingAccountBalanceCsv>_bookkeepingAccountBalanceCsv()Returns the raw JSON value of bookkeepingAccountBalanceCsv. final JsonField<Export.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Export.DailyAccountBalanceCsv>_dailyAccountBalanceCsv()Returns the raw JSON value of dailyAccountBalanceCsv. final JsonField<Export.DashboardTableCsv>_dashboardTableCsv()Returns the raw JSON value of dashboardTableCsv. final JsonField<Export.EntityCsv>_entityCsv()Returns the raw JSON value of entityCsv. final JsonField<Export.FeeCsv>_feeCsv()Returns the raw JSON value of feeCsv. final JsonField<Export.Form1099Int>_form1099Int()Returns the raw JSON value of form1099Int. final JsonField<Export.Form1099Misc>_form1099Misc()Returns the raw JSON value of form1099Misc. final JsonField<Export.FundingInstructions>_fundingInstructions()Returns the raw JSON value of fundingInstructions. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<Export.Result>_result()Returns the raw JSON value of result. final JsonField<Export.Status>_status()Returns the raw JSON value of status. final JsonField<Export.TransactionCsv>_transactionCsv()Returns the raw JSON value of transactionCsv. final JsonField<Export.Type>_type()Returns the raw JSON value of type. final JsonField<Export.VendorCsv>_vendorCsv()Returns the raw JSON value of vendorCsv. final JsonField<Export.VoidedCheck>_voidedCheck()Returns the raw JSON value of voidedCheck. final Map<String, JsonValue>_additionalProperties()final Export.BuildertoBuilder()final Exportvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.Builderbuilder()Returns a mutable builder for constructing an instance of Export. -
-
Method Detail
-
accountStatementBai2
final Optional<Export.AccountStatementBai2> accountStatementBai2()
Details of the account statement BAI2 export. This field will be present when the
categoryis equal toaccount_statement_bai2.
-
accountStatementOfx
final Optional<Export.AccountStatementOfx> accountStatementOfx()
Details of the account statement OFX export. This field will be present when the
categoryis equal toaccount_statement_ofx.
-
accountVerificationLetter
final Optional<Export.AccountVerificationLetter> accountVerificationLetter()
Details of the account verification letter export. This field will be present when the
categoryis equal toaccount_verification_letter.
-
balanceCsv
final Optional<Export.BalanceCsv> balanceCsv()
Details of the balance CSV export. This field will be present when the
categoryis equal tobalance_csv.
-
bookkeepingAccountBalanceCsv
final Optional<Export.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv()
Details of the bookkeeping account balance CSV export. This field will be present when the
categoryis equal tobookkeeping_account_balance_csv.
-
category
final Export.Category category()
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
createdAt
final OffsetDateTime createdAt()
The time the Export was created.
-
dailyAccountBalanceCsv
final Optional<Export.DailyAccountBalanceCsv> dailyAccountBalanceCsv()
Details of the daily account balance CSV export. This field will be present when the
categoryis equal todaily_account_balance_csv.
-
dashboardTableCsv
final Optional<Export.DashboardTableCsv> dashboardTableCsv()
Details of the dashboard table CSV export. This field will be present when the
categoryis equal todashboard_table_csv.
-
entityCsv
final Optional<Export.EntityCsv> entityCsv()
Details of the entity CSV export. This field will be present when the
categoryis equal toentity_csv.
-
feeCsv
final Optional<Export.FeeCsv> feeCsv()
Details of the fee CSV export. This field will be present when the
categoryis equal tofee_csv.
-
form1099Int
final Optional<Export.Form1099Int> form1099Int()
Details of the Form 1099-INT export. This field will be present when the
categoryis equal toform_1099_int.
-
form1099Misc
final Optional<Export.Form1099Misc> form1099Misc()
Details of the Form 1099-MISC export. This field will be present when the
categoryis equal toform_1099_misc.
-
fundingInstructions
final Optional<Export.FundingInstructions> fundingInstructions()
Details of the funding instructions export. This field will be present when the
categoryis equal tofunding_instructions.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
result
final Optional<Export.Result> result()
The result of the Export. This will be present when the Export's status transitions to
complete.
-
status
final Export.Status status()
The status of the Export.
-
transactionCsv
final Optional<Export.TransactionCsv> transactionCsv()
Details of the transaction CSV export. This field will be present when the
categoryis equal totransaction_csv.
-
type
final Export.Type type()
A constant representing the object's type. For this resource it will always be
export.
-
vendorCsv
final Optional<Export.VendorCsv> vendorCsv()
Details of the vendor CSV export. This field will be present when the
categoryis equal tovendor_csv.
-
voidedCheck
final Optional<Export.VoidedCheck> voidedCheck()
Details of the voided check export. This field will be present when the
categoryis equal tovoided_check.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStatementBai2
final JsonField<Export.AccountStatementBai2> _accountStatementBai2()
Returns the raw JSON value of accountStatementBai2.
Unlike accountStatementBai2, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStatementOfx
final JsonField<Export.AccountStatementOfx> _accountStatementOfx()
Returns the raw JSON value of accountStatementOfx.
Unlike accountStatementOfx, this method doesn't throw if the JSON field has an unexpected type.
-
_accountVerificationLetter
final JsonField<Export.AccountVerificationLetter> _accountVerificationLetter()
Returns the raw JSON value of accountVerificationLetter.
Unlike accountVerificationLetter, this method doesn't throw if the JSON field has an unexpected type.
-
_balanceCsv
final JsonField<Export.BalanceCsv> _balanceCsv()
Returns the raw JSON value of balanceCsv.
Unlike balanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_bookkeepingAccountBalanceCsv
final JsonField<Export.BookkeepingAccountBalanceCsv> _bookkeepingAccountBalanceCsv()
Returns the raw JSON value of bookkeepingAccountBalanceCsv.
Unlike bookkeepingAccountBalanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Export.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyAccountBalanceCsv
final JsonField<Export.DailyAccountBalanceCsv> _dailyAccountBalanceCsv()
Returns the raw JSON value of dailyAccountBalanceCsv.
Unlike dailyAccountBalanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_dashboardTableCsv
final JsonField<Export.DashboardTableCsv> _dashboardTableCsv()
Returns the raw JSON value of dashboardTableCsv.
Unlike dashboardTableCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_entityCsv
final JsonField<Export.EntityCsv> _entityCsv()
Returns the raw JSON value of entityCsv.
Unlike entityCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_feeCsv
final JsonField<Export.FeeCsv> _feeCsv()
Returns the raw JSON value of feeCsv.
Unlike feeCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_form1099Int
final JsonField<Export.Form1099Int> _form1099Int()
Returns the raw JSON value of form1099Int.
Unlike form1099Int, this method doesn't throw if the JSON field has an unexpected type.
-
_form1099Misc
final JsonField<Export.Form1099Misc> _form1099Misc()
Returns the raw JSON value of form1099Misc.
Unlike form1099Misc, this method doesn't throw if the JSON field has an unexpected type.
-
_fundingInstructions
final JsonField<Export.FundingInstructions> _fundingInstructions()
Returns the raw JSON value of fundingInstructions.
Unlike fundingInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Export.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Export.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionCsv
final JsonField<Export.TransactionCsv> _transactionCsv()
Returns the raw JSON value of transactionCsv.
Unlike transactionCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Export.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_vendorCsv
final JsonField<Export.VendorCsv> _vendorCsv()
Returns the raw JSON value of vendorCsv.
Unlike vendorCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_voidedCheck
final JsonField<Export.VoidedCheck> _voidedCheck()
Returns the raw JSON value of voidedCheck.
Unlike voidedCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.Builder toBuilder()
-
validate
final Export validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.Builder builder()
Returns a mutable builder for constructing an instance of Export.
The following fields are required:
.id() .accountStatementBai2() .accountStatementOfx() .accountVerificationLetter() .balanceCsv() .bookkeepingAccountBalanceCsv() .category() .createdAt() .dailyAccountBalanceCsv() .dashboardTableCsv() .entityCsv() .feeCsv() .form1099Int() .form1099Misc() .fundingInstructions() .idempotencyKey() .result() .status() .transactionCsv() .type() .vendorCsv() .voidedCheck()
-
-
-
-