Class Export.AccountStatementBai2
-
- All Implemented Interfaces:
public final class Export.AccountStatementBai2Details of the account statement BAI2 export. This field will be present when the
categoryis equal toaccount_statement_bai2.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.AccountStatementBai2.BuilderA builder for AccountStatementBai2.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter results by Account. final Optional<LocalDate>effectiveDate()The date for which to retrieve the balance. final Optional<String>programId()Filter results by Program. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalProperties()final Export.AccountStatementBai2.BuildertoBuilder()final Export.AccountStatementBai2validate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.AccountStatementBai2.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementBai2. -
-
Method Detail
-
effectiveDate
final Optional<LocalDate> effectiveDate()
The date for which to retrieve the balance.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.AccountStatementBai2.Builder toBuilder()
-
validate
final Export.AccountStatementBai2 validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.AccountStatementBai2.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementBai2.
The following fields are required:
.accountId() .effectiveDate() .programId()
-
-
-
-