Class Export.AccountStatementBai2.Builder
-
- All Implemented Interfaces:
public final class Export.AccountStatementBai2.BuilderA builder for AccountStatementBai2.
-
-
Method Summary
-
-
Method Detail
-
accountId
final Export.AccountStatementBai2.Builder accountId(String accountId)
Filter results by Account.
-
accountId
final Export.AccountStatementBai2.Builder accountId(Optional<String> accountId)
Alias for calling Builder.accountId with
accountId.orElse(null).
-
accountId
final Export.AccountStatementBai2.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveDate
final Export.AccountStatementBai2.Builder effectiveDate(LocalDate effectiveDate)
The date for which to retrieve the balance.
-
effectiveDate
final Export.AccountStatementBai2.Builder effectiveDate(Optional<LocalDate> effectiveDate)
Alias for calling Builder.effectiveDate with
effectiveDate.orElse(null).
-
effectiveDate
final Export.AccountStatementBai2.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
Sets Builder.effectiveDate to an arbitrary JSON value.
You should usually call Builder.effectiveDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final Export.AccountStatementBai2.Builder programId(String programId)
Filter results by Program.
-
programId
final Export.AccountStatementBai2.Builder programId(Optional<String> programId)
Alias for calling Builder.programId with
programId.orElse(null).
-
programId
final Export.AccountStatementBai2.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Export.AccountStatementBai2.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.AccountStatementBai2.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.AccountStatementBai2.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.AccountStatementBai2.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.AccountStatementBai2.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Export.AccountStatementBai2 build()
Returns an immutable instance of AccountStatementBai2.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .effectiveDate() .programId()
-
-
-
-