Package com.increase.api.models.exports
Class Export.BalanceCsv
-
- All Implemented Interfaces:
public final class Export.BalanceCsvDetails of the balance CSV export. This field will be present when the
categoryis equal tobalance_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.BalanceCsv.BuilderA builder for BalanceCsv.
public final classExport.BalanceCsv.CreatedAtFilter balances by their created date.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter results by Account. final Optional<Export.BalanceCsv.CreatedAt>createdAt()Filter balances by their created date. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Export.BalanceCsv.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final Export.BalanceCsv.BuildertoBuilder()final Export.BalanceCsvvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.BalanceCsv.Builderbuilder()Returns a mutable builder for constructing an instance of BalanceCsv. -
-
Method Detail
-
createdAt
final Optional<Export.BalanceCsv.CreatedAt> createdAt()
Filter balances by their created date.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Export.BalanceCsv.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.BalanceCsv.Builder toBuilder()
-
validate
final Export.BalanceCsv validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.BalanceCsv.Builder builder()
Returns a mutable builder for constructing an instance of BalanceCsv.
The following fields are required:
.accountId() .createdAt()
-
-
-
-