Class Export.DailyAccountBalanceCsv
-
- All Implemented Interfaces:
public final class Export.DailyAccountBalanceCsvDetails of the daily account balance CSV export. This field will be present when the
categoryis equal todaily_account_balance_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.DailyAccountBalanceCsv.BuilderA builder for DailyAccountBalanceCsv.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter results by Account. final Optional<LocalDate>onOrAfterDate()Filter balances on or after this date. final Optional<LocalDate>onOrBeforeDate()Filter balances on or before this date. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<LocalDate>_onOrAfterDate()Returns the raw JSON value of onOrAfterDate. final JsonField<LocalDate>_onOrBeforeDate()Returns the raw JSON value of onOrBeforeDate. final Map<String, JsonValue>_additionalProperties()final Export.DailyAccountBalanceCsv.BuildertoBuilder()final Export.DailyAccountBalanceCsvvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.DailyAccountBalanceCsv.Builderbuilder()Returns a mutable builder for constructing an instance of DailyAccountBalanceCsv. -
-
Method Detail
-
onOrAfterDate
final Optional<LocalDate> onOrAfterDate()
Filter balances on or after this date.
-
onOrBeforeDate
final Optional<LocalDate> onOrBeforeDate()
Filter balances on or before this date.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_onOrAfterDate
final JsonField<LocalDate> _onOrAfterDate()
Returns the raw JSON value of onOrAfterDate.
Unlike onOrAfterDate, this method doesn't throw if the JSON field has an unexpected type.
-
_onOrBeforeDate
final JsonField<LocalDate> _onOrBeforeDate()
Returns the raw JSON value of onOrBeforeDate.
Unlike onOrBeforeDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.DailyAccountBalanceCsv.Builder toBuilder()
-
validate
final Export.DailyAccountBalanceCsv validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.DailyAccountBalanceCsv.Builder builder()
Returns a mutable builder for constructing an instance of DailyAccountBalanceCsv.
The following fields are required:
.accountId() .onOrAfterDate() .onOrBeforeDate()
-
-
-
-