Package com.increase.api.models.exports
Class Export.DashboardTableCsv
-
- All Implemented Interfaces:
public final class Export.DashboardTableCsvDetails of the dashboard table CSV export. This field will be present when the
categoryis equal todashboard_table_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.DashboardTableCsv.BuilderA builder for DashboardTableCsv.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final Export.DashboardTableCsv.BuildertoBuilder()final Export.DashboardTableCsvvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.DashboardTableCsv.Builderbuilder()Returns a mutable builder for constructing an instance of DashboardTableCsv. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.DashboardTableCsv.Builder toBuilder()
-
validate
final Export.DashboardTableCsv validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.DashboardTableCsv.Builder builder()
Returns a mutable builder for constructing an instance of DashboardTableCsv.
-
-
-
-