Package com.increase.api.models.exports
Class Export.EntityCsv
-
- All Implemented Interfaces:
public final class Export.EntityCsvDetails of the entity CSV export. This field will be present when the
categoryis equal toentity_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.EntityCsv.BuilderA builder for EntityCsv.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final Export.EntityCsv.BuildertoBuilder()final Export.EntityCsvvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.EntityCsv.Builderbuilder()Returns a mutable builder for constructing an instance of EntityCsv. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.EntityCsv.Builder toBuilder()
-
validate
final Export.EntityCsv validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.EntityCsv.Builder builder()
Returns a mutable builder for constructing an instance of EntityCsv.
-
-
-
-