Package com.increase.api.models.exports
Class Export.FeeCsv
-
- All Implemented Interfaces:
public final class Export.FeeCsvDetails of the fee CSV export. This field will be present when the
categoryis equal tofee_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.FeeCsv.BuilderA builder for FeeCsv.
public final classExport.FeeCsv.CreatedAtFilter fees by their created date. The time range must not include any fees that are part of an open fee statement.
-
Method Summary
Modifier and Type Method Description final Optional<Export.FeeCsv.CreatedAt>createdAt()Filter fees by their created date. final JsonField<Export.FeeCsv.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final Export.FeeCsv.BuildertoBuilder()final Export.FeeCsvvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.FeeCsv.Builderbuilder()Returns a mutable builder for constructing an instance of FeeCsv. -
-
Method Detail
-
createdAt
final Optional<Export.FeeCsv.CreatedAt> createdAt()
Filter fees by their created date. The time range must not include any fees that are part of an open fee statement.
-
_createdAt
final JsonField<Export.FeeCsv.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.FeeCsv.Builder toBuilder()
-
validate
final Export.FeeCsv validate()
-
builder
final static Export.FeeCsv.Builder builder()
Returns a mutable builder for constructing an instance of FeeCsv.
The following fields are required:
.createdAt()
-
-
-
-