Class Export.Form1099Int
-
- All Implemented Interfaces:
public final class Export.Form1099IntDetails of the Form 1099-INT export. This field will be present when the
categoryis equal toform_1099_int.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.Form1099Int.BuilderA builder for Form1099Int.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the tax form is for. final Booleancorrected()Whether the tax form is a corrected form. final Stringdescription()A description of the tax form. final Longyear()The tax year for the tax form. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Boolean>_corrected()Returns the raw JSON value of corrected. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Long>_year()Returns the raw JSON value of year. final Map<String, JsonValue>_additionalProperties()final Export.Form1099Int.BuildertoBuilder()final Export.Form1099Intvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.Form1099Int.Builderbuilder()Returns a mutable builder for constructing an instance of Form1099Int. -
-
Method Detail
-
description
final String description()
A description of the tax form.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_corrected
final JsonField<Boolean> _corrected()
Returns the raw JSON value of corrected.
Unlike corrected, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_year
final JsonField<Long> _year()
Returns the raw JSON value of year.
Unlike year, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.Form1099Int.Builder toBuilder()
-
validate
final Export.Form1099Int validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.Form1099Int.Builder builder()
Returns a mutable builder for constructing an instance of Form1099Int.
The following fields are required:
.accountId() .corrected() .description() .year()
-
-
-
-