Class Export.Form1099Misc.Builder
-
- All Implemented Interfaces:
public final class Export.Form1099Misc.BuilderA builder for Form1099Misc.
-
-
Method Summary
-
-
Method Detail
-
accountId
final Export.Form1099Misc.Builder accountId(String accountId)
The Account the tax form is for.
-
accountId
final Export.Form1099Misc.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
corrected
final Export.Form1099Misc.Builder corrected(Boolean corrected)
Whether the tax form is a corrected form.
-
corrected
final Export.Form1099Misc.Builder corrected(JsonField<Boolean> corrected)
Sets Builder.corrected to an arbitrary JSON value.
You should usually call Builder.corrected with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
year
final Export.Form1099Misc.Builder year(Long year)
The tax year for the tax form.
-
year
final Export.Form1099Misc.Builder year(JsonField<Long> year)
Sets Builder.year to an arbitrary JSON value.
You should usually call Builder.year with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Export.Form1099Misc.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.Form1099Misc.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.Form1099Misc.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.Form1099Misc.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.Form1099Misc.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Export.Form1099Misc build()
Returns an immutable instance of Form1099Misc.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .corrected() .year()
-
-
-
-