Package com.increase.api.models.exports
Class Export.FundingInstructions
-
- All Implemented Interfaces:
public final class Export.FundingInstructionsDetails of the funding instructions export. This field will be present when the
categoryis equal tofunding_instructions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.FundingInstructions.BuilderA builder for FundingInstructions.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number to create funding instructions for. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final Map<String, JsonValue>_additionalProperties()final Export.FundingInstructions.BuildertoBuilder()final Export.FundingInstructionsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.FundingInstructions.Builderbuilder()Returns a mutable builder for constructing an instance of FundingInstructions. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to create funding instructions for.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.FundingInstructions.Builder toBuilder()
-
validate
final Export.FundingInstructions validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.FundingInstructions.Builder builder()
Returns a mutable builder for constructing an instance of FundingInstructions.
The following fields are required:
.accountNumberId()
-
-
-
-