Package com.increase.api.models.exports
Class Export.Result
-
- All Implemented Interfaces:
public final class Export.ResultThe result of the Export. This will be present when the Export's status transitions to
complete.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.Result.BuilderA builder for Result.
-
Method Summary
Modifier and Type Method Description final StringfileId()The File containing the contents of the Export. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final Export.Result.BuildertoBuilder()final Export.Resultvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.Result.Builderbuilder()Returns a mutable builder for constructing an instance of Result. -
-
Method Detail
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.Result.Builder toBuilder()
-
validate
final Export.Result validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.Result.Builder builder()
Returns a mutable builder for constructing an instance of Result.
The following fields are required:
.fileId()
-
-
-
-