Enum Export.Status.Known

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      PENDING

      Increase is generating the export.

      COMPLETE

      The export has been successfully generated.

      FAILED

      The export failed to generate. Increase will reach out to you to resolve the issue.

    • Method Summary

      Modifier and Type Method Description
      final Export.Status.Known valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<Export.Status.Known> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<Export.Status.Known> getEntries() An enum containing Status's known values.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • valueOf

         final Export.Status.Known valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • values

         final Array<Export.Status.Known> values()

        Returns an array containing the constants of this enum type, in the order they're declared.

        This method may be used to iterate over the constants.