Class Export.TransactionCsv.Builder
-
- All Implemented Interfaces:
public final class Export.TransactionCsv.BuilderA builder for TransactionCsv.
-
-
Method Summary
-
-
Method Detail
-
accountId
final Export.TransactionCsv.Builder accountId(String accountId)
Filter results by Account.
-
accountId
final Export.TransactionCsv.Builder accountId(Optional<String> accountId)
Alias for calling Builder.accountId with
accountId.orElse(null).
-
accountId
final Export.TransactionCsv.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Export.TransactionCsv.Builder createdAt(Export.TransactionCsv.CreatedAt createdAt)
Filter transactions by their created date.
-
createdAt
final Export.TransactionCsv.Builder createdAt(Optional<Export.TransactionCsv.CreatedAt> createdAt)
Alias for calling Builder.createdAt with
createdAt.orElse(null).
-
createdAt
final Export.TransactionCsv.Builder createdAt(JsonField<Export.TransactionCsv.CreatedAt> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed CreatedAt value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Export.TransactionCsv.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.TransactionCsv.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.TransactionCsv.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.TransactionCsv.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.TransactionCsv.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Export.TransactionCsv build()
Returns an immutable instance of TransactionCsv.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .createdAt()
-
-
-
-