Class Export.VoidedCheck.Builder
-
- All Implemented Interfaces:
public final class Export.VoidedCheck.BuilderA builder for VoidedCheck.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final Export.VoidedCheck.Builder accountNumberId(String accountNumberId)
The Account Number for the voided check.
-
accountNumberId
final Export.VoidedCheck.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payer
final Export.VoidedCheck.Builder payer(List<Export.VoidedCheck.Payer> payer)
The payer information printed on the check.
-
payer
final Export.VoidedCheck.Builder payer(JsonField<List<Export.VoidedCheck.Payer>> payer)
Sets Builder.payer to an arbitrary JSON value.
You should usually call Builder.payer with a well-typed
List<Payer>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayer
final Export.VoidedCheck.Builder addPayer(Export.VoidedCheck.Payer payer)
Adds a single Payer to Builder.payer.
-
additionalProperties
final Export.VoidedCheck.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.VoidedCheck.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.VoidedCheck.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.VoidedCheck.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.VoidedCheck.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Export.VoidedCheck build()
Returns an immutable instance of VoidedCheck.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .payer()
-
-
-
-