Package com.increase.api.models.exports
Class Export.VoidedCheck.Payer
-
- All Implemented Interfaces:
public final class Export.VoidedCheck.Payer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.VoidedCheck.Payer.BuilderA builder for Payer.
-
Method Summary
Modifier and Type Method Description final Stringline()The contents of the line. final JsonField<String>_line()Returns the raw JSON value of line. final Map<String, JsonValue>_additionalProperties()final Export.VoidedCheck.Payer.BuildertoBuilder()final Export.VoidedCheck.Payervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.VoidedCheck.Payer.Builderbuilder()Returns a mutable builder for constructing an instance of Payer. -
-
Method Detail
-
_line
final JsonField<String> _line()
Returns the raw JSON value of line.
Unlike line, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.VoidedCheck.Payer.Builder toBuilder()
-
validate
final Export.VoidedCheck.Payer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Export.VoidedCheck.Payer.Builder builder()
Returns a mutable builder for constructing an instance of Payer.
The following fields are required:
.line()
-
-
-
-