Class ExportCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExportCreateParams implements Params
Create an Export
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.BuilderA builder for ExportCreateParams.
public final classExportCreateParams.Bodypublic final classExportCreateParams.CategoryThe type of Export to create.
public final classExportCreateParams.AccountStatementBai2Options for the created export. Required if
categoryis equal toaccount_statement_bai2.public final classExportCreateParams.AccountStatementOfxOptions for the created export. Required if
categoryis equal toaccount_statement_ofx.public final classExportCreateParams.AccountVerificationLetterOptions for the created export. Required if
categoryis equal toaccount_verification_letter.public final classExportCreateParams.BalanceCsvOptions for the created export. Required if
categoryis equal tobalance_csv.public final classExportCreateParams.BookkeepingAccountBalanceCsvOptions for the created export. Required if
categoryis equal tobookkeeping_account_balance_csv.public final classExportCreateParams.EntityCsvOptions for the created export. Required if
categoryis equal toentity_csv.public final classExportCreateParams.FundingInstructionsOptions for the created export. Required if
categoryis equal tofunding_instructions.public final classExportCreateParams.TransactionCsvOptions for the created export. Required if
categoryis equal totransaction_csv.public final classExportCreateParams.VendorCsvOptions for the created export. Required if
categoryis equal tovendor_csv.public final classExportCreateParams.VoidedCheckOptions for the created export. Required if
categoryis equal tovoided_check.
-
Method Summary
-
-
Method Detail
-
category
final ExportCreateParams.Category category()
The type of Export to create.
-
accountStatementBai2
final Optional<ExportCreateParams.AccountStatementBai2> accountStatementBai2()
Options for the created export. Required if
categoryis equal toaccount_statement_bai2.
-
accountStatementOfx
final Optional<ExportCreateParams.AccountStatementOfx> accountStatementOfx()
Options for the created export. Required if
categoryis equal toaccount_statement_ofx.
-
accountVerificationLetter
final Optional<ExportCreateParams.AccountVerificationLetter> accountVerificationLetter()
Options for the created export. Required if
categoryis equal toaccount_verification_letter.
-
balanceCsv
final Optional<ExportCreateParams.BalanceCsv> balanceCsv()
Options for the created export. Required if
categoryis equal tobalance_csv.
-
bookkeepingAccountBalanceCsv
final Optional<ExportCreateParams.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv()
Options for the created export. Required if
categoryis equal tobookkeeping_account_balance_csv.
-
entityCsv
final Optional<ExportCreateParams.EntityCsv> entityCsv()
Options for the created export. Required if
categoryis equal toentity_csv.
-
fundingInstructions
final Optional<ExportCreateParams.FundingInstructions> fundingInstructions()
Options for the created export. Required if
categoryis equal tofunding_instructions.
-
transactionCsv
final Optional<ExportCreateParams.TransactionCsv> transactionCsv()
Options for the created export. Required if
categoryis equal totransaction_csv.
-
vendorCsv
final Optional<ExportCreateParams.VendorCsv> vendorCsv()
Options for the created export. Required if
categoryis equal tovendor_csv.
-
voidedCheck
final Optional<ExportCreateParams.VoidedCheck> voidedCheck()
Options for the created export. Required if
categoryis equal tovoided_check.
-
_category
final JsonField<ExportCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStatementBai2
final JsonField<ExportCreateParams.AccountStatementBai2> _accountStatementBai2()
Returns the raw JSON value of accountStatementBai2.
Unlike accountStatementBai2, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStatementOfx
final JsonField<ExportCreateParams.AccountStatementOfx> _accountStatementOfx()
Returns the raw JSON value of accountStatementOfx.
Unlike accountStatementOfx, this method doesn't throw if the JSON field has an unexpected type.
-
_accountVerificationLetter
final JsonField<ExportCreateParams.AccountVerificationLetter> _accountVerificationLetter()
Returns the raw JSON value of accountVerificationLetter.
Unlike accountVerificationLetter, this method doesn't throw if the JSON field has an unexpected type.
-
_balanceCsv
final JsonField<ExportCreateParams.BalanceCsv> _balanceCsv()
Returns the raw JSON value of balanceCsv.
Unlike balanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_bookkeepingAccountBalanceCsv
final JsonField<ExportCreateParams.BookkeepingAccountBalanceCsv> _bookkeepingAccountBalanceCsv()
Returns the raw JSON value of bookkeepingAccountBalanceCsv.
Unlike bookkeepingAccountBalanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_entityCsv
final JsonField<ExportCreateParams.EntityCsv> _entityCsv()
Returns the raw JSON value of entityCsv.
Unlike entityCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_fundingInstructions
final JsonField<ExportCreateParams.FundingInstructions> _fundingInstructions()
Returns the raw JSON value of fundingInstructions.
Unlike fundingInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionCsv
final JsonField<ExportCreateParams.TransactionCsv> _transactionCsv()
Returns the raw JSON value of transactionCsv.
Unlike transactionCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_vendorCsv
final JsonField<ExportCreateParams.VendorCsv> _vendorCsv()
Returns the raw JSON value of vendorCsv.
Unlike vendorCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_voidedCheck
final JsonField<ExportCreateParams.VoidedCheck> _voidedCheck()
Returns the raw JSON value of voidedCheck.
Unlike voidedCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExportCreateParams.Builder toBuilder()
-
_body
final ExportCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExportCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExportCreateParams.
The following fields are required:
.category()
-
-
-
-