Class ExportCreateParams.AccountStatementBai2
-
- All Implemented Interfaces:
public final class ExportCreateParams.AccountStatementBai2Options for the created export. Required if
categoryis equal toaccount_statement_bai2.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.AccountStatementBai2.BuilderA builder for AccountStatementBai2.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()The Account to create a BAI2 report for. final Optional<LocalDate>effectiveDate()The date to create a BAI2 report for. final Optional<String>programId()The Program to create a BAI2 report for. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.AccountStatementBai2.BuildertoBuilder()final ExportCreateParams.AccountStatementBai2validate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.AccountStatementBai2.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementBai2. -
-
Method Detail
-
accountId
final Optional<String> accountId()
The Account to create a BAI2 report for. If not provided, all open accounts will be included.
-
effectiveDate
final Optional<LocalDate> effectiveDate()
The date to create a BAI2 report for. If not provided, the current date will be used. The timezone is UTC. If the current date is used, the report will include intraday balances, otherwise it will include end-of-day balances for the provided date.
-
programId
final Optional<String> programId()
The Program to create a BAI2 report for. If not provided, all open accounts will be included.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.AccountStatementBai2.Builder toBuilder()
-
validate
final ExportCreateParams.AccountStatementBai2 validate()
-
builder
final static ExportCreateParams.AccountStatementBai2.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementBai2.
-
-
-
-