Class ExportCreateParams.AccountStatementBai2.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.AccountStatementBai2.BuilderA builder for AccountStatementBai2.
-
-
Method Summary
-
-
Method Detail
-
accountId
final ExportCreateParams.AccountStatementBai2.Builder accountId(String accountId)
The Account to create a BAI2 report for. If not provided, all open accounts will be included.
-
accountId
final ExportCreateParams.AccountStatementBai2.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveDate
final ExportCreateParams.AccountStatementBai2.Builder effectiveDate(LocalDate effectiveDate)
The date to create a BAI2 report for. If not provided, the current date will be used. The timezone is UTC. If the current date is used, the report will include intraday balances, otherwise it will include end-of-day balances for the provided date.
-
effectiveDate
final ExportCreateParams.AccountStatementBai2.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
Sets Builder.effectiveDate to an arbitrary JSON value.
You should usually call Builder.effectiveDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final ExportCreateParams.AccountStatementBai2.Builder programId(String programId)
The Program to create a BAI2 report for. If not provided, all open accounts will be included.
-
programId
final ExportCreateParams.AccountStatementBai2.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.AccountStatementBai2.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.AccountStatementBai2.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.AccountStatementBai2.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.AccountStatementBai2.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.AccountStatementBai2.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.AccountStatementBai2 build()
Returns an immutable instance of AccountStatementBai2.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-