Package com.increase.api.models.exports
Class ExportCreateParams.AccountStatementOfx
-
- All Implemented Interfaces:
public final class ExportCreateParams.AccountStatementOfxOptions for the created export. Required if
categoryis equal toaccount_statement_ofx.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.AccountStatementOfx.BuilderA builder for AccountStatementOfx.
public final classExportCreateParams.AccountStatementOfx.CreatedAtFilter transactions by their created date.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account to create a statement for. final Optional<ExportCreateParams.AccountStatementOfx.CreatedAt>createdAt()Filter transactions by their created date. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<ExportCreateParams.AccountStatementOfx.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.AccountStatementOfx.BuildertoBuilder()final ExportCreateParams.AccountStatementOfxvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.AccountStatementOfx.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementOfx. -
-
Method Detail
-
createdAt
final Optional<ExportCreateParams.AccountStatementOfx.CreatedAt> createdAt()
Filter transactions by their created date.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<ExportCreateParams.AccountStatementOfx.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.AccountStatementOfx.Builder toBuilder()
-
validate
final ExportCreateParams.AccountStatementOfx validate()
-
builder
final static ExportCreateParams.AccountStatementOfx.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementOfx.
The following fields are required:
.accountId()
-
-
-
-