Class ExportCreateParams.AccountVerificationLetter.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.AccountVerificationLetter.BuilderA builder for AccountVerificationLetter.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final ExportCreateParams.AccountVerificationLetter.Builder accountNumberId(String accountNumberId)
The Account Number to create a letter for.
-
accountNumberId
final ExportCreateParams.AccountVerificationLetter.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balanceDate
final ExportCreateParams.AccountVerificationLetter.Builder balanceDate(LocalDate balanceDate)
The date of the balance to include in the letter. Defaults to the current date.
-
balanceDate
final ExportCreateParams.AccountVerificationLetter.Builder balanceDate(JsonField<LocalDate> balanceDate)
Sets Builder.balanceDate to an arbitrary JSON value.
You should usually call Builder.balanceDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.AccountVerificationLetter.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.AccountVerificationLetter.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.AccountVerificationLetter.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.AccountVerificationLetter.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.AccountVerificationLetter.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.AccountVerificationLetter build()
Returns an immutable instance of AccountVerificationLetter.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId()
-
-
-
-