Class ExportCreateParams.Body
-
- All Implemented Interfaces:
public final class ExportCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
category
final ExportCreateParams.Category category()
The type of Export to create.
-
accountStatementBai2
final Optional<ExportCreateParams.AccountStatementBai2> accountStatementBai2()
Options for the created export. Required if
categoryis equal toaccount_statement_bai2.
-
accountStatementOfx
final Optional<ExportCreateParams.AccountStatementOfx> accountStatementOfx()
Options for the created export. Required if
categoryis equal toaccount_statement_ofx.
-
accountVerificationLetter
final Optional<ExportCreateParams.AccountVerificationLetter> accountVerificationLetter()
Options for the created export. Required if
categoryis equal toaccount_verification_letter.
-
bookkeepingAccountBalanceCsv
final Optional<ExportCreateParams.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv()
Options for the created export. Required if
categoryis equal tobookkeeping_account_balance_csv.
-
dailyAccountBalanceCsv
final Optional<ExportCreateParams.DailyAccountBalanceCsv> dailyAccountBalanceCsv()
Options for the created export. Required if
categoryis equal todaily_account_balance_csv.
-
entityCsv
final Optional<ExportCreateParams.EntityCsv> entityCsv()
Options for the created export. Required if
categoryis equal toentity_csv.
-
fundingInstructions
final Optional<ExportCreateParams.FundingInstructions> fundingInstructions()
Options for the created export. Required if
categoryis equal tofunding_instructions.
-
transactionCsv
final Optional<ExportCreateParams.TransactionCsv> transactionCsv()
Options for the created export. Required if
categoryis equal totransaction_csv.
-
vendorCsv
final Optional<ExportCreateParams.VendorCsv> vendorCsv()
Options for the created export. Required if
categoryis equal tovendor_csv.
-
voidedCheck
final Optional<ExportCreateParams.VoidedCheck> voidedCheck()
Options for the created export. Required if
categoryis equal tovoided_check.
-
_category
final JsonField<ExportCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStatementBai2
final JsonField<ExportCreateParams.AccountStatementBai2> _accountStatementBai2()
Returns the raw JSON value of accountStatementBai2.
Unlike accountStatementBai2, this method doesn't throw if the JSON field has an unexpected type.
-
_accountStatementOfx
final JsonField<ExportCreateParams.AccountStatementOfx> _accountStatementOfx()
Returns the raw JSON value of accountStatementOfx.
Unlike accountStatementOfx, this method doesn't throw if the JSON field has an unexpected type.
-
_accountVerificationLetter
final JsonField<ExportCreateParams.AccountVerificationLetter> _accountVerificationLetter()
Returns the raw JSON value of accountVerificationLetter.
Unlike accountVerificationLetter, this method doesn't throw if the JSON field has an unexpected type.
-
_bookkeepingAccountBalanceCsv
final JsonField<ExportCreateParams.BookkeepingAccountBalanceCsv> _bookkeepingAccountBalanceCsv()
Returns the raw JSON value of bookkeepingAccountBalanceCsv.
Unlike bookkeepingAccountBalanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyAccountBalanceCsv
final JsonField<ExportCreateParams.DailyAccountBalanceCsv> _dailyAccountBalanceCsv()
Returns the raw JSON value of dailyAccountBalanceCsv.
Unlike dailyAccountBalanceCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_entityCsv
final JsonField<ExportCreateParams.EntityCsv> _entityCsv()
Returns the raw JSON value of entityCsv.
Unlike entityCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_fundingInstructions
final JsonField<ExportCreateParams.FundingInstructions> _fundingInstructions()
Returns the raw JSON value of fundingInstructions.
Unlike fundingInstructions, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionCsv
final JsonField<ExportCreateParams.TransactionCsv> _transactionCsv()
Returns the raw JSON value of transactionCsv.
Unlike transactionCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_vendorCsv
final JsonField<ExportCreateParams.VendorCsv> _vendorCsv()
Returns the raw JSON value of vendorCsv.
Unlike vendorCsv, this method doesn't throw if the JSON field has an unexpected type.
-
_voidedCheck
final JsonField<ExportCreateParams.VoidedCheck> _voidedCheck()
Returns the raw JSON value of voidedCheck.
Unlike voidedCheck, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.Body.Builder toBuilder()
-
validate
final ExportCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.category()
-
-
-
-