Class ExportCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
category
final ExportCreateParams.Body.Builder category(ExportCreateParams.Category category)
The type of Export to create.
-
category
final ExportCreateParams.Body.Builder category(JsonField<ExportCreateParams.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountStatementBai2
final ExportCreateParams.Body.Builder accountStatementBai2(ExportCreateParams.AccountStatementBai2 accountStatementBai2)
Options for the created export. Required if
categoryis equal toaccount_statement_bai2.
-
accountStatementBai2
final ExportCreateParams.Body.Builder accountStatementBai2(JsonField<ExportCreateParams.AccountStatementBai2> accountStatementBai2)
Sets Builder.accountStatementBai2 to an arbitrary JSON value.
You should usually call Builder.accountStatementBai2 with a well-typed AccountStatementBai2 value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountStatementOfx
final ExportCreateParams.Body.Builder accountStatementOfx(ExportCreateParams.AccountStatementOfx accountStatementOfx)
Options for the created export. Required if
categoryis equal toaccount_statement_ofx.
-
accountStatementOfx
final ExportCreateParams.Body.Builder accountStatementOfx(JsonField<ExportCreateParams.AccountStatementOfx> accountStatementOfx)
Sets Builder.accountStatementOfx to an arbitrary JSON value.
You should usually call Builder.accountStatementOfx with a well-typed AccountStatementOfx value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balanceCsv
final ExportCreateParams.Body.Builder balanceCsv(ExportCreateParams.BalanceCsv balanceCsv)
Options for the created export. Required if
categoryis equal tobalance_csv.
-
balanceCsv
final ExportCreateParams.Body.Builder balanceCsv(JsonField<ExportCreateParams.BalanceCsv> balanceCsv)
Sets Builder.balanceCsv to an arbitrary JSON value.
You should usually call Builder.balanceCsv with a well-typed BalanceCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bookkeepingAccountBalanceCsv
final ExportCreateParams.Body.Builder bookkeepingAccountBalanceCsv(ExportCreateParams.BookkeepingAccountBalanceCsv bookkeepingAccountBalanceCsv)
Options for the created export. Required if
categoryis equal tobookkeeping_account_balance_csv.
-
bookkeepingAccountBalanceCsv
final ExportCreateParams.Body.Builder bookkeepingAccountBalanceCsv(JsonField<ExportCreateParams.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv)
Sets Builder.bookkeepingAccountBalanceCsv to an arbitrary JSON value.
You should usually call Builder.bookkeepingAccountBalanceCsv with a well-typed BookkeepingAccountBalanceCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityCsv
final ExportCreateParams.Body.Builder entityCsv(ExportCreateParams.EntityCsv entityCsv)
Options for the created export. Required if
categoryis equal toentity_csv.
-
entityCsv
final ExportCreateParams.Body.Builder entityCsv(JsonField<ExportCreateParams.EntityCsv> entityCsv)
Sets Builder.entityCsv to an arbitrary JSON value.
You should usually call Builder.entityCsv with a well-typed EntityCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionCsv
final ExportCreateParams.Body.Builder transactionCsv(ExportCreateParams.TransactionCsv transactionCsv)
Options for the created export. Required if
categoryis equal totransaction_csv.
-
transactionCsv
final ExportCreateParams.Body.Builder transactionCsv(JsonField<ExportCreateParams.TransactionCsv> transactionCsv)
Sets Builder.transactionCsv to an arbitrary JSON value.
You should usually call Builder.transactionCsv with a well-typed TransactionCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vendorCsv
final ExportCreateParams.Body.Builder vendorCsv(ExportCreateParams.VendorCsv vendorCsv)
Options for the created export. Required if
categoryis equal tovendor_csv.
-
vendorCsv
final ExportCreateParams.Body.Builder vendorCsv(JsonField<ExportCreateParams.VendorCsv> vendorCsv)
Sets Builder.vendorCsv to an arbitrary JSON value.
You should usually call Builder.vendorCsv with a well-typed VendorCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category()
-
-
-
-