Package com.increase.api.models.exports
Class ExportCreateParams.EntityCsv
-
- All Implemented Interfaces:
public final class ExportCreateParams.EntityCsvOptions for the created export. Required if
categoryis equal toentity_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.EntityCsv.BuilderA builder for EntityCsv.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.EntityCsv.BuildertoBuilder()final ExportCreateParams.EntityCsvvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.EntityCsv.Builderbuilder()Returns a mutable builder for constructing an instance of EntityCsv. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.EntityCsv.Builder toBuilder()
-
validate
final ExportCreateParams.EntityCsv validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportCreateParams.EntityCsv.Builder builder()
Returns a mutable builder for constructing an instance of EntityCsv.
-
-
-
-