Package com.increase.api.models.exports
Class ExportCreateParams.FeeCsv
-
- All Implemented Interfaces:
public final class ExportCreateParams.FeeCsvOptions for the created export. Required if
categoryis equal tofee_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.FeeCsv.BuilderA builder for FeeCsv.
public final classExportCreateParams.FeeCsv.CreatedAtFilter results by time range on the
created_atattribute.
-
Method Summary
Modifier and Type Method Description final Optional<ExportCreateParams.FeeCsv.CreatedAt>createdAt()Filter results by time range on the created_atattribute.final Optional<String>programId()Filter exported Fees to the specified Program. final JsonField<ExportCreateParams.FeeCsv.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.FeeCsv.BuildertoBuilder()final ExportCreateParams.FeeCsvvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.FeeCsv.Builderbuilder()Returns a mutable builder for constructing an instance of FeeCsv. -
-
Method Detail
-
createdAt
final Optional<ExportCreateParams.FeeCsv.CreatedAt> createdAt()
Filter results by time range on the
created_atattribute.
-
_createdAt
final JsonField<ExportCreateParams.FeeCsv.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.FeeCsv.Builder toBuilder()
-
validate
final ExportCreateParams.FeeCsv validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportCreateParams.FeeCsv.Builder builder()
Returns a mutable builder for constructing an instance of FeeCsv.
-
-
-
-