Package com.increase.api.models.exports
Class ExportCreateParams.FundingInstructions
-
- All Implemented Interfaces:
public final class ExportCreateParams.FundingInstructionsOptions for the created export. Required if
categoryis equal tofunding_instructions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.FundingInstructions.BuilderA builder for FundingInstructions.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number to create funding instructions for. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.FundingInstructions.BuildertoBuilder()final ExportCreateParams.FundingInstructionsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.FundingInstructions.Builderbuilder()Returns a mutable builder for constructing an instance of FundingInstructions. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to create funding instructions for.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.FundingInstructions.Builder toBuilder()
-
validate
final ExportCreateParams.FundingInstructions validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportCreateParams.FundingInstructions.Builder builder()
Returns a mutable builder for constructing an instance of FundingInstructions.
The following fields are required:
.accountNumberId()
-
-
-
-