Package com.increase.api.models.exports
Class ExportCreateParams.TransactionCsv.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.TransactionCsv.BuilderA builder for TransactionCsv.
-
-
Method Summary
-
-
Method Detail
-
accountId
final ExportCreateParams.TransactionCsv.Builder accountId(String accountId)
Filter exported Transactions to the specified Account.
-
accountId
final ExportCreateParams.TransactionCsv.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ExportCreateParams.TransactionCsv.Builder createdAt(ExportCreateParams.TransactionCsv.CreatedAt createdAt)
Filter results by time range on the
created_atattribute.
-
createdAt
final ExportCreateParams.TransactionCsv.Builder createdAt(JsonField<ExportCreateParams.TransactionCsv.CreatedAt> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed CreatedAt value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.TransactionCsv.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.TransactionCsv.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.TransactionCsv.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.TransactionCsv.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.TransactionCsv.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.TransactionCsv build()
Returns an immutable instance of TransactionCsv.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-