Class ExportCreateParams.TransactionCsv.CreatedAt.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.TransactionCsv.CreatedAt.BuilderA builder for CreatedAt.
-
-
Method Summary
-
-
Method Detail
-
after
final ExportCreateParams.TransactionCsv.CreatedAt.Builder after(OffsetDateTime after)
Return results after this ISO 8601 timestamp.
-
after
final ExportCreateParams.TransactionCsv.CreatedAt.Builder after(JsonField<OffsetDateTime> after)
Sets Builder.after to an arbitrary JSON value.
You should usually call Builder.after with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
before
final ExportCreateParams.TransactionCsv.CreatedAt.Builder before(OffsetDateTime before)
Return results before this ISO 8601 timestamp.
-
before
final ExportCreateParams.TransactionCsv.CreatedAt.Builder before(JsonField<OffsetDateTime> before)
Sets Builder.before to an arbitrary JSON value.
You should usually call Builder.before with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
onOrAfter
final ExportCreateParams.TransactionCsv.CreatedAt.Builder onOrAfter(OffsetDateTime onOrAfter)
Return results on or after this ISO 8601 timestamp.
-
onOrAfter
final ExportCreateParams.TransactionCsv.CreatedAt.Builder onOrAfter(JsonField<OffsetDateTime> onOrAfter)
Sets Builder.onOrAfter to an arbitrary JSON value.
You should usually call Builder.onOrAfter with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
onOrBefore
final ExportCreateParams.TransactionCsv.CreatedAt.Builder onOrBefore(OffsetDateTime onOrBefore)
Return results on or before this ISO 8601 timestamp.
-
onOrBefore
final ExportCreateParams.TransactionCsv.CreatedAt.Builder onOrBefore(JsonField<OffsetDateTime> onOrBefore)
Sets Builder.onOrBefore to an arbitrary JSON value.
You should usually call Builder.onOrBefore with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.TransactionCsv.CreatedAt.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.TransactionCsv.CreatedAt.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.TransactionCsv.CreatedAt.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.TransactionCsv.CreatedAt.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.TransactionCsv.CreatedAt.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.TransactionCsv.CreatedAt build()
Returns an immutable instance of CreatedAt.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-