Package com.increase.api.models.exports
Class ExportCreateParams.VoidedCheck
-
- All Implemented Interfaces:
public final class ExportCreateParams.VoidedCheckOptions for the created export. Required if
categoryis equal tovoided_check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.VoidedCheck.BuilderA builder for VoidedCheck.
public final classExportCreateParams.VoidedCheck.Payer
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number for the voided check. final Optional<List<ExportCreateParams.VoidedCheck.Payer>>payer()The payer information to be printed on the check. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<List<ExportCreateParams.VoidedCheck.Payer>>_payer()Returns the raw JSON value of payer. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.VoidedCheck.BuildertoBuilder()final ExportCreateParams.VoidedCheckvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.VoidedCheck.Builderbuilder()Returns a mutable builder for constructing an instance of VoidedCheck. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number for the voided check.
-
payer
final Optional<List<ExportCreateParams.VoidedCheck.Payer>> payer()
The payer information to be printed on the check.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_payer
final JsonField<List<ExportCreateParams.VoidedCheck.Payer>> _payer()
Returns the raw JSON value of payer.
Unlike payer, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.VoidedCheck.Builder toBuilder()
-
validate
final ExportCreateParams.VoidedCheck validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportCreateParams.VoidedCheck.Builder builder()
Returns a mutable builder for constructing an instance of VoidedCheck.
The following fields are required:
.accountNumberId()
-
-
-
-