Class ExportCreateParams.VoidedCheck.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.VoidedCheck.BuilderA builder for VoidedCheck.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final ExportCreateParams.VoidedCheck.Builder accountNumberId(String accountNumberId)
The Account Number for the voided check.
-
accountNumberId
final ExportCreateParams.VoidedCheck.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payer
final ExportCreateParams.VoidedCheck.Builder payer(List<ExportCreateParams.VoidedCheck.Payer> payer)
The payer information to be printed on the check.
-
payer
final ExportCreateParams.VoidedCheck.Builder payer(JsonField<List<ExportCreateParams.VoidedCheck.Payer>> payer)
Sets Builder.payer to an arbitrary JSON value.
You should usually call Builder.payer with a well-typed
List<Payer>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addPayer
final ExportCreateParams.VoidedCheck.Builder addPayer(ExportCreateParams.VoidedCheck.Payer payer)
Adds a single Payer to Builder.payer.
-
additionalProperties
final ExportCreateParams.VoidedCheck.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.VoidedCheck.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.VoidedCheck.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.VoidedCheck.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.VoidedCheck.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.VoidedCheck build()
Returns an immutable instance of VoidedCheck.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId()
-
-
-
-