Package com.increase.api.models.exports
Class ExportListPage.Builder
-
- All Implemented Interfaces:
public final class ExportListPage.BuilderA builder for ExportListPage.
-
-
Method Summary
Modifier and Type Method Description final ExportListPage.Builderservice(ExportService service)final ExportListPage.Builderparams(ExportListParams params)The parameters that were used to request this page. final ExportListPage.Builderresponse(ExportListPageResponse response)The response that this page was parsed from. final ExportListPagebuild()Returns an immutable instance of ExportListPage. -
-
Method Detail
-
service
final ExportListPage.Builder service(ExportService service)
-
params
final ExportListPage.Builder params(ExportListParams params)
The parameters that were used to request this page.
-
response
final ExportListPage.Builder response(ExportListPageResponse response)
The response that this page was parsed from.
-
build
final ExportListPage build()
Returns an immutable instance of ExportListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-