Package com.increase.api.models.exports
Class ExportListPageAsync
-
- All Implemented Interfaces:
public final class ExportListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportListPageAsync.BuilderA builder for ExportListPageAsync.
public final classExportListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Export>data()Delegates to ExportListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ExportListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<ExportListParams>getNextPageParams()final CompletableFuture<Optional<ExportListPageAsync>>getNextPage()final ExportListPageAsync.AutoPagerautoPager()final ExportListParamsparams()The parameters that were used to request this page. final ExportListPageResponseresponse()The response that this page was parsed from. final ExportListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of ExportListPageAsync. -
-
Method Detail
-
data
final List<Export> data()
Delegates to ExportListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ExportListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ExportListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<ExportListPageAsync>> getNextPage()
-
autoPager
final ExportListPageAsync.AutoPager autoPager()
-
params
final ExportListParams params()
The parameters that were used to request this page.
-
response
final ExportListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ExportListPageAsync.Builder toBuilder()
-
builder
final static ExportListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ExportListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-