Package com.increase.api.models.exports
Class ExportListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ExportListPageAsync.BuilderA builder for ExportListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ExportListPageAsync.Builderservice(ExportServiceAsync service)final ExportListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final ExportListPageAsync.Builderparams(ExportListParams params)The parameters that were used to request this page. final ExportListPageAsync.Builderresponse(ExportListPageResponse response)The response that this page was parsed from. final ExportListPageAsyncbuild()Returns an immutable instance of ExportListPageAsync. -
-
Method Detail
-
service
final ExportListPageAsync.Builder service(ExportServiceAsync service)
-
streamHandlerExecutor
final ExportListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final ExportListPageAsync.Builder params(ExportListParams params)
The parameters that were used to request this page.
-
response
final ExportListPageAsync.Builder response(ExportListPageResponse response)
The response that this page was parsed from.
-
build
final ExportListPageAsync build()
Returns an immutable instance of ExportListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-