Package com.increase.api.models.exports
Class ExportListPageAsync.Response
-
- All Implemented Interfaces:
public final class ExportListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportListPageAsync.Response.Builder
-
Method Summary
Modifier and Type Method Description final List<Export>data()final Optional<String>nextCursor()final Optional<JsonField<List<Export>>>_data()final Optional<JsonField<String>>_nextCursor()final Map<String, JsonValue>_additionalProperties()final ExportListPageAsync.Responsevalidate()final BooleanisValid()final ExportListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of ExportListPageAsync. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
-
_nextCursor
final Optional<JsonField<String>> _nextCursor()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ExportListPageAsync.Response validate()
-
toBuilder
final ExportListPageAsync.Response.Builder toBuilder()
-
builder
final static ExportListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of ExportListPageAsync.
-
-
-
-