Class ExportListPageResponse
-
- All Implemented Interfaces:
public final class ExportListPageResponseA list of Export objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportListPageResponse.BuilderA builder for ExportListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Export>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<Export>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final ExportListPageResponse.BuildertoBuilder()final ExportListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExportListPageResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
_data
final JsonField<List<Export>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportListPageResponse.Builder toBuilder()
-
validate
final ExportListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExportListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-