Class ExportListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExportListParams implements Params
List Exports
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportListParams.BuilderA builder for ExportListParams.
public final classExportListParams.CategoryFilter Exports for those with the specified category.
public final classExportListParams.CreatedAtpublic final classExportListParams.Form1099Intpublic final classExportListParams.Form1099Miscpublic final classExportListParams.Status
-
Method Summary
Modifier and Type Method Description final Optional<ExportListParams.Category>category()Filter Exports for those with the specified category. final Optional<ExportListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<ExportListParams.Form1099Int>form1099Int()final Optional<ExportListParams.Form1099Misc>form1099Misc()final Optional<String>idempotencyKey()Filter records to the one with the specified idempotency_keyyou chose for that object.final Optional<Long>limit()Limit the size of the list that is returned. final Optional<ExportListParams.Status>status()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExportListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportListParamsnone()final static ExportListParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExportListParams. -
-
Method Detail
-
category
final Optional<ExportListParams.Category> category()
Filter Exports for those with the specified category.
-
createdAt
final Optional<ExportListParams.CreatedAt> createdAt()
-
form1099Int
final Optional<ExportListParams.Form1099Int> form1099Int()
-
form1099Misc
final Optional<ExportListParams.Form1099Misc> form1099Misc()
-
idempotencyKey
final Optional<String> idempotencyKey()
Filter records to the one with the specified
idempotency_keyyou chose for that object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
status
final Optional<ExportListParams.Status> status()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExportListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExportListParams none()
-
builder
final static ExportListParams.Builder builder()
Returns a mutable builder for constructing an instance of ExportListParams.
-
-
-
-