Package com.increase.api.models.exports
Class ExportListResponse
-
- All Implemented Interfaces:
public final class ExportListResponseA list of Export objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportListResponse.BuilderA builder for ExportListResponse.
-
Method Summary
Modifier and Type Method Description final List<Export>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<Export>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final ExportListResponse.BuildertoBuilder()final ExportListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExportListResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<Export>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportListResponse.Builder toBuilder()
-
validate
final ExportListResponse validate()
-
builder
final static ExportListResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExportListResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-