Package com.increase.api.models.exports
See: Description
-
Class Summary Class Description Builder A builder for Export. Category The category of the Export. Status The status of the Export. Type A constant representing the object's type. Export Exports are batch summaries of your Increase data. Builder A builder for ExportCreateParams. Builder A builder for Body. Body Category The type of Export to create. Builder A builder for AccountStatementBai2. AccountStatementBai2 Options for the created export. Builder A builder for AccountStatementOfx. Builder A builder for CreatedAt. CreatedAt Filter results by time range on the created_atattribute.AccountStatementOfx Options for the created export. Builder A builder for BalanceCsv. Builder A builder for CreatedAt. CreatedAt Filter results by time range on the created_atattribute.BalanceCsv Options for the created export. Builder A builder for BookkeepingAccountBalanceCsv. Builder A builder for CreatedAt. CreatedAt Filter results by time range on the created_atattribute.BookkeepingAccountBalanceCsv Options for the created export. Builder A builder for EntityCsv. Builder A builder for Status. In Status Entity statuses to filter by. EntityCsv Options for the created export. Builder A builder for TransactionCsv. Builder A builder for CreatedAt. CreatedAt Filter results by time range on the created_atattribute.TransactionCsv Options for the created export. ExportCreateParams Create an Export Builder A builder for ExportListPage. ExportListPage Builder A builder for ExportListPageAsync. ExportListPageAsync Builder A builder for ExportListPageResponse. ExportListPageResponse A list of Export objects. Builder A builder for ExportListParams. Builder A builder for Category. In Category Builder A builder for CreatedAt. CreatedAt Builder A builder for Status. In Status ExportListParams List Exports Builder A builder for ExportRetrieveParams. ExportRetrieveParams Retrieve an Export -
Enum Summary Enum Description Known An enum containing Category's known values. Value An enum containing Category's known values, as well as an _UNKNOWN member. Known An enum containing Status's known values. Value An enum containing Status's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Category's known values. Value An enum containing Category's known values, as well as an _UNKNOWN member. Known An enum containing In's known values. Value An enum containing In's known values, as well as an _UNKNOWN member. Known An enum containing In's known values. Value An enum containing In's known values, as well as an _UNKNOWN member. Known An enum containing In's known values. Value An enum containing In's known values, as well as an _UNKNOWN member.