Class ExternalAccount
-
- All Implemented Interfaces:
public final class ExternalAccountExternal Accounts represent accounts at financial institutions other than Increase. You can use this API to store their details for reuse.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccount.BuilderA builder for ExternalAccount.
public final classExternalAccount.AccountHolderThe type of entity that owns the External Account.
public final classExternalAccount.FundingThe type of the account to which the transfer will be sent.
public final classExternalAccount.StatusThe External Account's status.
public final classExternalAccount.TypeA constant representing the object's type. For this resource it will always be
external_account.
-
Method Summary
Modifier and Type Method Description final Stringid()The External Account's identifier. final ExternalAccount.AccountHolderaccountHolder()The type of entity that owns the External Account. final StringaccountNumber()The destination account number. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the External Account was created. final Stringdescription()The External Account's description for display purposes. final ExternalAccount.Fundingfunding()The type of the account to which the transfer will be sent. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final ExternalAccount.Statusstatus()The External Account's status. final ExternalAccount.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<ExternalAccount.AccountHolder>_accountHolder()Returns the raw JSON value of accountHolder. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<ExternalAccount.Funding>_funding()Returns the raw JSON value of funding. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<ExternalAccount.Status>_status()Returns the raw JSON value of status. final JsonField<ExternalAccount.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final ExternalAccount.BuildertoBuilder()final ExternalAccountvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccount.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccount. -
-
Method Detail
-
accountHolder
final ExternalAccount.AccountHolder accountHolder()
The type of entity that owns the External Account.
-
accountNumber
final String accountNumber()
The destination account number.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the External Account was created.
-
description
final String description()
The External Account's description for display purposes.
-
funding
final ExternalAccount.Funding funding()
The type of the account to which the transfer will be sent.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
status
final ExternalAccount.Status status()
The External Account's status.
-
type
final ExternalAccount.Type type()
A constant representing the object's type. For this resource it will always be
external_account.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountHolder
final JsonField<ExternalAccount.AccountHolder> _accountHolder()
Returns the raw JSON value of accountHolder.
Unlike accountHolder, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<ExternalAccount.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ExternalAccount.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ExternalAccount.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalAccount.Builder toBuilder()
-
validate
final ExternalAccount validate()
-
builder
final static ExternalAccount.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccount.
The following fields are required:
.id() .accountHolder() .accountNumber() .createdAt() .description() .funding() .idempotencyKey() .routingNumber() .status() .type()
-
-
-
-