Class ExternalAccount.Builder
-
- All Implemented Interfaces:
public final class ExternalAccount.BuilderA builder for ExternalAccount.
-
-
Method Summary
-
-
Method Detail
-
id
final ExternalAccount.Builder id(String id)
The External Account's identifier.
-
id
final ExternalAccount.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolder
final ExternalAccount.Builder accountHolder(ExternalAccount.AccountHolder accountHolder)
The type of entity that owns the External Account.
-
accountHolder
final ExternalAccount.Builder accountHolder(JsonField<ExternalAccount.AccountHolder> accountHolder)
Sets Builder.accountHolder to an arbitrary JSON value.
You should usually call Builder.accountHolder with a well-typed AccountHolder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final ExternalAccount.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final ExternalAccount.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final ExternalAccount.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the External Account was created.
-
createdAt
final ExternalAccount.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ExternalAccount.Builder description(String description)
The External Account's description for display purposes.
-
description
final ExternalAccount.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final ExternalAccount.Builder funding(ExternalAccount.Funding funding)
The type of the account to which the transfer will be sent.
-
funding
final ExternalAccount.Builder funding(JsonField<ExternalAccount.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final ExternalAccount.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final ExternalAccount.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final ExternalAccount.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final ExternalAccount.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final ExternalAccount.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ExternalAccount.Builder status(ExternalAccount.Status status)
The External Account's status.
-
status
final ExternalAccount.Builder status(JsonField<ExternalAccount.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ExternalAccount.Builder type(ExternalAccount.Type type)
A constant representing the object's type. For this resource it will always be
external_account.
-
type
final ExternalAccount.Builder type(JsonField<ExternalAccount.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExternalAccount.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalAccount.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalAccount.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalAccount.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalAccount.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalAccount build()
Returns an immutable instance of ExternalAccount.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountHolder() .accountNumber() .createdAt() .description() .funding() .idempotencyKey() .routingNumber() .status() .type()
-
-
-
-