Enum ExternalAccount.VerificationStatus.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ExternalAccount.VerificationStatus.Known extends Enum<ExternalAccount.VerificationStatus.Known>
An enum containing VerificationStatus's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ExternalAccount.VerificationStatus.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description UNVERIFIEDThe External Account has not been verified.
PENDINGThe External Account is in the process of being verified.
VERIFIEDThe External Account is verified.
-
Method Summary
Modifier and Type Method Description final ExternalAccount.VerificationStatus.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ExternalAccount.VerificationStatus.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ExternalAccount.VerificationStatus.Known>getEntries()An enum containing VerificationStatus's known values. -
-
Method Detail
-
valueOf
final ExternalAccount.VerificationStatus.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ExternalAccount.VerificationStatus.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ExternalAccount.VerificationStatus.Known> getEntries()
An enum containing VerificationStatus's known values.
-
-
-
-