Class ExternalAccountCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExternalAccountCreateParams implements Params
Create an External Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountCreateParams.BuilderA builder for ExternalAccountCreateParams.
public final classExternalAccountCreateParams.Bodypublic final classExternalAccountCreateParams.AccountHolderThe type of entity that owns the External Account.
public final classExternalAccountCreateParams.FundingThe type of the destination account. Defaults to
checking.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number for the destination account. final Stringdescription()The name you choose for the Account. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<ExternalAccountCreateParams.AccountHolder>accountHolder()The type of entity that owns the External Account. final Optional<ExternalAccountCreateParams.Funding>funding()The type of the destination account. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<ExternalAccountCreateParams.AccountHolder>_accountHolder()Returns the raw JSON value of accountHolder. final JsonField<ExternalAccountCreateParams.Funding>_funding()Returns the raw JSON value of funding. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExternalAccountCreateParams.BuildertoBuilder()final ExternalAccountCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccountCreateParams. -
-
Method Detail
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
description
final String description()
The name you choose for the Account.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
accountHolder
final Optional<ExternalAccountCreateParams.AccountHolder> accountHolder()
The type of entity that owns the External Account.
-
funding
final Optional<ExternalAccountCreateParams.Funding> funding()
The type of the destination account. Defaults to
checking.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_accountHolder
final JsonField<ExternalAccountCreateParams.AccountHolder> _accountHolder()
Returns the raw JSON value of accountHolder.
Unlike accountHolder, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<ExternalAccountCreateParams.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalAccountCreateParams.Builder toBuilder()
-
_body
final ExternalAccountCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExternalAccountCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccountCreateParams.
The following fields are required:
.accountNumber() .description() .routingNumber()
-
-
-
-