Class ExternalAccountCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ExternalAccountCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumber
final ExternalAccountCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final ExternalAccountCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ExternalAccountCreateParams.Body.Builder description(String description)
The name you choose for the Account.
-
description
final ExternalAccountCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final ExternalAccountCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final ExternalAccountCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountHolder
final ExternalAccountCreateParams.Body.Builder accountHolder(ExternalAccountCreateParams.AccountHolder accountHolder)
The type of entity that owns the External Account.
-
accountHolder
final ExternalAccountCreateParams.Body.Builder accountHolder(JsonField<ExternalAccountCreateParams.AccountHolder> accountHolder)
Sets Builder.accountHolder to an arbitrary JSON value.
You should usually call Builder.accountHolder with a well-typed AccountHolder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final ExternalAccountCreateParams.Body.Builder funding(ExternalAccountCreateParams.Funding funding)
The type of the destination account. Defaults to
checking.
-
funding
final ExternalAccountCreateParams.Body.Builder funding(JsonField<ExternalAccountCreateParams.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExternalAccountCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalAccountCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalAccountCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalAccountCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalAccountCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalAccountCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumber() .description() .routingNumber()
-
-
-
-