Enum ExternalAccountCreateParams.Funding.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ExternalAccountCreateParams.Funding.Known extends Enum<ExternalAccountCreateParams.Funding.Known>
An enum containing Funding's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ExternalAccountCreateParams.Funding.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CHECKINGA checking account.
SAVINGSA savings account.
GENERAL_LEDGERA general ledger account.
OTHERA different type of account.
-
Method Summary
Modifier and Type Method Description final ExternalAccountCreateParams.Funding.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ExternalAccountCreateParams.Funding.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ExternalAccountCreateParams.Funding.Known>getEntries()An enum containing Funding's known values. -
-
Method Detail
-
valueOf
final ExternalAccountCreateParams.Funding.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ExternalAccountCreateParams.Funding.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ExternalAccountCreateParams.Funding.Known> getEntries()
An enum containing Funding's known values.
-
-
-
-