Class ExternalAccountListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class ExternalAccountListPage implements Page<ExternalAccount>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountListPage.BuilderA builder for ExternalAccountListPage.
-
Method Summary
Modifier and Type Method Description final List<ExternalAccount>data()Delegates to ExternalAccountListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ExternalAccountListPageResponse, but gracefully handles missing data. List<ExternalAccount>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final ExternalAccountListParamsnextPageParams()ExternalAccountListPagenextPage()Returns the page after this one by making another request. final AutoPager<ExternalAccount>autoPager()final ExternalAccountListParamsparams()The parameters that were used to request this page. final ExternalAccountListPageResponseresponse()The response that this page was parsed from. final ExternalAccountListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountListPage.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccountListPage. -
-
Method Detail
-
data
final List<ExternalAccount> data()
Delegates to ExternalAccountListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ExternalAccountListPageResponse, but gracefully handles missing data.
-
items
List<ExternalAccount> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ExternalAccountListParams nextPageParams()
-
nextPage
ExternalAccountListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<ExternalAccount> autoPager()
-
params
final ExternalAccountListParams params()
The parameters that were used to request this page.
-
response
final ExternalAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ExternalAccountListPage.Builder toBuilder()
-
builder
final static ExternalAccountListPage.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccountListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-