Class ExternalAccountListPage.Builder
-
- All Implemented Interfaces:
public final class ExternalAccountListPage.BuilderA builder for ExternalAccountListPage.
-
-
Method Summary
Modifier and Type Method Description final ExternalAccountListPage.Builderservice(ExternalAccountService service)final ExternalAccountListPage.Builderparams(ExternalAccountListParams params)The parameters that were used to request this page. final ExternalAccountListPage.Builderresponse(ExternalAccountListPageResponse response)The response that this page was parsed from. final ExternalAccountListPagebuild()Returns an immutable instance of ExternalAccountListPage. -
-
Method Detail
-
service
final ExternalAccountListPage.Builder service(ExternalAccountService service)
-
params
final ExternalAccountListPage.Builder params(ExternalAccountListParams params)
The parameters that were used to request this page.
-
response
final ExternalAccountListPage.Builder response(ExternalAccountListPageResponse response)
The response that this page was parsed from.
-
build
final ExternalAccountListPage build()
Returns an immutable instance of ExternalAccountListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-