Class ExternalAccountListPageAsync
-
- All Implemented Interfaces:
public final class ExternalAccountListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountListPageAsync.BuilderA builder for ExternalAccountListPageAsync.
public final classExternalAccountListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<ExternalAccount>data()Delegates to ExternalAccountListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ExternalAccountListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<ExternalAccountListParams>getNextPageParams()final CompletableFuture<Optional<ExternalAccountListPageAsync>>getNextPage()final ExternalAccountListPageAsync.AutoPagerautoPager()final ExternalAccountListParamsparams()The parameters that were used to request this page. final ExternalAccountListPageResponseresponse()The response that this page was parsed from. final ExternalAccountListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccountListPageAsync. -
-
Method Detail
-
data
final List<ExternalAccount> data()
Delegates to ExternalAccountListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ExternalAccountListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ExternalAccountListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<ExternalAccountListPageAsync>> getNextPage()
-
autoPager
final ExternalAccountListPageAsync.AutoPager autoPager()
-
params
final ExternalAccountListParams params()
The parameters that were used to request this page.
-
response
final ExternalAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ExternalAccountListPageAsync.Builder toBuilder()
-
builder
final static ExternalAccountListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccountListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-