Class ExternalAccountListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ExternalAccountListPageAsync.BuilderA builder for ExternalAccountListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ExternalAccountListPageAsync.Builderservice(ExternalAccountServiceAsync service)final ExternalAccountListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final ExternalAccountListPageAsync.Builderparams(ExternalAccountListParams params)The parameters that were used to request this page. final ExternalAccountListPageAsync.Builderresponse(ExternalAccountListPageResponse response)The response that this page was parsed from. final ExternalAccountListPageAsyncbuild()Returns an immutable instance of ExternalAccountListPageAsync. -
-
Method Detail
-
service
final ExternalAccountListPageAsync.Builder service(ExternalAccountServiceAsync service)
-
streamHandlerExecutor
final ExternalAccountListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final ExternalAccountListPageAsync.Builder params(ExternalAccountListParams params)
The parameters that were used to request this page.
-
response
final ExternalAccountListPageAsync.Builder response(ExternalAccountListPageResponse response)
The response that this page was parsed from.
-
build
final ExternalAccountListPageAsync build()
Returns an immutable instance of ExternalAccountListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-