Class ExternalAccountUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExternalAccountUpdateParams implements Params
Update an External Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountUpdateParams.BuilderA builder for ExternalAccountUpdateParams.
public final classExternalAccountUpdateParams.Bodypublic final classExternalAccountUpdateParams.AccountHolderThe type of entity that owns the External Account.
public final classExternalAccountUpdateParams.FundingThe funding type of the External Account.
public final classExternalAccountUpdateParams.StatusThe status of the External Account.
-
Method Summary
Modifier and Type Method Description final Optional<String>externalAccountId()The external account identifier. final Optional<ExternalAccountUpdateParams.AccountHolder>accountHolder()The type of entity that owns the External Account. final Optional<String>description()The description you choose to give the external account. final Optional<ExternalAccountUpdateParams.Funding>funding()The funding type of the External Account. final Optional<ExternalAccountUpdateParams.Status>status()The status of the External Account. final JsonField<ExternalAccountUpdateParams.AccountHolder>_accountHolder()Returns the raw JSON value of accountHolder. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<ExternalAccountUpdateParams.Funding>_funding()Returns the raw JSON value of funding. final JsonField<ExternalAccountUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExternalAccountUpdateParams.BuildertoBuilder()final ExternalAccountUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountUpdateParamsnone()final static ExternalAccountUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccountUpdateParams. -
-
Method Detail
-
externalAccountId
final Optional<String> externalAccountId()
The external account identifier.
-
accountHolder
final Optional<ExternalAccountUpdateParams.AccountHolder> accountHolder()
The type of entity that owns the External Account.
-
description
final Optional<String> description()
The description you choose to give the external account.
-
funding
final Optional<ExternalAccountUpdateParams.Funding> funding()
The funding type of the External Account.
-
status
final Optional<ExternalAccountUpdateParams.Status> status()
The status of the External Account.
-
_accountHolder
final JsonField<ExternalAccountUpdateParams.AccountHolder> _accountHolder()
Returns the raw JSON value of accountHolder.
Unlike accountHolder, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<ExternalAccountUpdateParams.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ExternalAccountUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExternalAccountUpdateParams.Builder toBuilder()
-
_body
final ExternalAccountUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ExternalAccountUpdateParams none()
-
builder
final static ExternalAccountUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccountUpdateParams.
-
-
-
-