Class ExternalAccountUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ExternalAccountUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountHolder
final ExternalAccountUpdateParams.Body.Builder accountHolder(ExternalAccountUpdateParams.AccountHolder accountHolder)
The type of entity that owns the External Account.
-
accountHolder
final ExternalAccountUpdateParams.Body.Builder accountHolder(JsonField<ExternalAccountUpdateParams.AccountHolder> accountHolder)
Sets Builder.accountHolder to an arbitrary JSON value.
You should usually call Builder.accountHolder with a well-typed AccountHolder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final ExternalAccountUpdateParams.Body.Builder description(String description)
The description you choose to give the external account.
-
description
final ExternalAccountUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final ExternalAccountUpdateParams.Body.Builder funding(ExternalAccountUpdateParams.Funding funding)
The funding type of the External Account.
-
funding
final ExternalAccountUpdateParams.Body.Builder funding(JsonField<ExternalAccountUpdateParams.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final ExternalAccountUpdateParams.Body.Builder status(ExternalAccountUpdateParams.Status status)
The status of the External Account.
-
status
final ExternalAccountUpdateParams.Body.Builder status(JsonField<ExternalAccountUpdateParams.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExternalAccountUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExternalAccountUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExternalAccountUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExternalAccountUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExternalAccountUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExternalAccountUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-