Class FednowTransfer
-
- All Implemented Interfaces:
public final class FednowTransferFedNow transfers move funds, within seconds, between your Increase account and any other account supporting FedNow.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFednowTransfer.BuilderA builder for FednowTransfer.
public final classFednowTransfer.AcknowledgementIf the transfer is acknowledged by the recipient bank, this will contain supplemental details.
public final classFednowTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classFednowTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For FedNow transfers this is always equal to
USD.public final classFednowTransfer.RejectionIf the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details.
public final classFednowTransfer.StatusThe lifecycle status of the transfer.
public final classFednowTransfer.SubmissionAfter the transfer is submitted to FedNow, this will contain supplemental details.
public final classFednowTransfer.TypeA constant representing the object's type. For this resource it will always be
fednow_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The FedNow Transfer's identifier. final StringaccountId()The Account from which the transfer was sent. final StringaccountNumber()The destination account number. final Optional<FednowTransfer.Acknowledgement>acknowledgement()If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final Longamount()The transfer amount in USD cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<FednowTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final StringcreditorName()The name of the transfer's recipient. final FednowTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final StringdebtorName()The name of the transfer's sender. final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<FednowTransfer.Rejection>rejection()If the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details. final StringroutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final StringsourceAccountNumberId()The Account Number the recipient will see as having sent the transfer. final FednowTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<FednowTransfer.Submission>submission()After the transfer is submitted to FedNow, this will contain supplemental details. final Optional<String>transactionId()The Transaction funding the transfer once it is complete. final FednowTransfer.Typetype()A constant representing the object's type. final StringuniqueEndToEndTransactionReference()The Unique End-to-end Transaction Reference (UETR) of the transfer. final StringunstructuredRemittanceInformation()Unstructured information that will show on the recipient's bank statement. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<FednowTransfer.Acknowledgement>_acknowledgement()Returns the raw JSON value of acknowledgement. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<FednowTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<FednowTransfer.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<FednowTransfer.Rejection>_rejection()Returns the raw JSON value of rejection. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<FednowTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<FednowTransfer.Submission>_submission()Returns the raw JSON value of submission. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<FednowTransfer.Type>_type()Returns the raw JSON value of type. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final FednowTransfer.BuildertoBuilder()final FednowTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FednowTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of FednowTransfer. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
acknowledgement
final Optional<FednowTransfer.Acknowledgement> acknowledgement()
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<FednowTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
creditorName
final String creditorName()
The name of the transfer's recipient. This is set by the sender when creating the transfer.
-
currency
final FednowTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For FedNow transfers this is always equal to
USD.
-
debtorName
final String debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer.
-
rejection
final Optional<FednowTransfer.Rejection> rejection()
If the transfer is rejected by FedNow or the destination financial institution, this will contain supplemental details.
-
routingNumber
final String routingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number the recipient will see as having sent the transfer.
-
status
final FednowTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<FednowTransfer.Submission> submission()
After the transfer is submitted to FedNow, this will contain supplemental details.
-
transactionId
final Optional<String> transactionId()
The Transaction funding the transfer once it is complete.
-
type
final FednowTransfer.Type type()
A constant representing the object's type. For this resource it will always be
fednow_transfer.
-
uniqueEndToEndTransactionReference
final String uniqueEndToEndTransactionReference()
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_acknowledgement
final JsonField<FednowTransfer.Acknowledgement> _acknowledgement()
Returns the raw JSON value of acknowledgement.
Unlike acknowledgement, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<FednowTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<FednowTransfer.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_rejection
final JsonField<FednowTransfer.Rejection> _rejection()
Returns the raw JSON value of rejection.
Unlike rejection, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<FednowTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<FednowTransfer.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<FednowTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FednowTransfer.Builder toBuilder()
-
validate
final FednowTransfer validate()
-
builder
final static FednowTransfer.Builder builder()
Returns a mutable builder for constructing an instance of FednowTransfer.
The following fields are required:
.id() .accountId() .accountNumber() .acknowledgement() .amount() .createdAt() .createdBy() .creditorName() .currency() .debtorName() .externalAccountId() .idempotencyKey() .pendingTransactionId() .rejection() .routingNumber() .sourceAccountNumberId() .status() .submission() .transactionId() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation()
-
-
-
-