Class FednowTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class FednowTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFednowTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The amount, in minor units, to send to the creditor. final StringcreditorName()The creditor's name. final StringdebtorName()The debtor's name. final StringsourceAccountNumberId()The Account Number to include in the transfer as the debtor's account number. final StringunstructuredRemittanceInformation()Unstructured remittance information to include in the transfer. final Optional<String>accountNumber()The creditor's account number. final Optional<FednowTransferCreateParams.CreditorAddress>creditorAddress()The creditor's address. final Optional<FednowTransferCreateParams.DebtorAddress>debtorAddress()The debtor's address. final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The creditor's bank account routing number. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<FednowTransferCreateParams.CreditorAddress>_creditorAddress()Returns the raw JSON value of creditorAddress. final JsonField<FednowTransferCreateParams.DebtorAddress>_debtorAddress()Returns the raw JSON value of debtorAddress. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final Map<String, JsonValue>_additionalProperties()final FednowTransferCreateParams.Body.BuildertoBuilder()final FednowTransferCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FednowTransferCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
creditorName
final String creditorName()
The creditor's name.
-
debtorName
final String debtorName()
The debtor's name.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number to include in the transfer as the debtor's account number.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Unstructured remittance information to include in the transfer.
-
accountNumber
final Optional<String> accountNumber()
The creditor's account number.
-
creditorAddress
final Optional<FednowTransferCreateParams.CreditorAddress> creditorAddress()
The creditor's address.
-
debtorAddress
final Optional<FednowTransferCreateParams.DebtorAddress> debtorAddress()
The debtor's address.
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The creditor's bank account routing number.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddress
final JsonField<FednowTransferCreateParams.CreditorAddress> _creditorAddress()
Returns the raw JSON value of creditorAddress.
Unlike creditorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddress
final JsonField<FednowTransferCreateParams.DebtorAddress> _debtorAddress()
Returns the raw JSON value of debtorAddress.
Unlike debtorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FednowTransferCreateParams.Body.Builder toBuilder()
-
validate
final FednowTransferCreateParams.Body validate()
-
builder
final static FednowTransferCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount() .creditorName() .debtorName() .sourceAccountNumberId() .unstructuredRemittanceInformation()
-
-
-
-