Class FednowTransferCreateParams.DebtorAddress
-
- All Implemented Interfaces:
public final class FednowTransferCreateParams.DebtorAddressThe debtor's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFednowTransferCreateParams.DebtorAddress.BuilderA builder for DebtorAddress.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city, district, town, or village of the address. final StringpostalCode()The postal code component of the address. final Stringstate()The US state component of the address. final Optional<String>line1()The first line of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_line1()Returns the raw JSON value of line1. final Map<String, JsonValue>_additionalProperties()final FednowTransferCreateParams.DebtorAddress.BuildertoBuilder()final FednowTransferCreateParams.DebtorAddressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FednowTransferCreateParams.DebtorAddress.Builderbuilder()Returns a mutable builder for constructing an instance of DebtorAddress. -
-
Method Detail
-
postalCode
final String postalCode()
The postal code component of the address.
-
line1
final Optional<String> line1()
The first line of the address. This is usually the street number and street.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FednowTransferCreateParams.DebtorAddress.Builder toBuilder()
-
validate
final FednowTransferCreateParams.DebtorAddress validate()
-
builder
final static FednowTransferCreateParams.DebtorAddress.Builder builder()
Returns a mutable builder for constructing an instance of DebtorAddress.
The following fields are required:
.city() .postalCode() .state()
-
-
-
-