Class FileLink
-
- All Implemented Interfaces:
public final class FileLinkFile Links let you generate a URL that can be used to download a File.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileLink.BuilderA builder for FileLink.
public final classFileLink.TypeA constant representing the object's type. For this resource it will always be
file_link.
-
Method Summary
Modifier and Type Method Description final Stringid()The File Link identifier. final OffsetDateTimecreatedAt()The ISO 8601 time at which the File Link was created. final OffsetDateTimeexpiresAt()The ISO 8601 time at which the File Link will expire. final StringfileId()The identifier of the File the File Link points to. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final FileLink.Typetype()A constant representing the object's type. final StringunauthenticatedUrl()A URL where the File can be downloaded. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<FileLink.Type>_type()Returns the raw JSON value of type. final JsonField<String>_unauthenticatedUrl()Returns the raw JSON value of unauthenticatedUrl. final Map<String, JsonValue>_additionalProperties()final FileLink.BuildertoBuilder()final FileLinkvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileLink.Builderbuilder()Returns a mutable builder for constructing an instance of FileLink. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the File Link was created.
-
expiresAt
final OffsetDateTime expiresAt()
The ISO 8601 time at which the File Link will expire.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final FileLink.Type type()
A constant representing the object's type. For this resource it will always be
file_link.
-
unauthenticatedUrl
final String unauthenticatedUrl()
A URL where the File can be downloaded. The URL will expire after the
expires_attime. This URL is unauthenticated and can be used to download the File without an Increase API key.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<FileLink.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_unauthenticatedUrl
final JsonField<String> _unauthenticatedUrl()
Returns the raw JSON value of unauthenticatedUrl.
Unlike unauthenticatedUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileLink.Builder toBuilder()
-
validate
final FileLink validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileLink.Builder builder()
Returns a mutable builder for constructing an instance of FileLink.
The following fields are required:
.id() .createdAt() .expiresAt() .fileId() .idempotencyKey() .type() .unauthenticatedUrl()
-
-
-
-