Class FileLink.Builder
-
- All Implemented Interfaces:
public final class FileLink.BuilderA builder for FileLink.
-
-
Method Summary
Modifier and Type Method Description final FileLink.Builderid(String id)The File Link identifier. final FileLink.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final FileLink.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the File Link was created. final FileLink.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final FileLink.BuilderexpiresAt(OffsetDateTime expiresAt)The ISO 8601 time at which the File Link will expire. final FileLink.BuilderexpiresAt(JsonField<OffsetDateTime> expiresAt)Sets Builder.expiresAt to an arbitrary JSON value. final FileLink.BuilderfileId(String fileId)The identifier of the File the File Link points to. final FileLink.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final FileLink.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final FileLink.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final FileLink.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final FileLink.Buildertype(FileLink.Type type)A constant representing the object's type. final FileLink.Buildertype(JsonField<FileLink.Type> type)Sets Builder.type to an arbitrary JSON value. final FileLink.BuilderunauthenticatedUrl(String unauthenticatedUrl)A URL where the File can be downloaded. final FileLink.BuilderunauthenticatedUrl(JsonField<String> unauthenticatedUrl)Sets Builder.unauthenticatedUrl to an arbitrary JSON value. final FileLink.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final FileLink.BuilderputAdditionalProperty(String key, JsonValue value)final FileLink.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final FileLink.BuilderremoveAdditionalProperty(String key)final FileLink.BuilderremoveAllAdditionalProperties(Set<String> keys)final FileLinkbuild()Returns an immutable instance of FileLink. -
-
Method Detail
-
id
final FileLink.Builder id(String id)
The File Link identifier.
-
id
final FileLink.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final FileLink.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the File Link was created.
-
createdAt
final FileLink.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
expiresAt
final FileLink.Builder expiresAt(OffsetDateTime expiresAt)
The ISO 8601 time at which the File Link will expire.
-
expiresAt
final FileLink.Builder expiresAt(JsonField<OffsetDateTime> expiresAt)
Sets Builder.expiresAt to an arbitrary JSON value.
You should usually call Builder.expiresAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final FileLink.Builder fileId(String fileId)
The identifier of the File the File Link points to.
-
fileId
final FileLink.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final FileLink.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final FileLink.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final FileLink.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final FileLink.Builder type(FileLink.Type type)
A constant representing the object's type. For this resource it will always be
file_link.
-
type
final FileLink.Builder type(JsonField<FileLink.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unauthenticatedUrl
final FileLink.Builder unauthenticatedUrl(String unauthenticatedUrl)
A URL where the File can be downloaded. The URL will expire after the
expires_attime. This URL is unauthenticated and can be used to download the File without an Increase API key.
-
unauthenticatedUrl
final FileLink.Builder unauthenticatedUrl(JsonField<String> unauthenticatedUrl)
Sets Builder.unauthenticatedUrl to an arbitrary JSON value.
You should usually call Builder.unauthenticatedUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileLink.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileLink.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileLink.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileLink.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileLink.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-