Class FileLinkCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class FileLinkCreateParams implements Params
Create a File Link
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileLinkCreateParams.BuilderA builder for FileLinkCreateParams.
public final classFileLinkCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringfileId()The File to create a File Link for. final Optional<OffsetDateTime>expiresAt()The time at which the File Link will expire. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FileLinkCreateParams.BuildertoBuilder()final FileLinkCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileLinkCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of FileLinkCreateParams. -
-
Method Detail
-
expiresAt
final Optional<OffsetDateTime> expiresAt()
The time at which the File Link will expire. The default is 1 hour from the time of the request. The maximum is 1 day from the time of the request.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FileLinkCreateParams.Builder toBuilder()
-
_body
final FileLinkCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static FileLinkCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of FileLinkCreateParams.
The following fields are required:
.fileId()
-
-
-
-