Package com.increase.api.models.filelinks
See: Description
-
Class Summary Class Description Builder A builder for FileLink. Type A constant representing the object's type. FileLink File Links let you generate a URL that can be used to download a File. Builder A builder for FileLinkCreateParams. Builder A builder for Body. Body FileLinkCreateParams Create a File Link