Class File

  • All Implemented Interfaces:

    
    public final class File
    
                        

    Files are objects that represent a file hosted on Increase's servers. The file may have been uploaded by you (for example, when uploading a check image) or it may have been created by Increase (for example, an autogenerated statement PDF). If you need to download a File, use the /files/{file_id}/contents endpoint. If you need to share a File with someone who doesn't have access to your API key, create a File Link.