Enum File.Direction.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum File.Direction.Value extends Enum<File.Direction.Value>
An enum containing Direction's known values, as well as an _UNKNOWN member.
An instance of Direction can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<File.Direction.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description TO_INCREASEThis File was sent by you to Increase.
FROM_INCREASEThis File was generated by Increase.
_UNKNOWNAn enum member indicating that Direction was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final File.Direction.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<File.Direction.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<File.Direction.Value>getEntries()An enum containing Direction's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final File.Direction.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<File.Direction.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<File.Direction.Value> getEntries()
An enum containing Direction's known values, as well as an _UNKNOWN member.
An instance of Direction can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-