Class FileContentsParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class FileContentsParams implements Params
Download the contents of a File. Responds with a 307 redirect whose
Locationheader points at a short-lived, pre-signed URL. Our /documentation/software-development-kits follow the redirect and return the File's contents; if you call the API directly, follow the redirect to download it. The pre-signed URL serves the File with aContent-Typematching itsmimeand aContent-Dispositionheader set to itsfilename. It expires in 10 minutes. To share a File with someone who doesn't have access to your API key, create a File Link.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileContentsParams.BuilderA builder for FileContentsParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>fileId()The identifier of the File. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FileContentsParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileContentsParamsnone()final static FileContentsParams.Builderbuilder()Returns a mutable builder for constructing an instance of FileContentsParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FileContentsParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static FileContentsParams none()
-
builder
final static FileContentsParams.Builder builder()
Returns a mutable builder for constructing an instance of FileContentsParams.
-
-
-
-