Class FileCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class FileCreateParams
     implements Params
                        

    To upload a file to Increase, you'll need to send a request of Content-Type multipart/form-data. The request should contain the file you would like to upload, as well as the parameters for creating a file.