Class FileCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class FileCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
file
final FileCreateParams.Body.Builder file(InputStream file)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
file
final FileCreateParams.Body.Builder file(MultipartField<InputStream> file)
Sets Builder.file to an arbitrary multipart value.
You should usually call Builder.file with a well-typed InputStream value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
file
final FileCreateParams.Body.Builder file(ByteArray file)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
file
final FileCreateParams.Body.Builder file(Path path)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
purpose
final FileCreateParams.Body.Builder purpose(FileCreateParams.Purpose purpose)
What the File will be used for in Increase's systems.
-
purpose
final FileCreateParams.Body.Builder purpose(MultipartField<FileCreateParams.Purpose> purpose)
Sets Builder.purpose to an arbitrary multipart value.
You should usually call Builder.purpose with a well-typed Purpose value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final FileCreateParams.Body.Builder description(String description)
The description you choose to give the File.
-
description
final FileCreateParams.Body.Builder description(MultipartField<String> description)
Sets Builder.description to an arbitrary multipart value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.file() .purpose()
-
-
-
-