Enum FileCreateParams.Purpose.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum FileCreateParams.Purpose.Value extends Enum<FileCreateParams.Purpose.Value>
An enum containing Purpose's known values, as well as an _UNKNOWN member.
An instance of Purpose can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<FileCreateParams.Purpose.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARD_DISPUTE_ATTACHMENTA file to be attached to a Card Dispute.
CHECK_IMAGE_FRONTAn image of the front of a check, used for check deposits.
CHECK_IMAGE_BACKAn image of the back of a check, used for check deposits.
MAILED_CHECK_IMAGEAn image of a check that was mailed to a recipient.
CHECK_ATTACHMENTA document to be printed on an additional page and mailed with a check that you've requested Increase print. This must be a PDF whose pages are all US letter size and all have the same orientation.
CHECK_VOUCHER_IMAGEAn image to be used as the check voucher image, which is printed in the middle of the trifold area of a check. This must be a 2550x1100 pixel PNG.
CHECK_SIGNATUREA signature image to be printed on a check. This must be a 1320x120 pixel PNG.
FORM_SS_4IRS Form SS-4.
IDENTITY_DOCUMENTAn image of a government-issued ID.
LOAN_APPLICATION_SUPPLEMENTAL_DOCUMENTA supplemental document for a Loan Application.
OTHERA file purpose not covered by any of the other cases.
TRUST_FORMATION_DOCUMENTA legal document forming a trust.
DIGITAL_WALLET_ARTWORKA card image to be rendered inside digital wallet apps. This must be a 1536x969 pixel PNG.
DIGITAL_WALLET_APP_ICONAn icon for you app to be rendered inside digital wallet apps. This must be a 100x100 pixel PNG.
PHYSICAL_CARD_FRONTA card image to be printed on the front of a physical card. This must be a 2100x1344 pixel PNG with no other color but black.
PHYSICAL_CARD_CARRIERAn image representing the entirety of the carrier used for a physical card. This must be a 2550x3300 pixel PNG with no other color but black.
DOCUMENT_REQUESTA document requested by Increase.
ENTITY_SUPPLEMENTAL_DOCUMENTA supplemental document associated an an Entity.
UNUSUAL_ACTIVITY_REPORT_ATTACHMENTAn attachment to an Unusual Activity Report.
PROOF_OF_AUTHORIZATION_REQUEST_SUBMISSIONA file containing additional evidence for a Proof of Authorization Request Submission.
_UNKNOWNAn enum member indicating that Purpose was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final FileCreateParams.Purpose.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<FileCreateParams.Purpose.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<FileCreateParams.Purpose.Value>getEntries()An enum containing Purpose's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final FileCreateParams.Purpose.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<FileCreateParams.Purpose.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<FileCreateParams.Purpose.Value> getEntries()
An enum containing Purpose's known values, as well as an _UNKNOWN member.
An instance of Purpose can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-