Package com.increase.api.models.files
Class FileListPageAsync
-
- All Implemented Interfaces:
public final class FileListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileListPageAsync.BuilderA builder for FileListPageAsync.
public final classFileListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<File>data()Delegates to FileListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to FileListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<FileListParams>getNextPageParams()final CompletableFuture<Optional<FileListPageAsync>>getNextPage()final FileListPageAsync.AutoPagerautoPager()final FileListParamsparams()The parameters that were used to request this page. final FileListPageResponseresponse()The response that this page was parsed from. final FileListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of FileListPageAsync. -
-
Method Detail
-
data
final List<File> data()
Delegates to FileListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to FileListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<FileListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<FileListPageAsync>> getNextPage()
-
autoPager
final FileListPageAsync.AutoPager autoPager()
-
params
final FileListParams params()
The parameters that were used to request this page.
-
response
final FileListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final FileListPageAsync.Builder toBuilder()
-
builder
final static FileListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of FileListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-