Package com.increase.api.models.files
Class FileListPageResponse
-
- All Implemented Interfaces:
public final class FileListPageResponseA list of File objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileListPageResponse.BuilderA builder for FileListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<File>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<File>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final FileListPageResponse.BuildertoBuilder()final FileListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FileListPageResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<File>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileListPageResponse.Builder toBuilder()
-
validate
final FileListPageResponse validate()
-
builder
final static FileListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of FileListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-