Package com.increase.api.models.files
Class FileListParams.Purpose
-
- All Implemented Interfaces:
public final class FileListParams.Purpose
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileListParams.Purpose.BuilderA builder for Purpose.
public final classFileListParams.Purpose.In
-
Method Summary
Modifier and Type Method Description final Optional<List<FileListParams.Purpose.In>>in_()Filter Files for those with the specified purpose or purposes. final QueryParams_additionalProperties()Query params to send with the request. final FileListParams.Purpose.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileListParams.Purpose.Builderbuilder()Returns a mutable builder for constructing an instance of Purpose. -
-
Method Detail
-
in_
final Optional<List<FileListParams.Purpose.In>> in_()
Filter Files for those with the specified purpose or purposes. For GET requests, this should be encoded as a comma-delimited string, such as
?in=one,two,three.
-
_additionalProperties
final QueryParams _additionalProperties()
Query params to send with the request.
-
toBuilder
final FileListParams.Purpose.Builder toBuilder()
-
builder
final static FileListParams.Purpose.Builder builder()
Returns a mutable builder for constructing an instance of Purpose.
-
-
-
-