Enum FileListParams.Purpose.In.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum FileListParams.Purpose.In.Value extends Enum<FileListParams.Purpose.In.Value>
An enum containing In's known values, as well as an _UNKNOWN member.
An instance of In can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<FileListParams.Purpose.In.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CARD_DISPUTE_ATTACHMENTA file to be attached to a Card Dispute.
CHECK_IMAGE_FRONTAn image of the front of a check, used for check deposits.
CHECK_IMAGE_BACKAn image of the back of a check, used for check deposits.
PROCESSED_CHECK_IMAGE_FRONTAn image of the front of a deposited check after processing by Increase and submission to the Federal Reserve.
PROCESSED_CHECK_IMAGE_BACKAn image of the back of a deposited check after processing by Increase and submission to the Federal Reserve.
MAILED_CHECK_IMAGEAn image of a check that was mailed to a recipient.
CHECK_ATTACHMENTA document to be printed on an additional page and mailed with a check that you've requested Increase print. This must be a PDF whose pages are all US letter size and all have the same orientation.
CHECK_VOUCHER_IMAGEAn image to be used as the check voucher image, which is printed in the middle of the trifold area of a check. This must be a 2550x1100 pixel PNG.
CHECK_SIGNATUREA signature image to be printed on a check. This must be a 1320x120 pixel PNG.
INBOUND_MAIL_ITEMA scanned mail item sent to Increase.
FORM_1099_INTIRS Form 1099-INT.
FORM_1099_MISCIRS Form 1099-MISC.
FORM_SS_4IRS Form SS-4.
IDENTITY_DOCUMENTAn image of a government-issued ID.
INCREASE_STATEMENTA statement generated by Increase.
LOAN_APPLICATION_SUPPLEMENTAL_DOCUMENTA supplemental document for a Loan Application.
OTHERA file purpose not covered by any of the other cases.
TRUST_FORMATION_DOCUMENTA legal document forming a trust.
DIGITAL_WALLET_ARTWORKA card image to be rendered inside digital wallet apps. This must be a 1536x969 pixel PNG.
DIGITAL_WALLET_APP_ICONAn icon for you app to be rendered inside digital wallet apps. This must be a 100x100 pixel PNG.
PHYSICAL_CARD_FRONTA card image to be printed on the front of a physical card. This must be a 2100x1344 pixel PNG with no other color but black.
PHYSICAL_CARD_BACKThe image to be printed on the back of a physical card.
PHYSICAL_CARD_CARRIERAn image representing the entirety of the carrier used for a physical card. This must be a 2550x3300 pixel PNG with no other color but black.
DOCUMENT_REQUESTA document requested by Increase.
ENTITY_SUPPLEMENTAL_DOCUMENTA supplemental document associated an an Entity.
EXPORTThe results of an Export you requested via the dashboard or API.
FEE_STATEMENTA fee statement.
UNUSUAL_ACTIVITY_REPORT_ATTACHMENTAn attachment to an Unusual Activity Report.
DEPOSIT_ACCOUNT_CONTROL_AGREEMENTA document granting another entity access to the funds into your account.
PROOF_OF_AUTHORIZATION_REQUEST_SUBMISSIONA file containing additional evidence for a Proof of Authorization Request Submission.
ACCOUNT_VERIFICATION_LETTERAn account verification letter.
FUNDING_INSTRUCTIONSFunding instructions.
HOLD_HARMLESS_LETTERA Hold Harmless Letter.
_UNKNOWNAn enum member indicating that In was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final FileListParams.Purpose.In.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<FileListParams.Purpose.In.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<FileListParams.Purpose.In.Value>getEntries()An enum containing In's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final FileListParams.Purpose.In.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<FileListParams.Purpose.In.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<FileListParams.Purpose.In.Value> getEntries()
An enum containing In's known values, as well as an _UNKNOWN member.
An instance of In can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-