Package com.increase.api.models.files
Class FileListResponse
-
- All Implemented Interfaces:
public final class FileListResponseA list of File objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileListResponse.BuilderA builder for FileListResponse.
-
Method Summary
Modifier and Type Method Description final List<File>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<File>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final FileListResponse.BuildertoBuilder()final FileListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FileListResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<File>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileListResponse.Builder toBuilder()
-
validate
final FileListResponse validate()
-
builder
final static FileListResponse.Builder builder()
Returns a mutable builder for constructing an instance of FileListResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-