Package com.increase.api.models.files
See: Description
-
Class Summary Class Description Builder A builder for File. Direction Whether the File was generated by Increase or by you and sent to Increase. Purpose What the File will be used for. Type A constant representing the object's type. File Files are objects that represent a file hosted on Increase's servers. Builder A builder for FileCreateParams. Builder A builder for Body. Body Purpose What the File will be used for in Increase's systems. FileCreateParams To upload a file to Increase, you'll need to send a request of Content-Type multipart/form-data.Builder A builder for FileListPage. FileListPage Builder A builder for FileListPageAsync. FileListPageAsync Builder A builder for FileListPageResponse. FileListPageResponse A list of File objects. Builder A builder for FileListParams. Builder A builder for CreatedAt. CreatedAt Builder A builder for Purpose. In Purpose FileListParams List Files Builder A builder for FileRetrieveParams. FileRetrieveParams Retrieve a File -
Enum Summary Enum Description Known An enum containing Direction's known values. Value An enum containing Direction's known values, as well as an _UNKNOWN member. Known An enum containing Purpose's known values. Value An enum containing Purpose's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing Purpose's known values. Value An enum containing Purpose's known values, as well as an _UNKNOWN member. Known An enum containing In's known values. Value An enum containing In's known values, as well as an _UNKNOWN member.