Class Group
-
- All Implemented Interfaces:
public final class GroupGroups represent organizations using Increase. You can retrieve information about your own organization via the API. More commonly, OAuth platforms can retrieve information about the organizations that have granted them access. Learn more about OAuth here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroup.BuilderA builder for Group.
public final classGroup.TypeA constant representing the object's type. For this resource it will always be
group.
-
Method Summary
Modifier and Type Method Description final Stringid()The Group identifier. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Group was created. final Group.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Group.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Group.BuildertoBuilder()final Groupvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Group.Builderbuilder()Returns a mutable builder for constructing an instance of Group. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Group was created.
-
type
final Group.Type type()
A constant representing the object's type. For this resource it will always be
group.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Group.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Group.Builder toBuilder()
-
validate
final Group validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Group.Builder builder()
Returns a mutable builder for constructing an instance of Group.
The following fields are required:
.id() .createdAt() .type()
-
-
-
-