Class InboundAchTransfer
-
- All Implemented Interfaces:
public final class InboundAchTransferAn Inbound ACH Transfer is an ACH transfer initiated outside of Increase to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.BuilderA builder for InboundAchTransfer.
public final classInboundAchTransfer.AcceptanceIf your transfer is accepted, this will contain details of the acceptance.
public final classInboundAchTransfer.AddendaAdditional information sent from the originator.
public final classInboundAchTransfer.DeclineIf your transfer is declined, this will contain details of the decline.
public final classInboundAchTransfer.DirectionThe direction of the transfer.
public final classInboundAchTransfer.InternationalAddendaIf the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
public final classInboundAchTransfer.NotificationOfChangeIf you initiate a notification of change in response to the transfer, this will contain its details.
public final classInboundAchTransfer.SettlementA subhash containing information about when and how the transfer settled at the Federal Reserve.
public final classInboundAchTransfer.StandardEntryClassCodeThe Standard Entry Class (SEC) code of the transfer.
public final classInboundAchTransfer.StatusThe status of the transfer.
public final classInboundAchTransfer.TransferReturnIf your transfer is returned, this will contain details of the return.
public final classInboundAchTransfer.TypeA constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The inbound ACH transfer's identifier. final Optional<InboundAchTransfer.Acceptance>acceptance()If your transfer is accepted, this will contain details of the acceptance. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumberId()The identifier of the Account Number to which this transfer was sent. final Optional<InboundAchTransfer.Addenda>addenda()Additional information sent from the originator. final Longamount()The transfer amount in USD cents. final OffsetDateTimeautomaticallyResolvesAt()The time at which the transfer will be automatically resolved. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound ACH transfer was created. final Optional<InboundAchTransfer.Decline>decline()If your transfer is declined, this will contain details of the decline. final InboundAchTransfer.Directiondirection()The direction of the transfer. final LocalDateeffectiveDate()The effective date of the transfer. final Optional<InboundAchTransfer.InternationalAddenda>internationalAddenda()If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction. final Optional<InboundAchTransfer.NotificationOfChange>notificationOfChange()If you initiate a notification of change in response to the transfer, this will contain its details. final Optional<String>originatorCompanyDescriptiveDate()The descriptive date of the transfer. final Optional<String>originatorCompanyDiscretionaryData()The additional information included with the transfer. final StringoriginatorCompanyEntryDescription()The description of the transfer. final StringoriginatorCompanyId()The id of the company that initiated the transfer. final StringoriginatorCompanyName()The name of the company that initiated the transfer. final StringoriginatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>receiverIdNumber()The id of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final InboundAchTransfer.Settlementsettlement()A subhash containing information about when and how the transfer settled at the Federal Reserve. final InboundAchTransfer.StandardEntryClassCodestandardEntryClassCode()The Standard Entry Class (SEC) code of the transfer. final InboundAchTransfer.Statusstatus()The status of the transfer. final StringtraceNumber()A 15 digit number set by the sending bank and transmitted to the receiving bank. final Optional<InboundAchTransfer.TransferReturn>transferReturn()If your transfer is returned, this will contain details of the return. final InboundAchTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<InboundAchTransfer.Acceptance>_acceptance()Returns the raw JSON value of acceptance. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<InboundAchTransfer.Addenda>_addenda()Returns the raw JSON value of addenda. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_automaticallyResolvesAt()Returns the raw JSON value of automaticallyResolvesAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<InboundAchTransfer.Decline>_decline()Returns the raw JSON value of decline. final JsonField<InboundAchTransfer.Direction>_direction()Returns the raw JSON value of direction. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<InboundAchTransfer.InternationalAddenda>_internationalAddenda()Returns the raw JSON value of internationalAddenda. final JsonField<InboundAchTransfer.NotificationOfChange>_notificationOfChange()Returns the raw JSON value of notificationOfChange. final JsonField<String>_originatorCompanyDescriptiveDate()Returns the raw JSON value of originatorCompanyDescriptiveDate. final JsonField<String>_originatorCompanyDiscretionaryData()Returns the raw JSON value of originatorCompanyDiscretionaryData. final JsonField<String>_originatorCompanyEntryDescription()Returns the raw JSON value of originatorCompanyEntryDescription. final JsonField<String>_originatorCompanyId()Returns the raw JSON value of originatorCompanyId. final JsonField<String>_originatorCompanyName()Returns the raw JSON value of originatorCompanyName. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_receiverIdNumber()Returns the raw JSON value of receiverIdNumber. final JsonField<String>_receiverName()Returns the raw JSON value of receiverName. final JsonField<InboundAchTransfer.Settlement>_settlement()Returns the raw JSON value of settlement. final JsonField<InboundAchTransfer.StandardEntryClassCode>_standardEntryClassCode()Returns the raw JSON value of standardEntryClassCode. final JsonField<InboundAchTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<String>_traceNumber()Returns the raw JSON value of traceNumber. final JsonField<InboundAchTransfer.TransferReturn>_transferReturn()Returns the raw JSON value of transferReturn. final JsonField<InboundAchTransfer.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.BuildertoBuilder()final InboundAchTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAchTransfer. -
-
Method Detail
-
acceptance
final Optional<InboundAchTransfer.Acceptance> acceptance()
If your transfer is accepted, this will contain details of the acceptance.
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
addenda
final Optional<InboundAchTransfer.Addenda> addenda()
Additional information sent from the originator.
-
automaticallyResolvesAt
final OffsetDateTime automaticallyResolvesAt()
The time at which the transfer will be automatically resolved.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound ACH transfer was created.
-
decline
final Optional<InboundAchTransfer.Decline> decline()
If your transfer is declined, this will contain details of the decline.
-
direction
final InboundAchTransfer.Direction direction()
The direction of the transfer.
-
effectiveDate
final LocalDate effectiveDate()
The effective date of the transfer. This is sent by the sending bank and is a factor in determining funds availability.
-
internationalAddenda
final Optional<InboundAchTransfer.InternationalAddenda> internationalAddenda()
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
notificationOfChange
final Optional<InboundAchTransfer.NotificationOfChange> notificationOfChange()
If you initiate a notification of change in response to the transfer, this will contain its details.
-
originatorCompanyDescriptiveDate
final Optional<String> originatorCompanyDescriptiveDate()
The descriptive date of the transfer.
-
originatorCompanyDiscretionaryData
final Optional<String> originatorCompanyDiscretionaryData()
The additional information included with the transfer.
-
originatorCompanyEntryDescription
final String originatorCompanyEntryDescription()
The description of the transfer.
-
originatorCompanyId
final String originatorCompanyId()
The id of the company that initiated the transfer.
-
originatorCompanyName
final String originatorCompanyName()
The name of the company that initiated the transfer.
-
originatorRoutingNumber
final String originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The id of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
settlement
final InboundAchTransfer.Settlement settlement()
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
standardEntryClassCode
final InboundAchTransfer.StandardEntryClassCode standardEntryClassCode()
The Standard Entry Class (SEC) code of the transfer.
-
status
final InboundAchTransfer.Status status()
The status of the transfer.
-
traceNumber
final String traceNumber()
A 15 digit number set by the sending bank and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer. ACH trace numbers are not unique, but are used to correlate returns.
-
transferReturn
final Optional<InboundAchTransfer.TransferReturn> transferReturn()
If your transfer is returned, this will contain details of the return.
-
type
final InboundAchTransfer.Type type()
A constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptance
final JsonField<InboundAchTransfer.Acceptance> _acceptance()
Returns the raw JSON value of acceptance.
Unlike acceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<InboundAchTransfer.Addenda> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_automaticallyResolvesAt
final JsonField<OffsetDateTime> _automaticallyResolvesAt()
Returns the raw JSON value of automaticallyResolvesAt.
Unlike automaticallyResolvesAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_decline
final JsonField<InboundAchTransfer.Decline> _decline()
Returns the raw JSON value of decline.
Unlike decline, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<InboundAchTransfer.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_internationalAddenda
final JsonField<InboundAchTransfer.InternationalAddenda> _internationalAddenda()
Returns the raw JSON value of internationalAddenda.
Unlike internationalAddenda, this method doesn't throw if the JSON field has an unexpected type.
-
_notificationOfChange
final JsonField<InboundAchTransfer.NotificationOfChange> _notificationOfChange()
Returns the raw JSON value of notificationOfChange.
Unlike notificationOfChange, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyDescriptiveDate
final JsonField<String> _originatorCompanyDescriptiveDate()
Returns the raw JSON value of originatorCompanyDescriptiveDate.
Unlike originatorCompanyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyDiscretionaryData
final JsonField<String> _originatorCompanyDiscretionaryData()
Returns the raw JSON value of originatorCompanyDiscretionaryData.
Unlike originatorCompanyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyEntryDescription
final JsonField<String> _originatorCompanyEntryDescription()
Returns the raw JSON value of originatorCompanyEntryDescription.
Unlike originatorCompanyEntryDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyId
final JsonField<String> _originatorCompanyId()
Returns the raw JSON value of originatorCompanyId.
Unlike originatorCompanyId, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorCompanyName
final JsonField<String> _originatorCompanyName()
Returns the raw JSON value of originatorCompanyName.
Unlike originatorCompanyName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
Returns the raw JSON value of receiverIdNumber.
Unlike receiverIdNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverName
final JsonField<String> _receiverName()
Returns the raw JSON value of receiverName.
Unlike receiverName, this method doesn't throw if the JSON field has an unexpected type.
-
_settlement
final JsonField<InboundAchTransfer.Settlement> _settlement()
Returns the raw JSON value of settlement.
Unlike settlement, this method doesn't throw if the JSON field has an unexpected type.
-
_standardEntryClassCode
final JsonField<InboundAchTransfer.StandardEntryClassCode> _standardEntryClassCode()
Returns the raw JSON value of standardEntryClassCode.
Unlike standardEntryClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InboundAchTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_traceNumber
final JsonField<String> _traceNumber()
Returns the raw JSON value of traceNumber.
Unlike traceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_transferReturn
final JsonField<InboundAchTransfer.TransferReturn> _transferReturn()
Returns the raw JSON value of transferReturn.
Unlike transferReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundAchTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransfer.Builder toBuilder()
-
validate
final InboundAchTransfer validate()
-
builder
final static InboundAchTransfer.Builder builder()
Returns a mutable builder for constructing an instance of InboundAchTransfer.
The following fields are required:
.id() .acceptance() .accountId() .accountNumberId() .addenda() .amount() .automaticallyResolvesAt() .createdAt() .decline() .direction() .effectiveDate() .internationalAddenda() .notificationOfChange() .originatorCompanyDescriptiveDate() .originatorCompanyDiscretionaryData() .originatorCompanyEntryDescription() .originatorCompanyId() .originatorCompanyName() .originatorRoutingNumber() .receiverIdNumber() .receiverName() .settlement() .standardEntryClassCode() .status() .traceNumber() .transferReturn() .type()
-
-
-
-