Class InboundAchTransfer.Acceptance
-
- All Implemented Interfaces:
public final class InboundAchTransfer.AcceptanceIf your transfer is accepted, this will contain details of the acceptance.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.Acceptance.BuilderA builder for Acceptance.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The time at which the transfer was accepted. final StringtransactionId()The id of the transaction for the accepted transfer. final JsonField<OffsetDateTime>_acceptedAt()Returns the raw JSON value of acceptedAt. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.Acceptance.BuildertoBuilder()final InboundAchTransfer.Acceptancevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Acceptance.Builderbuilder()Returns a mutable builder for constructing an instance of Acceptance. -
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The time at which the transfer was accepted.
-
transactionId
final String transactionId()
The id of the transaction for the accepted transfer.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransfer.Acceptance.Builder toBuilder()
-
validate
final InboundAchTransfer.Acceptance validate()
-
builder
final static InboundAchTransfer.Acceptance.Builder builder()
Returns a mutable builder for constructing an instance of Acceptance.
The following fields are required:
.acceptedAt() .transactionId()
-
-
-
-