Class InboundAchTransfer.Addenda
-
- All Implemented Interfaces:
public final class InboundAchTransfer.AddendaAdditional information sent from the originator.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.Addenda.BuilderA builder for Addenda.
public final classInboundAchTransfer.Addenda.CategoryThe type of addendum.
public final classInboundAchTransfer.Addenda.FreeformUnstructured
payment_related_informationpassed through by the originator.
-
Method Summary
Modifier and Type Method Description final InboundAchTransfer.Addenda.Categorycategory()The type of addendum. final Optional<InboundAchTransfer.Addenda.Freeform>freeform()Unstructured payment_related_informationpassed through by the originator.final JsonField<InboundAchTransfer.Addenda.Category>_category()Returns the raw JSON value of category. final JsonField<InboundAchTransfer.Addenda.Freeform>_freeform()Returns the raw JSON value of freeform. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.Addenda.BuildertoBuilder()final InboundAchTransfer.Addendavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Addenda.Builderbuilder()Returns a mutable builder for constructing an instance of Addenda. -
-
Method Detail
-
category
final InboundAchTransfer.Addenda.Category category()
The type of addendum.
-
freeform
final Optional<InboundAchTransfer.Addenda.Freeform> freeform()
Unstructured
payment_related_informationpassed through by the originator.
-
_category
final JsonField<InboundAchTransfer.Addenda.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_freeform
final JsonField<InboundAchTransfer.Addenda.Freeform> _freeform()
Returns the raw JSON value of freeform.
Unlike freeform, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransfer.Addenda.Builder toBuilder()
-
validate
final InboundAchTransfer.Addenda validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundAchTransfer.Addenda.Builder builder()
Returns a mutable builder for constructing an instance of Addenda.
The following fields are required:
.category() .freeform()
-
-
-
-