Class InboundAchTransfer.Builder
-
- All Implemented Interfaces:
public final class InboundAchTransfer.BuilderA builder for InboundAchTransfer.
-
-
Method Summary
-
-
Method Detail
-
id
final InboundAchTransfer.Builder id(String id)
The inbound ACH transfer's identifier.
-
id
final InboundAchTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acceptance
final InboundAchTransfer.Builder acceptance(InboundAchTransfer.Acceptance acceptance)
If your transfer is accepted, this will contain details of the acceptance.
-
acceptance
final InboundAchTransfer.Builder acceptance(Optional<InboundAchTransfer.Acceptance> acceptance)
Alias for calling Builder.acceptance with
acceptance.orElse(null).
-
acceptance
final InboundAchTransfer.Builder acceptance(JsonField<InboundAchTransfer.Acceptance> acceptance)
Sets Builder.acceptance to an arbitrary JSON value.
You should usually call Builder.acceptance with a well-typed Acceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final InboundAchTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final InboundAchTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumberId
final InboundAchTransfer.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
accountNumberId
final InboundAchTransfer.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addenda
final InboundAchTransfer.Builder addenda(InboundAchTransfer.Addenda addenda)
Additional information sent from the originator.
-
addenda
final InboundAchTransfer.Builder addenda(Optional<InboundAchTransfer.Addenda> addenda)
Alias for calling Builder.addenda with
addenda.orElse(null).
-
addenda
final InboundAchTransfer.Builder addenda(JsonField<InboundAchTransfer.Addenda> addenda)
Sets Builder.addenda to an arbitrary JSON value.
You should usually call Builder.addenda with a well-typed Addenda value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundAchTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final InboundAchTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
automaticallyResolvesAt
final InboundAchTransfer.Builder automaticallyResolvesAt(OffsetDateTime automaticallyResolvesAt)
The time at which the transfer will be automatically resolved.
-
automaticallyResolvesAt
final InboundAchTransfer.Builder automaticallyResolvesAt(JsonField<OffsetDateTime> automaticallyResolvesAt)
Sets Builder.automaticallyResolvesAt to an arbitrary JSON value.
You should usually call Builder.automaticallyResolvesAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InboundAchTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound ACH transfer was created.
-
createdAt
final InboundAchTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decline
final InboundAchTransfer.Builder decline(InboundAchTransfer.Decline decline)
If your transfer is declined, this will contain details of the decline.
-
decline
final InboundAchTransfer.Builder decline(Optional<InboundAchTransfer.Decline> decline)
Alias for calling Builder.decline with
decline.orElse(null).
-
decline
final InboundAchTransfer.Builder decline(JsonField<InboundAchTransfer.Decline> decline)
Sets Builder.decline to an arbitrary JSON value.
You should usually call Builder.decline with a well-typed Decline value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
direction
final InboundAchTransfer.Builder direction(InboundAchTransfer.Direction direction)
The direction of the transfer.
-
direction
final InboundAchTransfer.Builder direction(JsonField<InboundAchTransfer.Direction> direction)
Sets Builder.direction to an arbitrary JSON value.
You should usually call Builder.direction with a well-typed Direction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveDate
final InboundAchTransfer.Builder effectiveDate(LocalDate effectiveDate)
The effective date of the transfer. This is sent by the sending bank and is a factor in determining funds availability.
-
effectiveDate
final InboundAchTransfer.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
Sets Builder.effectiveDate to an arbitrary JSON value.
You should usually call Builder.effectiveDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
internationalAddenda
final InboundAchTransfer.Builder internationalAddenda(InboundAchTransfer.InternationalAddenda internationalAddenda)
If the Inbound ACH Transfer has a Standard Entry Class Code of IAT, this will contain fields pertaining to the International ACH Transaction.
-
internationalAddenda
final InboundAchTransfer.Builder internationalAddenda(Optional<InboundAchTransfer.InternationalAddenda> internationalAddenda)
Alias for calling Builder.internationalAddenda with
internationalAddenda.orElse(null).
-
internationalAddenda
final InboundAchTransfer.Builder internationalAddenda(JsonField<InboundAchTransfer.InternationalAddenda> internationalAddenda)
Sets Builder.internationalAddenda to an arbitrary JSON value.
You should usually call Builder.internationalAddenda with a well-typed InternationalAddenda value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
notificationOfChange
final InboundAchTransfer.Builder notificationOfChange(InboundAchTransfer.NotificationOfChange notificationOfChange)
If you initiate a notification of change in response to the transfer, this will contain its details.
-
notificationOfChange
final InboundAchTransfer.Builder notificationOfChange(Optional<InboundAchTransfer.NotificationOfChange> notificationOfChange)
Alias for calling Builder.notificationOfChange with
notificationOfChange.orElse(null).
-
notificationOfChange
final InboundAchTransfer.Builder notificationOfChange(JsonField<InboundAchTransfer.NotificationOfChange> notificationOfChange)
Sets Builder.notificationOfChange to an arbitrary JSON value.
You should usually call Builder.notificationOfChange with a well-typed NotificationOfChange value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyDescriptiveDate
final InboundAchTransfer.Builder originatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)
The descriptive date of the transfer.
-
originatorCompanyDescriptiveDate
final InboundAchTransfer.Builder originatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)
Alias for calling Builder.originatorCompanyDescriptiveDate with
originatorCompanyDescriptiveDate.orElse(null).
-
originatorCompanyDescriptiveDate
final InboundAchTransfer.Builder originatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)
Sets Builder.originatorCompanyDescriptiveDate to an arbitrary JSON value.
You should usually call Builder.originatorCompanyDescriptiveDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyDiscretionaryData
final InboundAchTransfer.Builder originatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)
The additional information included with the transfer.
-
originatorCompanyDiscretionaryData
final InboundAchTransfer.Builder originatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)
Alias for calling Builder.originatorCompanyDiscretionaryData with
originatorCompanyDiscretionaryData.orElse(null).
-
originatorCompanyDiscretionaryData
final InboundAchTransfer.Builder originatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)
Sets Builder.originatorCompanyDiscretionaryData to an arbitrary JSON value.
You should usually call Builder.originatorCompanyDiscretionaryData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyEntryDescription
final InboundAchTransfer.Builder originatorCompanyEntryDescription(String originatorCompanyEntryDescription)
The description of the transfer.
-
originatorCompanyEntryDescription
final InboundAchTransfer.Builder originatorCompanyEntryDescription(JsonField<String> originatorCompanyEntryDescription)
Sets Builder.originatorCompanyEntryDescription to an arbitrary JSON value.
You should usually call Builder.originatorCompanyEntryDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyId
final InboundAchTransfer.Builder originatorCompanyId(String originatorCompanyId)
The id of the company that initiated the transfer.
-
originatorCompanyId
final InboundAchTransfer.Builder originatorCompanyId(JsonField<String> originatorCompanyId)
Sets Builder.originatorCompanyId to an arbitrary JSON value.
You should usually call Builder.originatorCompanyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyName
final InboundAchTransfer.Builder originatorCompanyName(String originatorCompanyName)
The name of the company that initiated the transfer.
-
originatorCompanyName
final InboundAchTransfer.Builder originatorCompanyName(JsonField<String> originatorCompanyName)
Sets Builder.originatorCompanyName to an arbitrary JSON value.
You should usually call Builder.originatorCompanyName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final InboundAchTransfer.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final InboundAchTransfer.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverIdNumber
final InboundAchTransfer.Builder receiverIdNumber(String receiverIdNumber)
The id of the receiver of the transfer.
-
receiverIdNumber
final InboundAchTransfer.Builder receiverIdNumber(Optional<String> receiverIdNumber)
Alias for calling Builder.receiverIdNumber with
receiverIdNumber.orElse(null).
-
receiverIdNumber
final InboundAchTransfer.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
Sets Builder.receiverIdNumber to an arbitrary JSON value.
You should usually call Builder.receiverIdNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverName
final InboundAchTransfer.Builder receiverName(String receiverName)
The name of the receiver of the transfer.
-
receiverName
final InboundAchTransfer.Builder receiverName(Optional<String> receiverName)
Alias for calling Builder.receiverName with
receiverName.orElse(null).
-
receiverName
final InboundAchTransfer.Builder receiverName(JsonField<String> receiverName)
Sets Builder.receiverName to an arbitrary JSON value.
You should usually call Builder.receiverName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
settlement
final InboundAchTransfer.Builder settlement(InboundAchTransfer.Settlement settlement)
A subhash containing information about when and how the transfer settled at the Federal Reserve.
-
settlement
final InboundAchTransfer.Builder settlement(JsonField<InboundAchTransfer.Settlement> settlement)
Sets Builder.settlement to an arbitrary JSON value.
You should usually call Builder.settlement with a well-typed Settlement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
standardEntryClassCode
final InboundAchTransfer.Builder standardEntryClassCode(InboundAchTransfer.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code of the transfer.
-
standardEntryClassCode
final InboundAchTransfer.Builder standardEntryClassCode(JsonField<InboundAchTransfer.StandardEntryClassCode> standardEntryClassCode)
Sets Builder.standardEntryClassCode to an arbitrary JSON value.
You should usually call Builder.standardEntryClassCode with a well-typed StandardEntryClassCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InboundAchTransfer.Builder status(InboundAchTransfer.Status status)
The status of the transfer.
-
status
final InboundAchTransfer.Builder status(JsonField<InboundAchTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
traceNumber
final InboundAchTransfer.Builder traceNumber(String traceNumber)
A 15 digit number set by the sending bank and transmitted to the receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer. ACH trace numbers are not unique, but are used to correlate returns.
-
traceNumber
final InboundAchTransfer.Builder traceNumber(JsonField<String> traceNumber)
Sets Builder.traceNumber to an arbitrary JSON value.
You should usually call Builder.traceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferReturn
final InboundAchTransfer.Builder transferReturn(InboundAchTransfer.TransferReturn transferReturn)
If your transfer is returned, this will contain details of the return.
-
transferReturn
final InboundAchTransfer.Builder transferReturn(Optional<InboundAchTransfer.TransferReturn> transferReturn)
Alias for calling Builder.transferReturn with
transferReturn.orElse(null).
-
transferReturn
final InboundAchTransfer.Builder transferReturn(JsonField<InboundAchTransfer.TransferReturn> transferReturn)
Sets Builder.transferReturn to an arbitrary JSON value.
You should usually call Builder.transferReturn with a well-typed TransferReturn value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundAchTransfer.Builder type(InboundAchTransfer.Type type)
A constant representing the object's type. For this resource it will always be
inbound_ach_transfer.
-
type
final InboundAchTransfer.Builder type(JsonField<InboundAchTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundAchTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundAchTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundAchTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundAchTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundAchTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundAchTransfer build()
Returns an immutable instance of InboundAchTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .acceptance() .accountId() .accountNumberId() .addenda() .amount() .automaticallyResolvesAt() .createdAt() .decline() .direction() .effectiveDate() .internationalAddenda() .notificationOfChange() .originatorCompanyDescriptiveDate() .originatorCompanyDiscretionaryData() .originatorCompanyEntryDescription() .originatorCompanyId() .originatorCompanyName() .originatorRoutingNumber() .receiverIdNumber() .receiverName() .settlement() .standardEntryClassCode() .status() .traceNumber() .transferReturn() .type()
-
-
-
-