Class InboundAchTransfer.Decline
-
- All Implemented Interfaces:
public final class InboundAchTransfer.DeclineIf your transfer is declined, this will contain details of the decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.Decline.BuilderA builder for Decline.
public final classInboundAchTransfer.Decline.ReasonThe reason for the transfer decline.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimedeclinedAt()The time at which the transfer was declined. final StringdeclinedTransactionId()The id of the transaction for the declined transfer. final InboundAchTransfer.Decline.Reasonreason()The reason for the transfer decline. final JsonField<OffsetDateTime>_declinedAt()Returns the raw JSON value of declinedAt. final JsonField<String>_declinedTransactionId()Returns the raw JSON value of declinedTransactionId. final JsonField<InboundAchTransfer.Decline.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.Decline.BuildertoBuilder()final InboundAchTransfer.Declinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.Decline.Builderbuilder()Returns a mutable builder for constructing an instance of Decline. -
-
Method Detail
-
declinedAt
final OffsetDateTime declinedAt()
The time at which the transfer was declined.
-
declinedTransactionId
final String declinedTransactionId()
The id of the transaction for the declined transfer.
-
reason
final InboundAchTransfer.Decline.Reason reason()
The reason for the transfer decline.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
Returns the raw JSON value of declinedAt.
Unlike declinedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
Returns the raw JSON value of declinedTransactionId.
Unlike declinedTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<InboundAchTransfer.Decline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransfer.Decline.Builder toBuilder()
-
validate
final InboundAchTransfer.Decline validate()
-
builder
final static InboundAchTransfer.Decline.Builder builder()
Returns a mutable builder for constructing an instance of Decline.
The following fields are required:
.declinedAt() .declinedTransactionId() .reason()
-
-
-
-