Class InboundAchTransfer.NotificationOfChange
-
- All Implemented Interfaces:
public final class InboundAchTransfer.NotificationOfChangeIf you initiate a notification of change in response to the transfer, this will contain its details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransfer.NotificationOfChange.BuilderA builder for NotificationOfChange.
-
Method Summary
Modifier and Type Method Description final Optional<String>updatedAccountNumber()The new account number provided in the notification of change. final Optional<String>updatedRoutingNumber()The new routing number provided in the notification of change. final JsonField<String>_updatedAccountNumber()Returns the raw JSON value of updatedAccountNumber. final JsonField<String>_updatedRoutingNumber()Returns the raw JSON value of updatedRoutingNumber. final Map<String, JsonValue>_additionalProperties()final InboundAchTransfer.NotificationOfChange.BuildertoBuilder()final InboundAchTransfer.NotificationOfChangevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransfer.NotificationOfChange.Builderbuilder()Returns a mutable builder for constructing an instance of NotificationOfChange. -
-
Method Detail
-
updatedAccountNumber
final Optional<String> updatedAccountNumber()
The new account number provided in the notification of change.
-
updatedRoutingNumber
final Optional<String> updatedRoutingNumber()
The new routing number provided in the notification of change.
-
_updatedAccountNumber
final JsonField<String> _updatedAccountNumber()
Returns the raw JSON value of updatedAccountNumber.
Unlike updatedAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedRoutingNumber
final JsonField<String> _updatedRoutingNumber()
Returns the raw JSON value of updatedRoutingNumber.
Unlike updatedRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransfer.NotificationOfChange.Builder toBuilder()
-
validate
final InboundAchTransfer.NotificationOfChange validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundAchTransfer.NotificationOfChange.Builder builder()
Returns a mutable builder for constructing an instance of NotificationOfChange.
The following fields are required:
.updatedAccountNumber() .updatedRoutingNumber()
-
-
-
-