Class InboundAchTransfer.NotificationOfChange.Builder
-
- All Implemented Interfaces:
public final class InboundAchTransfer.NotificationOfChange.BuilderA builder for NotificationOfChange.
-
-
Method Summary
-
-
Method Detail
-
updatedAccountNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedAccountNumber(String updatedAccountNumber)
The new account number provided in the notification of change.
-
updatedAccountNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedAccountNumber(Optional<String> updatedAccountNumber)
Alias for calling Builder.updatedAccountNumber with
updatedAccountNumber.orElse(null).
-
updatedAccountNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedAccountNumber(JsonField<String> updatedAccountNumber)
Sets Builder.updatedAccountNumber to an arbitrary JSON value.
You should usually call Builder.updatedAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedRoutingNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedRoutingNumber(String updatedRoutingNumber)
The new routing number provided in the notification of change.
-
updatedRoutingNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedRoutingNumber(Optional<String> updatedRoutingNumber)
Alias for calling Builder.updatedRoutingNumber with
updatedRoutingNumber.orElse(null).
-
updatedRoutingNumber
final InboundAchTransfer.NotificationOfChange.Builder updatedRoutingNumber(JsonField<String> updatedRoutingNumber)
Sets Builder.updatedRoutingNumber to an arbitrary JSON value.
You should usually call Builder.updatedRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundAchTransfer.NotificationOfChange.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundAchTransfer.NotificationOfChange.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundAchTransfer.NotificationOfChange.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundAchTransfer.NotificationOfChange.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundAchTransfer.NotificationOfChange.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundAchTransfer.NotificationOfChange build()
Returns an immutable instance of NotificationOfChange.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.updatedAccountNumber() .updatedRoutingNumber()
-
-
-
-