Enum InboundAchTransfer.StandardEntryClassCode.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundAchTransfer.StandardEntryClassCode.Known extends Enum<InboundAchTransfer.StandardEntryClassCode.Known>
An enum containing StandardEntryClassCode's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundAchTransfer.StandardEntryClassCode.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CORPORATE_CREDIT_OR_DEBITCorporate Credit and Debit (CCD).
CORPORATE_TRADE_EXCHANGECorporate Trade Exchange (CTX).
PREARRANGED_PAYMENTS_AND_DEPOSITPrearranged Payments and Deposits (PPD).
INTERNET_INITIATEDInternet Initiated (WEB).
POINT_OF_SALEPoint of Sale (POS).
TELEPHONE_INITIATEDTelephone Initiated (TEL).
CUSTOMER_INITIATEDCustomer Initiated (CIE).
ACCOUNTS_RECEIVABLEAccounts Receivable (ARC).
MACHINE_TRANSFERMachine Transfer (MTE).
SHARED_NETWORK_TRANSACTIONShared Network Transaction (SHR).
REPRESENTED_CHECKRepresented Check (RCK).
BACK_OFFICE_CONVERSIONBack Office Conversion (BOC).
POINT_OF_PURCHASEPoint of Purchase (POP).
CHECK_TRUNCATIONCheck Truncation (TRC).
DESTROYED_CHECKDestroyed Check (XCK).
INTERNATIONAL_ACH_TRANSACTIONInternational ACH Transaction (IAT).
-
Method Summary
Modifier and Type Method Description final InboundAchTransfer.StandardEntryClassCode.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundAchTransfer.StandardEntryClassCode.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundAchTransfer.StandardEntryClassCode.Known>getEntries()An enum containing StandardEntryClassCode's known values. -
-
Method Detail
-
valueOf
final InboundAchTransfer.StandardEntryClassCode.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundAchTransfer.StandardEntryClassCode.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundAchTransfer.StandardEntryClassCode.Known> getEntries()
An enum containing StandardEntryClassCode's known values.
-
-
-
-