Enum InboundAchTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundAchTransfer.Status.Known extends Enum<InboundAchTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundAchTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDINGThe Inbound ACH Transfer is awaiting action, will transition automatically if no action is taken.
DECLINEDThe Inbound ACH Transfer has been declined.
ACCEPTEDThe Inbound ACH Transfer is accepted.
RETURNEDThe Inbound ACH Transfer has been returned.
-
Method Summary
Modifier and Type Method Description final InboundAchTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundAchTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundAchTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final InboundAchTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundAchTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundAchTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-