Class InboundAchTransferCreateNotificationOfChangeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundAchTransferCreateNotificationOfChangeParams implements Params
Create a notification of change for an Inbound ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferCreateNotificationOfChangeParams.BuilderA builder for InboundAchTransferCreateNotificationOfChangeParams.
public final classInboundAchTransferCreateNotificationOfChangeParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>inboundAchTransferId()The identifier of the Inbound ACH Transfer for which to create a notification of change. final Optional<String>updatedAccountNumber()The updated account number to send in the notification of change. final Optional<String>updatedRoutingNumber()The updated routing number to send in the notification of change. final JsonField<String>_updatedAccountNumber()Returns the raw JSON value of updatedAccountNumber. final JsonField<String>_updatedRoutingNumber()Returns the raw JSON value of updatedRoutingNumber. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundAchTransferCreateNotificationOfChangeParams.BuildertoBuilder()final InboundAchTransferCreateNotificationOfChangeParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferCreateNotificationOfChangeParamsnone()final static InboundAchTransferCreateNotificationOfChangeParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAchTransferCreateNotificationOfChangeParams. -
-
Method Detail
-
inboundAchTransferId
final Optional<String> inboundAchTransferId()
The identifier of the Inbound ACH Transfer for which to create a notification of change.
-
updatedAccountNumber
final Optional<String> updatedAccountNumber()
The updated account number to send in the notification of change.
-
updatedRoutingNumber
final Optional<String> updatedRoutingNumber()
The updated routing number to send in the notification of change.
-
_updatedAccountNumber
final JsonField<String> _updatedAccountNumber()
Returns the raw JSON value of updatedAccountNumber.
Unlike updatedAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedRoutingNumber
final JsonField<String> _updatedRoutingNumber()
Returns the raw JSON value of updatedRoutingNumber.
Unlike updatedRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundAchTransferCreateNotificationOfChangeParams.Builder toBuilder()
-
_body
final InboundAchTransferCreateNotificationOfChangeParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboundAchTransferCreateNotificationOfChangeParams none()
-
builder
final static InboundAchTransferCreateNotificationOfChangeParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundAchTransferCreateNotificationOfChangeParams.
-
-
-
-