Class InboundAchTransferCreateNotificationOfChangeParams.Body
-
- All Implemented Interfaces:
public final class InboundAchTransferCreateNotificationOfChangeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferCreateNotificationOfChangeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>updatedAccountNumber()The updated account number to send in the notification of change. final Optional<String>updatedRoutingNumber()The updated routing number to send in the notification of change. final JsonField<String>_updatedAccountNumber()Returns the raw JSON value of updatedAccountNumber. final JsonField<String>_updatedRoutingNumber()Returns the raw JSON value of updatedRoutingNumber. final Map<String, JsonValue>_additionalProperties()final InboundAchTransferCreateNotificationOfChangeParams.Body.BuildertoBuilder()final InboundAchTransferCreateNotificationOfChangeParams.Bodyvalidate()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferCreateNotificationOfChangeParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
updatedAccountNumber
final Optional<String> updatedAccountNumber()
The updated account number to send in the notification of change.
-
updatedRoutingNumber
final Optional<String> updatedRoutingNumber()
The updated routing number to send in the notification of change.
-
_updatedAccountNumber
final JsonField<String> _updatedAccountNumber()
Returns the raw JSON value of updatedAccountNumber.
Unlike updatedAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedRoutingNumber
final JsonField<String> _updatedRoutingNumber()
Returns the raw JSON value of updatedRoutingNumber.
Unlike updatedRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder toBuilder()
-
validate
final InboundAchTransferCreateNotificationOfChangeParams.Body validate()
-
builder
final static InboundAchTransferCreateNotificationOfChangeParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-