Class InboundAchTransferCreateNotificationOfChangeParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboundAchTransferCreateNotificationOfChangeParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
updatedAccountNumber
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder updatedAccountNumber(String updatedAccountNumber)
The updated account number to send in the notification of change.
-
updatedAccountNumber
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder updatedAccountNumber(JsonField<String> updatedAccountNumber)
Sets Builder.updatedAccountNumber to an arbitrary JSON value.
You should usually call Builder.updatedAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedRoutingNumber
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder updatedRoutingNumber(String updatedRoutingNumber)
The updated routing number to send in the notification of change.
-
updatedRoutingNumber
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder updatedRoutingNumber(JsonField<String> updatedRoutingNumber)
Sets Builder.updatedRoutingNumber to an arbitrary JSON value.
You should usually call Builder.updatedRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundAchTransferCreateNotificationOfChangeParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundAchTransferCreateNotificationOfChangeParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-