Class InboundAchTransferDeclineParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundAchTransferDeclineParams implements Params
Decline an Inbound ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferDeclineParams.BuilderA builder for InboundAchTransferDeclineParams.
public final classInboundAchTransferDeclineParams.Bodypublic final classInboundAchTransferDeclineParams.ReasonThe reason why this transfer will be returned. If this parameter is unset, the return codes will be
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
Method Summary
Modifier and Type Method Description final Optional<String>inboundAchTransferId()The identifier of the Inbound ACH Transfer to decline. final Optional<InboundAchTransferDeclineParams.Reason>reason()The reason why this transfer will be returned. final JsonField<InboundAchTransferDeclineParams.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final InboundAchTransferDeclineParams.BuildertoBuilder()final InboundAchTransferDeclineParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferDeclineParamsnone()final static InboundAchTransferDeclineParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAchTransferDeclineParams. -
-
Method Detail
-
inboundAchTransferId
final Optional<String> inboundAchTransferId()
The identifier of the Inbound ACH Transfer to decline.
-
reason
final Optional<InboundAchTransferDeclineParams.Reason> reason()
The reason why this transfer will be returned. If this parameter is unset, the return codes will be
payment_stoppedfor debits andcredit_entry_refused_by_receiverfor credits.
-
_reason
final JsonField<InboundAchTransferDeclineParams.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final InboundAchTransferDeclineParams.Builder toBuilder()
-
_body
final InboundAchTransferDeclineParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboundAchTransferDeclineParams none()
-
builder
final static InboundAchTransferDeclineParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundAchTransferDeclineParams.
-
-
-
-