Class InboundAchTransferListPageAsync
-
- All Implemented Interfaces:
public final class InboundAchTransferListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferListPageAsync.BuilderA builder for InboundAchTransferListPageAsync.
public final classInboundAchTransferListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<InboundAchTransfer>data()Delegates to InboundAchTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundAchTransferListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<InboundAchTransferListParams>getNextPageParams()final CompletableFuture<Optional<InboundAchTransferListPageAsync>>getNextPage()final InboundAchTransferListPageAsync.AutoPagerautoPager()final InboundAchTransferListParamsparams()The parameters that were used to request this page. final InboundAchTransferListPageResponseresponse()The response that this page was parsed from. final InboundAchTransferListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAchTransferListPageAsync. -
-
Method Detail
-
data
final List<InboundAchTransfer> data()
Delegates to InboundAchTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundAchTransferListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<InboundAchTransferListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<InboundAchTransferListPageAsync>> getNextPage()
-
autoPager
final InboundAchTransferListPageAsync.AutoPager autoPager()
-
params
final InboundAchTransferListParams params()
The parameters that were used to request this page.
-
response
final InboundAchTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundAchTransferListPageAsync.Builder toBuilder()
-
builder
final static InboundAchTransferListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of InboundAchTransferListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-