Class InboundCheckDeposit
-
- All Implemented Interfaces:
public final class InboundCheckDepositInbound Check Deposits are records of third-parties attempting to deposit checks against your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDeposit.BuilderA builder for InboundCheckDeposit.
public final classInboundCheckDeposit.Adjustmentpublic final classInboundCheckDeposit.CurrencyThe ISO 4217 code for the deposit.
public final classInboundCheckDeposit.DepositReturnIf you requested a return of this deposit, this will contain details of the return.
public final classInboundCheckDeposit.PayeeNameAnalysisWhether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
public final classInboundCheckDeposit.StatusThe status of the Inbound Check Deposit.
public final classInboundCheckDeposit.TypeA constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
Method Summary
Modifier and Type Method Description final Stringid()The deposit's identifier. final Optional<OffsetDateTime>acceptedAt()If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final StringaccountId()The Account the check is being deposited against. final Optional<String>accountNumberId()The Account Number the check is being deposited against. final List<InboundCheckDeposit.Adjustment>adjustments()If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final Longamount()The deposited amount in USD cents. final Optional<String>backImageFileId()The ID for the File containing the image of the back of the check. final Optional<String>bankOfFirstDepositRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final Optional<String>checkNumber()The check number printed on the check being deposited. final Optional<String>checkTransferId()If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the deposit was attempted. final InboundCheckDeposit.Currencycurrency()The ISO 4217 code for the deposit. final Optional<OffsetDateTime>declinedAt()If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final Optional<String>declinedTransactionId()If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final Optional<InboundCheckDeposit.DepositReturn>depositReturn()If you requested a return of this deposit, this will contain details of the return. final Optional<String>frontImageFileId()The ID for the File containing the image of the front of the check. final InboundCheckDeposit.PayeeNameAnalysispayeeNameAnalysis()Whether the details on the check match the recipient name of the check transfer. final InboundCheckDeposit.Statusstatus()The status of the Inbound Check Deposit. final Optional<String>transactionId()If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final InboundCheckDeposit.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_acceptedAt()Returns the raw JSON value of acceptedAt. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<List<InboundCheckDeposit.Adjustment>>_adjustments()Returns the raw JSON value of adjustments. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_bankOfFirstDepositRoutingNumber()Returns the raw JSON value of bankOfFirstDepositRoutingNumber. final JsonField<String>_checkNumber()Returns the raw JSON value of checkNumber. final JsonField<String>_checkTransferId()Returns the raw JSON value of checkTransferId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<InboundCheckDeposit.Currency>_currency()Returns the raw JSON value of currency. final JsonField<OffsetDateTime>_declinedAt()Returns the raw JSON value of declinedAt. final JsonField<String>_declinedTransactionId()Returns the raw JSON value of declinedTransactionId. final JsonField<InboundCheckDeposit.DepositReturn>_depositReturn()Returns the raw JSON value of depositReturn. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<InboundCheckDeposit.PayeeNameAnalysis>_payeeNameAnalysis()Returns the raw JSON value of payeeNameAnalysis. final JsonField<InboundCheckDeposit.Status>_status()Returns the raw JSON value of status. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<InboundCheckDeposit.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final InboundCheckDeposit.BuildertoBuilder()final InboundCheckDepositvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDeposit.Builderbuilder()Returns a mutable builder for constructing an instance of InboundCheckDeposit. -
-
Method Detail
-
acceptedAt
final Optional<OffsetDateTime> acceptedAt()
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
accountNumberId
final Optional<String> accountNumberId()
The Account Number the check is being deposited against.
-
adjustments
final List<InboundCheckDeposit.Adjustment> adjustments()
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
backImageFileId
final Optional<String> backImageFileId()
The ID for the File containing the image of the back of the check.
-
bankOfFirstDepositRoutingNumber
final Optional<String> bankOfFirstDepositRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
checkNumber
final Optional<String> checkNumber()
The check number printed on the check being deposited.
-
checkTransferId
final Optional<String> checkTransferId()
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the deposit was attempted.
-
currency
final InboundCheckDeposit.Currency currency()
The ISO 4217 code for the deposit.
-
declinedAt
final Optional<OffsetDateTime> declinedAt()
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
declinedTransactionId
final Optional<String> declinedTransactionId()
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
depositReturn
final Optional<InboundCheckDeposit.DepositReturn> depositReturn()
If you requested a return of this deposit, this will contain details of the return.
-
frontImageFileId
final Optional<String> frontImageFileId()
The ID for the File containing the image of the front of the check.
-
payeeNameAnalysis
final InboundCheckDeposit.PayeeNameAnalysis payeeNameAnalysis()
Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
-
status
final InboundCheckDeposit.Status status()
The status of the Inbound Check Deposit.
-
transactionId
final Optional<String> transactionId()
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
type
final InboundCheckDeposit.Type type()
A constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_adjustments
final JsonField<List<InboundCheckDeposit.Adjustment>> _adjustments()
Returns the raw JSON value of adjustments.
Unlike adjustments, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_bankOfFirstDepositRoutingNumber
final JsonField<String> _bankOfFirstDepositRoutingNumber()
Returns the raw JSON value of bankOfFirstDepositRoutingNumber.
Unlike bankOfFirstDepositRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_checkTransferId
final JsonField<String> _checkTransferId()
Returns the raw JSON value of checkTransferId.
Unlike checkTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<InboundCheckDeposit.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
Returns the raw JSON value of declinedAt.
Unlike declinedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
Returns the raw JSON value of declinedTransactionId.
Unlike declinedTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_depositReturn
final JsonField<InboundCheckDeposit.DepositReturn> _depositReturn()
Returns the raw JSON value of depositReturn.
Unlike depositReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_payeeNameAnalysis
final JsonField<InboundCheckDeposit.PayeeNameAnalysis> _payeeNameAnalysis()
Returns the raw JSON value of payeeNameAnalysis.
Unlike payeeNameAnalysis, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InboundCheckDeposit.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundCheckDeposit.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundCheckDeposit.Builder toBuilder()
-
validate
final InboundCheckDeposit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundCheckDeposit.Builder builder()
Returns a mutable builder for constructing an instance of InboundCheckDeposit.
The following fields are required:
.id() .acceptedAt() .accountId() .accountNumberId() .adjustments() .amount() .backImageFileId() .bankOfFirstDepositRoutingNumber() .checkNumber() .checkTransferId() .createdAt() .currency() .declinedAt() .declinedTransactionId() .depositReturn() .frontImageFileId() .payeeNameAnalysis() .status() .transactionId() .type()
-
-
-
-