Class InboundCheckDeposit.Adjustment
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.Adjustment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDeposit.Adjustment.BuilderA builder for Adjustment.
public final classInboundCheckDeposit.Adjustment.ReasonThe reason for the adjustment.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeadjustedAt()The time at which the return adjustment was received. final Longamount()The amount of the adjustment. final InboundCheckDeposit.Adjustment.Reasonreason()The reason for the adjustment. final StringtransactionId()The id of the transaction for the adjustment. final JsonField<OffsetDateTime>_adjustedAt()Returns the raw JSON value of adjustedAt. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<InboundCheckDeposit.Adjustment.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final InboundCheckDeposit.Adjustment.BuildertoBuilder()final InboundCheckDeposit.Adjustmentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDeposit.Adjustment.Builderbuilder()Returns a mutable builder for constructing an instance of Adjustment. -
-
Method Detail
-
adjustedAt
final OffsetDateTime adjustedAt()
The time at which the return adjustment was received.
-
reason
final InboundCheckDeposit.Adjustment.Reason reason()
The reason for the adjustment.
-
transactionId
final String transactionId()
The id of the transaction for the adjustment.
-
_adjustedAt
final JsonField<OffsetDateTime> _adjustedAt()
Returns the raw JSON value of adjustedAt.
Unlike adjustedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<InboundCheckDeposit.Adjustment.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundCheckDeposit.Adjustment.Builder toBuilder()
-
validate
final InboundCheckDeposit.Adjustment validate()
-
builder
final static InboundCheckDeposit.Adjustment.Builder builder()
Returns a mutable builder for constructing an instance of Adjustment.
The following fields are required:
.adjustedAt() .amount() .reason() .transactionId()
-
-
-
-