Class InboundCheckDeposit.Adjustment.Builder
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.Adjustment.BuilderA builder for Adjustment.
-
-
Method Summary
-
-
Method Detail
-
adjustedAt
final InboundCheckDeposit.Adjustment.Builder adjustedAt(OffsetDateTime adjustedAt)
The time at which the return adjustment was received.
-
adjustedAt
final InboundCheckDeposit.Adjustment.Builder adjustedAt(JsonField<OffsetDateTime> adjustedAt)
Sets Builder.adjustedAt to an arbitrary JSON value.
You should usually call Builder.adjustedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundCheckDeposit.Adjustment.Builder amount(Long amount)
The amount of the adjustment.
-
amount
final InboundCheckDeposit.Adjustment.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final InboundCheckDeposit.Adjustment.Builder reason(InboundCheckDeposit.Adjustment.Reason reason)
The reason for the adjustment.
-
reason
final InboundCheckDeposit.Adjustment.Builder reason(JsonField<InboundCheckDeposit.Adjustment.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final InboundCheckDeposit.Adjustment.Builder transactionId(String transactionId)
The id of the transaction for the adjustment.
-
transactionId
final InboundCheckDeposit.Adjustment.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundCheckDeposit.Adjustment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundCheckDeposit.Adjustment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundCheckDeposit.Adjustment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundCheckDeposit.Adjustment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundCheckDeposit.Adjustment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundCheckDeposit.Adjustment build()
Returns an immutable instance of Adjustment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.adjustedAt() .amount() .reason() .transactionId()
-
-
-
-