Class InboundCheckDeposit.Builder
-
- All Implemented Interfaces:
public final class InboundCheckDeposit.BuilderA builder for InboundCheckDeposit.
-
-
Method Summary
Modifier and Type Method Description final InboundCheckDeposit.Builderid(String id)The deposit's identifier. final InboundCheckDeposit.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final InboundCheckDeposit.BuilderacceptedAt(OffsetDateTime acceptedAt)If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderacceptedAt(Optional<OffsetDateTime> acceptedAt)Alias for calling Builder.acceptedAt with acceptedAt.orElse(null).final InboundCheckDeposit.BuilderacceptedAt(JsonField<OffsetDateTime> acceptedAt)Sets Builder.acceptedAt to an arbitrary JSON value. final InboundCheckDeposit.BuilderaccountId(String accountId)The Account the check is being deposited against. final InboundCheckDeposit.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final InboundCheckDeposit.BuilderaccountNumberId(String accountNumberId)The Account Number the check is being deposited against. final InboundCheckDeposit.BuilderaccountNumberId(Optional<String> accountNumberId)Alias for calling Builder.accountNumberId with accountNumberId.orElse(null).final InboundCheckDeposit.BuilderaccountNumberId(JsonField<String> accountNumberId)Sets Builder.accountNumberId to an arbitrary JSON value. final InboundCheckDeposit.Builderadjustments(List<InboundCheckDeposit.Adjustment> adjustments)If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments. final InboundCheckDeposit.Builderadjustments(JsonField<List<InboundCheckDeposit.Adjustment>> adjustments)Sets Builder.adjustments to an arbitrary JSON value. final InboundCheckDeposit.BuilderaddAdjustment(InboundCheckDeposit.Adjustment adjustment)Adds a single Adjustment to adjustments. final InboundCheckDeposit.Builderamount(Long amount)The deposited amount in USD cents. final InboundCheckDeposit.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final InboundCheckDeposit.BuilderbackImageFileId(String backImageFileId)The ID for the File containing the image of the back of the check. final InboundCheckDeposit.BuilderbackImageFileId(Optional<String> backImageFileId)Alias for calling Builder.backImageFileId with backImageFileId.orElse(null).final InboundCheckDeposit.BuilderbackImageFileId(JsonField<String> backImageFileId)Sets Builder.backImageFileId to an arbitrary JSON value. final InboundCheckDeposit.BuilderbankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final InboundCheckDeposit.BuilderbankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)Alias for calling Builder.bankOfFirstDepositRoutingNumber with bankOfFirstDepositRoutingNumber.orElse(null).final InboundCheckDeposit.BuilderbankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)Sets Builder.bankOfFirstDepositRoutingNumber to an arbitrary JSON value. final InboundCheckDeposit.BuildercheckNumber(String checkNumber)The check number printed on the check being deposited. final InboundCheckDeposit.BuildercheckNumber(Optional<String> checkNumber)Alias for calling Builder.checkNumber with checkNumber.orElse(null).final InboundCheckDeposit.BuildercheckNumber(JsonField<String> checkNumber)Sets Builder.checkNumber to an arbitrary JSON value. final InboundCheckDeposit.BuildercheckTransferId(String checkTransferId)If this deposit is for an existing Check Transfer, the identifier of that Check Transfer. final InboundCheckDeposit.BuildercheckTransferId(Optional<String> checkTransferId)Alias for calling Builder.checkTransferId with checkTransferId.orElse(null).final InboundCheckDeposit.BuildercheckTransferId(JsonField<String> checkTransferId)Sets Builder.checkTransferId to an arbitrary JSON value. final InboundCheckDeposit.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the deposit was attempted. final InboundCheckDeposit.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final InboundCheckDeposit.Buildercurrency(InboundCheckDeposit.Currency currency)The ISO 4217 code for the deposit. final InboundCheckDeposit.Buildercurrency(JsonField<InboundCheckDeposit.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final InboundCheckDeposit.BuilderdeclinedAt(OffsetDateTime declinedAt)If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place. final InboundCheckDeposit.BuilderdeclinedAt(Optional<OffsetDateTime> declinedAt)Alias for calling Builder.declinedAt with declinedAt.orElse(null).final InboundCheckDeposit.BuilderdeclinedAt(JsonField<OffsetDateTime> declinedAt)Sets Builder.declinedAt to an arbitrary JSON value. final InboundCheckDeposit.BuilderdeclinedTransactionId(String declinedTransactionId)If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit. final InboundCheckDeposit.BuilderdeclinedTransactionId(Optional<String> declinedTransactionId)Alias for calling Builder.declinedTransactionId with declinedTransactionId.orElse(null).final InboundCheckDeposit.BuilderdeclinedTransactionId(JsonField<String> declinedTransactionId)Sets Builder.declinedTransactionId to an arbitrary JSON value. final InboundCheckDeposit.BuilderdepositReturn(InboundCheckDeposit.DepositReturn depositReturn)If you requested a return of this deposit, this will contain details of the return. final InboundCheckDeposit.BuilderdepositReturn(Optional<InboundCheckDeposit.DepositReturn> depositReturn)Alias for calling Builder.depositReturn with depositReturn.orElse(null).final InboundCheckDeposit.BuilderdepositReturn(JsonField<InboundCheckDeposit.DepositReturn> depositReturn)Sets Builder.depositReturn to an arbitrary JSON value. final InboundCheckDeposit.BuilderfrontImageFileId(String frontImageFileId)The ID for the File containing the image of the front of the check. final InboundCheckDeposit.BuilderfrontImageFileId(Optional<String> frontImageFileId)Alias for calling Builder.frontImageFileId with frontImageFileId.orElse(null).final InboundCheckDeposit.BuilderfrontImageFileId(JsonField<String> frontImageFileId)Sets Builder.frontImageFileId to an arbitrary JSON value. final InboundCheckDeposit.BuilderpayeeNameAnalysis(InboundCheckDeposit.PayeeNameAnalysis payeeNameAnalysis)Whether the details on the check match the recipient name of the check transfer. final InboundCheckDeposit.BuilderpayeeNameAnalysis(JsonField<InboundCheckDeposit.PayeeNameAnalysis> payeeNameAnalysis)Sets Builder.payeeNameAnalysis to an arbitrary JSON value. final InboundCheckDeposit.Builderstatus(InboundCheckDeposit.Status status)The status of the Inbound Check Deposit. final InboundCheckDeposit.Builderstatus(JsonField<InboundCheckDeposit.Status> status)Sets Builder.status to an arbitrary JSON value. final InboundCheckDeposit.BuildertransactionId(String transactionId)If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit. final InboundCheckDeposit.BuildertransactionId(Optional<String> transactionId)Alias for calling Builder.transactionId with transactionId.orElse(null).final InboundCheckDeposit.BuildertransactionId(JsonField<String> transactionId)Sets Builder.transactionId to an arbitrary JSON value. final InboundCheckDeposit.Buildertype(InboundCheckDeposit.Type type)A constant representing the object's type. final InboundCheckDeposit.Buildertype(JsonField<InboundCheckDeposit.Type> type)Sets Builder.type to an arbitrary JSON value. final InboundCheckDeposit.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final InboundCheckDeposit.BuilderputAdditionalProperty(String key, JsonValue value)final InboundCheckDeposit.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final InboundCheckDeposit.BuilderremoveAdditionalProperty(String key)final InboundCheckDeposit.BuilderremoveAllAdditionalProperties(Set<String> keys)final InboundCheckDepositbuild()Returns an immutable instance of InboundCheckDeposit. -
-
Method Detail
-
id
final InboundCheckDeposit.Builder id(String id)
The deposit's identifier.
-
id
final InboundCheckDeposit.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acceptedAt
final InboundCheckDeposit.Builder acceptedAt(OffsetDateTime acceptedAt)
If the Inbound Check Deposit was accepted, the ISO 8601 date and time at which this took place.
-
acceptedAt
final InboundCheckDeposit.Builder acceptedAt(Optional<OffsetDateTime> acceptedAt)
Alias for calling Builder.acceptedAt with
acceptedAt.orElse(null).
-
acceptedAt
final InboundCheckDeposit.Builder acceptedAt(JsonField<OffsetDateTime> acceptedAt)
Sets Builder.acceptedAt to an arbitrary JSON value.
You should usually call Builder.acceptedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final InboundCheckDeposit.Builder accountId(String accountId)
The Account the check is being deposited against.
-
accountId
final InboundCheckDeposit.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumberId
final InboundCheckDeposit.Builder accountNumberId(String accountNumberId)
The Account Number the check is being deposited against.
-
accountNumberId
final InboundCheckDeposit.Builder accountNumberId(Optional<String> accountNumberId)
Alias for calling Builder.accountNumberId with
accountNumberId.orElse(null).
-
accountNumberId
final InboundCheckDeposit.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
adjustments
final InboundCheckDeposit.Builder adjustments(List<InboundCheckDeposit.Adjustment> adjustments)
If the deposit or the return was adjusted by the sending institution, this will contain details of the adjustments.
-
adjustments
final InboundCheckDeposit.Builder adjustments(JsonField<List<InboundCheckDeposit.Adjustment>> adjustments)
Sets Builder.adjustments to an arbitrary JSON value.
You should usually call Builder.adjustments with a well-typed
List<Adjustment>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAdjustment
final InboundCheckDeposit.Builder addAdjustment(InboundCheckDeposit.Adjustment adjustment)
Adds a single Adjustment to adjustments.
-
amount
final InboundCheckDeposit.Builder amount(Long amount)
The deposited amount in USD cents.
-
amount
final InboundCheckDeposit.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backImageFileId
final InboundCheckDeposit.Builder backImageFileId(String backImageFileId)
The ID for the File containing the image of the back of the check.
-
backImageFileId
final InboundCheckDeposit.Builder backImageFileId(Optional<String> backImageFileId)
Alias for calling Builder.backImageFileId with
backImageFileId.orElse(null).
-
backImageFileId
final InboundCheckDeposit.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bankOfFirstDepositRoutingNumber
final InboundCheckDeposit.Builder bankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
bankOfFirstDepositRoutingNumber
final InboundCheckDeposit.Builder bankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)
Alias for calling Builder.bankOfFirstDepositRoutingNumber with
bankOfFirstDepositRoutingNumber.orElse(null).
-
bankOfFirstDepositRoutingNumber
final InboundCheckDeposit.Builder bankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)
Sets Builder.bankOfFirstDepositRoutingNumber to an arbitrary JSON value.
You should usually call Builder.bankOfFirstDepositRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkNumber
final InboundCheckDeposit.Builder checkNumber(String checkNumber)
The check number printed on the check being deposited.
-
checkNumber
final InboundCheckDeposit.Builder checkNumber(Optional<String> checkNumber)
Alias for calling Builder.checkNumber with
checkNumber.orElse(null).
-
checkNumber
final InboundCheckDeposit.Builder checkNumber(JsonField<String> checkNumber)
Sets Builder.checkNumber to an arbitrary JSON value.
You should usually call Builder.checkNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkTransferId
final InboundCheckDeposit.Builder checkTransferId(String checkTransferId)
If this deposit is for an existing Check Transfer, the identifier of that Check Transfer.
-
checkTransferId
final InboundCheckDeposit.Builder checkTransferId(Optional<String> checkTransferId)
Alias for calling Builder.checkTransferId with
checkTransferId.orElse(null).
-
checkTransferId
final InboundCheckDeposit.Builder checkTransferId(JsonField<String> checkTransferId)
Sets Builder.checkTransferId to an arbitrary JSON value.
You should usually call Builder.checkTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InboundCheckDeposit.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the deposit was attempted.
-
createdAt
final InboundCheckDeposit.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InboundCheckDeposit.Builder currency(InboundCheckDeposit.Currency currency)
The ISO 4217 code for the deposit.
-
currency
final InboundCheckDeposit.Builder currency(JsonField<InboundCheckDeposit.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declinedAt
final InboundCheckDeposit.Builder declinedAt(OffsetDateTime declinedAt)
If the Inbound Check Deposit was declined, the ISO 8601 date and time at which this took place.
-
declinedAt
final InboundCheckDeposit.Builder declinedAt(Optional<OffsetDateTime> declinedAt)
Alias for calling Builder.declinedAt with
declinedAt.orElse(null).
-
declinedAt
final InboundCheckDeposit.Builder declinedAt(JsonField<OffsetDateTime> declinedAt)
Sets Builder.declinedAt to an arbitrary JSON value.
You should usually call Builder.declinedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declinedTransactionId
final InboundCheckDeposit.Builder declinedTransactionId(String declinedTransactionId)
If the deposit attempt has been rejected, the identifier of the Declined Transaction object created as a result of the failed deposit.
-
declinedTransactionId
final InboundCheckDeposit.Builder declinedTransactionId(Optional<String> declinedTransactionId)
Alias for calling Builder.declinedTransactionId with
declinedTransactionId.orElse(null).
-
declinedTransactionId
final InboundCheckDeposit.Builder declinedTransactionId(JsonField<String> declinedTransactionId)
Sets Builder.declinedTransactionId to an arbitrary JSON value.
You should usually call Builder.declinedTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
depositReturn
final InboundCheckDeposit.Builder depositReturn(InboundCheckDeposit.DepositReturn depositReturn)
If you requested a return of this deposit, this will contain details of the return.
-
depositReturn
final InboundCheckDeposit.Builder depositReturn(Optional<InboundCheckDeposit.DepositReturn> depositReturn)
Alias for calling Builder.depositReturn with
depositReturn.orElse(null).
-
depositReturn
final InboundCheckDeposit.Builder depositReturn(JsonField<InboundCheckDeposit.DepositReturn> depositReturn)
Sets Builder.depositReturn to an arbitrary JSON value.
You should usually call Builder.depositReturn with a well-typed DepositReturn value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final InboundCheckDeposit.Builder frontImageFileId(String frontImageFileId)
The ID for the File containing the image of the front of the check.
-
frontImageFileId
final InboundCheckDeposit.Builder frontImageFileId(Optional<String> frontImageFileId)
Alias for calling Builder.frontImageFileId with
frontImageFileId.orElse(null).
-
frontImageFileId
final InboundCheckDeposit.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
payeeNameAnalysis
final InboundCheckDeposit.Builder payeeNameAnalysis(InboundCheckDeposit.PayeeNameAnalysis payeeNameAnalysis)
Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.
-
payeeNameAnalysis
final InboundCheckDeposit.Builder payeeNameAnalysis(JsonField<InboundCheckDeposit.PayeeNameAnalysis> payeeNameAnalysis)
Sets Builder.payeeNameAnalysis to an arbitrary JSON value.
You should usually call Builder.payeeNameAnalysis with a well-typed PayeeNameAnalysis value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InboundCheckDeposit.Builder status(InboundCheckDeposit.Status status)
The status of the Inbound Check Deposit.
-
status
final InboundCheckDeposit.Builder status(JsonField<InboundCheckDeposit.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final InboundCheckDeposit.Builder transactionId(String transactionId)
If the deposit attempt has been accepted, the identifier of the Transaction object created as a result of the successful deposit.
-
transactionId
final InboundCheckDeposit.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final InboundCheckDeposit.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundCheckDeposit.Builder type(InboundCheckDeposit.Type type)
A constant representing the object's type. For this resource it will always be
inbound_check_deposit.
-
type
final InboundCheckDeposit.Builder type(JsonField<InboundCheckDeposit.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundCheckDeposit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundCheckDeposit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundCheckDeposit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundCheckDeposit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundCheckDeposit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundCheckDeposit build()
Returns an immutable instance of InboundCheckDeposit.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .acceptedAt() .accountId() .accountNumberId() .adjustments() .amount() .backImageFileId() .bankOfFirstDepositRoutingNumber() .checkNumber() .checkTransferId() .createdAt() .currency() .declinedAt() .declinedTransactionId() .depositReturn() .frontImageFileId() .payeeNameAnalysis() .status() .transactionId() .type()
-
-
-
-