Class InboundCheckDeposit.Currency
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class InboundCheckDeposit.Currency implements EnumThe ISO 4217 code for the deposit.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumInboundCheckDeposit.Currency.KnownAn enum containing Currency's known values.
public enumInboundCheckDeposit.Currency.ValueAn enum containing Currency's known values, as well as an _UNKNOWN member.
An instance of Currency can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static InboundCheckDeposit.CurrencyCADpublic final static InboundCheckDeposit.CurrencyCHFpublic final static InboundCheckDeposit.CurrencyEURpublic final static InboundCheckDeposit.CurrencyGBPpublic final static InboundCheckDeposit.CurrencyJPYpublic final static InboundCheckDeposit.CurrencyUSD
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final InboundCheckDeposit.Currency.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final InboundCheckDeposit.Currency.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final InboundCheckDeposit.Currencyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDeposit.Currencyof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final InboundCheckDeposit.Currency.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final InboundCheckDeposit.Currency.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final InboundCheckDeposit.Currency validate()
-
of
final static InboundCheckDeposit.Currency of(String value)
-
-
-
-