Class InboundCheckDeposit.PayeeNameAnalysis

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class InboundCheckDeposit.PayeeNameAnalysis
     implements Enum
                        

    Whether the details on the check match the recipient name of the check transfer. This is an optional feature, contact sales to enable.

    • Constructor Detail