Enum InboundCheckDeposit.PayeeNameAnalysis.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundCheckDeposit.PayeeNameAnalysis.Value extends Enum<InboundCheckDeposit.PayeeNameAnalysis.Value>
An enum containing PayeeNameAnalysis's known values, as well as an _UNKNOWN member.
An instance of PayeeNameAnalysis can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundCheckDeposit.PayeeNameAnalysis.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NAME_MATCHESThe details on the check match the recipient name of the check transfer.
DOES_NOT_MATCHThe details on the check do not match the recipient name of the check transfer.
NOT_EVALUATEDThe payee name analysis was not evaluated.
_UNKNOWNAn enum member indicating that PayeeNameAnalysis was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final InboundCheckDeposit.PayeeNameAnalysis.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundCheckDeposit.PayeeNameAnalysis.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundCheckDeposit.PayeeNameAnalysis.Value>getEntries()An enum containing PayeeNameAnalysis's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final InboundCheckDeposit.PayeeNameAnalysis.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundCheckDeposit.PayeeNameAnalysis.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundCheckDeposit.PayeeNameAnalysis.Value> getEntries()
An enum containing PayeeNameAnalysis's known values, as well as an _UNKNOWN member.
An instance of PayeeNameAnalysis can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-