Enum InboundCheckDeposit.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundCheckDeposit.Status.Known extends Enum<InboundCheckDeposit.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundCheckDeposit.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDINGThe Inbound Check Deposit is pending.
ACCEPTEDThe Inbound Check Deposit was accepted.
DECLINEDThe Inbound Check Deposit was rejected.
RETURNEDThe Inbound Check Deposit was returned.
REQUIRES_ATTENTIONThe Inbound Check Deposit requires attention from an Increase operator.
-
Method Summary
Modifier and Type Method Description final InboundCheckDeposit.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundCheckDeposit.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundCheckDeposit.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final InboundCheckDeposit.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundCheckDeposit.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundCheckDeposit.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-