Class InboundCheckDepositListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class InboundCheckDepositListPage implements Page<InboundCheckDeposit>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositListPage.BuilderA builder for InboundCheckDepositListPage.
-
Method Summary
Modifier and Type Method Description final List<InboundCheckDeposit>data()Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data. List<InboundCheckDeposit>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final InboundCheckDepositListParamsnextPageParams()InboundCheckDepositListPagenextPage()Returns the page after this one by making another request. final AutoPager<InboundCheckDeposit>autoPager()final InboundCheckDepositListParamsparams()The parameters that were used to request this page. final InboundCheckDepositListPageResponseresponse()The response that this page was parsed from. final InboundCheckDepositListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDepositListPage.Builderbuilder()Returns a mutable builder for constructing an instance of InboundCheckDepositListPage. -
-
Method Detail
-
data
final List<InboundCheckDeposit> data()
Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data.
-
items
List<InboundCheckDeposit> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final InboundCheckDepositListParams nextPageParams()
-
nextPage
InboundCheckDepositListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<InboundCheckDeposit> autoPager()
-
params
final InboundCheckDepositListParams params()
The parameters that were used to request this page.
-
response
final InboundCheckDepositListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundCheckDepositListPage.Builder toBuilder()
-
builder
final static InboundCheckDepositListPage.Builder builder()
Returns a mutable builder for constructing an instance of InboundCheckDepositListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-