Class InboundCheckDepositListPage.Builder
-
- All Implemented Interfaces:
public final class InboundCheckDepositListPage.BuilderA builder for InboundCheckDepositListPage.
-
-
Method Summary
Modifier and Type Method Description final InboundCheckDepositListPage.Builderservice(InboundCheckDepositService service)final InboundCheckDepositListPage.Builderparams(InboundCheckDepositListParams params)The parameters that were used to request this page. final InboundCheckDepositListPage.Builderresponse(InboundCheckDepositListPageResponse response)The response that this page was parsed from. final InboundCheckDepositListPagebuild()Returns an immutable instance of InboundCheckDepositListPage. -
-
Method Detail
-
service
final InboundCheckDepositListPage.Builder service(InboundCheckDepositService service)
-
params
final InboundCheckDepositListPage.Builder params(InboundCheckDepositListParams params)
The parameters that were used to request this page.
-
response
final InboundCheckDepositListPage.Builder response(InboundCheckDepositListPageResponse response)
The response that this page was parsed from.
-
build
final InboundCheckDepositListPage build()
Returns an immutable instance of InboundCheckDepositListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-