Class InboundCheckDepositListPageAsync
-
- All Implemented Interfaces:
public final class InboundCheckDepositListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositListPageAsync.BuilderA builder for InboundCheckDepositListPageAsync.
public final classInboundCheckDepositListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<InboundCheckDeposit>data()Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<InboundCheckDepositListParams>getNextPageParams()final CompletableFuture<Optional<InboundCheckDepositListPageAsync>>getNextPage()final InboundCheckDepositListPageAsync.AutoPagerautoPager()final InboundCheckDepositListParamsparams()The parameters that were used to request this page. final InboundCheckDepositListPageResponseresponse()The response that this page was parsed from. final InboundCheckDepositListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDepositListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of InboundCheckDepositListPageAsync. -
-
Method Detail
-
data
final List<InboundCheckDeposit> data()
Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundCheckDepositListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<InboundCheckDepositListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<InboundCheckDepositListPageAsync>> getNextPage()
-
autoPager
final InboundCheckDepositListPageAsync.AutoPager autoPager()
-
params
final InboundCheckDepositListParams params()
The parameters that were used to request this page.
-
response
final InboundCheckDepositListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundCheckDepositListPageAsync.Builder toBuilder()
-
builder
final static InboundCheckDepositListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of InboundCheckDepositListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-