Class InboundCheckDepositListPageAsync.Builder
-
- All Implemented Interfaces:
public final class InboundCheckDepositListPageAsync.BuilderA builder for InboundCheckDepositListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final InboundCheckDepositListPageAsync.Builderservice(InboundCheckDepositServiceAsync service)final InboundCheckDepositListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final InboundCheckDepositListPageAsync.Builderparams(InboundCheckDepositListParams params)The parameters that were used to request this page. final InboundCheckDepositListPageAsync.Builderresponse(InboundCheckDepositListPageResponse response)The response that this page was parsed from. final InboundCheckDepositListPageAsyncbuild()Returns an immutable instance of InboundCheckDepositListPageAsync. -
-
Method Detail
-
service
final InboundCheckDepositListPageAsync.Builder service(InboundCheckDepositServiceAsync service)
-
streamHandlerExecutor
final InboundCheckDepositListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final InboundCheckDepositListPageAsync.Builder params(InboundCheckDepositListParams params)
The parameters that were used to request this page.
-
response
final InboundCheckDepositListPageAsync.Builder response(InboundCheckDepositListPageResponse response)
The response that this page was parsed from.
-
build
final InboundCheckDepositListPageAsync build()
Returns an immutable instance of InboundCheckDepositListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-