Class InboundCheckDepositRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundCheckDepositRetrieveParams implements Params
Retrieve an Inbound Check Deposit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositRetrieveParams.BuilderA builder for InboundCheckDepositRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>inboundCheckDepositId()The identifier of the Inbound Check Deposit to get details for. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundCheckDepositRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDepositRetrieveParamsnone()final static InboundCheckDepositRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundCheckDepositRetrieveParams. -
-
Method Detail
-
inboundCheckDepositId
final Optional<String> inboundCheckDepositId()
The identifier of the Inbound Check Deposit to get details for.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundCheckDepositRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboundCheckDepositRetrieveParams none()
-
builder
final static InboundCheckDepositRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundCheckDepositRetrieveParams.
-
-
-
-