Class InboundMailItem
-
- All Implemented Interfaces:
public final class InboundMailItemInbound Mail Items represent pieces of physical mail delivered to a Lockbox Address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItem.BuilderA builder for InboundMailItem.
public final classInboundMailItem.CheckInbound Mail Item Checks represent the checks in an Inbound Mail Item.
public final classInboundMailItem.RejectionReasonIf the mail item has been rejected, why it was rejected.
public final classInboundMailItem.StatusIf the mail item has been processed.
public final classInboundMailItem.TypeA constant representing the object's type. For this resource it will always be
inbound_mail_item.
-
Method Summary
Modifier and Type Method Description final Stringid()The Inbound Mail Item identifier. final List<InboundMailItem.Check>checks()The checks in the mail item. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Inbound Mail Item was created. final StringfileId()The identifier for the File containing the scanned contents of the mail item. final StringlockboxAddressId()The identifier for the Lockbox Address that received this mail item. final Optional<String>lockboxRecipientId()The identifier for the Lockbox Recipient that received this mail item. final Optional<String>recipientName()The recipient name as written on the mail item. final Optional<InboundMailItem.RejectionReason>rejectionReason()If the mail item has been rejected, why it was rejected. final InboundMailItem.Statusstatus()If the mail item has been processed. final InboundMailItem.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<InboundMailItem.Check>>_checks()Returns the raw JSON value of checks. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_lockboxAddressId()Returns the raw JSON value of lockboxAddressId. final JsonField<String>_lockboxRecipientId()Returns the raw JSON value of lockboxRecipientId. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<InboundMailItem.RejectionReason>_rejectionReason()Returns the raw JSON value of rejectionReason. final JsonField<InboundMailItem.Status>_status()Returns the raw JSON value of status. final JsonField<InboundMailItem.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final InboundMailItem.BuildertoBuilder()final InboundMailItemvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItem.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItem. -
-
Method Detail
-
checks
final List<InboundMailItem.Check> checks()
The checks in the mail item.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Inbound Mail Item was created.
-
fileId
final String fileId()
The identifier for the File containing the scanned contents of the mail item.
-
lockboxAddressId
final String lockboxAddressId()
The identifier for the Lockbox Address that received this mail item.
-
lockboxRecipientId
final Optional<String> lockboxRecipientId()
The identifier for the Lockbox Recipient that received this mail item. For mail items that could not be routed to a Lockbox Recipient, this will be null.
-
recipientName
final Optional<String> recipientName()
The recipient name as written on the mail item.
-
rejectionReason
final Optional<InboundMailItem.RejectionReason> rejectionReason()
If the mail item has been rejected, why it was rejected.
-
status
final InboundMailItem.Status status()
If the mail item has been processed.
-
type
final InboundMailItem.Type type()
A constant representing the object's type. For this resource it will always be
inbound_mail_item.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_checks
final JsonField<List<InboundMailItem.Check>> _checks()
Returns the raw JSON value of checks.
Unlike checks, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxAddressId
final JsonField<String> _lockboxAddressId()
Returns the raw JSON value of lockboxAddressId.
Unlike lockboxAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxRecipientId
final JsonField<String> _lockboxRecipientId()
Returns the raw JSON value of lockboxRecipientId.
Unlike lockboxRecipientId, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectionReason
final JsonField<InboundMailItem.RejectionReason> _rejectionReason()
Returns the raw JSON value of rejectionReason.
Unlike rejectionReason, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InboundMailItem.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundMailItem.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundMailItem.Builder toBuilder()
-
validate
final InboundMailItem validate()
-
builder
final static InboundMailItem.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItem.
The following fields are required:
.id() .checks() .createdAt() .fileId() .lockboxAddressId() .lockboxRecipientId() .recipientName() .rejectionReason() .status() .type()
-
-
-
-