Class InboundMailItem.Builder
-
- All Implemented Interfaces:
public final class InboundMailItem.BuilderA builder for InboundMailItem.
-
-
Method Summary
-
-
Method Detail
-
id
final InboundMailItem.Builder id(String id)
The Inbound Mail Item identifier.
-
id
final InboundMailItem.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checks
final InboundMailItem.Builder checks(List<InboundMailItem.Check> checks)
The checks in the mail item.
-
checks
final InboundMailItem.Builder checks(JsonField<List<InboundMailItem.Check>> checks)
Sets Builder.checks to an arbitrary JSON value.
You should usually call Builder.checks with a well-typed
List<Check>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addCheck
final InboundMailItem.Builder addCheck(InboundMailItem.Check check)
-
createdAt
final InboundMailItem.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Inbound Mail Item was created.
-
createdAt
final InboundMailItem.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final InboundMailItem.Builder fileId(String fileId)
The identifier for the File containing the scanned contents of the mail item.
-
fileId
final InboundMailItem.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxAddressId
final InboundMailItem.Builder lockboxAddressId(String lockboxAddressId)
The identifier for the Lockbox Address that received this mail item.
-
lockboxAddressId
final InboundMailItem.Builder lockboxAddressId(JsonField<String> lockboxAddressId)
Sets Builder.lockboxAddressId to an arbitrary JSON value.
You should usually call Builder.lockboxAddressId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxRecipientId
final InboundMailItem.Builder lockboxRecipientId(String lockboxRecipientId)
The identifier for the Lockbox Recipient that received this mail item. For mail items that could not be routed to a Lockbox Recipient, this will be null.
-
lockboxRecipientId
final InboundMailItem.Builder lockboxRecipientId(Optional<String> lockboxRecipientId)
Alias for calling Builder.lockboxRecipientId with
lockboxRecipientId.orElse(null).
-
lockboxRecipientId
final InboundMailItem.Builder lockboxRecipientId(JsonField<String> lockboxRecipientId)
Sets Builder.lockboxRecipientId to an arbitrary JSON value.
You should usually call Builder.lockboxRecipientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final InboundMailItem.Builder recipientName(String recipientName)
The recipient name as written on the mail item.
-
recipientName
final InboundMailItem.Builder recipientName(Optional<String> recipientName)
Alias for calling Builder.recipientName with
recipientName.orElse(null).
-
recipientName
final InboundMailItem.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rejectionReason
final InboundMailItem.Builder rejectionReason(InboundMailItem.RejectionReason rejectionReason)
If the mail item has been rejected, why it was rejected.
-
rejectionReason
final InboundMailItem.Builder rejectionReason(Optional<InboundMailItem.RejectionReason> rejectionReason)
Alias for calling Builder.rejectionReason with
rejectionReason.orElse(null).
-
rejectionReason
final InboundMailItem.Builder rejectionReason(JsonField<InboundMailItem.RejectionReason> rejectionReason)
Sets Builder.rejectionReason to an arbitrary JSON value.
You should usually call Builder.rejectionReason with a well-typed RejectionReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InboundMailItem.Builder status(InboundMailItem.Status status)
If the mail item has been processed.
-
status
final InboundMailItem.Builder status(JsonField<InboundMailItem.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundMailItem.Builder type(InboundMailItem.Type type)
A constant representing the object's type. For this resource it will always be
inbound_mail_item.
-
type
final InboundMailItem.Builder type(JsonField<InboundMailItem.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundMailItem.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundMailItem.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundMailItem.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundMailItem.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundMailItem.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundMailItem build()
Returns an immutable instance of InboundMailItem.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .checks() .createdAt() .fileId() .lockboxAddressId() .lockboxRecipientId() .recipientName() .rejectionReason() .status() .type()
-
-
-
-