Enum InboundMailItem.RejectionReason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundMailItem.RejectionReason.Known extends Enum<InboundMailItem.RejectionReason.Known>
An enum containing RejectionReason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundMailItem.RejectionReason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NO_MATCHING_LOCKBOXThe mail item does not match any lockbox.
NO_CHECKThe mail item does not contain a check.
LOCKBOX_NOT_ACTIVEThe Lockbox or its associated Account is not active.
LOCKBOX_ADDRESS_NOT_ACTIVEThe Lockbox Address is not active.
LOCKBOX_RECIPIENT_NOT_ACTIVEThe Lockbox Recipient or its associated Account is not active.
-
Method Summary
Modifier and Type Method Description final InboundMailItem.RejectionReason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundMailItem.RejectionReason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundMailItem.RejectionReason.Known>getEntries()An enum containing RejectionReason's known values. -
-
Method Detail
-
valueOf
final InboundMailItem.RejectionReason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundMailItem.RejectionReason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundMailItem.RejectionReason.Known> getEntries()
An enum containing RejectionReason's known values.
-
-
-
-