Enum InboundMailItem.RejectionReason.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum InboundMailItem.RejectionReason.Value
    extends Enum<InboundMailItem.RejectionReason.Value>
                        

    An enum containing RejectionReason's known values, as well as an _UNKNOWN member.

    An instance of RejectionReason can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Constructor Detail

    • Method Detail

      • valueOf

         final InboundMailItem.RejectionReason.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<InboundMailItem.RejectionReason.Value> getEntries()

        An enum containing RejectionReason's known values, as well as an _UNKNOWN member.

        An instance of RejectionReason can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.