Class InboundMailItemActionParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundMailItemActionParams implements Params
Action an Inbound Mail Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemActionParams.BuilderA builder for InboundMailItemActionParams.
public final classInboundMailItemActionParams.Bodypublic final classInboundMailItemActionParams.Check
-
Method Summary
Modifier and Type Method Description final Optional<String>inboundMailItemId()The identifier of the Inbound Mail Item to action. final List<InboundMailItemActionParams.Check>checks()The actions to perform on the Inbound Mail Item. final JsonField<List<InboundMailItemActionParams.Check>>_checks()Returns the raw JSON value of checks. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundMailItemActionParams.BuildertoBuilder()final InboundMailItemActionParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemActionParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemActionParams. -
-
Method Detail
-
inboundMailItemId
final Optional<String> inboundMailItemId()
The identifier of the Inbound Mail Item to action.
-
checks
final List<InboundMailItemActionParams.Check> checks()
The actions to perform on the Inbound Mail Item.
-
_checks
final JsonField<List<InboundMailItemActionParams.Check>> _checks()
Returns the raw JSON value of checks.
Unlike checks, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundMailItemActionParams.Builder toBuilder()
-
_body
final InboundMailItemActionParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundMailItemActionParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemActionParams.
The following fields are required:
.checks()
-
-
-
-