Class InboundMailItemActionParams.Body
-
- All Implemented Interfaces:
public final class InboundMailItemActionParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemActionParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<InboundMailItemActionParams.Check>checks()The actions to perform on the Inbound Mail Item. final JsonField<List<InboundMailItemActionParams.Check>>_checks()Returns the raw JSON value of checks. final Map<String, JsonValue>_additionalProperties()final InboundMailItemActionParams.Body.BuildertoBuilder()final InboundMailItemActionParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemActionParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
checks
final List<InboundMailItemActionParams.Check> checks()
The actions to perform on the Inbound Mail Item.
-
_checks
final JsonField<List<InboundMailItemActionParams.Check>> _checks()
Returns the raw JSON value of checks.
Unlike checks, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundMailItemActionParams.Body.Builder toBuilder()
-
validate
final InboundMailItemActionParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundMailItemActionParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.checks()
-
-
-
-