Class InboundMailItemActionParams.Check
-
- All Implemented Interfaces:
public final class InboundMailItemActionParams.Check
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemActionParams.Check.BuilderA builder for Check.
public final classInboundMailItemActionParams.Check.ActionThe action to perform on the Inbound Mail Item.
-
Method Summary
Modifier and Type Method Description final InboundMailItemActionParams.Check.Actionaction()The action to perform on the Inbound Mail Item. final Optional<String>accountId()The identifier of the Account to deposit the check into. final JsonField<InboundMailItemActionParams.Check.Action>_action()Returns the raw JSON value of action. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final Map<String, JsonValue>_additionalProperties()final InboundMailItemActionParams.Check.BuildertoBuilder()final InboundMailItemActionParams.Checkvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemActionParams.Check.Builderbuilder()Returns a mutable builder for constructing an instance of Check. -
-
Method Detail
-
action
final InboundMailItemActionParams.Check.Action action()
The action to perform on the Inbound Mail Item.
-
accountId
final Optional<String> accountId()
The identifier of the Account to deposit the check into.
-
_action
final JsonField<InboundMailItemActionParams.Check.Action> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundMailItemActionParams.Check.Builder toBuilder()
-
validate
final InboundMailItemActionParams.Check validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundMailItemActionParams.Check.Builder builder()
Returns a mutable builder for constructing an instance of Check.
The following fields are required:
.action()
-
-
-
-