Class InboundMailItemListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class InboundMailItemListPage implements Page<InboundMailItem>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemListPage.BuilderA builder for InboundMailItemListPage.
-
Method Summary
Modifier and Type Method Description final List<InboundMailItem>data()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. List<InboundMailItem>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final InboundMailItemListParamsnextPageParams()InboundMailItemListPagenextPage()Returns the page after this one by making another request. final AutoPager<InboundMailItem>autoPager()final InboundMailItemListParamsparams()The parameters that were used to request this page. final InboundMailItemListPageResponseresponse()The response that this page was parsed from. final InboundMailItemListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemListPage.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemListPage. -
-
Method Detail
-
data
final List<InboundMailItem> data()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
items
List<InboundMailItem> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final InboundMailItemListParams nextPageParams()
-
nextPage
InboundMailItemListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<InboundMailItem> autoPager()
-
params
final InboundMailItemListParams params()
The parameters that were used to request this page.
-
response
final InboundMailItemListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundMailItemListPage.Builder toBuilder()
-
builder
final static InboundMailItemListPage.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-