Class InboundMailItemListPage.Builder
-
- All Implemented Interfaces:
public final class InboundMailItemListPage.BuilderA builder for InboundMailItemListPage.
-
-
Method Summary
Modifier and Type Method Description final InboundMailItemListPage.Builderservice(InboundMailItemService service)final InboundMailItemListPage.Builderparams(InboundMailItemListParams params)The parameters that were used to request this page. final InboundMailItemListPage.Builderresponse(InboundMailItemListPageResponse response)The response that this page was parsed from. final InboundMailItemListPagebuild()Returns an immutable instance of InboundMailItemListPage. -
-
Method Detail
-
service
final InboundMailItemListPage.Builder service(InboundMailItemService service)
-
params
final InboundMailItemListPage.Builder params(InboundMailItemListParams params)
The parameters that were used to request this page.
-
response
final InboundMailItemListPage.Builder response(InboundMailItemListPageResponse response)
The response that this page was parsed from.
-
build
final InboundMailItemListPage build()
Returns an immutable instance of InboundMailItemListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-