Class InboundMailItemListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class InboundMailItemListPageAsync implements PageAsync<InboundMailItem>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemListPageAsync.BuilderA builder for InboundMailItemListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<InboundMailItem>data()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. List<InboundMailItem>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final InboundMailItemListParamsnextPageParams()CompletableFuture<InboundMailItemListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<InboundMailItem>autoPager()final InboundMailItemListParamsparams()The parameters that were used to request this page. final InboundMailItemListPageResponseresponse()The response that this page was parsed from. final InboundMailItemListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemListPageAsync. -
-
Method Detail
-
data
final List<InboundMailItem> data()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
items
List<InboundMailItem> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final InboundMailItemListParams nextPageParams()
-
nextPage
CompletableFuture<InboundMailItemListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<InboundMailItem> autoPager()
-
params
final InboundMailItemListParams params()
The parameters that were used to request this page.
-
response
final InboundMailItemListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundMailItemListPageAsync.Builder toBuilder()
-
builder
final static InboundMailItemListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-