Class InboundMailItemListPageAsync.Builder
-
- All Implemented Interfaces:
public final class InboundMailItemListPageAsync.BuilderA builder for InboundMailItemListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final InboundMailItemListPageAsync.Builderservice(InboundMailItemServiceAsync service)final InboundMailItemListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final InboundMailItemListPageAsync.Builderparams(InboundMailItemListParams params)The parameters that were used to request this page. final InboundMailItemListPageAsync.Builderresponse(InboundMailItemListPageResponse response)The response that this page was parsed from. final InboundMailItemListPageAsyncbuild()Returns an immutable instance of InboundMailItemListPageAsync. -
-
Method Detail
-
service
final InboundMailItemListPageAsync.Builder service(InboundMailItemServiceAsync service)
-
streamHandlerExecutor
final InboundMailItemListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final InboundMailItemListPageAsync.Builder params(InboundMailItemListParams params)
The parameters that were used to request this page.
-
response
final InboundMailItemListPageAsync.Builder response(InboundMailItemListPageResponse response)
The response that this page was parsed from.
-
build
final InboundMailItemListPageAsync build()
Returns an immutable instance of InboundMailItemListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-