Class InboundMailItemListPageResponse.Builder
-
- All Implemented Interfaces:
public final class InboundMailItemListPageResponse.BuilderA builder for InboundMailItemListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final InboundMailItemListPageResponse.Builder data(List<InboundMailItem> data)
The contents of the list.
-
data
final InboundMailItemListPageResponse.Builder data(JsonField<List<InboundMailItem>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<InboundMailItem>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final InboundMailItemListPageResponse.Builder addData(InboundMailItem data)
Adds a single InboundMailItem to Builder.data.
-
nextCursor
final InboundMailItemListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final InboundMailItemListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final InboundMailItemListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundMailItemListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundMailItemListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundMailItemListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundMailItemListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundMailItemListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundMailItemListPageResponse build()
Returns an immutable instance of InboundMailItemListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-