Class InboundWireDrawdownRequest
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestInbound wire drawdown requests are requests from someone else to send them a wire. For more information, see our /documentation/wire-drawdown-requests.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequest.BuilderA builder for InboundWireDrawdownRequest.
public final classInboundWireDrawdownRequest.TypeA constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Wire drawdown request identifier. final Longamount()The amount being requested in cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound wire drawdown request was created. final StringcreditorAccountNumber()The creditor's account number. final Optional<String>creditorAddressLine1()A free-form address field set by the sender. final Optional<String>creditorAddressLine2()A free-form address field set by the sender. final Optional<String>creditorAddressLine3()A free-form address field set by the sender. final Optional<String>creditorName()A name set by the sender. final StringcreditorRoutingNumber()The creditor's routing number. final Stringcurrency()The ISO 4217 code for the amount being requested. final Optional<String>debtorAddressLine1()A free-form address field set by the sender. final Optional<String>debtorAddressLine2()A free-form address field set by the sender. final Optional<String>debtorAddressLine3()A free-form address field set by the sender. final Optional<String>debtorName()A name set by the sender. final Optional<String>endToEndIdentification()A free-form reference string set by the sender, to help identify the drawdown request. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>instructionIdentification()The sending bank's identifier for the drawdown request. final StringrecipientAccountNumberId()The Account Number from which the recipient of this request is being requested to send funds. final InboundWireDrawdownRequest.Typetype()A constant representing the object's type. final Optional<String>uniqueEndToEndTransactionReference()The Unique End-to-end Transaction Reference (UETR) of the drawdown request. final Optional<String>unstructuredRemittanceInformation()A free-form message set by the sender. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_creditorAccountNumber()Returns the raw JSON value of creditorAccountNumber. final JsonField<String>_creditorAddressLine1()Returns the raw JSON value of creditorAddressLine1. final JsonField<String>_creditorAddressLine2()Returns the raw JSON value of creditorAddressLine2. final JsonField<String>_creditorAddressLine3()Returns the raw JSON value of creditorAddressLine3. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_creditorRoutingNumber()Returns the raw JSON value of creditorRoutingNumber. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_debtorAddressLine1()Returns the raw JSON value of debtorAddressLine1. final JsonField<String>_debtorAddressLine2()Returns the raw JSON value of debtorAddressLine2. final JsonField<String>_debtorAddressLine3()Returns the raw JSON value of debtorAddressLine3. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_instructionIdentification()Returns the raw JSON value of instructionIdentification. final JsonField<String>_recipientAccountNumberId()Returns the raw JSON value of recipientAccountNumberId. final JsonField<InboundWireDrawdownRequest.Type>_type()Returns the raw JSON value of type. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final InboundWireDrawdownRequest.BuildertoBuilder()final InboundWireDrawdownRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequest.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireDrawdownRequest. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound wire drawdown request was created.
-
creditorAccountNumber
final String creditorAccountNumber()
The creditor's account number.
-
creditorAddressLine1
final Optional<String> creditorAddressLine1()
A free-form address field set by the sender.
-
creditorAddressLine2
final Optional<String> creditorAddressLine2()
A free-form address field set by the sender.
-
creditorAddressLine3
final Optional<String> creditorAddressLine3()
A free-form address field set by the sender.
-
creditorName
final Optional<String> creditorName()
A name set by the sender.
-
creditorRoutingNumber
final String creditorRoutingNumber()
The creditor's routing number.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
debtorAddressLine1
final Optional<String> debtorAddressLine1()
A free-form address field set by the sender.
-
debtorAddressLine2
final Optional<String> debtorAddressLine2()
A free-form address field set by the sender.
-
debtorAddressLine3
final Optional<String> debtorAddressLine3()
A free-form address field set by the sender.
-
debtorName
final Optional<String> debtorName()
A name set by the sender.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender, to help identify the drawdown request.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
instructionIdentification
final Optional<String> instructionIdentification()
The sending bank's identifier for the drawdown request.
-
recipientAccountNumberId
final String recipientAccountNumberId()
The Account Number from which the recipient of this request is being requested to send funds.
-
type
final InboundWireDrawdownRequest.Type type()
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
uniqueEndToEndTransactionReference
final Optional<String> uniqueEndToEndTransactionReference()
The Unique End-to-end Transaction Reference (UETR) of the drawdown request.
-
unstructuredRemittanceInformation
final Optional<String> unstructuredRemittanceInformation()
A free-form message set by the sender.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAccountNumber
final JsonField<String> _creditorAccountNumber()
Returns the raw JSON value of creditorAccountNumber.
Unlike creditorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine1
final JsonField<String> _creditorAddressLine1()
Returns the raw JSON value of creditorAddressLine1.
Unlike creditorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine2
final JsonField<String> _creditorAddressLine2()
Returns the raw JSON value of creditorAddressLine2.
Unlike creditorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine3
final JsonField<String> _creditorAddressLine3()
Returns the raw JSON value of creditorAddressLine3.
Unlike creditorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorRoutingNumber
final JsonField<String> _creditorRoutingNumber()
Returns the raw JSON value of creditorRoutingNumber.
Unlike creditorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine1
final JsonField<String> _debtorAddressLine1()
Returns the raw JSON value of debtorAddressLine1.
Unlike debtorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine2
final JsonField<String> _debtorAddressLine2()
Returns the raw JSON value of debtorAddressLine2.
Unlike debtorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine3
final JsonField<String> _debtorAddressLine3()
Returns the raw JSON value of debtorAddressLine3.
Unlike debtorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_instructionIdentification
final JsonField<String> _instructionIdentification()
Returns the raw JSON value of instructionIdentification.
Unlike instructionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAccountNumberId
final JsonField<String> _recipientAccountNumberId()
Returns the raw JSON value of recipientAccountNumberId.
Unlike recipientAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundWireDrawdownRequest.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundWireDrawdownRequest.Builder toBuilder()
-
validate
final InboundWireDrawdownRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundWireDrawdownRequest.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequest.
The following fields are required:
.id() .amount() .createdAt() .creditorAccountNumber() .creditorAddressLine1() .creditorAddressLine2() .creditorAddressLine3() .creditorName() .creditorRoutingNumber() .currency() .debtorAddressLine1() .debtorAddressLine2() .debtorAddressLine3() .debtorName() .endToEndIdentification() .inputMessageAccountabilityData() .instructionIdentification() .recipientAccountNumberId() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation()
-
-
-
-