Class InboundWireDrawdownRequest.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequest.BuilderA builder for InboundWireDrawdownRequest.
-
-
Method Summary
-
-
Method Detail
-
id
final InboundWireDrawdownRequest.Builder id(String id)
The Wire drawdown request identifier.
-
id
final InboundWireDrawdownRequest.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireDrawdownRequest.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final InboundWireDrawdownRequest.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InboundWireDrawdownRequest.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound wire drawdown request was created.
-
createdAt
final InboundWireDrawdownRequest.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAccountNumber
final InboundWireDrawdownRequest.Builder creditorAccountNumber(String creditorAccountNumber)
The creditor's account number.
-
creditorAccountNumber
final InboundWireDrawdownRequest.Builder creditorAccountNumber(JsonField<String> creditorAccountNumber)
Sets Builder.creditorAccountNumber to an arbitrary JSON value.
You should usually call Builder.creditorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine1
final InboundWireDrawdownRequest.Builder creditorAddressLine1(String creditorAddressLine1)
A free-form address field set by the sender.
-
creditorAddressLine1
final InboundWireDrawdownRequest.Builder creditorAddressLine1(Optional<String> creditorAddressLine1)
Alias for calling Builder.creditorAddressLine1 with
creditorAddressLine1.orElse(null).
-
creditorAddressLine1
final InboundWireDrawdownRequest.Builder creditorAddressLine1(JsonField<String> creditorAddressLine1)
Sets Builder.creditorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine2
final InboundWireDrawdownRequest.Builder creditorAddressLine2(String creditorAddressLine2)
A free-form address field set by the sender.
-
creditorAddressLine2
final InboundWireDrawdownRequest.Builder creditorAddressLine2(Optional<String> creditorAddressLine2)
Alias for calling Builder.creditorAddressLine2 with
creditorAddressLine2.orElse(null).
-
creditorAddressLine2
final InboundWireDrawdownRequest.Builder creditorAddressLine2(JsonField<String> creditorAddressLine2)
Sets Builder.creditorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine3
final InboundWireDrawdownRequest.Builder creditorAddressLine3(String creditorAddressLine3)
A free-form address field set by the sender.
-
creditorAddressLine3
final InboundWireDrawdownRequest.Builder creditorAddressLine3(Optional<String> creditorAddressLine3)
Alias for calling Builder.creditorAddressLine3 with
creditorAddressLine3.orElse(null).
-
creditorAddressLine3
final InboundWireDrawdownRequest.Builder creditorAddressLine3(JsonField<String> creditorAddressLine3)
Sets Builder.creditorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final InboundWireDrawdownRequest.Builder creditorName(String creditorName)
A name set by the sender.
-
creditorName
final InboundWireDrawdownRequest.Builder creditorName(Optional<String> creditorName)
Alias for calling Builder.creditorName with
creditorName.orElse(null).
-
creditorName
final InboundWireDrawdownRequest.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorRoutingNumber
final InboundWireDrawdownRequest.Builder creditorRoutingNumber(String creditorRoutingNumber)
The creditor's routing number.
-
creditorRoutingNumber
final InboundWireDrawdownRequest.Builder creditorRoutingNumber(JsonField<String> creditorRoutingNumber)
Sets Builder.creditorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.creditorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InboundWireDrawdownRequest.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final InboundWireDrawdownRequest.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine1
final InboundWireDrawdownRequest.Builder debtorAddressLine1(String debtorAddressLine1)
A free-form address field set by the sender.
-
debtorAddressLine1
final InboundWireDrawdownRequest.Builder debtorAddressLine1(Optional<String> debtorAddressLine1)
Alias for calling Builder.debtorAddressLine1 with
debtorAddressLine1.orElse(null).
-
debtorAddressLine1
final InboundWireDrawdownRequest.Builder debtorAddressLine1(JsonField<String> debtorAddressLine1)
Sets Builder.debtorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine2
final InboundWireDrawdownRequest.Builder debtorAddressLine2(String debtorAddressLine2)
A free-form address field set by the sender.
-
debtorAddressLine2
final InboundWireDrawdownRequest.Builder debtorAddressLine2(Optional<String> debtorAddressLine2)
Alias for calling Builder.debtorAddressLine2 with
debtorAddressLine2.orElse(null).
-
debtorAddressLine2
final InboundWireDrawdownRequest.Builder debtorAddressLine2(JsonField<String> debtorAddressLine2)
Sets Builder.debtorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine3
final InboundWireDrawdownRequest.Builder debtorAddressLine3(String debtorAddressLine3)
A free-form address field set by the sender.
-
debtorAddressLine3
final InboundWireDrawdownRequest.Builder debtorAddressLine3(Optional<String> debtorAddressLine3)
Alias for calling Builder.debtorAddressLine3 with
debtorAddressLine3.orElse(null).
-
debtorAddressLine3
final InboundWireDrawdownRequest.Builder debtorAddressLine3(JsonField<String> debtorAddressLine3)
Sets Builder.debtorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final InboundWireDrawdownRequest.Builder debtorName(String debtorName)
A name set by the sender.
-
debtorName
final InboundWireDrawdownRequest.Builder debtorName(Optional<String> debtorName)
Alias for calling Builder.debtorName with
debtorName.orElse(null).
-
debtorName
final InboundWireDrawdownRequest.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final InboundWireDrawdownRequest.Builder endToEndIdentification(String endToEndIdentification)
A free-form reference string set by the sender, to help identify the drawdown request.
-
endToEndIdentification
final InboundWireDrawdownRequest.Builder endToEndIdentification(Optional<String> endToEndIdentification)
Alias for calling Builder.endToEndIdentification with
endToEndIdentification.orElse(null).
-
endToEndIdentification
final InboundWireDrawdownRequest.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputMessageAccountabilityData
final InboundWireDrawdownRequest.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final InboundWireDrawdownRequest.Builder inputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)
Alias for calling Builder.inputMessageAccountabilityData with
inputMessageAccountabilityData.orElse(null).
-
inputMessageAccountabilityData
final InboundWireDrawdownRequest.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.inputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructionIdentification
final InboundWireDrawdownRequest.Builder instructionIdentification(String instructionIdentification)
The sending bank's identifier for the drawdown request.
-
instructionIdentification
final InboundWireDrawdownRequest.Builder instructionIdentification(Optional<String> instructionIdentification)
Alias for calling Builder.instructionIdentification with
instructionIdentification.orElse(null).
-
instructionIdentification
final InboundWireDrawdownRequest.Builder instructionIdentification(JsonField<String> instructionIdentification)
Sets Builder.instructionIdentification to an arbitrary JSON value.
You should usually call Builder.instructionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumberId
final InboundWireDrawdownRequest.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number from which the recipient of this request is being requested to send funds.
-
recipientAccountNumberId
final InboundWireDrawdownRequest.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
Sets Builder.recipientAccountNumberId to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundWireDrawdownRequest.Builder type(InboundWireDrawdownRequest.Type type)
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
type
final InboundWireDrawdownRequest.Builder type(JsonField<InboundWireDrawdownRequest.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueEndToEndTransactionReference
final InboundWireDrawdownRequest.Builder uniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)
The Unique End-to-end Transaction Reference (UETR) of the drawdown request.
-
uniqueEndToEndTransactionReference
final InboundWireDrawdownRequest.Builder uniqueEndToEndTransactionReference(Optional<String> uniqueEndToEndTransactionReference)
Alias for calling Builder.uniqueEndToEndTransactionReference with
uniqueEndToEndTransactionReference.orElse(null).
-
uniqueEndToEndTransactionReference
final InboundWireDrawdownRequest.Builder uniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)
Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value.
You should usually call Builder.uniqueEndToEndTransactionReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final InboundWireDrawdownRequest.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
A free-form message set by the sender.
-
unstructuredRemittanceInformation
final InboundWireDrawdownRequest.Builder unstructuredRemittanceInformation(Optional<String> unstructuredRemittanceInformation)
Alias for calling Builder.unstructuredRemittanceInformation with
unstructuredRemittanceInformation.orElse(null).
-
unstructuredRemittanceInformation
final InboundWireDrawdownRequest.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireDrawdownRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireDrawdownRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireDrawdownRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireDrawdownRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireDrawdownRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireDrawdownRequest build()
Returns an immutable instance of InboundWireDrawdownRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .amount() .createdAt() .creditorAccountNumber() .creditorAddressLine1() .creditorAddressLine2() .creditorAddressLine3() .creditorName() .creditorRoutingNumber() .currency() .debtorAddressLine1() .debtorAddressLine2() .debtorAddressLine3() .debtorName() .endToEndIdentification() .inputMessageAccountabilityData() .instructionIdentification() .recipientAccountNumberId() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation()
-
-
-
-