Class InboundWireDrawdownRequestListPage.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestListPage.BuilderA builder for InboundWireDrawdownRequestListPage.
-
-
Method Summary
Modifier and Type Method Description final InboundWireDrawdownRequestListPage.Builderservice(InboundWireDrawdownRequestService service)final InboundWireDrawdownRequestListPage.Builderparams(InboundWireDrawdownRequestListParams params)The parameters that were used to request this page. final InboundWireDrawdownRequestListPage.Builderresponse(InboundWireDrawdownRequestListPageResponse response)The response that this page was parsed from. final InboundWireDrawdownRequestListPagebuild()Returns an immutable instance of InboundWireDrawdownRequestListPage. -
-
Method Detail
-
service
final InboundWireDrawdownRequestListPage.Builder service(InboundWireDrawdownRequestService service)
-
params
final InboundWireDrawdownRequestListPage.Builder params(InboundWireDrawdownRequestListParams params)
The parameters that were used to request this page.
-
response
final InboundWireDrawdownRequestListPage.Builder response(InboundWireDrawdownRequestListPageResponse response)
The response that this page was parsed from.
-
build
final InboundWireDrawdownRequestListPage build()
Returns an immutable instance of InboundWireDrawdownRequestListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-