Class InboundWireDrawdownRequestListPageAsync
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestListPageAsync.BuilderA builder for InboundWireDrawdownRequestListPageAsync.
public final classInboundWireDrawdownRequestListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<InboundWireDrawdownRequest> data()
Delegates to InboundWireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundWireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<InboundWireDrawdownRequestListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<InboundWireDrawdownRequestListPageAsync>> getNextPage()
-
autoPager
final InboundWireDrawdownRequestListPageAsync.AutoPager autoPager()
-
params
final InboundWireDrawdownRequestListParams params()
The parameters that were used to request this page.
-
response
final InboundWireDrawdownRequestListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundWireDrawdownRequestListPageAsync.Builder toBuilder()
-
builder
final static InboundWireDrawdownRequestListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-