Class InboundWireDrawdownRequestListPageAsync.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestListPageAsync.BuilderA builder for InboundWireDrawdownRequestListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final InboundWireDrawdownRequestListPageAsync.Builderservice(InboundWireDrawdownRequestServiceAsync service)final InboundWireDrawdownRequestListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final InboundWireDrawdownRequestListPageAsync.Builderparams(InboundWireDrawdownRequestListParams params)The parameters that were used to request this page. final InboundWireDrawdownRequestListPageAsync.Builderresponse(InboundWireDrawdownRequestListPageResponse response)The response that this page was parsed from. final InboundWireDrawdownRequestListPageAsyncbuild()Returns an immutable instance of InboundWireDrawdownRequestListPageAsync. -
-
Method Detail
-
service
final InboundWireDrawdownRequestListPageAsync.Builder service(InboundWireDrawdownRequestServiceAsync service)
-
streamHandlerExecutor
final InboundWireDrawdownRequestListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final InboundWireDrawdownRequestListPageAsync.Builder params(InboundWireDrawdownRequestListParams params)
The parameters that were used to request this page.
-
response
final InboundWireDrawdownRequestListPageAsync.Builder response(InboundWireDrawdownRequestListPageResponse response)
The response that this page was parsed from.
-
build
final InboundWireDrawdownRequestListPageAsync build()
Returns an immutable instance of InboundWireDrawdownRequestListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-