Class InboundWireDrawdownRequestListPageAsync.Response
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestListPageAsync.Response.Builder
-
Constructor Summary
Constructors Constructor Description InboundWireDrawdownRequestListPageAsync.Response(JsonField<List<InboundWireDrawdownRequest>> data, JsonField<String> nextCursor, Map<String, JsonValue> additionalProperties)
-
Method Summary
Modifier and Type Method Description final List<InboundWireDrawdownRequest>data()final Optional<String>nextCursor()final Optional<JsonField<List<InboundWireDrawdownRequest>>>_data()final Optional<JsonField<String>>_nextCursor()final Map<String, JsonValue>_additionalProperties()final InboundWireDrawdownRequestListPageAsync.Responsevalidate()final BooleanisValid()final InboundWireDrawdownRequestListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequestListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestListPageAsync. -
-
Method Detail
-
data
final List<InboundWireDrawdownRequest> data()
-
nextCursor
final Optional<String> nextCursor()
-
_data
final Optional<JsonField<List<InboundWireDrawdownRequest>>> _data()
-
_nextCursor
final Optional<JsonField<String>> _nextCursor()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InboundWireDrawdownRequestListPageAsync.Response validate()
-
toBuilder
final InboundWireDrawdownRequestListPageAsync.Response.Builder toBuilder()
-
builder
final static InboundWireDrawdownRequestListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestListPageAsync.
-
-
-
-