Class InboundWireDrawdownRequestListPageResponse.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestListPageResponse.BuilderA builder for InboundWireDrawdownRequestListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final InboundWireDrawdownRequestListPageResponse.Builder data(List<InboundWireDrawdownRequest> data)
The contents of the list.
-
data
final InboundWireDrawdownRequestListPageResponse.Builder data(JsonField<List<InboundWireDrawdownRequest>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<InboundWireDrawdownRequest>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final InboundWireDrawdownRequestListPageResponse.Builder addData(InboundWireDrawdownRequest data)
Adds a single InboundWireDrawdownRequest to Builder.data.
-
nextCursor
final InboundWireDrawdownRequestListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final InboundWireDrawdownRequestListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final InboundWireDrawdownRequestListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireDrawdownRequestListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireDrawdownRequestListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireDrawdownRequestListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireDrawdownRequestListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireDrawdownRequestListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireDrawdownRequestListPageResponse build()
Returns an immutable instance of InboundWireDrawdownRequestListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-