Class InboundWireDrawdownRequestRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundWireDrawdownRequestRetrieveParams implements Params
Retrieve an Inbound Wire Drawdown Request
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestRetrieveParams.BuilderA builder for InboundWireDrawdownRequestRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>inboundWireDrawdownRequestId()The identifier of the Inbound Wire Drawdown Request to retrieve. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundWireDrawdownRequestRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequestRetrieveParamsnone()final static InboundWireDrawdownRequestRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestRetrieveParams. -
-
Method Detail
-
inboundWireDrawdownRequestId
final Optional<String> inboundWireDrawdownRequestId()
The identifier of the Inbound Wire Drawdown Request to retrieve.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundWireDrawdownRequestRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboundWireDrawdownRequestRetrieveParams none()
-
builder
final static InboundWireDrawdownRequestRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestRetrieveParams.
-
-
-
-