Class InboundWireTransfer
-
- All Implemented Interfaces:
public final class InboundWireTransferAn Inbound Wire Transfer is a wire transfer initiated outside of Increase to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransfer.BuilderA builder for InboundWireTransfer.
public final classInboundWireTransfer.AcceptanceIf the transfer is accepted, this will contain details of the acceptance.
public final classInboundWireTransfer.ReversalIf the transfer is reversed, this will contain details of the reversal.
public final classInboundWireTransfer.StatusThe status of the transfer.
public final classInboundWireTransfer.TypeA constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The inbound wire transfer's identifier. final Optional<InboundWireTransfer.Acceptance>acceptance()If the transfer is accepted, this will contain details of the acceptance. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumberId()The identifier of the Account Number to which this transfer was sent. final Longamount()The amount in USD cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound wire transfer was created. final Optional<String>creditorAddressLine1()A free-form address field set by the sender. final Optional<String>creditorAddressLine2()A free-form address field set by the sender. final Optional<String>creditorAddressLine3()A free-form address field set by the sender. final Optional<String>creditorName()A name set by the sender. final Optional<String>debtorAddressLine1()A free-form address field set by the sender. final Optional<String>debtorAddressLine2()A free-form address field set by the sender. final Optional<String>debtorAddressLine3()A free-form address field set by the sender. final Optional<String>debtorName()A name set by the sender. final Stringdescription()An Increase-constructed description of the transfer. final Optional<String>endToEndIdentification()A free-form reference string set by the sender, to help identify the transfer. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>instructingAgentRoutingNumber()The American Banking Association (ABA) routing number of the bank that sent the wire. final Optional<String>instructionIdentification()The sending bank's identifier for the wire transfer. final Optional<InboundWireTransfer.Reversal>reversal()If the transfer is reversed, this will contain details of the reversal. final InboundWireTransfer.Statusstatus()The status of the transfer. final InboundWireTransfer.Typetype()A constant representing the object's type. final Optional<String>uniqueEndToEndTransactionReference()The Unique End-to-end Transaction Reference (UETR) of the transfer. final Optional<String>unstructuredRemittanceInformation()A free-form message set by the sender. final Optional<String>wireDrawdownRequestId()The wire drawdown request the inbound wire transfer is fulfilling. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<InboundWireTransfer.Acceptance>_acceptance()Returns the raw JSON value of acceptance. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_creditorAddressLine1()Returns the raw JSON value of creditorAddressLine1. final JsonField<String>_creditorAddressLine2()Returns the raw JSON value of creditorAddressLine2. final JsonField<String>_creditorAddressLine3()Returns the raw JSON value of creditorAddressLine3. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_debtorAddressLine1()Returns the raw JSON value of debtorAddressLine1. final JsonField<String>_debtorAddressLine2()Returns the raw JSON value of debtorAddressLine2. final JsonField<String>_debtorAddressLine3()Returns the raw JSON value of debtorAddressLine3. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_instructingAgentRoutingNumber()Returns the raw JSON value of instructingAgentRoutingNumber. final JsonField<String>_instructionIdentification()Returns the raw JSON value of instructionIdentification. final JsonField<InboundWireTransfer.Reversal>_reversal()Returns the raw JSON value of reversal. final JsonField<InboundWireTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<InboundWireTransfer.Type>_type()Returns the raw JSON value of type. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final JsonField<String>_wireDrawdownRequestId()Returns the raw JSON value of wireDrawdownRequestId. final Map<String, JsonValue>_additionalProperties()final InboundWireTransfer.BuildertoBuilder()final InboundWireTransfervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransfer. -
-
Method Detail
-
acceptance
final Optional<InboundWireTransfer.Acceptance> acceptance()
If the transfer is accepted, this will contain details of the acceptance.
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound wire transfer was created.
-
creditorAddressLine1
final Optional<String> creditorAddressLine1()
A free-form address field set by the sender.
-
creditorAddressLine2
final Optional<String> creditorAddressLine2()
A free-form address field set by the sender.
-
creditorAddressLine3
final Optional<String> creditorAddressLine3()
A free-form address field set by the sender.
-
creditorName
final Optional<String> creditorName()
A name set by the sender.
-
debtorAddressLine1
final Optional<String> debtorAddressLine1()
A free-form address field set by the sender.
-
debtorAddressLine2
final Optional<String> debtorAddressLine2()
A free-form address field set by the sender.
-
debtorAddressLine3
final Optional<String> debtorAddressLine3()
A free-form address field set by the sender.
-
debtorName
final Optional<String> debtorName()
A name set by the sender.
-
description
final String description()
An Increase-constructed description of the transfer.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender, to help identify the transfer.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
instructingAgentRoutingNumber
final Optional<String> instructingAgentRoutingNumber()
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
instructionIdentification
final Optional<String> instructionIdentification()
The sending bank's identifier for the wire transfer.
-
reversal
final Optional<InboundWireTransfer.Reversal> reversal()
If the transfer is reversed, this will contain details of the reversal.
-
status
final InboundWireTransfer.Status status()
The status of the transfer.
-
type
final InboundWireTransfer.Type type()
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
uniqueEndToEndTransactionReference
final Optional<String> uniqueEndToEndTransactionReference()
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
unstructuredRemittanceInformation
final Optional<String> unstructuredRemittanceInformation()
A free-form message set by the sender.
-
wireDrawdownRequestId
final Optional<String> wireDrawdownRequestId()
The wire drawdown request the inbound wire transfer is fulfilling.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_acceptance
final JsonField<InboundWireTransfer.Acceptance> _acceptance()
Returns the raw JSON value of acceptance.
Unlike acceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine1
final JsonField<String> _creditorAddressLine1()
Returns the raw JSON value of creditorAddressLine1.
Unlike creditorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine2
final JsonField<String> _creditorAddressLine2()
Returns the raw JSON value of creditorAddressLine2.
Unlike creditorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine3
final JsonField<String> _creditorAddressLine3()
Returns the raw JSON value of creditorAddressLine3.
Unlike creditorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine1
final JsonField<String> _debtorAddressLine1()
Returns the raw JSON value of debtorAddressLine1.
Unlike debtorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine2
final JsonField<String> _debtorAddressLine2()
Returns the raw JSON value of debtorAddressLine2.
Unlike debtorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine3
final JsonField<String> _debtorAddressLine3()
Returns the raw JSON value of debtorAddressLine3.
Unlike debtorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_instructingAgentRoutingNumber
final JsonField<String> _instructingAgentRoutingNumber()
Returns the raw JSON value of instructingAgentRoutingNumber.
Unlike instructingAgentRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_instructionIdentification
final JsonField<String> _instructionIdentification()
Returns the raw JSON value of instructionIdentification.
Unlike instructionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_reversal
final JsonField<InboundWireTransfer.Reversal> _reversal()
Returns the raw JSON value of reversal.
Unlike reversal, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InboundWireTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundWireTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_wireDrawdownRequestId
final JsonField<String> _wireDrawdownRequestId()
Returns the raw JSON value of wireDrawdownRequestId.
Unlike wireDrawdownRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundWireTransfer.Builder toBuilder()
-
validate
final InboundWireTransfer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundWireTransfer.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransfer.
The following fields are required:
.id() .acceptance() .accountId() .accountNumberId() .amount() .createdAt() .creditorAddressLine1() .creditorAddressLine2() .creditorAddressLine3() .creditorName() .debtorAddressLine1() .debtorAddressLine2() .debtorAddressLine3() .debtorName() .description() .endToEndIdentification() .inputMessageAccountabilityData() .instructingAgentRoutingNumber() .instructionIdentification() .reversal() .status() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation() .wireDrawdownRequestId()
-
-
-
-