Class InboundWireTransfer.Acceptance
-
- All Implemented Interfaces:
public final class InboundWireTransfer.AcceptanceIf the transfer is accepted, this will contain details of the acceptance.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransfer.Acceptance.BuilderA builder for Acceptance.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The ISO 8601 date and time at which the transfer was accepted. final StringtransactionId()The identifier of the transaction for the accepted transfer. final JsonField<OffsetDateTime>_acceptedAt()Returns the raw JSON value of acceptedAt. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final InboundWireTransfer.Acceptance.BuildertoBuilder()final InboundWireTransfer.Acceptancevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransfer.Acceptance.Builderbuilder()Returns a mutable builder for constructing an instance of Acceptance. -
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the transfer was accepted.
-
transactionId
final String transactionId()
The identifier of the transaction for the accepted transfer.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundWireTransfer.Acceptance.Builder toBuilder()
-
validate
final InboundWireTransfer.Acceptance validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundWireTransfer.Acceptance.Builder builder()
Returns a mutable builder for constructing an instance of Acceptance.
The following fields are required:
.acceptedAt() .transactionId()
-
-
-
-