Class InboundWireTransfer.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
-
Method Summary
-
-
Method Detail
-
id
final InboundWireTransfer.Builder id(String id)
The inbound wire transfer's identifier.
-
id
final InboundWireTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
acceptance
final InboundWireTransfer.Builder acceptance(InboundWireTransfer.Acceptance acceptance)
If the transfer is accepted, this will contain details of the acceptance.
-
acceptance
final InboundWireTransfer.Builder acceptance(Optional<InboundWireTransfer.Acceptance> acceptance)
Alias for calling Builder.acceptance with
acceptance.orElse(null).
-
acceptance
final InboundWireTransfer.Builder acceptance(JsonField<InboundWireTransfer.Acceptance> acceptance)
Sets Builder.acceptance to an arbitrary JSON value.
You should usually call Builder.acceptance with a well-typed Acceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final InboundWireTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final InboundWireTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumberId
final InboundWireTransfer.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
accountNumberId
final InboundWireTransfer.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireTransfer.Builder amount(Long amount)
The amount in USD cents.
-
amount
final InboundWireTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InboundWireTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound wire transfer was created.
-
createdAt
final InboundWireTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine1
final InboundWireTransfer.Builder creditorAddressLine1(String creditorAddressLine1)
A free-form address field set by the sender.
-
creditorAddressLine1
final InboundWireTransfer.Builder creditorAddressLine1(Optional<String> creditorAddressLine1)
Alias for calling Builder.creditorAddressLine1 with
creditorAddressLine1.orElse(null).
-
creditorAddressLine1
final InboundWireTransfer.Builder creditorAddressLine1(JsonField<String> creditorAddressLine1)
Sets Builder.creditorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine2
final InboundWireTransfer.Builder creditorAddressLine2(String creditorAddressLine2)
A free-form address field set by the sender.
-
creditorAddressLine2
final InboundWireTransfer.Builder creditorAddressLine2(Optional<String> creditorAddressLine2)
Alias for calling Builder.creditorAddressLine2 with
creditorAddressLine2.orElse(null).
-
creditorAddressLine2
final InboundWireTransfer.Builder creditorAddressLine2(JsonField<String> creditorAddressLine2)
Sets Builder.creditorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine3
final InboundWireTransfer.Builder creditorAddressLine3(String creditorAddressLine3)
A free-form address field set by the sender.
-
creditorAddressLine3
final InboundWireTransfer.Builder creditorAddressLine3(Optional<String> creditorAddressLine3)
Alias for calling Builder.creditorAddressLine3 with
creditorAddressLine3.orElse(null).
-
creditorAddressLine3
final InboundWireTransfer.Builder creditorAddressLine3(JsonField<String> creditorAddressLine3)
Sets Builder.creditorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final InboundWireTransfer.Builder creditorName(String creditorName)
A name set by the sender.
-
creditorName
final InboundWireTransfer.Builder creditorName(Optional<String> creditorName)
Alias for calling Builder.creditorName with
creditorName.orElse(null).
-
creditorName
final InboundWireTransfer.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine1
final InboundWireTransfer.Builder debtorAddressLine1(String debtorAddressLine1)
A free-form address field set by the sender.
-
debtorAddressLine1
final InboundWireTransfer.Builder debtorAddressLine1(Optional<String> debtorAddressLine1)
Alias for calling Builder.debtorAddressLine1 with
debtorAddressLine1.orElse(null).
-
debtorAddressLine1
final InboundWireTransfer.Builder debtorAddressLine1(JsonField<String> debtorAddressLine1)
Sets Builder.debtorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine2
final InboundWireTransfer.Builder debtorAddressLine2(String debtorAddressLine2)
A free-form address field set by the sender.
-
debtorAddressLine2
final InboundWireTransfer.Builder debtorAddressLine2(Optional<String> debtorAddressLine2)
Alias for calling Builder.debtorAddressLine2 with
debtorAddressLine2.orElse(null).
-
debtorAddressLine2
final InboundWireTransfer.Builder debtorAddressLine2(JsonField<String> debtorAddressLine2)
Sets Builder.debtorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine3
final InboundWireTransfer.Builder debtorAddressLine3(String debtorAddressLine3)
A free-form address field set by the sender.
-
debtorAddressLine3
final InboundWireTransfer.Builder debtorAddressLine3(Optional<String> debtorAddressLine3)
Alias for calling Builder.debtorAddressLine3 with
debtorAddressLine3.orElse(null).
-
debtorAddressLine3
final InboundWireTransfer.Builder debtorAddressLine3(JsonField<String> debtorAddressLine3)
Sets Builder.debtorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final InboundWireTransfer.Builder debtorName(String debtorName)
A name set by the sender.
-
debtorName
final InboundWireTransfer.Builder debtorName(Optional<String> debtorName)
Alias for calling Builder.debtorName with
debtorName.orElse(null).
-
debtorName
final InboundWireTransfer.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final InboundWireTransfer.Builder description(String description)
An Increase-constructed description of the transfer.
-
description
final InboundWireTransfer.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final InboundWireTransfer.Builder endToEndIdentification(String endToEndIdentification)
A free-form reference string set by the sender, to help identify the transfer.
-
endToEndIdentification
final InboundWireTransfer.Builder endToEndIdentification(Optional<String> endToEndIdentification)
Alias for calling Builder.endToEndIdentification with
endToEndIdentification.orElse(null).
-
endToEndIdentification
final InboundWireTransfer.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)
Alias for calling Builder.inputMessageAccountabilityData with
inputMessageAccountabilityData.orElse(null).
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.inputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructingAgentRoutingNumber
final InboundWireTransfer.Builder instructingAgentRoutingNumber(String instructingAgentRoutingNumber)
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
instructingAgentRoutingNumber
final InboundWireTransfer.Builder instructingAgentRoutingNumber(Optional<String> instructingAgentRoutingNumber)
Alias for calling Builder.instructingAgentRoutingNumber with
instructingAgentRoutingNumber.orElse(null).
-
instructingAgentRoutingNumber
final InboundWireTransfer.Builder instructingAgentRoutingNumber(JsonField<String> instructingAgentRoutingNumber)
Sets Builder.instructingAgentRoutingNumber to an arbitrary JSON value.
You should usually call Builder.instructingAgentRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructionIdentification
final InboundWireTransfer.Builder instructionIdentification(String instructionIdentification)
The sending bank's identifier for the wire transfer.
-
instructionIdentification
final InboundWireTransfer.Builder instructionIdentification(Optional<String> instructionIdentification)
Alias for calling Builder.instructionIdentification with
instructionIdentification.orElse(null).
-
instructionIdentification
final InboundWireTransfer.Builder instructionIdentification(JsonField<String> instructionIdentification)
Sets Builder.instructionIdentification to an arbitrary JSON value.
You should usually call Builder.instructionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversal
final InboundWireTransfer.Builder reversal(InboundWireTransfer.Reversal reversal)
If the transfer is reversed, this will contain details of the reversal.
-
reversal
final InboundWireTransfer.Builder reversal(Optional<InboundWireTransfer.Reversal> reversal)
Alias for calling Builder.reversal with
reversal.orElse(null).
-
reversal
final InboundWireTransfer.Builder reversal(JsonField<InboundWireTransfer.Reversal> reversal)
Sets Builder.reversal to an arbitrary JSON value.
You should usually call Builder.reversal with a well-typed Reversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InboundWireTransfer.Builder status(InboundWireTransfer.Status status)
The status of the transfer.
-
status
final InboundWireTransfer.Builder status(JsonField<InboundWireTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundWireTransfer.Builder type(InboundWireTransfer.Type type)
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
type
final InboundWireTransfer.Builder type(JsonField<InboundWireTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueEndToEndTransactionReference
final InboundWireTransfer.Builder uniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
uniqueEndToEndTransactionReference
final InboundWireTransfer.Builder uniqueEndToEndTransactionReference(Optional<String> uniqueEndToEndTransactionReference)
Alias for calling Builder.uniqueEndToEndTransactionReference with
uniqueEndToEndTransactionReference.orElse(null).
-
uniqueEndToEndTransactionReference
final InboundWireTransfer.Builder uniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)
Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value.
You should usually call Builder.uniqueEndToEndTransactionReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final InboundWireTransfer.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
A free-form message set by the sender.
-
unstructuredRemittanceInformation
final InboundWireTransfer.Builder unstructuredRemittanceInformation(Optional<String> unstructuredRemittanceInformation)
Alias for calling Builder.unstructuredRemittanceInformation with
unstructuredRemittanceInformation.orElse(null).
-
unstructuredRemittanceInformation
final InboundWireTransfer.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireDrawdownRequestId
final InboundWireTransfer.Builder wireDrawdownRequestId(String wireDrawdownRequestId)
The wire drawdown request the inbound wire transfer is fulfilling.
-
wireDrawdownRequestId
final InboundWireTransfer.Builder wireDrawdownRequestId(Optional<String> wireDrawdownRequestId)
Alias for calling Builder.wireDrawdownRequestId with
wireDrawdownRequestId.orElse(null).
-
wireDrawdownRequestId
final InboundWireTransfer.Builder wireDrawdownRequestId(JsonField<String> wireDrawdownRequestId)
Sets Builder.wireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.wireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireTransfer build()
Returns an immutable instance of InboundWireTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .acceptance() .accountId() .accountNumberId() .amount() .createdAt() .creditorAddressLine1() .creditorAddressLine2() .creditorAddressLine3() .creditorName() .debtorAddressLine1() .debtorAddressLine2() .debtorAddressLine3() .debtorName() .description() .endToEndIdentification() .inputMessageAccountabilityData() .instructingAgentRoutingNumber() .instructionIdentification() .reversal() .status() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation() .wireDrawdownRequestId()
-
-
-
-