Class InboundWireTransfer.Reversal
-
- All Implemented Interfaces:
public final class InboundWireTransfer.ReversalIf the transfer is reversed, this will contain details of the reversal.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransfer.Reversal.BuilderA builder for Reversal.
public final classInboundWireTransfer.Reversal.ReasonThe reason for the reversal.
-
Method Summary
Modifier and Type Method Description final InboundWireTransfer.Reversal.Reasonreason()The reason for the reversal. final OffsetDateTimereversedAt()The ISO 8601 date and time at which the transfer was reversed. final JsonField<InboundWireTransfer.Reversal.Reason>_reason()Returns the raw JSON value of reason. final JsonField<OffsetDateTime>_reversedAt()Returns the raw JSON value of reversedAt. final Map<String, JsonValue>_additionalProperties()final InboundWireTransfer.Reversal.BuildertoBuilder()final InboundWireTransfer.Reversalvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransfer.Reversal.Builderbuilder()Returns a mutable builder for constructing an instance of Reversal. -
-
Method Detail
-
reason
final InboundWireTransfer.Reversal.Reason reason()
The reason for the reversal.
-
reversedAt
final OffsetDateTime reversedAt()
The ISO 8601 date and time at which the transfer was reversed.
-
_reason
final JsonField<InboundWireTransfer.Reversal.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_reversedAt
final JsonField<OffsetDateTime> _reversedAt()
Returns the raw JSON value of reversedAt.
Unlike reversedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundWireTransfer.Reversal.Builder toBuilder()
-
validate
final InboundWireTransfer.Reversal validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InboundWireTransfer.Reversal.Builder builder()
Returns a mutable builder for constructing an instance of Reversal.
The following fields are required:
.reason() .reversedAt()
-
-
-
-