Class InboundWireTransfer.Reversal.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransfer.Reversal.BuilderA builder for Reversal.
-
-
Method Summary
-
-
Method Detail
-
reason
final InboundWireTransfer.Reversal.Builder reason(InboundWireTransfer.Reversal.Reason reason)
The reason for the reversal.
-
reason
final InboundWireTransfer.Reversal.Builder reason(JsonField<InboundWireTransfer.Reversal.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversedAt
final InboundWireTransfer.Reversal.Builder reversedAt(OffsetDateTime reversedAt)
The ISO 8601 date and time at which the transfer was reversed.
-
reversedAt
final InboundWireTransfer.Reversal.Builder reversedAt(JsonField<OffsetDateTime> reversedAt)
Sets Builder.reversedAt to an arbitrary JSON value.
You should usually call Builder.reversedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireTransfer.Reversal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireTransfer.Reversal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireTransfer.Reversal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireTransfer.Reversal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireTransfer.Reversal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireTransfer.Reversal build()
Returns an immutable instance of Reversal.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.reason() .reversedAt()
-
-
-
-