Enum InboundWireTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundWireTransfer.Status.Known extends Enum<InboundWireTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundWireTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDINGThe Inbound Wire Transfer is awaiting action, will transition automatically if no action is taken.
ACCEPTEDThe Inbound Wire Transfer is accepted.
DECLINEDThe Inbound Wire Transfer was declined.
REVERSEDThe Inbound Wire Transfer was reversed.
-
Method Summary
Modifier and Type Method Description final InboundWireTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundWireTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundWireTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final InboundWireTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundWireTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundWireTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-