Class InboundWireTransferListPage
-
- All Implemented Interfaces:
public final class InboundWireTransferListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferListPage.BuilderA builder for InboundWireTransferListPage.
public final classInboundWireTransferListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<InboundWireTransfer>data()Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<InboundWireTransferListParams>getNextPageParams()final Optional<InboundWireTransferListPage>getNextPage()final InboundWireTransferListPage.AutoPagerautoPager()final InboundWireTransferListParamsparams()The parameters that were used to request this page. final InboundWireTransferListPageResponseresponse()The response that this page was parsed from. final InboundWireTransferListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransferListPage.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransferListPage. -
-
Method Detail
-
data
final List<InboundWireTransfer> data()
Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<InboundWireTransferListParams> getNextPageParams()
-
getNextPage
final Optional<InboundWireTransferListPage> getNextPage()
-
autoPager
final InboundWireTransferListPage.AutoPager autoPager()
-
params
final InboundWireTransferListParams params()
The parameters that were used to request this page.
-
response
final InboundWireTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundWireTransferListPage.Builder toBuilder()
-
builder
final static InboundWireTransferListPage.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransferListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-