Class InboundWireTransferListPage.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransferListPage.BuilderA builder for InboundWireTransferListPage.
-
-
Method Summary
Modifier and Type Method Description final InboundWireTransferListPage.Builderservice(InboundWireTransferService service)final InboundWireTransferListPage.Builderparams(InboundWireTransferListParams params)The parameters that were used to request this page. final InboundWireTransferListPage.Builderresponse(InboundWireTransferListPageResponse response)The response that this page was parsed from. final InboundWireTransferListPagebuild()Returns an immutable instance of InboundWireTransferListPage. -
-
Method Detail
-
service
final InboundWireTransferListPage.Builder service(InboundWireTransferService service)
-
params
final InboundWireTransferListPage.Builder params(InboundWireTransferListParams params)
The parameters that were used to request this page.
-
response
final InboundWireTransferListPage.Builder response(InboundWireTransferListPageResponse response)
The response that this page was parsed from.
-
build
final InboundWireTransferListPage build()
Returns an immutable instance of InboundWireTransferListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-