Class InboundWireTransferListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class InboundWireTransferListPageAsync implements PageAsync<InboundWireTransfer>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferListPageAsync.BuilderA builder for InboundWireTransferListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<InboundWireTransfer>data()Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data. List<InboundWireTransfer>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final InboundWireTransferListParamsnextPageParams()CompletableFuture<InboundWireTransferListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<InboundWireTransfer>autoPager()final InboundWireTransferListParamsparams()The parameters that were used to request this page. final InboundWireTransferListPageResponseresponse()The response that this page was parsed from. final InboundWireTransferListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransferListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransferListPageAsync. -
-
Method Detail
-
data
final List<InboundWireTransfer> data()
Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundWireTransferListPageResponse, but gracefully handles missing data.
-
items
List<InboundWireTransfer> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final InboundWireTransferListParams nextPageParams()
-
nextPage
CompletableFuture<InboundWireTransferListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<InboundWireTransfer> autoPager()
-
params
final InboundWireTransferListParams params()
The parameters that were used to request this page.
-
response
final InboundWireTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundWireTransferListPageAsync.Builder toBuilder()
-
builder
final static InboundWireTransferListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransferListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-