Class InboundWireTransferListPageAsync.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransferListPageAsync.BuilderA builder for InboundWireTransferListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final InboundWireTransferListPageAsync.Builderservice(InboundWireTransferServiceAsync service)final InboundWireTransferListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final InboundWireTransferListPageAsync.Builderparams(InboundWireTransferListParams params)The parameters that were used to request this page. final InboundWireTransferListPageAsync.Builderresponse(InboundWireTransferListPageResponse response)The response that this page was parsed from. final InboundWireTransferListPageAsyncbuild()Returns an immutable instance of InboundWireTransferListPageAsync. -
-
Method Detail
-
service
final InboundWireTransferListPageAsync.Builder service(InboundWireTransferServiceAsync service)
-
streamHandlerExecutor
final InboundWireTransferListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final InboundWireTransferListPageAsync.Builder params(InboundWireTransferListParams params)
The parameters that were used to request this page.
-
response
final InboundWireTransferListPageAsync.Builder response(InboundWireTransferListPageResponse response)
The response that this page was parsed from.
-
build
final InboundWireTransferListPageAsync build()
Returns an immutable instance of InboundWireTransferListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-