Class InboundWireTransferListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundWireTransferListParams implements Params
List Inbound Wire Transfers
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferListParams.BuilderA builder for InboundWireTransferListParams.
public final classInboundWireTransferListParams.CreatedAtpublic final classInboundWireTransferListParams.Status
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Inbound Wire Transfers to ones belonging to the specified Account. final Optional<String>accountNumberId()Filter Inbound Wire Transfers to ones belonging to the specified Account Number. final Optional<InboundWireTransferListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Optional<InboundWireTransferListParams.Status>status()final Optional<String>wireDrawdownRequestId()Filter Inbound Wire Transfers to ones belonging to the specified Wire Drawdown Request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundWireTransferListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransferListParamsnone()final static InboundWireTransferListParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransferListParams. -
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Inbound Wire Transfers to ones belonging to the specified Account.
-
accountNumberId
final Optional<String> accountNumberId()
Filter Inbound Wire Transfers to ones belonging to the specified Account Number.
-
createdAt
final Optional<InboundWireTransferListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
status
final Optional<InboundWireTransferListParams.Status> status()
-
wireDrawdownRequestId
final Optional<String> wireDrawdownRequestId()
Filter Inbound Wire Transfers to ones belonging to the specified Wire Drawdown Request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundWireTransferListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InboundWireTransferListParams none()
-
builder
final static InboundWireTransferListParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransferListParams.
-
-
-
-