Class IntrafiBalance
-
- All Implemented Interfaces:
public final class IntrafiBalanceWhen using IntraFi, each account's balance over the standard FDIC insurance amount is swept to various other institutions. Funds are rebalanced across banks as needed once per business day.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiBalance.BuilderA builder for IntrafiBalance.
public final classIntrafiBalance.Balancepublic final classIntrafiBalance.CurrencyThe ISO 4217 code for the account currency.
public final classIntrafiBalance.TypeA constant representing the object's type. For this resource it will always be
intrafi_balance.
-
Method Summary
Modifier and Type Method Description final List<IntrafiBalance.Balance>balances()Each entry represents a balance held at a different bank. final IntrafiBalance.Currencycurrency()The ISO 4217 code for the account currency. final LocalDateeffectiveDate()The date this balance reflects. final LongtotalBalance()The total balance, in minor units of currency.final IntrafiBalance.Typetype()A constant representing the object's type. final JsonField<List<IntrafiBalance.Balance>>_balances()Returns the raw JSON value of balances. final JsonField<IntrafiBalance.Currency>_currency()Returns the raw JSON value of currency. final JsonField<LocalDate>_effectiveDate()Returns the raw JSON value of effectiveDate. final JsonField<Long>_totalBalance()Returns the raw JSON value of totalBalance. final JsonField<IntrafiBalance.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final IntrafiBalance.BuildertoBuilder()final IntrafiBalancevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiBalance.Builderbuilder()Returns a mutable builder for constructing an instance of IntrafiBalance. -
-
Method Detail
-
balances
final List<IntrafiBalance.Balance> balances()
Each entry represents a balance held at a different bank. IntraFi separates the total balance across many participating banks in the network.
-
currency
final IntrafiBalance.Currency currency()
The ISO 4217 code for the account currency.
-
effectiveDate
final LocalDate effectiveDate()
The date this balance reflects.
-
totalBalance
final Long totalBalance()
The total balance, in minor units of
currency. Increase reports this balance to IntraFi daily.
-
type
final IntrafiBalance.Type type()
A constant representing the object's type. For this resource it will always be
intrafi_balance.
-
_balances
final JsonField<List<IntrafiBalance.Balance>> _balances()
Returns the raw JSON value of balances.
Unlike balances, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<IntrafiBalance.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_effectiveDate
final JsonField<LocalDate> _effectiveDate()
Returns the raw JSON value of effectiveDate.
Unlike effectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_totalBalance
final JsonField<Long> _totalBalance()
Returns the raw JSON value of totalBalance.
Unlike totalBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<IntrafiBalance.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IntrafiBalance.Builder toBuilder()
-
validate
final IntrafiBalance validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static IntrafiBalance.Builder builder()
Returns a mutable builder for constructing an instance of IntrafiBalance.
The following fields are required:
.balances() .currency() .effectiveDate() .totalBalance() .type()
-
-
-
-