Class IntrafiBalance.Balance
-
- All Implemented Interfaces:
public final class IntrafiBalance.Balance
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiBalance.Balance.BuilderA builder for Balance.
public final classIntrafiBalance.Balance.BankLocationThe primary location of the bank.
-
Method Summary
Modifier and Type Method Description final Stringid()The identifier of this balance. final Longbalance()The balance, in minor units of currency, held with this bank.final Stringbank()The name of the bank holding these funds. final Optional<IntrafiBalance.Balance.BankLocation>bankLocation()The primary location of the bank. final StringfdicCertificateNumber()The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_balance()Returns the raw JSON value of balance. final JsonField<String>_bank()Returns the raw JSON value of bank. final JsonField<IntrafiBalance.Balance.BankLocation>_bankLocation()Returns the raw JSON value of bankLocation. final JsonField<String>_fdicCertificateNumber()Returns the raw JSON value of fdicCertificateNumber. final Map<String, JsonValue>_additionalProperties()final IntrafiBalance.Balance.BuildertoBuilder()final IntrafiBalance.Balancevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiBalance.Balance.Builderbuilder()Returns a mutable builder for constructing an instance of Balance. -
-
Method Detail
-
bankLocation
final Optional<IntrafiBalance.Balance.BankLocation> bankLocation()
The primary location of the bank.
-
fdicCertificateNumber
final String fdicCertificateNumber()
The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank. Because many banks have the same or similar names, this can be used to uniquely identify the institution.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_balance
final JsonField<Long> _balance()
Returns the raw JSON value of balance.
Unlike balance, this method doesn't throw if the JSON field has an unexpected type.
-
_bank
final JsonField<String> _bank()
Returns the raw JSON value of bank.
Unlike bank, this method doesn't throw if the JSON field has an unexpected type.
-
_bankLocation
final JsonField<IntrafiBalance.Balance.BankLocation> _bankLocation()
Returns the raw JSON value of bankLocation.
Unlike bankLocation, this method doesn't throw if the JSON field has an unexpected type.
-
_fdicCertificateNumber
final JsonField<String> _fdicCertificateNumber()
Returns the raw JSON value of fdicCertificateNumber.
Unlike fdicCertificateNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final IntrafiBalance.Balance.Builder toBuilder()
-
validate
final IntrafiBalance.Balance validate()
-
builder
final static IntrafiBalance.Balance.Builder builder()
Returns a mutable builder for constructing an instance of Balance.
The following fields are required:
.id() .balance() .bank() .bankLocation() .fdicCertificateNumber()
-
-
-
-