Class IntrafiBalance.Balance.Builder
-
- All Implemented Interfaces:
public final class IntrafiBalance.Balance.BuilderA builder for Balance.
-
-
Method Summary
-
-
Method Detail
-
id
final IntrafiBalance.Balance.Builder id(String id)
The identifier of this balance.
-
id
final IntrafiBalance.Balance.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balance
final IntrafiBalance.Balance.Builder balance(Long balance)
The balance, in minor units of
currency, held with this bank.
-
balance
final IntrafiBalance.Balance.Builder balance(JsonField<Long> balance)
Sets Builder.balance to an arbitrary JSON value.
You should usually call Builder.balance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bank
final IntrafiBalance.Balance.Builder bank(String bank)
The name of the bank holding these funds.
-
bank
final IntrafiBalance.Balance.Builder bank(JsonField<String> bank)
Sets Builder.bank to an arbitrary JSON value.
You should usually call Builder.bank with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bankLocation
final IntrafiBalance.Balance.Builder bankLocation(IntrafiBalance.Balance.BankLocation bankLocation)
The primary location of the bank.
-
bankLocation
final IntrafiBalance.Balance.Builder bankLocation(Optional<IntrafiBalance.Balance.BankLocation> bankLocation)
Alias for calling Builder.bankLocation with
bankLocation.orElse(null).
-
bankLocation
final IntrafiBalance.Balance.Builder bankLocation(JsonField<IntrafiBalance.Balance.BankLocation> bankLocation)
Sets Builder.bankLocation to an arbitrary JSON value.
You should usually call Builder.bankLocation with a well-typed BankLocation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fdicCertificateNumber
final IntrafiBalance.Balance.Builder fdicCertificateNumber(String fdicCertificateNumber)
The Federal Deposit Insurance Corporation (FDIC) certificate number of the bank. Because many banks have the same or similar names, this can be used to uniquely identify the institution.
-
fdicCertificateNumber
final IntrafiBalance.Balance.Builder fdicCertificateNumber(JsonField<String> fdicCertificateNumber)
Sets Builder.fdicCertificateNumber to an arbitrary JSON value.
You should usually call Builder.fdicCertificateNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final IntrafiBalance.Balance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final IntrafiBalance.Balance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final IntrafiBalance.Balance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final IntrafiBalance.Balance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final IntrafiBalance.Balance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final IntrafiBalance.Balance build()
Returns an immutable instance of Balance.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .balance() .bank() .bankLocation() .fdicCertificateNumber()
-
-
-
-