Class IntrafiBalance.Builder
-
- All Implemented Interfaces:
public final class IntrafiBalance.BuilderA builder for IntrafiBalance.
-
-
Method Summary
-
-
Method Detail
-
id
final IntrafiBalance.Builder id(String id)
The identifier of this balance.
-
id
final IntrafiBalance.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balances
final IntrafiBalance.Builder balances(List<IntrafiBalance.Balance> balances)
Each entry represents a balance held at a different bank. IntraFi separates the total balance across many participating banks in the network.
-
balances
final IntrafiBalance.Builder balances(JsonField<List<IntrafiBalance.Balance>> balances)
Sets Builder.balances to an arbitrary JSON value.
You should usually call Builder.balances with a well-typed
List<Balance>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addBalance
final IntrafiBalance.Builder addBalance(IntrafiBalance.Balance balance)
-
currency
final IntrafiBalance.Builder currency(IntrafiBalance.Currency currency)
The ISO 4217 code for the account currency.
-
currency
final IntrafiBalance.Builder currency(JsonField<IntrafiBalance.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
effectiveDate
final IntrafiBalance.Builder effectiveDate(LocalDate effectiveDate)
The date this balance reflects.
-
effectiveDate
final IntrafiBalance.Builder effectiveDate(JsonField<LocalDate> effectiveDate)
Sets Builder.effectiveDate to an arbitrary JSON value.
You should usually call Builder.effectiveDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalBalance
final IntrafiBalance.Builder totalBalance(Long totalBalance)
The total balance, in minor units of
currency. Increase reports this balance to IntraFi daily.
-
totalBalance
final IntrafiBalance.Builder totalBalance(JsonField<Long> totalBalance)
Sets Builder.totalBalance to an arbitrary JSON value.
You should usually call Builder.totalBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final IntrafiBalance.Builder type(IntrafiBalance.Type type)
A constant representing the object's type. For this resource it will always be
intrafi_balance.
-
type
final IntrafiBalance.Builder type(JsonField<IntrafiBalance.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final IntrafiBalance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final IntrafiBalance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final IntrafiBalance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final IntrafiBalance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final IntrafiBalance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final IntrafiBalance build()
Returns an immutable instance of IntrafiBalance.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .balances() .currency() .effectiveDate() .totalBalance() .type()
-
-
-
-