Package com.increase.api.models.intrafiexclusions
See: Description
-
Class Summary Class Description Builder A builder for IntrafiExclusion. Status The status of the exclusion request. Type A constant representing the object's type. IntrafiExclusion Certain institutions may be excluded per Entity when sweeping funds into the IntraFi network. Builder A builder for IntrafiExclusionArchiveParams. IntrafiExclusionArchiveParams Archive an IntraFi Exclusion Builder A builder for IntrafiExclusionCreateParams. Builder A builder for Body. Body IntrafiExclusionCreateParams Create an IntraFi Exclusion Builder Response AutoPager IntrafiExclusionListPage List IntraFi Exclusions Builder Response AutoPager IntrafiExclusionListPageAsync List IntraFi Exclusions Builder A builder for IntrafiExclusionListParams. IntrafiExclusionListParams List IntraFi Exclusions Builder A builder for IntrafiExclusionRetrieveParams. IntrafiExclusionRetrieveParams Get an IntraFi Exclusion