Class LockboxAddress
-
- All Implemented Interfaces:
public final class LockboxAddressLockbox Addresses are physical locations that can receive mail containing paper checks.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddress.BuilderA builder for LockboxAddress.
public final classLockboxAddress.AddressThe mailing address for the Lockbox Address. It will be present after Increase generates it.
public final classLockboxAddress.StatusThe status of the Lockbox Address.
public final classLockboxAddress.TypeA constant representing the object's type. For this resource it will always be
lockbox_address.
-
Method Summary
Modifier and Type Method Description final Stringid()The Lockbox Address identifier. final Optional<LockboxAddress.Address>address()The mailing address for the Lockbox Address. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Lockbox Address was created. final Optional<String>description()The description you choose for the Lockbox Address. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final LockboxAddress.Statusstatus()The status of the Lockbox Address. final LockboxAddress.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<LockboxAddress.Address>_address()Returns the raw JSON value of address. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<LockboxAddress.Status>_status()Returns the raw JSON value of status. final JsonField<LockboxAddress.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final LockboxAddress.BuildertoBuilder()final LockboxAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddress.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxAddress. -
-
Method Detail
-
address
final Optional<LockboxAddress.Address> address()
The mailing address for the Lockbox Address. It will be present after Increase generates it.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Lockbox Address was created.
-
description
final Optional<String> description()
The description you choose for the Lockbox Address.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final LockboxAddress.Status status()
The status of the Lockbox Address.
-
type
final LockboxAddress.Type type()
A constant representing the object's type. For this resource it will always be
lockbox_address.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<LockboxAddress.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<LockboxAddress.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<LockboxAddress.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxAddress.Builder toBuilder()
-
validate
final LockboxAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LockboxAddress.Builder builder()
Returns a mutable builder for constructing an instance of LockboxAddress.
The following fields are required:
.id() .address() .createdAt() .description() .idempotencyKey() .status() .type()
-
-
-
-