Class LockboxAddress.Address
-
- All Implemented Interfaces:
public final class LockboxAddress.AddressThe mailing address for the Lockbox Address. It will be present after Increase generates it.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddress.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the address. final Stringline1()The first line of the address. final Stringline2()The second line of the address. final StringpostalCode()The postal code of the address. final Stringstate()The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final LockboxAddress.Address.BuildertoBuilder()final LockboxAddress.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddress.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
postalCode
final String postalCode()
The postal code of the address.
-
state
final String state()
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxAddress.Address.Builder toBuilder()
-
validate
final LockboxAddress.Address validate()
-
builder
final static LockboxAddress.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .line1() .line2() .postalCode() .state()
-
-
-
-