Class LockboxAddress.Builder
-
- All Implemented Interfaces:
public final class LockboxAddress.BuilderA builder for LockboxAddress.
-
-
Method Summary
-
-
Method Detail
-
id
final LockboxAddress.Builder id(String id)
The Lockbox Address identifier.
-
id
final LockboxAddress.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address
final LockboxAddress.Builder address(LockboxAddress.Address address)
The mailing address for the Lockbox Address. It will be present after Increase generates it.
-
address
final LockboxAddress.Builder address(Optional<LockboxAddress.Address> address)
Alias for calling Builder.address with
address.orElse(null).
-
address
final LockboxAddress.Builder address(JsonField<LockboxAddress.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final LockboxAddress.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Lockbox Address was created.
-
createdAt
final LockboxAddress.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LockboxAddress.Builder description(String description)
The description you choose for the Lockbox Address.
-
description
final LockboxAddress.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final LockboxAddress.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final LockboxAddress.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final LockboxAddress.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final LockboxAddress.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final LockboxAddress.Builder status(LockboxAddress.Status status)
The status of the Lockbox Address.
-
status
final LockboxAddress.Builder status(JsonField<LockboxAddress.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final LockboxAddress.Builder type(LockboxAddress.Type type)
A constant representing the object's type. For this resource it will always be
lockbox_address.
-
type
final LockboxAddress.Builder type(JsonField<LockboxAddress.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LockboxAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxAddress build()
Returns an immutable instance of LockboxAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .address() .createdAt() .description() .idempotencyKey() .status() .type()
-
-
-
-