Class LockboxAddressCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxAddressCreateParams implements Params
Create a Lockbox Address
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressCreateParams.BuilderA builder for LockboxAddressCreateParams.
public final classLockboxAddressCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The description you choose for the Lockbox Address. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxAddressCreateParams.BuildertoBuilder()final LockboxAddressCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressCreateParamsnone()final static LockboxAddressCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxAddressCreateParams. -
-
Method Detail
-
description
final Optional<String> description()
The description you choose for the Lockbox Address.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxAddressCreateParams.Builder toBuilder()
-
_body
final LockboxAddressCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LockboxAddressCreateParams none()
-
builder
final static LockboxAddressCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxAddressCreateParams.
-
-
-
-