Class LockboxAddressCreateParams.Body
-
- All Implemented Interfaces:
public final class LockboxAddressCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The description you choose for the Lockbox Address. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final LockboxAddressCreateParams.Body.BuildertoBuilder()final LockboxAddressCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
The description you choose for the Lockbox Address.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxAddressCreateParams.Body.Builder toBuilder()
-
validate
final LockboxAddressCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LockboxAddressCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-