Class LockboxAddressListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class LockboxAddressListPage implements Page<LockboxAddress>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressListPage.BuilderA builder for LockboxAddressListPage.
-
Method Summary
Modifier and Type Method Description final List<LockboxAddress>data()Delegates to LockboxAddressListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to LockboxAddressListPageResponse, but gracefully handles missing data. List<LockboxAddress>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final LockboxAddressListParamsnextPageParams()LockboxAddressListPagenextPage()Returns the page after this one by making another request. final AutoPager<LockboxAddress>autoPager()final LockboxAddressListParamsparams()The parameters that were used to request this page. final LockboxAddressListPageResponseresponse()The response that this page was parsed from. final LockboxAddressListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressListPage.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxAddressListPage. -
-
Method Detail
-
data
final List<LockboxAddress> data()
Delegates to LockboxAddressListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to LockboxAddressListPageResponse, but gracefully handles missing data.
-
items
List<LockboxAddress> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final LockboxAddressListParams nextPageParams()
-
nextPage
LockboxAddressListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<LockboxAddress> autoPager()
-
params
final LockboxAddressListParams params()
The parameters that were used to request this page.
-
response
final LockboxAddressListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final LockboxAddressListPage.Builder toBuilder()
-
builder
final static LockboxAddressListPage.Builder builder()
Returns a mutable builder for constructing an instance of LockboxAddressListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-