Class LockboxAddressListPage.Builder
-
- All Implemented Interfaces:
public final class LockboxAddressListPage.BuilderA builder for LockboxAddressListPage.
-
-
Method Summary
Modifier and Type Method Description final LockboxAddressListPage.Builderservice(LockboxAddressService service)final LockboxAddressListPage.Builderparams(LockboxAddressListParams params)The parameters that were used to request this page. final LockboxAddressListPage.Builderresponse(LockboxAddressListPageResponse response)The response that this page was parsed from. final LockboxAddressListPagebuild()Returns an immutable instance of LockboxAddressListPage. -
-
Method Detail
-
service
final LockboxAddressListPage.Builder service(LockboxAddressService service)
-
params
final LockboxAddressListPage.Builder params(LockboxAddressListParams params)
The parameters that were used to request this page.
-
response
final LockboxAddressListPage.Builder response(LockboxAddressListPageResponse response)
The response that this page was parsed from.
-
build
final LockboxAddressListPage build()
Returns an immutable instance of LockboxAddressListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-