Class LockboxAddressListPageAsync.Builder
-
- All Implemented Interfaces:
public final class LockboxAddressListPageAsync.BuilderA builder for LockboxAddressListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final LockboxAddressListPageAsync.Builderservice(LockboxAddressServiceAsync service)final LockboxAddressListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final LockboxAddressListPageAsync.Builderparams(LockboxAddressListParams params)The parameters that were used to request this page. final LockboxAddressListPageAsync.Builderresponse(LockboxAddressListPageResponse response)The response that this page was parsed from. final LockboxAddressListPageAsyncbuild()Returns an immutable instance of LockboxAddressListPageAsync. -
-
Method Detail
-
service
final LockboxAddressListPageAsync.Builder service(LockboxAddressServiceAsync service)
-
streamHandlerExecutor
final LockboxAddressListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final LockboxAddressListPageAsync.Builder params(LockboxAddressListParams params)
The parameters that were used to request this page.
-
response
final LockboxAddressListPageAsync.Builder response(LockboxAddressListPageResponse response)
The response that this page was parsed from.
-
build
final LockboxAddressListPageAsync build()
Returns an immutable instance of LockboxAddressListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-