Class LockboxAddressListPageResponse
-
- All Implemented Interfaces:
public final class LockboxAddressListPageResponseA list of Lockbox Address objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressListPageResponse.BuilderA builder for LockboxAddressListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<LockboxAddress>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<LockboxAddress>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final LockboxAddressListPageResponse.BuildertoBuilder()final LockboxAddressListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxAddressListPageResponse. -
-
Method Detail
-
data
final List<LockboxAddress> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
_data
final JsonField<List<LockboxAddress>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxAddressListPageResponse.Builder toBuilder()
-
validate
final LockboxAddressListPageResponse validate()
-
builder
final static LockboxAddressListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of LockboxAddressListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-