Class LockboxAddressRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxAddressRetrieveParams implements Params
Retrieve a Lockbox Address
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressRetrieveParams.BuilderA builder for LockboxAddressRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>lockboxAddressId()The identifier of the Lockbox Address to retrieve. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxAddressRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressRetrieveParamsnone()final static LockboxAddressRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxAddressRetrieveParams. -
-
Method Detail
-
lockboxAddressId
final Optional<String> lockboxAddressId()
The identifier of the Lockbox Address to retrieve.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxAddressRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LockboxAddressRetrieveParams none()
-
builder
final static LockboxAddressRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxAddressRetrieveParams.
-
-
-
-