Class LockboxAddressUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxAddressUpdateParams implements Params
Update a Lockbox Address
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressUpdateParams.BuilderA builder for LockboxAddressUpdateParams.
public final classLockboxAddressUpdateParams.Bodypublic final classLockboxAddressUpdateParams.StatusThe status of the Lockbox Address.
-
Method Summary
Modifier and Type Method Description final Optional<String>lockboxAddressId()The identifier of the Lockbox Address. final Optional<String>description()The description you choose for the Lockbox Address. final Optional<LockboxAddressUpdateParams.Status>status()The status of the Lockbox Address. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<LockboxAddressUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxAddressUpdateParams.BuildertoBuilder()final LockboxAddressUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressUpdateParamsnone()final static LockboxAddressUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxAddressUpdateParams. -
-
Method Detail
-
lockboxAddressId
final Optional<String> lockboxAddressId()
The identifier of the Lockbox Address.
-
description
final Optional<String> description()
The description you choose for the Lockbox Address.
-
status
final Optional<LockboxAddressUpdateParams.Status> status()
The status of the Lockbox Address.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<LockboxAddressUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxAddressUpdateParams.Builder toBuilder()
-
_body
final LockboxAddressUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LockboxAddressUpdateParams none()
-
builder
final static LockboxAddressUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxAddressUpdateParams.
-
-
-
-