Class LockboxAddressUpdateParams.Body
-
- All Implemented Interfaces:
public final class LockboxAddressUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The description you choose for the Lockbox Address. final Optional<LockboxAddressUpdateParams.Status>status()The status of the Lockbox Address. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<LockboxAddressUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final LockboxAddressUpdateParams.Body.BuildertoBuilder()final LockboxAddressUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxAddressUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
The description you choose for the Lockbox Address.
-
status
final Optional<LockboxAddressUpdateParams.Status> status()
The status of the Lockbox Address.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<LockboxAddressUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxAddressUpdateParams.Body.Builder toBuilder()
-
validate
final LockboxAddressUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LockboxAddressUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-