Class Lockbox
-
- All Implemented Interfaces:
public final class LockboxLockboxes are physical locations that can receive mail containing paper checks. Increase will automatically create a Check Deposit for checks received this way.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockbox.BuilderA builder for Lockbox.
public final classLockbox.AddressThe mailing address for the Lockbox.
public final classLockbox.CheckDepositBehaviorIndicates if checks mailed to this lockbox will be deposited.
public final classLockbox.TypeA constant representing the object's type. For this resource it will always be
lockbox.
-
Method Summary
Modifier and Type Method Description final Stringid()The Lockbox identifier. final StringaccountId()The identifier for the Account checks sent to this lockbox will be deposited into. final Lockbox.Addressaddress()The mailing address for the Lockbox. final Lockbox.CheckDepositBehaviorcheckDepositBehavior()Indicates if checks mailed to this lockbox will be deposited. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Lockbox was created. final Optional<String>description()The description you choose for the Lockbox. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>recipientName()The recipient name you choose for the Lockbox. final Lockbox.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Lockbox.Address>_address()Returns the raw JSON value of address. final JsonField<Lockbox.CheckDepositBehavior>_checkDepositBehavior()Returns the raw JSON value of checkDepositBehavior. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<Lockbox.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Lockbox.BuildertoBuilder()final Lockboxvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Lockbox.Builderbuilder()Returns a mutable builder for constructing an instance of Lockbox. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account checks sent to this lockbox will be deposited into.
-
address
final Lockbox.Address address()
The mailing address for the Lockbox.
-
checkDepositBehavior
final Lockbox.CheckDepositBehavior checkDepositBehavior()
Indicates if checks mailed to this lockbox will be deposited.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Lockbox was created.
-
description
final Optional<String> description()
The description you choose for the Lockbox.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
recipientName
final Optional<String> recipientName()
The recipient name you choose for the Lockbox.
-
type
final Lockbox.Type type()
A constant representing the object's type. For this resource it will always be
lockbox.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<Lockbox.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositBehavior
final JsonField<Lockbox.CheckDepositBehavior> _checkDepositBehavior()
Returns the raw JSON value of checkDepositBehavior.
Unlike checkDepositBehavior, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Lockbox.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Lockbox.Builder toBuilder()
-
builder
final static Lockbox.Builder builder()
Returns a mutable builder for constructing an instance of Lockbox.
The following fields are required:
.id() .accountId() .address() .checkDepositBehavior() .createdAt() .description() .idempotencyKey() .recipientName() .type()
-
-
-
-