Class Lockbox.Address
-
- All Implemented Interfaces:
public final class Lockbox.AddressThe mailing address for the Lockbox.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockbox.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the address. final Stringline1()The first line of the address. final Stringline2()The second line of the address. final StringpostalCode()The postal code of the address. final Optional<String>recipient()The recipient line of the address. final Stringstate()The two-letter United States Postal Service (USPS) abbreviation for the state of the address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_recipient()Returns the raw JSON value of recipient. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final Lockbox.Address.BuildertoBuilder()final Lockbox.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Lockbox.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
postalCode
final String postalCode()
The postal code of the address.
-
recipient
final Optional<String> recipient()
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
state
final String state()
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_recipient
final JsonField<String> _recipient()
Returns the raw JSON value of recipient.
Unlike recipient, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Lockbox.Address.Builder toBuilder()
-
validate
final Lockbox.Address validate()
-
builder
final static Lockbox.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .line1() .line2() .postalCode() .recipient() .state()
-
-
-
-