Class Lockbox.Address.Builder
-
- All Implemented Interfaces:
public final class Lockbox.Address.BuilderA builder for Address.
-
-
Method Summary
-
-
Method Detail
-
city
final Lockbox.Address.Builder city(String city)
The city of the address.
-
city
final Lockbox.Address.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final Lockbox.Address.Builder line1(String line1)
The first line of the address.
-
line1
final Lockbox.Address.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final Lockbox.Address.Builder line2(String line2)
The second line of the address.
-
line2
final Lockbox.Address.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final Lockbox.Address.Builder postalCode(String postalCode)
The postal code of the address.
-
postalCode
final Lockbox.Address.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipient
final Lockbox.Address.Builder recipient(String recipient)
The recipient line of the address. This will include the recipient name you provide when creating the address, as well as an ATTN suffix to help route the mail to your lockbox. Mail senders must include this ATTN line to receive mail at this Lockbox.
-
recipient
final Lockbox.Address.Builder recipient(Optional<String> recipient)
Alias for calling Builder.recipient with
recipient.orElse(null).
-
recipient
final Lockbox.Address.Builder recipient(JsonField<String> recipient)
Sets Builder.recipient to an arbitrary JSON value.
You should usually call Builder.recipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final Lockbox.Address.Builder state(String state)
The two-letter United States Postal Service (USPS) abbreviation for the state of the address.
-
state
final Lockbox.Address.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Lockbox.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Lockbox.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Lockbox.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Lockbox.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Lockbox.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Lockbox.Address build()
Returns an immutable instance of Address.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .line1() .line2() .postalCode() .recipient() .state()
-
-
-
-