Class Lockbox.Builder
-
- All Implemented Interfaces:
public final class Lockbox.BuilderA builder for Lockbox.
-
-
Method Summary
Modifier and Type Method Description final Lockbox.Builderid(String id)The Lockbox identifier. final Lockbox.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Lockbox.BuilderaccountId(String accountId)The identifier for the Account checks sent to this lockbox will be deposited into. final Lockbox.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final Lockbox.Builderaddress(Lockbox.Address address)The mailing address for the Lockbox. final Lockbox.Builderaddress(JsonField<Lockbox.Address> address)Sets Builder.address to an arbitrary JSON value. final Lockbox.BuildercheckDepositBehavior(Lockbox.CheckDepositBehavior checkDepositBehavior)Indicates if checks mailed to this lockbox will be deposited. final Lockbox.BuildercheckDepositBehavior(JsonField<Lockbox.CheckDepositBehavior> checkDepositBehavior)Sets Builder.checkDepositBehavior to an arbitrary JSON value. final Lockbox.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Lockbox was created. final Lockbox.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Lockbox.Builderdescription(String description)The description you choose for the Lockbox. final Lockbox.Builderdescription(Optional<String> description)Alias for calling Builder.description with description.orElse(null).final Lockbox.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final Lockbox.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Lockbox.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final Lockbox.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final Lockbox.BuilderrecipientName(String recipientName)The recipient name you choose for the Lockbox. final Lockbox.BuilderrecipientName(Optional<String> recipientName)Alias for calling Builder.recipientName with recipientName.orElse(null).final Lockbox.BuilderrecipientName(JsonField<String> recipientName)Sets Builder.recipientName to an arbitrary JSON value. final Lockbox.Buildertype(Lockbox.Type type)A constant representing the object's type. final Lockbox.Buildertype(JsonField<Lockbox.Type> type)Sets Builder.type to an arbitrary JSON value. final Lockbox.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Lockbox.BuilderputAdditionalProperty(String key, JsonValue value)final Lockbox.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Lockbox.BuilderremoveAdditionalProperty(String key)final Lockbox.BuilderremoveAllAdditionalProperties(Set<String> keys)final Lockboxbuild()Returns an immutable instance of Lockbox. -
-
Method Detail
-
id
final Lockbox.Builder id(String id)
The Lockbox identifier.
-
id
final Lockbox.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final Lockbox.Builder accountId(String accountId)
The identifier for the Account checks sent to this lockbox will be deposited into.
-
accountId
final Lockbox.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address
final Lockbox.Builder address(Lockbox.Address address)
The mailing address for the Lockbox.
-
address
final Lockbox.Builder address(JsonField<Lockbox.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositBehavior
final Lockbox.Builder checkDepositBehavior(Lockbox.CheckDepositBehavior checkDepositBehavior)
Indicates if checks mailed to this lockbox will be deposited.
-
checkDepositBehavior
final Lockbox.Builder checkDepositBehavior(JsonField<Lockbox.CheckDepositBehavior> checkDepositBehavior)
Sets Builder.checkDepositBehavior to an arbitrary JSON value.
You should usually call Builder.checkDepositBehavior with a well-typed CheckDepositBehavior value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Lockbox.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Lockbox was created.
-
createdAt
final Lockbox.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Lockbox.Builder description(String description)
The description you choose for the Lockbox.
-
description
final Lockbox.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final Lockbox.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final Lockbox.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Lockbox.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final Lockbox.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final Lockbox.Builder recipientName(String recipientName)
The recipient name you choose for the Lockbox.
-
recipientName
final Lockbox.Builder recipientName(Optional<String> recipientName)
Alias for calling Builder.recipientName with
recipientName.orElse(null).
-
recipientName
final Lockbox.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Lockbox.Builder type(Lockbox.Type type)
A constant representing the object's type. For this resource it will always be
lockbox.
-
type
final Lockbox.Builder type(JsonField<Lockbox.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Lockbox.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Lockbox.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Lockbox.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Lockbox.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Lockbox.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-