Enum Lockbox.CheckDepositBehavior.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Lockbox.CheckDepositBehavior.Known extends Enum<Lockbox.CheckDepositBehavior.Known>
An enum containing CheckDepositBehavior's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Lockbox.CheckDepositBehavior.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ENABLEDChecks mailed to this Lockbox will be deposited.
DISABLEDChecks mailed to this Lockbox will not be deposited.
PEND_FOR_PROCESSINGChecks mailed to this Lockbox will be pending until actioned.
-
Method Summary
Modifier and Type Method Description final Lockbox.CheckDepositBehavior.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Lockbox.CheckDepositBehavior.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Lockbox.CheckDepositBehavior.Known>getEntries()An enum containing CheckDepositBehavior's known values. -
-
Method Detail
-
valueOf
final Lockbox.CheckDepositBehavior.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Lockbox.CheckDepositBehavior.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Lockbox.CheckDepositBehavior.Known> getEntries()
An enum containing CheckDepositBehavior's known values.
-
-
-
-