Class LockboxCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxCreateParams implements Params
Create a Lockbox
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxCreateParams.BuilderA builder for LockboxCreateParams.
public final classLockboxCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account checks sent to this Lockbox should be deposited into. final Optional<String>description()The description you choose for the Lockbox, for display purposes. final Optional<String>recipientName()The name of the recipient that will receive mail at this location. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxCreateParams.BuildertoBuilder()final LockboxCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxCreateParams. -
-
Method Detail
-
accountId
final String accountId()
The Account checks sent to this Lockbox should be deposited into.
-
description
final Optional<String> description()
The description you choose for the Lockbox, for display purposes.
-
recipientName
final Optional<String> recipientName()
The name of the recipient that will receive mail at this location.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxCreateParams.Builder toBuilder()
-
_body
final LockboxCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static LockboxCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxCreateParams.
The following fields are required:
.accountId()
-
-
-
-