Class LockboxCreateParams.Body
-
- All Implemented Interfaces:
public final class LockboxCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account checks sent to this Lockbox should be deposited into. final Optional<String>description()The description you choose for the Lockbox, for display purposes. final Optional<String>recipientName()The name of the recipient that will receive mail at this location. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalProperties()final LockboxCreateParams.Body.BuildertoBuilder()final LockboxCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountId
final String accountId()
The Account checks sent to this Lockbox should be deposited into.
-
description
final Optional<String> description()
The description you choose for the Lockbox, for display purposes.
-
recipientName
final Optional<String> recipientName()
The name of the recipient that will receive mail at this location.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxCreateParams.Body.Builder toBuilder()
-
validate
final LockboxCreateParams.Body validate()
-
builder
final static LockboxCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId()
-
-
-
-