Class LockboxCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class LockboxCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final LockboxCreateParams.Body.Builder accountId(String accountId)
The Account checks sent to this Lockbox should be deposited into.
-
accountId
final LockboxCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LockboxCreateParams.Body.Builder description(String description)
The description you choose for the Lockbox, for display purposes.
-
description
final LockboxCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final LockboxCreateParams.Body.Builder recipientName(String recipientName)
The name of the recipient that will receive mail at this location.
-
recipientName
final LockboxCreateParams.Body.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LockboxCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId()
-
-
-
-