Class LockboxListPage
-
- All Implemented Interfaces:
public final class LockboxListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxListPage.BuilderA builder for LockboxListPage.
public final classLockboxListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Lockbox>data()Delegates to LockboxListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to LockboxListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<LockboxListParams>getNextPageParams()final Optional<LockboxListPage>getNextPage()final LockboxListPage.AutoPagerautoPager()final LockboxListParamsparams()The parameters that were used to request this page. final LockboxListPageResponseresponse()The response that this page was parsed from. final LockboxListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxListPage.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxListPage. -
-
Method Detail
-
data
final List<Lockbox> data()
Delegates to LockboxListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to LockboxListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<LockboxListParams> getNextPageParams()
-
getNextPage
final Optional<LockboxListPage> getNextPage()
-
autoPager
final LockboxListPage.AutoPager autoPager()
-
params
final LockboxListParams params()
The parameters that were used to request this page.
-
response
final LockboxListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final LockboxListPage.Builder toBuilder()
-
builder
final static LockboxListPage.Builder builder()
Returns a mutable builder for constructing an instance of LockboxListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-