Class LockboxListPage.Builder
-
- All Implemented Interfaces:
public final class LockboxListPage.BuilderA builder for LockboxListPage.
-
-
Method Summary
Modifier and Type Method Description final LockboxListPage.Builderservice(LockboxService service)final LockboxListPage.Builderparams(LockboxListParams params)The parameters that were used to request this page. final LockboxListPage.Builderresponse(LockboxListPageResponse response)The response that this page was parsed from. final LockboxListPagebuild()Returns an immutable instance of LockboxListPage. -
-
Method Detail
-
service
final LockboxListPage.Builder service(LockboxService service)
-
params
final LockboxListPage.Builder params(LockboxListParams params)
The parameters that were used to request this page.
-
response
final LockboxListPage.Builder response(LockboxListPageResponse response)
The response that this page was parsed from.
-
build
final LockboxListPage build()
Returns an immutable instance of LockboxListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-