Class LockboxListPageAsync
-
- All Implemented Interfaces:
public final class LockboxListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxListPageAsync.BuilderA builder for LockboxListPageAsync.
public final classLockboxListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Lockbox>data()Delegates to LockboxListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to LockboxListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<LockboxListParams>getNextPageParams()final CompletableFuture<Optional<LockboxListPageAsync>>getNextPage()final LockboxListPageAsync.AutoPagerautoPager()final LockboxListParamsparams()The parameters that were used to request this page. final LockboxListPageResponseresponse()The response that this page was parsed from. final LockboxListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxListPageAsync. -
-
Method Detail
-
data
final List<Lockbox> data()
Delegates to LockboxListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to LockboxListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<LockboxListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<LockboxListPageAsync>> getNextPage()
-
autoPager
final LockboxListPageAsync.AutoPager autoPager()
-
params
final LockboxListParams params()
The parameters that were used to request this page.
-
response
final LockboxListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final LockboxListPageAsync.Builder toBuilder()
-
builder
final static LockboxListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of LockboxListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-