Class LockboxListPageAsync.Builder
-
- All Implemented Interfaces:
public final class LockboxListPageAsync.BuilderA builder for LockboxListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final LockboxListPageAsync.Builderservice(LockboxServiceAsync service)final LockboxListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final LockboxListPageAsync.Builderparams(LockboxListParams params)The parameters that were used to request this page. final LockboxListPageAsync.Builderresponse(LockboxListPageResponse response)The response that this page was parsed from. final LockboxListPageAsyncbuild()Returns an immutable instance of LockboxListPageAsync. -
-
Method Detail
-
service
final LockboxListPageAsync.Builder service(LockboxServiceAsync service)
-
streamHandlerExecutor
final LockboxListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final LockboxListPageAsync.Builder params(LockboxListParams params)
The parameters that were used to request this page.
-
response
final LockboxListPageAsync.Builder response(LockboxListPageResponse response)
The response that this page was parsed from.
-
build
final LockboxListPageAsync build()
Returns an immutable instance of LockboxListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-