Class LockboxListPageAsync.Response
-
- All Implemented Interfaces:
public final class LockboxListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxListPageAsync.Response.Builder
-
Method Summary
Modifier and Type Method Description final List<Lockbox>data()final Optional<String>nextCursor()final Optional<JsonField<List<Lockbox>>>_data()final Optional<JsonField<String>>_nextCursor()final Map<String, JsonValue>_additionalProperties()final LockboxListPageAsync.Responsevalidate()final LockboxListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxListPageAsync. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
-
_nextCursor
final Optional<JsonField<String>> _nextCursor()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final LockboxListPageAsync.Response validate()
-
toBuilder
final LockboxListPageAsync.Response.Builder toBuilder()
-
builder
final static LockboxListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of LockboxListPageAsync.
-
-
-
-