Class LockboxListPageResponse
-
- All Implemented Interfaces:
public final class LockboxListPageResponseA list of Lockbox objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxListPageResponse.BuilderA builder for LockboxListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<Lockbox>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<Lockbox>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final LockboxListPageResponse.BuildertoBuilder()final LockboxListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxListPageResponse. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<Lockbox>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxListPageResponse.Builder toBuilder()
-
validate
final LockboxListPageResponse validate()
-
builder
final static LockboxListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of LockboxListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-