Class LockboxListPageResponse.Builder
-
- All Implemented Interfaces:
public final class LockboxListPageResponse.BuilderA builder for LockboxListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final LockboxListPageResponse.Builder data(List<Lockbox> data)
The contents of the list.
-
data
final LockboxListPageResponse.Builder data(JsonField<List<Lockbox>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Lockbox>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final LockboxListPageResponse.Builder addData(Lockbox data)
Adds a single Lockbox to Builder.data.
-
nextCursor
final LockboxListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final LockboxListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final LockboxListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LockboxListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxListPageResponse build()
Returns an immutable instance of LockboxListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-