Class LockboxUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxUpdateParams implements Params
Update a Lockbox
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxUpdateParams.BuilderA builder for LockboxUpdateParams.
public final classLockboxUpdateParams.Bodypublic final classLockboxUpdateParams.CheckDepositBehaviorThis indicates if checks mailed to this lockbox will be deposited.
-
Method Summary
Modifier and Type Method Description final Optional<String>lockboxId()The identifier of the Lockbox. final Optional<LockboxUpdateParams.CheckDepositBehavior>checkDepositBehavior()This indicates if checks mailed to this lockbox will be deposited. final Optional<String>description()The description you choose for the Lockbox. final Optional<String>recipientName()The recipient name you choose for the Lockbox. final JsonField<LockboxUpdateParams.CheckDepositBehavior>_checkDepositBehavior()Returns the raw JSON value of checkDepositBehavior. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxUpdateParams.BuildertoBuilder()final LockboxUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxUpdateParamsnone()final static LockboxUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxUpdateParams. -
-
Method Detail
-
checkDepositBehavior
final Optional<LockboxUpdateParams.CheckDepositBehavior> checkDepositBehavior()
This indicates if checks mailed to this lockbox will be deposited.
-
description
final Optional<String> description()
The description you choose for the Lockbox.
-
recipientName
final Optional<String> recipientName()
The recipient name you choose for the Lockbox.
-
_checkDepositBehavior
final JsonField<LockboxUpdateParams.CheckDepositBehavior> _checkDepositBehavior()
Returns the raw JSON value of checkDepositBehavior.
Unlike checkDepositBehavior, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxUpdateParams.Builder toBuilder()
-
_body
final LockboxUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LockboxUpdateParams none()
-
builder
final static LockboxUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxUpdateParams.
-
-
-
-