Class LockboxUpdateParams.Body
-
- All Implemented Interfaces:
public final class LockboxUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
checkDepositBehavior
final Optional<LockboxUpdateParams.CheckDepositBehavior> checkDepositBehavior()
This indicates if checks mailed to this lockbox will be deposited.
-
description
final Optional<String> description()
The description you choose for the Lockbox.
-
recipientName
final Optional<String> recipientName()
The recipient name you choose for the Lockbox.
-
_checkDepositBehavior
final JsonField<LockboxUpdateParams.CheckDepositBehavior> _checkDepositBehavior()
Returns the raw JSON value of checkDepositBehavior.
Unlike checkDepositBehavior, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxUpdateParams.Body.Builder toBuilder()
-
validate
final LockboxUpdateParams.Body validate()
-
builder
final static LockboxUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-