Class LockboxUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class LockboxUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
checkDepositBehavior
final LockboxUpdateParams.Body.Builder checkDepositBehavior(LockboxUpdateParams.CheckDepositBehavior checkDepositBehavior)
This indicates if checks mailed to this lockbox will be deposited.
-
checkDepositBehavior
final LockboxUpdateParams.Body.Builder checkDepositBehavior(JsonField<LockboxUpdateParams.CheckDepositBehavior> checkDepositBehavior)
Sets Builder.checkDepositBehavior to an arbitrary JSON value.
You should usually call Builder.checkDepositBehavior with a well-typed CheckDepositBehavior value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LockboxUpdateParams.Body.Builder description(String description)
The description you choose for the Lockbox.
-
description
final LockboxUpdateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final LockboxUpdateParams.Body.Builder recipientName(String recipientName)
The recipient name you choose for the Lockbox.
-
recipientName
final LockboxUpdateParams.Body.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LockboxUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-