Class LockboxRecipient
-
- All Implemented Interfaces:
public final class LockboxRecipientLockbox Recipients represent an inbox at a Lockbox Address. Checks received for a Lockbox Recipient are deposited into its associated Account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipient.BuilderA builder for LockboxRecipient.
public final classLockboxRecipient.StatusThe status of the Lockbox Recipient.
public final classLockboxRecipient.TypeA constant representing the object's type. For this resource it will always be
lockbox_recipient.
-
Method Summary
Modifier and Type Method Description final Stringid()The Lockbox Recipient identifier. final StringaccountId()The identifier for the Account that checks sent to this Lockbox Recipient will be deposited into. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Lockbox Recipient was created. final Optional<String>description()The description of the Lockbox Recipient. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringlockboxAddressId()The identifier for the Lockbox Address where this Lockbox Recipient may receive physical mail. final StringmailStopCode()The mail stop code uniquely identifying this Lockbox Recipient at its Lockbox Address. final Optional<String>recipientName()The name of the Lockbox Recipient. final Optional<LockboxRecipient.Status>status()The status of the Lockbox Recipient. final LockboxRecipient.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_lockboxAddressId()Returns the raw JSON value of lockboxAddressId. final JsonField<String>_mailStopCode()Returns the raw JSON value of mailStopCode. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<LockboxRecipient.Status>_status()Returns the raw JSON value of status. final JsonField<LockboxRecipient.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final LockboxRecipient.BuildertoBuilder()final LockboxRecipientvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxRecipient.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxRecipient. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the Account that checks sent to this Lockbox Recipient will be deposited into.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Lockbox Recipient was created.
-
description
final Optional<String> description()
The description of the Lockbox Recipient.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
lockboxAddressId
final String lockboxAddressId()
The identifier for the Lockbox Address where this Lockbox Recipient may receive physical mail.
-
mailStopCode
final String mailStopCode()
The mail stop code uniquely identifying this Lockbox Recipient at its Lockbox Address. It should be included in the mailing address intended for this Lockbox Recipient.
-
recipientName
final Optional<String> recipientName()
The name of the Lockbox Recipient.
-
status
final Optional<LockboxRecipient.Status> status()
The status of the Lockbox Recipient.
-
type
final LockboxRecipient.Type type()
A constant representing the object's type. For this resource it will always be
lockbox_recipient.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxAddressId
final JsonField<String> _lockboxAddressId()
Returns the raw JSON value of lockboxAddressId.
Unlike lockboxAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_mailStopCode
final JsonField<String> _mailStopCode()
Returns the raw JSON value of mailStopCode.
Unlike mailStopCode, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<LockboxRecipient.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<LockboxRecipient.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxRecipient.Builder toBuilder()
-
validate
final LockboxRecipient validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LockboxRecipient.Builder builder()
Returns a mutable builder for constructing an instance of LockboxRecipient.
The following fields are required:
.id() .accountId() .createdAt() .description() .idempotencyKey() .lockboxAddressId() .mailStopCode() .recipientName() .status() .type()
-
-
-
-