Class LockboxRecipient.Builder
-
- All Implemented Interfaces:
public final class LockboxRecipient.BuilderA builder for LockboxRecipient.
-
-
Method Summary
Modifier and Type Method Description final LockboxRecipient.Builderid(String id)The Lockbox Recipient identifier. final LockboxRecipient.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final LockboxRecipient.BuilderaccountId(String accountId)The identifier for the Account that checks sent to this Lockbox Recipient will be deposited into. final LockboxRecipient.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final LockboxRecipient.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Lockbox Recipient was created. final LockboxRecipient.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final LockboxRecipient.Builderdescription(String description)The description of the Lockbox Recipient. final LockboxRecipient.Builderdescription(Optional<String> description)Alias for calling Builder.description with description.orElse(null).final LockboxRecipient.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final LockboxRecipient.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final LockboxRecipient.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final LockboxRecipient.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final LockboxRecipient.BuilderlockboxAddressId(String lockboxAddressId)The identifier for the Lockbox Address where this Lockbox Recipient may receive physical mail. final LockboxRecipient.BuilderlockboxAddressId(JsonField<String> lockboxAddressId)Sets Builder.lockboxAddressId to an arbitrary JSON value. final LockboxRecipient.BuildermailStopCode(String mailStopCode)The mail stop code uniquely identifying this Lockbox Recipient at its Lockbox Address. final LockboxRecipient.BuildermailStopCode(JsonField<String> mailStopCode)Sets Builder.mailStopCode to an arbitrary JSON value. final LockboxRecipient.BuilderrecipientName(String recipientName)The name of the Lockbox Recipient. final LockboxRecipient.BuilderrecipientName(Optional<String> recipientName)Alias for calling Builder.recipientName with recipientName.orElse(null).final LockboxRecipient.BuilderrecipientName(JsonField<String> recipientName)Sets Builder.recipientName to an arbitrary JSON value. final LockboxRecipient.Builderstatus(LockboxRecipient.Status status)The status of the Lockbox Recipient. final LockboxRecipient.Builderstatus(Optional<LockboxRecipient.Status> status)Alias for calling Builder.status with status.orElse(null).final LockboxRecipient.Builderstatus(JsonField<LockboxRecipient.Status> status)Sets Builder.status to an arbitrary JSON value. final LockboxRecipient.Buildertype(LockboxRecipient.Type type)A constant representing the object's type. final LockboxRecipient.Buildertype(JsonField<LockboxRecipient.Type> type)Sets Builder.type to an arbitrary JSON value. final LockboxRecipient.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final LockboxRecipient.BuilderputAdditionalProperty(String key, JsonValue value)final LockboxRecipient.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final LockboxRecipient.BuilderremoveAdditionalProperty(String key)final LockboxRecipient.BuilderremoveAllAdditionalProperties(Set<String> keys)final LockboxRecipientbuild()Returns an immutable instance of LockboxRecipient. -
-
Method Detail
-
id
final LockboxRecipient.Builder id(String id)
The Lockbox Recipient identifier.
-
id
final LockboxRecipient.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final LockboxRecipient.Builder accountId(String accountId)
The identifier for the Account that checks sent to this Lockbox Recipient will be deposited into.
-
accountId
final LockboxRecipient.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final LockboxRecipient.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Lockbox Recipient was created.
-
createdAt
final LockboxRecipient.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LockboxRecipient.Builder description(String description)
The description of the Lockbox Recipient.
-
description
final LockboxRecipient.Builder description(Optional<String> description)
Alias for calling Builder.description with
description.orElse(null).
-
description
final LockboxRecipient.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final LockboxRecipient.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final LockboxRecipient.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final LockboxRecipient.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxAddressId
final LockboxRecipient.Builder lockboxAddressId(String lockboxAddressId)
The identifier for the Lockbox Address where this Lockbox Recipient may receive physical mail.
-
lockboxAddressId
final LockboxRecipient.Builder lockboxAddressId(JsonField<String> lockboxAddressId)
Sets Builder.lockboxAddressId to an arbitrary JSON value.
You should usually call Builder.lockboxAddressId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mailStopCode
final LockboxRecipient.Builder mailStopCode(String mailStopCode)
The mail stop code uniquely identifying this Lockbox Recipient at its Lockbox Address. It should be included in the mailing address intended for this Lockbox Recipient.
-
mailStopCode
final LockboxRecipient.Builder mailStopCode(JsonField<String> mailStopCode)
Sets Builder.mailStopCode to an arbitrary JSON value.
You should usually call Builder.mailStopCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final LockboxRecipient.Builder recipientName(String recipientName)
The name of the Lockbox Recipient.
-
recipientName
final LockboxRecipient.Builder recipientName(Optional<String> recipientName)
Alias for calling Builder.recipientName with
recipientName.orElse(null).
-
recipientName
final LockboxRecipient.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final LockboxRecipient.Builder status(LockboxRecipient.Status status)
The status of the Lockbox Recipient.
-
status
final LockboxRecipient.Builder status(Optional<LockboxRecipient.Status> status)
Alias for calling Builder.status with
status.orElse(null).
-
status
final LockboxRecipient.Builder status(JsonField<LockboxRecipient.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final LockboxRecipient.Builder type(LockboxRecipient.Type type)
A constant representing the object's type. For this resource it will always be
lockbox_recipient.
-
type
final LockboxRecipient.Builder type(JsonField<LockboxRecipient.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LockboxRecipient.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxRecipient.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxRecipient.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxRecipient.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxRecipient.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxRecipient build()
Returns an immutable instance of LockboxRecipient.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .createdAt() .description() .idempotencyKey() .lockboxAddressId() .mailStopCode() .recipientName() .status() .type()
-
-
-
-