Enum LockboxRecipient.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum LockboxRecipient.Status.Known extends Enum<LockboxRecipient.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<LockboxRecipient.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACTIVEThis Lockbox Recipient is active.
DISABLEDThis Lockbox Recipient is disabled. Checks mailed to this Lockbox Recipient will be rejected.
CANCELEDThis Lockbox Recipient is canceled and cannot be modified. Checks mailed to this Lockbox Recipient will be rejected.
-
Method Summary
Modifier and Type Method Description final LockboxRecipient.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<LockboxRecipient.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<LockboxRecipient.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final LockboxRecipient.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<LockboxRecipient.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<LockboxRecipient.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-