Class LockboxRecipientCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxRecipientCreateParams implements Params
Create a Lockbox Recipient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientCreateParams.BuilderA builder for LockboxRecipientCreateParams.
public final classLockboxRecipientCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account that checks sent to this Lockbox Recipient should be deposited into. final StringlockboxAddressId()The Lockbox Address where this Lockbox Recipient may receive mail. final Optional<String>description()The description you choose for the Lockbox Recipient. final Optional<String>recipientName()The name of the Lockbox Recipient final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_lockboxAddressId()Returns the raw JSON value of lockboxAddressId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxRecipientCreateParams.BuildertoBuilder()final LockboxRecipientCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxRecipientCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxRecipientCreateParams. -
-
Method Detail
-
accountId
final String accountId()
The Account that checks sent to this Lockbox Recipient should be deposited into.
-
lockboxAddressId
final String lockboxAddressId()
The Lockbox Address where this Lockbox Recipient may receive mail.
-
description
final Optional<String> description()
The description you choose for the Lockbox Recipient.
-
recipientName
final Optional<String> recipientName()
The name of the Lockbox Recipient
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxAddressId
final JsonField<String> _lockboxAddressId()
Returns the raw JSON value of lockboxAddressId.
Unlike lockboxAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxRecipientCreateParams.Builder toBuilder()
-
_body
final LockboxRecipientCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static LockboxRecipientCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxRecipientCreateParams.
The following fields are required:
.accountId() .lockboxAddressId()
-
-
-
-