Class LockboxRecipientCreateParams.Body
-
- All Implemented Interfaces:
public final class LockboxRecipientCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account that checks sent to this Lockbox Recipient should be deposited into. final StringlockboxAddressId()The Lockbox Address where this Lockbox Recipient may receive mail. final Optional<String>description()The description you choose for the Lockbox Recipient. final Optional<String>recipientName()The name of the Lockbox Recipient final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_lockboxAddressId()Returns the raw JSON value of lockboxAddressId. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalProperties()final LockboxRecipientCreateParams.Body.BuildertoBuilder()final LockboxRecipientCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxRecipientCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountId
final String accountId()
The Account that checks sent to this Lockbox Recipient should be deposited into.
-
lockboxAddressId
final String lockboxAddressId()
The Lockbox Address where this Lockbox Recipient may receive mail.
-
description
final Optional<String> description()
The description you choose for the Lockbox Recipient.
-
recipientName
final Optional<String> recipientName()
The name of the Lockbox Recipient
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxAddressId
final JsonField<String> _lockboxAddressId()
Returns the raw JSON value of lockboxAddressId.
Unlike lockboxAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxRecipientCreateParams.Body.Builder toBuilder()
-
validate
final LockboxRecipientCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LockboxRecipientCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .lockboxAddressId()
-
-
-
-