Class LockboxRecipientCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class LockboxRecipientCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final LockboxRecipientCreateParams.Body.Builder accountId(String accountId)
The Account that checks sent to this Lockbox Recipient should be deposited into.
-
accountId
final LockboxRecipientCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxAddressId
final LockboxRecipientCreateParams.Body.Builder lockboxAddressId(String lockboxAddressId)
The Lockbox Address where this Lockbox Recipient may receive mail.
-
lockboxAddressId
final LockboxRecipientCreateParams.Body.Builder lockboxAddressId(JsonField<String> lockboxAddressId)
Sets Builder.lockboxAddressId to an arbitrary JSON value.
You should usually call Builder.lockboxAddressId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LockboxRecipientCreateParams.Body.Builder description(String description)
The description you choose for the Lockbox Recipient.
-
description
final LockboxRecipientCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final LockboxRecipientCreateParams.Body.Builder recipientName(String recipientName)
The name of the Lockbox Recipient
-
recipientName
final LockboxRecipientCreateParams.Body.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final LockboxRecipientCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final LockboxRecipientCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final LockboxRecipientCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final LockboxRecipientCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final LockboxRecipientCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final LockboxRecipientCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .lockboxAddressId()
-
-
-
-