Class LockboxRecipientCreateParams.Builder
-
- All Implemented Interfaces:
public final class LockboxRecipientCreateParams.BuilderA builder for LockboxRecipientCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final LockboxRecipientCreateParams.Builder body(LockboxRecipientCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
accountId
final LockboxRecipientCreateParams.Builder accountId(String accountId)
The Account that checks sent to this Lockbox Recipient should be deposited into.
-
accountId
final LockboxRecipientCreateParams.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxAddressId
final LockboxRecipientCreateParams.Builder lockboxAddressId(String lockboxAddressId)
The Lockbox Address where this Lockbox Recipient may receive mail.
-
lockboxAddressId
final LockboxRecipientCreateParams.Builder lockboxAddressId(JsonField<String> lockboxAddressId)
Sets Builder.lockboxAddressId to an arbitrary JSON value.
You should usually call Builder.lockboxAddressId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final LockboxRecipientCreateParams.Builder description(String description)
The description you choose for the Lockbox Recipient.
-
description
final LockboxRecipientCreateParams.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final LockboxRecipientCreateParams.Builder recipientName(String recipientName)
The name of the Lockbox Recipient
-
recipientName
final LockboxRecipientCreateParams.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final LockboxRecipientCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final LockboxRecipientCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final LockboxRecipientCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final LockboxRecipientCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final LockboxRecipientCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final LockboxRecipientCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final LockboxRecipientCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final LockboxRecipientCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final LockboxRecipientCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final LockboxRecipientCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final LockboxRecipientCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final LockboxRecipientCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final LockboxRecipientCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final LockboxRecipientCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final LockboxRecipientCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final LockboxRecipientCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final LockboxRecipientCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final LockboxRecipientCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final LockboxRecipientCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final LockboxRecipientCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final LockboxRecipientCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final LockboxRecipientCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final LockboxRecipientCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final LockboxRecipientCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final LockboxRecipientCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final LockboxRecipientCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final LockboxRecipientCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final LockboxRecipientCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final LockboxRecipientCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final LockboxRecipientCreateParams build()
Returns an immutable instance of LockboxRecipientCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .lockboxAddressId()
-
-
-
-