Class LockboxRecipientListPage.Builder
-
- All Implemented Interfaces:
public final class LockboxRecipientListPage.BuilderA builder for LockboxRecipientListPage.
-
-
Method Summary
Modifier and Type Method Description final LockboxRecipientListPage.Builderservice(LockboxRecipientService service)final LockboxRecipientListPage.Builderparams(LockboxRecipientListParams params)The parameters that were used to request this page. final LockboxRecipientListPage.Builderresponse(LockboxRecipientListPageResponse response)The response that this page was parsed from. final LockboxRecipientListPagebuild()Returns an immutable instance of LockboxRecipientListPage. -
-
Method Detail
-
service
final LockboxRecipientListPage.Builder service(LockboxRecipientService service)
-
params
final LockboxRecipientListPage.Builder params(LockboxRecipientListParams params)
The parameters that were used to request this page.
-
response
final LockboxRecipientListPage.Builder response(LockboxRecipientListPageResponse response)
The response that this page was parsed from.
-
build
final LockboxRecipientListPage build()
Returns an immutable instance of LockboxRecipientListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-