Class LockboxRecipientListPageAsync.Builder
-
- All Implemented Interfaces:
public final class LockboxRecipientListPageAsync.BuilderA builder for LockboxRecipientListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final LockboxRecipientListPageAsync.Builderservice(LockboxRecipientServiceAsync service)final LockboxRecipientListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final LockboxRecipientListPageAsync.Builderparams(LockboxRecipientListParams params)The parameters that were used to request this page. final LockboxRecipientListPageAsync.Builderresponse(LockboxRecipientListPageResponse response)The response that this page was parsed from. final LockboxRecipientListPageAsyncbuild()Returns an immutable instance of LockboxRecipientListPageAsync. -
-
Method Detail
-
service
final LockboxRecipientListPageAsync.Builder service(LockboxRecipientServiceAsync service)
-
streamHandlerExecutor
final LockboxRecipientListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final LockboxRecipientListPageAsync.Builder params(LockboxRecipientListParams params)
The parameters that were used to request this page.
-
response
final LockboxRecipientListPageAsync.Builder response(LockboxRecipientListPageResponse response)
The response that this page was parsed from.
-
build
final LockboxRecipientListPageAsync build()
Returns an immutable instance of LockboxRecipientListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-