Class LockboxRecipientListPageResponse
-
- All Implemented Interfaces:
public final class LockboxRecipientListPageResponseA list of Lockbox Recipient objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientListPageResponse.BuilderA builder for LockboxRecipientListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<LockboxRecipient>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<LockboxRecipient>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final LockboxRecipientListPageResponse.BuildertoBuilder()final LockboxRecipientListPageResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxRecipientListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxRecipientListPageResponse. -
-
Method Detail
-
data
final List<LockboxRecipient> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
_data
final JsonField<List<LockboxRecipient>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxRecipientListPageResponse.Builder toBuilder()
-
validate
final LockboxRecipientListPageResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static LockboxRecipientListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of LockboxRecipientListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-