Class LockboxRecipientUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class LockboxRecipientUpdateParams implements Params
Update a Lockbox Recipient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientUpdateParams.BuilderA builder for LockboxRecipientUpdateParams.
public final classLockboxRecipientUpdateParams.Bodypublic final classLockboxRecipientUpdateParams.StatusThe status of the Lockbox Recipient.
-
Method Summary
Modifier and Type Method Description final Optional<String>lockboxRecipientId()The identifier of the Lockbox Recipient. final Optional<String>description()The description you choose for the Lockbox Recipient. final Optional<String>recipientName()The name of the Lockbox Recipient. final Optional<LockboxRecipientUpdateParams.Status>status()The status of the Lockbox Recipient. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<LockboxRecipientUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final LockboxRecipientUpdateParams.BuildertoBuilder()final LockboxRecipientUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxRecipientUpdateParamsnone()final static LockboxRecipientUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of LockboxRecipientUpdateParams. -
-
Method Detail
-
lockboxRecipientId
final Optional<String> lockboxRecipientId()
The identifier of the Lockbox Recipient.
-
description
final Optional<String> description()
The description you choose for the Lockbox Recipient.
-
recipientName
final Optional<String> recipientName()
The name of the Lockbox Recipient.
-
status
final Optional<LockboxRecipientUpdateParams.Status> status()
The status of the Lockbox Recipient.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<LockboxRecipientUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final LockboxRecipientUpdateParams.Builder toBuilder()
-
_body
final LockboxRecipientUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static LockboxRecipientUpdateParams none()
-
builder
final static LockboxRecipientUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of LockboxRecipientUpdateParams.
-
-
-
-