Class OAuthApplication
-
- All Implemented Interfaces:
public final class OAuthApplicationAn OAuth Application lets you build an application for others to use with their Increase data. You can create an OAuth Application via the Dashboard and read information about it with the API. Learn more about OAuth here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplication.BuilderA builder for OAuthApplication.
public final classOAuthApplication.StatusWhether the application is active.
public final classOAuthApplication.TypeA constant representing the object's type. For this resource it will always be
oauth_application.
-
Method Summary
Modifier and Type Method Description final Stringid()The OAuth Application's identifier. final StringclientId()The OAuth Application's client_id. final OffsetDateTimecreatedAt()The ISO 8601 timestamp when the OAuth Application was created. final Optional<OffsetDateTime>deletedAt()The ISO 8601 timestamp when the OAuth Application was deleted. final Optional<String>name()The name you chose for this OAuth Application. final OAuthApplication.Statusstatus()Whether the application is active. final OAuthApplication.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<OffsetDateTime>_deletedAt()Returns the raw JSON value of deletedAt. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<OAuthApplication.Status>_status()Returns the raw JSON value of status. final JsonField<OAuthApplication.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final OAuthApplication.BuildertoBuilder()final OAuthApplicationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplication.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplication. -
-
Method Detail
-
clientId
final String clientId()
The OAuth Application's client_id. Use this to authenticate with the OAuth Application.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 timestamp when the OAuth Application was created.
-
deletedAt
final Optional<OffsetDateTime> deletedAt()
The ISO 8601 timestamp when the OAuth Application was deleted.
-
status
final OAuthApplication.Status status()
Whether the application is active.
-
type
final OAuthApplication.Type type()
A constant representing the object's type. For this resource it will always be
oauth_application.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_deletedAt
final JsonField<OffsetDateTime> _deletedAt()
Returns the raw JSON value of deletedAt.
Unlike deletedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<OAuthApplication.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<OAuthApplication.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OAuthApplication.Builder toBuilder()
-
validate
final OAuthApplication validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OAuthApplication.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplication.
The following fields are required:
.id() .clientId() .createdAt() .deletedAt() .name() .status() .type()
-
-
-
-