Class OAuthApplication.Builder
-
- All Implemented Interfaces:
public final class OAuthApplication.BuilderA builder for OAuthApplication.
-
-
Method Summary
-
-
Method Detail
-
id
final OAuthApplication.Builder id(String id)
The OAuth Application's identifier.
-
id
final OAuthApplication.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientId
final OAuthApplication.Builder clientId(String clientId)
The OAuth Application's client_id. Use this to authenticate with the OAuth Application.
-
clientId
final OAuthApplication.Builder clientId(JsonField<String> clientId)
Sets Builder.clientId to an arbitrary JSON value.
You should usually call Builder.clientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final OAuthApplication.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 timestamp when the OAuth Application was created.
-
createdAt
final OAuthApplication.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
deletedAt
final OAuthApplication.Builder deletedAt(OffsetDateTime deletedAt)
The ISO 8601 timestamp when the OAuth Application was deleted.
-
deletedAt
final OAuthApplication.Builder deletedAt(Optional<OffsetDateTime> deletedAt)
Alias for calling Builder.deletedAt with
deletedAt.orElse(null).
-
deletedAt
final OAuthApplication.Builder deletedAt(JsonField<OffsetDateTime> deletedAt)
Sets Builder.deletedAt to an arbitrary JSON value.
You should usually call Builder.deletedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final OAuthApplication.Builder name(String name)
The name you chose for this OAuth Application.
-
name
final OAuthApplication.Builder name(Optional<String> name)
Alias for calling Builder.name with
name.orElse(null).
-
name
final OAuthApplication.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final OAuthApplication.Builder status(OAuthApplication.Status status)
Whether the application is active.
-
status
final OAuthApplication.Builder status(JsonField<OAuthApplication.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final OAuthApplication.Builder type(OAuthApplication.Type type)
A constant representing the object's type. For this resource it will always be
oauth_application.
-
type
final OAuthApplication.Builder type(JsonField<OAuthApplication.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final OAuthApplication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OAuthApplication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OAuthApplication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OAuthApplication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OAuthApplication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OAuthApplication build()
Returns an immutable instance of OAuthApplication.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .clientId() .createdAt() .deletedAt() .name() .status() .type()
-
-
-
-