Class OAuthApplicationListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class OAuthApplicationListPage implements Page<OAuthApplication>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationListPage.BuilderA builder for OAuthApplicationListPage.
-
Method Summary
Modifier and Type Method Description final List<OAuthApplication>data()Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data. List<OAuthApplication>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final OAuthApplicationListParamsnextPageParams()OAuthApplicationListPagenextPage()Returns the page after this one by making another request. final AutoPager<OAuthApplication>autoPager()final OAuthApplicationListParamsparams()The parameters that were used to request this page. final OAuthApplicationListPageResponseresponse()The response that this page was parsed from. final OAuthApplicationListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplicationListPage.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplicationListPage. -
-
Method Detail
-
data
final List<OAuthApplication> data()
Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data.
-
items
List<OAuthApplication> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final OAuthApplicationListParams nextPageParams()
-
nextPage
OAuthApplicationListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<OAuthApplication> autoPager()
-
params
final OAuthApplicationListParams params()
The parameters that were used to request this page.
-
response
final OAuthApplicationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final OAuthApplicationListPage.Builder toBuilder()
-
builder
final static OAuthApplicationListPage.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplicationListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-