Class OAuthApplicationListPage.Builder
-
- All Implemented Interfaces:
public final class OAuthApplicationListPage.BuilderA builder for OAuthApplicationListPage.
-
-
Method Summary
Modifier and Type Method Description final OAuthApplicationListPage.Builderservice(OAuthApplicationService service)final OAuthApplicationListPage.Builderparams(OAuthApplicationListParams params)The parameters that were used to request this page. final OAuthApplicationListPage.Builderresponse(OAuthApplicationListPageResponse response)The response that this page was parsed from. final OAuthApplicationListPagebuild()Returns an immutable instance of OAuthApplicationListPage. -
-
Method Detail
-
service
final OAuthApplicationListPage.Builder service(OAuthApplicationService service)
-
params
final OAuthApplicationListPage.Builder params(OAuthApplicationListParams params)
The parameters that were used to request this page.
-
response
final OAuthApplicationListPage.Builder response(OAuthApplicationListPageResponse response)
The response that this page was parsed from.
-
build
final OAuthApplicationListPage build()
Returns an immutable instance of OAuthApplicationListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-