Class OAuthApplicationListPageAsync
-
- All Implemented Interfaces:
public final class OAuthApplicationListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationListPageAsync.BuilderA builder for OAuthApplicationListPageAsync.
public final classOAuthApplicationListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<OAuthApplication>data()Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<OAuthApplicationListParams>getNextPageParams()final CompletableFuture<Optional<OAuthApplicationListPageAsync>>getNextPage()final OAuthApplicationListPageAsync.AutoPagerautoPager()final OAuthApplicationListParamsparams()The parameters that were used to request this page. final OAuthApplicationListPageResponseresponse()The response that this page was parsed from. final OAuthApplicationListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplicationListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplicationListPageAsync. -
-
Method Detail
-
data
final List<OAuthApplication> data()
Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<OAuthApplicationListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<OAuthApplicationListPageAsync>> getNextPage()
-
autoPager
final OAuthApplicationListPageAsync.AutoPager autoPager()
-
params
final OAuthApplicationListParams params()
The parameters that were used to request this page.
-
response
final OAuthApplicationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final OAuthApplicationListPageAsync.Builder toBuilder()
-
builder
final static OAuthApplicationListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplicationListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-