Class OAuthApplicationListPageAsync.Builder
-
- All Implemented Interfaces:
public final class OAuthApplicationListPageAsync.BuilderA builder for OAuthApplicationListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final OAuthApplicationListPageAsync.Builderservice(OAuthApplicationServiceAsync service)final OAuthApplicationListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final OAuthApplicationListPageAsync.Builderparams(OAuthApplicationListParams params)The parameters that were used to request this page. final OAuthApplicationListPageAsync.Builderresponse(OAuthApplicationListPageResponse response)The response that this page was parsed from. final OAuthApplicationListPageAsyncbuild()Returns an immutable instance of OAuthApplicationListPageAsync. -
-
Method Detail
-
service
final OAuthApplicationListPageAsync.Builder service(OAuthApplicationServiceAsync service)
-
streamHandlerExecutor
final OAuthApplicationListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final OAuthApplicationListPageAsync.Builder params(OAuthApplicationListParams params)
The parameters that were used to request this page.
-
response
final OAuthApplicationListPageAsync.Builder response(OAuthApplicationListPageResponse response)
The response that this page was parsed from.
-
build
final OAuthApplicationListPageAsync build()
Returns an immutable instance of OAuthApplicationListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-