Class OAuthApplicationListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class OAuthApplicationListParams implements Params
List OAuth Applications
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationListParams.BuilderA builder for OAuthApplicationListParams.
public final classOAuthApplicationListParams.CreatedAtpublic final classOAuthApplicationListParams.Status
-
Method Summary
Modifier and Type Method Description final Optional<OAuthApplicationListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Optional<OAuthApplicationListParams.Status>status()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final OAuthApplicationListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplicationListParamsnone()final static OAuthApplicationListParams.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplicationListParams. -
-
Method Detail
-
createdAt
final Optional<OAuthApplicationListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
status
final Optional<OAuthApplicationListParams.Status> status()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final OAuthApplicationListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static OAuthApplicationListParams none()
-
builder
final static OAuthApplicationListParams.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplicationListParams.
-
-
-
-