Class OAuthConnection
-
- All Implemented Interfaces:
public final class OAuthConnectionWhen a user authorizes your OAuth application, an OAuth Connection object is created. Learn more about OAuth here.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnection.BuilderA builder for OAuthConnection.
public final classOAuthConnection.StatusWhether the connection is active.
public final classOAuthConnection.TypeA constant representing the object's type. For this resource it will always be
oauth_connection.
-
Method Summary
Modifier and Type Method Description final Stringid()The OAuth Connection's identifier. final OffsetDateTimecreatedAt()The ISO 8601 timestamp when the OAuth Connection was created. final Optional<OffsetDateTime>deletedAt()The ISO 8601 timestamp when the OAuth Connection was deleted. final StringgroupId()The identifier of the Group that has authorized your OAuth application. final StringoauthApplicationId()The identifier of the OAuth application this connection is for. final OAuthConnection.Statusstatus()Whether the connection is active. final OAuthConnection.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<OffsetDateTime>_deletedAt()Returns the raw JSON value of deletedAt. final JsonField<String>_groupId()Returns the raw JSON value of groupId. final JsonField<String>_oauthApplicationId()Returns the raw JSON value of oauthApplicationId. final JsonField<OAuthConnection.Status>_status()Returns the raw JSON value of status. final JsonField<OAuthConnection.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final OAuthConnection.BuildertoBuilder()final OAuthConnectionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthConnection.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthConnection. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 timestamp when the OAuth Connection was created.
-
deletedAt
final Optional<OffsetDateTime> deletedAt()
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
groupId
final String groupId()
The identifier of the Group that has authorized your OAuth application.
-
oauthApplicationId
final String oauthApplicationId()
The identifier of the OAuth application this connection is for.
-
status
final OAuthConnection.Status status()
Whether the connection is active.
-
type
final OAuthConnection.Type type()
A constant representing the object's type. For this resource it will always be
oauth_connection.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_deletedAt
final JsonField<OffsetDateTime> _deletedAt()
Returns the raw JSON value of deletedAt.
Unlike deletedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_groupId
final JsonField<String> _groupId()
Returns the raw JSON value of groupId.
Unlike groupId, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthApplicationId
final JsonField<String> _oauthApplicationId()
Returns the raw JSON value of oauthApplicationId.
Unlike oauthApplicationId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<OAuthConnection.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<OAuthConnection.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OAuthConnection.Builder toBuilder()
-
validate
final OAuthConnection validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OAuthConnection.Builder builder()
Returns a mutable builder for constructing an instance of OAuthConnection.
The following fields are required:
.id() .createdAt() .deletedAt() .groupId() .oauthApplicationId() .status() .type()
-
-
-
-