Class OAuthConnection.Builder
-
- All Implemented Interfaces:
public final class OAuthConnection.BuilderA builder for OAuthConnection.
-
-
Method Summary
-
-
Method Detail
-
id
final OAuthConnection.Builder id(String id)
The OAuth Connection's identifier.
-
id
final OAuthConnection.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final OAuthConnection.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 timestamp when the OAuth Connection was created.
-
createdAt
final OAuthConnection.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
deletedAt
final OAuthConnection.Builder deletedAt(OffsetDateTime deletedAt)
The ISO 8601 timestamp when the OAuth Connection was deleted.
-
deletedAt
final OAuthConnection.Builder deletedAt(Optional<OffsetDateTime> deletedAt)
Alias for calling Builder.deletedAt with
deletedAt.orElse(null).
-
deletedAt
final OAuthConnection.Builder deletedAt(JsonField<OffsetDateTime> deletedAt)
Sets Builder.deletedAt to an arbitrary JSON value.
You should usually call Builder.deletedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
groupId
final OAuthConnection.Builder groupId(String groupId)
The identifier of the Group that has authorized your OAuth application.
-
groupId
final OAuthConnection.Builder groupId(JsonField<String> groupId)
Sets Builder.groupId to an arbitrary JSON value.
You should usually call Builder.groupId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
oauthApplicationId
final OAuthConnection.Builder oauthApplicationId(String oauthApplicationId)
The identifier of the OAuth application this connection is for.
-
oauthApplicationId
final OAuthConnection.Builder oauthApplicationId(JsonField<String> oauthApplicationId)
Sets Builder.oauthApplicationId to an arbitrary JSON value.
You should usually call Builder.oauthApplicationId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final OAuthConnection.Builder status(OAuthConnection.Status status)
Whether the connection is active.
-
status
final OAuthConnection.Builder status(JsonField<OAuthConnection.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final OAuthConnection.Builder type(OAuthConnection.Type type)
A constant representing the object's type. For this resource it will always be
oauth_connection.
-
type
final OAuthConnection.Builder type(JsonField<OAuthConnection.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final OAuthConnection.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OAuthConnection.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OAuthConnection.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OAuthConnection.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OAuthConnection.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OAuthConnection build()
Returns an immutable instance of OAuthConnection.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .createdAt() .deletedAt() .groupId() .oauthApplicationId() .status() .type()
-
-
-
-