Class OAuthConnectionListPage
-
- All Implemented Interfaces:
public final class OAuthConnectionListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnectionListPage.BuilderA builder for OAuthConnectionListPage.
public final classOAuthConnectionListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<OAuthConnection>data()Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<OAuthConnectionListParams>getNextPageParams()final Optional<OAuthConnectionListPage>getNextPage()final OAuthConnectionListPage.AutoPagerautoPager()final OAuthConnectionListParamsparams()The parameters that were used to request this page. final OAuthConnectionListPageResponseresponse()The response that this page was parsed from. final OAuthConnectionListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthConnectionListPage.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthConnectionListPage. -
-
Method Detail
-
data
final List<OAuthConnection> data()
Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<OAuthConnectionListParams> getNextPageParams()
-
getNextPage
final Optional<OAuthConnectionListPage> getNextPage()
-
autoPager
final OAuthConnectionListPage.AutoPager autoPager()
-
params
final OAuthConnectionListParams params()
The parameters that were used to request this page.
-
response
final OAuthConnectionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final OAuthConnectionListPage.Builder toBuilder()
-
builder
final static OAuthConnectionListPage.Builder builder()
Returns a mutable builder for constructing an instance of OAuthConnectionListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-