Class OAuthConnectionListPage.Builder
-
- All Implemented Interfaces:
public final class OAuthConnectionListPage.BuilderA builder for OAuthConnectionListPage.
-
-
Method Summary
Modifier and Type Method Description final OAuthConnectionListPage.Builderservice(OAuthConnectionService service)final OAuthConnectionListPage.Builderparams(OAuthConnectionListParams params)The parameters that were used to request this page. final OAuthConnectionListPage.Builderresponse(OAuthConnectionListPageResponse response)The response that this page was parsed from. final OAuthConnectionListPagebuild()Returns an immutable instance of OAuthConnectionListPage. -
-
Method Detail
-
service
final OAuthConnectionListPage.Builder service(OAuthConnectionService service)
-
params
final OAuthConnectionListPage.Builder params(OAuthConnectionListParams params)
The parameters that were used to request this page.
-
response
final OAuthConnectionListPage.Builder response(OAuthConnectionListPageResponse response)
The response that this page was parsed from.
-
build
final OAuthConnectionListPage build()
Returns an immutable instance of OAuthConnectionListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-