Class OAuthConnectionListPageAsync
-
- All Implemented Interfaces:
public final class OAuthConnectionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnectionListPageAsync.BuilderA builder for OAuthConnectionListPageAsync.
public final classOAuthConnectionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<OAuthConnection>data()Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<OAuthConnectionListParams>getNextPageParams()final CompletableFuture<Optional<OAuthConnectionListPageAsync>>getNextPage()final OAuthConnectionListPageAsync.AutoPagerautoPager()final OAuthConnectionListParamsparams()The parameters that were used to request this page. final OAuthConnectionListPageResponseresponse()The response that this page was parsed from. final OAuthConnectionListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthConnectionListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthConnectionListPageAsync. -
-
Method Detail
-
data
final List<OAuthConnection> data()
Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to OAuthConnectionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<OAuthConnectionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<OAuthConnectionListPageAsync>> getNextPage()
-
autoPager
final OAuthConnectionListPageAsync.AutoPager autoPager()
-
params
final OAuthConnectionListParams params()
The parameters that were used to request this page.
-
response
final OAuthConnectionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final OAuthConnectionListPageAsync.Builder toBuilder()
-
builder
final static OAuthConnectionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of OAuthConnectionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-