Class OAuthConnectionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class OAuthConnectionListPageAsync.BuilderA builder for OAuthConnectionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final OAuthConnectionListPageAsync.Builderservice(OAuthConnectionServiceAsync service)final OAuthConnectionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final OAuthConnectionListPageAsync.Builderparams(OAuthConnectionListParams params)The parameters that were used to request this page. final OAuthConnectionListPageAsync.Builderresponse(OAuthConnectionListPageResponse response)The response that this page was parsed from. final OAuthConnectionListPageAsyncbuild()Returns an immutable instance of OAuthConnectionListPageAsync. -
-
Method Detail
-
service
final OAuthConnectionListPageAsync.Builder service(OAuthConnectionServiceAsync service)
-
streamHandlerExecutor
final OAuthConnectionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final OAuthConnectionListPageAsync.Builder params(OAuthConnectionListParams params)
The parameters that were used to request this page.
-
response
final OAuthConnectionListPageAsync.Builder response(OAuthConnectionListPageResponse response)
The response that this page was parsed from.
-
build
final OAuthConnectionListPageAsync build()
Returns an immutable instance of OAuthConnectionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-