Class OAuthConnectionListPageResponse
-
- All Implemented Interfaces:
public final class OAuthConnectionListPageResponseA list of OAuth Connection objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnectionListPageResponse.BuilderA builder for OAuthConnectionListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<OAuthConnection>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<OAuthConnection>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final OAuthConnectionListPageResponse.BuildertoBuilder()final OAuthConnectionListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthConnectionListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthConnectionListPageResponse. -
-
Method Detail
-
data
final List<OAuthConnection> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<OAuthConnection>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OAuthConnectionListPageResponse.Builder toBuilder()
-
validate
final OAuthConnectionListPageResponse validate()
-
builder
final static OAuthConnectionListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of OAuthConnectionListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-