Class OAuthToken

  • All Implemented Interfaces:

    
    public final class OAuthToken
    
                        

    A token that is returned to your application when a user completes the OAuth flow and may be used to authenticate requests. Learn more about OAuth /documentation/oauth.