Class OAuthToken.Builder
-
- All Implemented Interfaces:
public final class OAuthToken.BuilderA builder for OAuthToken.
-
-
Method Summary
-
-
Method Detail
-
accessToken
final OAuthToken.Builder accessToken(String accessToken)
You may use this token in place of an API key to make OAuth requests on a user's behalf.
-
accessToken
final OAuthToken.Builder accessToken(JsonField<String> accessToken)
Sets Builder.accessToken to an arbitrary JSON value.
You should usually call Builder.accessToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tokenType
final OAuthToken.Builder tokenType(OAuthToken.TokenType tokenType)
The type of OAuth token.
-
tokenType
final OAuthToken.Builder tokenType(JsonField<OAuthToken.TokenType> tokenType)
Sets Builder.tokenType to an arbitrary JSON value.
You should usually call Builder.tokenType with a well-typed TokenType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final OAuthToken.Builder type(OAuthToken.Type type)
A constant representing the object's type. For this resource it will always be
oauth_token.
-
type
final OAuthToken.Builder type(JsonField<OAuthToken.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final OAuthToken.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OAuthToken.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OAuthToken.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OAuthToken.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OAuthToken.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OAuthToken build()
Returns an immutable instance of OAuthToken.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accessToken() .tokenType() .type()
-
-
-
-