Class OAuthTokenCreateParams.Body
-
- All Implemented Interfaces:
public final class OAuthTokenCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthTokenCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final OAuthTokenCreateParams.GrantTypegrantType()The credential you request in exchange for the code. final Optional<String>clientId()The public identifier for your application. final Optional<String>clientSecret()The secret that confirms you own the application. final Optional<String>code()The authorization code generated by the user and given to you as a query parameter. final Optional<String>productionToken()The production token you want to exchange for a sandbox token. final JsonField<OAuthTokenCreateParams.GrantType>_grantType()Returns the raw JSON value of grantType. final JsonField<String>_clientId()Returns the raw JSON value of clientId. final JsonField<String>_clientSecret()Returns the raw JSON value of clientSecret. final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<String>_productionToken()Returns the raw JSON value of productionToken. final Map<String, JsonValue>_additionalProperties()final OAuthTokenCreateParams.Body.BuildertoBuilder()final OAuthTokenCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthTokenCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
grantType
final OAuthTokenCreateParams.GrantType grantType()
The credential you request in exchange for the code. In Production, this is always
authorization_code. In Sandbox, you can pass either enum value.
-
clientSecret
final Optional<String> clientSecret()
The secret that confirms you own the application. This is redundant given that the request is made with your API key but it's a required component of OAuth 2.0.
-
code
final Optional<String> code()
The authorization code generated by the user and given to you as a query parameter.
-
productionToken
final Optional<String> productionToken()
The production token you want to exchange for a sandbox token. This is only available in Sandbox. Set
grant_typetoproduction_tokento use this parameter.
-
_grantType
final JsonField<OAuthTokenCreateParams.GrantType> _grantType()
Returns the raw JSON value of grantType.
Unlike grantType, this method doesn't throw if the JSON field has an unexpected type.
-
_clientId
final JsonField<String> _clientId()
Returns the raw JSON value of clientId.
Unlike clientId, this method doesn't throw if the JSON field has an unexpected type.
-
_clientSecret
final JsonField<String> _clientSecret()
Returns the raw JSON value of clientSecret.
Unlike clientSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_productionToken
final JsonField<String> _productionToken()
Returns the raw JSON value of productionToken.
Unlike productionToken, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OAuthTokenCreateParams.Body.Builder toBuilder()
-
validate
final OAuthTokenCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OAuthTokenCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.grantType()
-
-
-
-