Class OAuthTokenCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class OAuthTokenCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
grantType
final OAuthTokenCreateParams.Body.Builder grantType(OAuthTokenCreateParams.GrantType grantType)
The credential you request in exchange for the code. In Production, this is always
authorization_code. In Sandbox, you can pass either enum value.
-
grantType
final OAuthTokenCreateParams.Body.Builder grantType(JsonField<OAuthTokenCreateParams.GrantType> grantType)
Sets Builder.grantType to an arbitrary JSON value.
You should usually call Builder.grantType with a well-typed GrantType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientId
final OAuthTokenCreateParams.Body.Builder clientId(String clientId)
The public identifier for your application.
-
clientId
final OAuthTokenCreateParams.Body.Builder clientId(JsonField<String> clientId)
Sets Builder.clientId to an arbitrary JSON value.
You should usually call Builder.clientId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
clientSecret
final OAuthTokenCreateParams.Body.Builder clientSecret(String clientSecret)
The secret that confirms you own the application. This is redundant given that the request is made with your API key but it's a required component of OAuth 2.0.
-
clientSecret
final OAuthTokenCreateParams.Body.Builder clientSecret(JsonField<String> clientSecret)
Sets Builder.clientSecret to an arbitrary JSON value.
You should usually call Builder.clientSecret with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
code
final OAuthTokenCreateParams.Body.Builder code(String code)
The authorization code generated by the user and given to you as a query parameter.
-
code
final OAuthTokenCreateParams.Body.Builder code(JsonField<String> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
productionToken
final OAuthTokenCreateParams.Body.Builder productionToken(String productionToken)
The production token you want to exchange for a sandbox token. This is only available in Sandbox. Set
grant_typetoproduction_tokento use this parameter.
-
productionToken
final OAuthTokenCreateParams.Body.Builder productionToken(JsonField<String> productionToken)
Sets Builder.productionToken to an arbitrary JSON value.
You should usually call Builder.productionToken with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final OAuthTokenCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OAuthTokenCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OAuthTokenCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OAuthTokenCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OAuthTokenCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OAuthTokenCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.grantType()
-
-
-
-