Class PendingTransaction
-
- All Implemented Interfaces:
public final class PendingTransactionPending Transactions are potential future additions and removals of money from your bank account. They impact your available balance, but not your current balance. To learn more, see /documentation/transactions-transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.BuilderA builder for PendingTransaction.
public final classPendingTransaction.CurrencyThe ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
public final classPendingTransaction.RouteTypeThe type of the route this Pending Transaction came through.
public final classPendingTransaction.SourceThis is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
public final classPendingTransaction.StatusWhether the Pending Transaction has been confirmed and has an associated Transaction.
public final classPendingTransaction.TypeA constant representing the object's type. For this resource it will always be
pending_transaction.
-
Method Summary
Modifier and Type Method Description final Stringid()The Pending Transaction identifier. final StringaccountId()The identifier for the account this Pending Transaction belongs to. final Longamount()The Pending Transaction amount in the minor unit of its currency. final Optional<OffsetDateTime>completedAt()The ISO 8601 date on which the Pending Transaction was completed. final OffsetDateTimecreatedAt()The ISO 8601 date on which the Pending Transaction occurred. final PendingTransaction.Currencycurrency()The ISO 4217 code for the Pending Transaction's currency. final Stringdescription()For a Pending Transaction related to a transfer, this is the description you provide. final LongheldAmount()The amount that this Pending Transaction decrements the available balance of its Account. final Optional<String>routeId()The identifier for the route this Pending Transaction came through. final Optional<PendingTransaction.RouteType>routeType()The type of the route this Pending Transaction came through. final PendingTransaction.Sourcesource()This is an object giving more details on the network-level event that caused the Pending Transaction. final PendingTransaction.Statusstatus()Whether the Pending Transaction has been confirmed and has an associated Transaction. final PendingTransaction.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_completedAt()Returns the raw JSON value of completedAt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<PendingTransaction.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Long>_heldAmount()Returns the raw JSON value of heldAmount. final JsonField<String>_routeId()Returns the raw JSON value of routeId. final JsonField<PendingTransaction.RouteType>_routeType()Returns the raw JSON value of routeType. final JsonField<PendingTransaction.Source>_source()Returns the raw JSON value of source. final JsonField<PendingTransaction.Status>_status()Returns the raw JSON value of status. final JsonField<PendingTransaction.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.BuildertoBuilder()final PendingTransactionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Builderbuilder()Returns a mutable builder for constructing an instance of PendingTransaction. -
-
Method Detail
-
accountId
final String accountId()
The identifier for the account this Pending Transaction belongs to.
-
amount
final Long amount()
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
completedAt
final Optional<OffsetDateTime> completedAt()
The ISO 8601 date on which the Pending Transaction was completed.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date on which the Pending Transaction occurred.
-
currency
final PendingTransaction.Currency currency()
The ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
-
description
final String description()
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
-
heldAmount
final Long heldAmount()
The amount that this Pending Transaction decrements the available balance of its Account. This is usually the same as
amount, but will differ if the amount is positive.
-
routeId
final Optional<String> routeId()
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
routeType
final Optional<PendingTransaction.RouteType> routeType()
The type of the route this Pending Transaction came through.
-
source
final PendingTransaction.Source source()
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
status
final PendingTransaction.Status status()
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
type
final PendingTransaction.Type type()
A constant representing the object's type. For this resource it will always be
pending_transaction.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_completedAt
final JsonField<OffsetDateTime> _completedAt()
Returns the raw JSON value of completedAt.
Unlike completedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<PendingTransaction.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_heldAmount
final JsonField<Long> _heldAmount()
Returns the raw JSON value of heldAmount.
Unlike heldAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_routeId
final JsonField<String> _routeId()
Returns the raw JSON value of routeId.
Unlike routeId, this method doesn't throw if the JSON field has an unexpected type.
-
_routeType
final JsonField<PendingTransaction.RouteType> _routeType()
Returns the raw JSON value of routeType.
Unlike routeType, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<PendingTransaction.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<PendingTransaction.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PendingTransaction.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Builder toBuilder()
-
validate
final PendingTransaction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Builder builder()
Returns a mutable builder for constructing an instance of PendingTransaction.
The following fields are required:
.id() .accountId() .amount() .completedAt() .createdAt() .currency() .description() .heldAmount() .routeId() .routeType() .source() .status() .type()
-
-
-
-