Enum PendingTransaction.BalanceImpact.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PendingTransaction.BalanceImpact.Known extends Enum<PendingTransaction.BalanceImpact.Known>
An enum containing BalanceImpact's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PendingTransaction.BalanceImpact.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description AFFECTS_AVAILABLE_BALANCEThis Pending Transaction will decrement the available balance on the Account while its status is
pending.NONEThis Pending Transaction does not affect the available balance on the Account.
-
Method Summary
Modifier and Type Method Description final PendingTransaction.BalanceImpact.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PendingTransaction.BalanceImpact.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PendingTransaction.BalanceImpact.Known>getEntries()An enum containing BalanceImpact's known values. -
-
Method Detail
-
valueOf
final PendingTransaction.BalanceImpact.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PendingTransaction.BalanceImpact.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PendingTransaction.BalanceImpact.Known> getEntries()
An enum containing BalanceImpact's known values.
-
-
-
-