Class PendingTransaction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.BuilderA builder for PendingTransaction.
-
-
Method Summary
Modifier and Type Method Description final PendingTransaction.Builderid(String id)The Pending Transaction identifier. final PendingTransaction.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final PendingTransaction.BuilderaccountId(String accountId)The identifier for the account this Pending Transaction belongs to. final PendingTransaction.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final PendingTransaction.Builderamount(Long amount)The Pending Transaction amount in the minor unit of its currency. final PendingTransaction.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final PendingTransaction.BuildercompletedAt(OffsetDateTime completedAt)The ISO 8601 date on which the Pending Transaction was completed. final PendingTransaction.BuildercompletedAt(Optional<OffsetDateTime> completedAt)Alias for calling Builder.completedAt with completedAt.orElse(null).final PendingTransaction.BuildercompletedAt(JsonField<OffsetDateTime> completedAt)Sets Builder.completedAt to an arbitrary JSON value. final PendingTransaction.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date on which the Pending Transaction occurred. final PendingTransaction.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final PendingTransaction.Buildercurrency(PendingTransaction.Currency currency)The ISO 4217 code for the Pending Transaction's currency. final PendingTransaction.Buildercurrency(JsonField<PendingTransaction.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final PendingTransaction.Builderdescription(String description)For a Pending Transaction related to a transfer, this is the description you provide. final PendingTransaction.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final PendingTransaction.BuilderheldAmount(Long heldAmount)The amount that this Pending Transaction decrements the available balance of its Account. final PendingTransaction.BuilderheldAmount(JsonField<Long> heldAmount)Sets Builder.heldAmount to an arbitrary JSON value. final PendingTransaction.BuilderrouteId(String routeId)The identifier for the route this Pending Transaction came through. final PendingTransaction.BuilderrouteId(Optional<String> routeId)Alias for calling Builder.routeId with routeId.orElse(null).final PendingTransaction.BuilderrouteId(JsonField<String> routeId)Sets Builder.routeId to an arbitrary JSON value. final PendingTransaction.BuilderrouteType(PendingTransaction.RouteType routeType)The type of the route this Pending Transaction came through. final PendingTransaction.BuilderrouteType(Optional<PendingTransaction.RouteType> routeType)Alias for calling Builder.routeType with routeType.orElse(null).final PendingTransaction.BuilderrouteType(JsonField<PendingTransaction.RouteType> routeType)Sets Builder.routeType to an arbitrary JSON value. final PendingTransaction.Buildersource(PendingTransaction.Source source)This is an object giving more details on the network-level event that caused the Pending Transaction. final PendingTransaction.Buildersource(JsonField<PendingTransaction.Source> source)Sets Builder.source to an arbitrary JSON value. final PendingTransaction.Builderstatus(PendingTransaction.Status status)Whether the Pending Transaction has been confirmed and has an associated Transaction. final PendingTransaction.Builderstatus(JsonField<PendingTransaction.Status> status)Sets Builder.status to an arbitrary JSON value. final PendingTransaction.Buildertype(PendingTransaction.Type type)A constant representing the object's type. final PendingTransaction.Buildertype(JsonField<PendingTransaction.Type> type)Sets Builder.type to an arbitrary JSON value. final PendingTransaction.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final PendingTransaction.BuilderputAdditionalProperty(String key, JsonValue value)final PendingTransaction.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final PendingTransaction.BuilderremoveAdditionalProperty(String key)final PendingTransaction.BuilderremoveAllAdditionalProperties(Set<String> keys)final PendingTransactionbuild()Returns an immutable instance of PendingTransaction. -
-
Method Detail
-
id
final PendingTransaction.Builder id(String id)
The Pending Transaction identifier.
-
id
final PendingTransaction.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final PendingTransaction.Builder accountId(String accountId)
The identifier for the account this Pending Transaction belongs to.
-
accountId
final PendingTransaction.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final PendingTransaction.Builder amount(Long amount)
The Pending Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final PendingTransaction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
completedAt
final PendingTransaction.Builder completedAt(OffsetDateTime completedAt)
The ISO 8601 date on which the Pending Transaction was completed.
-
completedAt
final PendingTransaction.Builder completedAt(Optional<OffsetDateTime> completedAt)
Alias for calling Builder.completedAt with
completedAt.orElse(null).
-
completedAt
final PendingTransaction.Builder completedAt(JsonField<OffsetDateTime> completedAt)
Sets Builder.completedAt to an arbitrary JSON value.
You should usually call Builder.completedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final PendingTransaction.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date on which the Pending Transaction occurred.
-
createdAt
final PendingTransaction.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PendingTransaction.Builder currency(PendingTransaction.Currency currency)
The ISO 4217 code for the Pending Transaction's currency. This will match the currency on the Pending Transaction's Account.
-
currency
final PendingTransaction.Builder currency(JsonField<PendingTransaction.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final PendingTransaction.Builder description(String description)
For a Pending Transaction related to a transfer, this is the description you provide. For a Pending Transaction related to a payment, this is the description the vendor provides.
-
description
final PendingTransaction.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
heldAmount
final PendingTransaction.Builder heldAmount(Long heldAmount)
The amount that this Pending Transaction decrements the available balance of its Account. This is usually the same as
amount, but will differ if the amount is positive.
-
heldAmount
final PendingTransaction.Builder heldAmount(JsonField<Long> heldAmount)
Sets Builder.heldAmount to an arbitrary JSON value.
You should usually call Builder.heldAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routeId
final PendingTransaction.Builder routeId(String routeId)
The identifier for the route this Pending Transaction came through. Routes are things like cards and ACH details.
-
routeId
final PendingTransaction.Builder routeId(Optional<String> routeId)
Alias for calling Builder.routeId with
routeId.orElse(null).
-
routeId
final PendingTransaction.Builder routeId(JsonField<String> routeId)
Sets Builder.routeId to an arbitrary JSON value.
You should usually call Builder.routeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routeType
final PendingTransaction.Builder routeType(PendingTransaction.RouteType routeType)
The type of the route this Pending Transaction came through.
-
routeType
final PendingTransaction.Builder routeType(Optional<PendingTransaction.RouteType> routeType)
Alias for calling Builder.routeType with
routeType.orElse(null).
-
routeType
final PendingTransaction.Builder routeType(JsonField<PendingTransaction.RouteType> routeType)
Sets Builder.routeType to an arbitrary JSON value.
You should usually call Builder.routeType with a well-typed RouteType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final PendingTransaction.Builder source(PendingTransaction.Source source)
This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
source
final PendingTransaction.Builder source(JsonField<PendingTransaction.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PendingTransaction.Builder status(PendingTransaction.Status status)
Whether the Pending Transaction has been confirmed and has an associated Transaction.
-
status
final PendingTransaction.Builder status(JsonField<PendingTransaction.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PendingTransaction.Builder type(PendingTransaction.Type type)
A constant representing the object's type. For this resource it will always be
pending_transaction.
-
type
final PendingTransaction.Builder type(JsonField<PendingTransaction.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction build()
Returns an immutable instance of PendingTransaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount() .completedAt() .createdAt() .currency() .description() .heldAmount() .routeId() .routeType() .source() .status() .type()
-
-
-
-