Class PendingTransaction.Source

  • All Implemented Interfaces:

    
    public final class PendingTransaction.Source
    
                        

    This is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.