Class PendingTransaction.Source.AccountTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.AccountTransferInstructionAn Account Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.AccountTransferInstruction.BuilderA builder for AccountTransferInstruction.
public final classPendingTransaction.Source.AccountTransferInstruction.CurrencyThe ISO 4217 code for the destination account currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The pending amount in the minor unit of the transaction's currency. final PendingTransaction.Source.AccountTransferInstruction.Currencycurrency()The ISO 4217 code for the destination account currency. final StringtransferId()The identifier of the Account Transfer that led to this Pending Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<PendingTransaction.Source.AccountTransferInstruction.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.AccountTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.AccountTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.AccountTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of AccountTransferInstruction. -
-
Method Detail
-
amount
final Long amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final PendingTransaction.Source.AccountTransferInstruction.Currency currency()
The ISO 4217 code for the destination account currency.
-
transferId
final String transferId()
The identifier of the Account Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<PendingTransaction.Source.AccountTransferInstruction.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.AccountTransferInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.AccountTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.AccountTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of AccountTransferInstruction.
The following fields are required:
.amount() .currency() .transferId()
-
-
-
-