Class PendingTransaction.Source.AccountTransferInstruction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.AccountTransferInstruction.BuilderA builder for AccountTransferInstruction.
-
-
Method Summary
-
-
Method Detail
-
amount
final PendingTransaction.Source.AccountTransferInstruction.Builder amount(Long amount)
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final PendingTransaction.Source.AccountTransferInstruction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PendingTransaction.Source.AccountTransferInstruction.Builder currency(PendingTransaction.Source.AccountTransferInstruction.Currency currency)
The ISO 4217 code for the destination account currency.
-
currency
final PendingTransaction.Source.AccountTransferInstruction.Builder currency(JsonField<PendingTransaction.Source.AccountTransferInstruction.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final PendingTransaction.Source.AccountTransferInstruction.Builder transferId(String transferId)
The identifier of the Account Transfer that led to this Pending Transaction.
-
transferId
final PendingTransaction.Source.AccountTransferInstruction.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.AccountTransferInstruction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.AccountTransferInstruction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.AccountTransferInstruction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.AccountTransferInstruction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.AccountTransferInstruction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.AccountTransferInstruction build()
Returns an immutable instance of AccountTransferInstruction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency() .transferId()
-
-
-
-