Class PendingTransaction.Source.BlockchainOfframpTransfer
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOfframpTransferA Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They're automatically created when funds land in a Blockchain Address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.BlockchainOfframpTransfer.BuilderA builder for BlockchainOfframpTransfer.
public final classPendingTransaction.Source.BlockchainOfframpTransfer.TokenThe token that was received.
public final classPendingTransaction.Source.BlockchainOfframpTransfer.StatusThe lifecycle status of the transfer.
public final classPendingTransaction.Source.BlockchainOfframpTransfer.TypeA constant representing the object's type. For this resource it will always be
blockchain_offramp_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Blockchain Off-Ramp Transfer's identifier. final PendingTransaction.Source.BlockchainOfframpTransfer.Tokentoken()The token that was received. final Longamount()The transfer amount in USD cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final StringdestinationAccountId()The Account the funds were transferred into. final StringinitiatingTransactionHash()The transaction hash of the blockchain transaction that initiated this transfer. final StringsourceBlockchainAddressId()The Blockchain Address from which the transfer originated. final PendingTransaction.Source.BlockchainOfframpTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<String>transactionId()The Transaction crediting the Account once the transfer is settled. final PendingTransaction.Source.BlockchainOfframpTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Token>_token()Returns the raw JSON value of token. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_destinationAccountId()Returns the raw JSON value of destinationAccountId. final JsonField<String>_initiatingTransactionHash()Returns the raw JSON value of initiatingTransactionHash. final JsonField<String>_sourceBlockchainAddressId()Returns the raw JSON value of sourceBlockchainAddressId. final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.BlockchainOfframpTransfer.BuildertoBuilder()final PendingTransaction.Source.BlockchainOfframpTransfervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.BlockchainOfframpTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of BlockchainOfframpTransfer. -
-
Method Detail
-
token
final PendingTransaction.Source.BlockchainOfframpTransfer.Token token()
The token that was received.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
destinationAccountId
final String destinationAccountId()
The Account the funds were transferred into.
-
initiatingTransactionHash
final String initiatingTransactionHash()
The transaction hash of the blockchain transaction that initiated this transfer.
-
sourceBlockchainAddressId
final String sourceBlockchainAddressId()
The Blockchain Address from which the transfer originated.
-
status
final PendingTransaction.Source.BlockchainOfframpTransfer.Status status()
The lifecycle status of the transfer.
-
transactionId
final Optional<String> transactionId()
The Transaction crediting the Account once the transfer is settled.
-
type
final PendingTransaction.Source.BlockchainOfframpTransfer.Type type()
A constant representing the object's type. For this resource it will always be
blockchain_offramp_transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_token
final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Token> _token()
Returns the raw JSON value of token.
Unlike token, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
Returns the raw JSON value of destinationAccountId.
Unlike destinationAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_initiatingTransactionHash
final JsonField<String> _initiatingTransactionHash()
Returns the raw JSON value of initiatingTransactionHash.
Unlike initiatingTransactionHash, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceBlockchainAddressId
final JsonField<String> _sourceBlockchainAddressId()
Returns the raw JSON value of sourceBlockchainAddressId.
Unlike sourceBlockchainAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder toBuilder()
-
validate
final PendingTransaction.Source.BlockchainOfframpTransfer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.BlockchainOfframpTransfer.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOfframpTransfer.
The following fields are required:
.id() .token() .amount() .createdAt() .destinationAccountId() .initiatingTransactionHash() .sourceBlockchainAddressId() .status() .transactionId() .type()
-
-
-
-