Class PendingTransaction.Source.BlockchainOfframpTransfer.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOfframpTransfer.BuilderA builder for BlockchainOfframpTransfer.
-
-
Method Summary
-
-
Method Detail
-
id
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder id(String id)
The Blockchain Off-Ramp Transfer's identifier.
-
id
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
token
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder token(PendingTransaction.Source.BlockchainOfframpTransfer.Token token)
The token that was received.
-
token
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder token(JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Token> token)
Sets Builder.token to an arbitrary JSON value.
You should usually call Builder.token with a well-typed Token value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationAccountId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder destinationAccountId(String destinationAccountId)
The Account the funds were transferred into.
-
destinationAccountId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder destinationAccountId(JsonField<String> destinationAccountId)
Sets Builder.destinationAccountId to an arbitrary JSON value.
You should usually call Builder.destinationAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
initiatingTransactionHash
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder initiatingTransactionHash(String initiatingTransactionHash)
The transaction hash of the blockchain transaction that initiated this transfer.
-
initiatingTransactionHash
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder initiatingTransactionHash(JsonField<String> initiatingTransactionHash)
Sets Builder.initiatingTransactionHash to an arbitrary JSON value.
You should usually call Builder.initiatingTransactionHash with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceBlockchainAddressId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder sourceBlockchainAddressId(String sourceBlockchainAddressId)
The Blockchain Address from which the transfer originated.
-
sourceBlockchainAddressId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder sourceBlockchainAddressId(JsonField<String> sourceBlockchainAddressId)
Sets Builder.sourceBlockchainAddressId to an arbitrary JSON value.
You should usually call Builder.sourceBlockchainAddressId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder status(PendingTransaction.Source.BlockchainOfframpTransfer.Status status)
The lifecycle status of the transfer.
-
status
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder status(JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder transactionId(String transactionId)
The Transaction crediting the Account once the transfer is settled.
-
transactionId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder type(PendingTransaction.Source.BlockchainOfframpTransfer.Type type)
A constant representing the object's type. For this resource it will always be
blockchain_offramp_transfer.
-
type
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder type(JsonField<PendingTransaction.Source.BlockchainOfframpTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.BlockchainOfframpTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.BlockchainOfframpTransfer build()
Returns an immutable instance of BlockchainOfframpTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .token() .amount() .createdAt() .destinationAccountId() .initiatingTransactionHash() .sourceBlockchainAddressId() .status() .transactionId() .type()
-
-
-
-