Class PendingTransaction.Source.BlockchainOfframpTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOfframpTransferInstructionA Blockchain Off-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.BlockchainOfframpTransferInstruction.BuilderA builder for BlockchainOfframpTransferInstruction.
-
Method Summary
Modifier and Type Method Description final StringsourceBlockchainAddressId()The identifier of the Blockchain Address the funds were received at. final StringtransferId()The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction. final JsonField<String>_sourceBlockchainAddressId()Returns the raw JSON value of sourceBlockchainAddressId. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.BlockchainOfframpTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.BlockchainOfframpTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.BlockchainOfframpTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of BlockchainOfframpTransferInstruction. -
-
Method Detail
-
sourceBlockchainAddressId
final String sourceBlockchainAddressId()
The identifier of the Blockchain Address the funds were received at.
-
transferId
final String transferId()
The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction.
-
_sourceBlockchainAddressId
final JsonField<String> _sourceBlockchainAddressId()
Returns the raw JSON value of sourceBlockchainAddressId.
Unlike sourceBlockchainAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.BlockchainOfframpTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.BlockchainOfframpTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOfframpTransferInstruction.
The following fields are required:
.sourceBlockchainAddressId() .transferId()
-
-
-
-