Class PendingTransaction.Source.BlockchainOfframpTransferIntention
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOfframpTransferIntentionA Blockchain Off-Ramp Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_intention.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.BlockchainOfframpTransferIntention.BuilderA builder for BlockchainOfframpTransferIntention.
-
Method Summary
Modifier and Type Method Description final StringsourceBlockchainAddressId()The identifier of the Blockchain Address the funds were received at. final StringtransferId()The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction. final JsonField<String>_sourceBlockchainAddressId()Returns the raw JSON value of sourceBlockchainAddressId. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.BlockchainOfframpTransferIntention.BuildertoBuilder()final PendingTransaction.Source.BlockchainOfframpTransferIntentionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.BlockchainOfframpTransferIntention.Builderbuilder()Returns a mutable builder for constructing an instance of BlockchainOfframpTransferIntention. -
-
Method Detail
-
sourceBlockchainAddressId
final String sourceBlockchainAddressId()
The identifier of the Blockchain Address the funds were received at.
-
transferId
final String transferId()
The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction.
-
_sourceBlockchainAddressId
final JsonField<String> _sourceBlockchainAddressId()
Returns the raw JSON value of sourceBlockchainAddressId.
Unlike sourceBlockchainAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.BlockchainOfframpTransferIntention validate()
-
builder
final static PendingTransaction.Source.BlockchainOfframpTransferIntention.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOfframpTransferIntention.
The following fields are required:
.sourceBlockchainAddressId() .transferId()
-
-
-
-