Class PendingTransaction.Source.BlockchainOnrampTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOnrampTransferInstructionA Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.BlockchainOnrampTransferInstruction.BuilderA builder for BlockchainOnrampTransferInstruction.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringdestinationBlockchainAddress()The blockchain address the funds are being sent to. final StringtransferId()The identifier of the Blockchain On-Ramp Transfer that led to this Pending Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_destinationBlockchainAddress()Returns the raw JSON value of destinationBlockchainAddress. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.BlockchainOnrampTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.BlockchainOnrampTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of BlockchainOnrampTransferInstruction. -
-
Method Detail
-
destinationBlockchainAddress
final String destinationBlockchainAddress()
The blockchain address the funds are being sent to.
-
transferId
final String transferId()
The identifier of the Blockchain On-Ramp Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationBlockchainAddress
final JsonField<String> _destinationBlockchainAddress()
Returns the raw JSON value of destinationBlockchainAddress.
Unlike destinationBlockchainAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.BlockchainOnrampTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOnrampTransferInstruction.
The following fields are required:
.amount() .destinationBlockchainAddress() .transferId()
-
-
-
-