Class PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOnrampTransferInstruction.BuilderA builder for BlockchainOnrampTransferInstruction.
-
-
Method Summary
-
-
Method Detail
-
amount
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationBlockchainAddress
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder destinationBlockchainAddress(String destinationBlockchainAddress)
The blockchain address the funds are being sent to.
-
destinationBlockchainAddress
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder destinationBlockchainAddress(JsonField<String> destinationBlockchainAddress)
Sets Builder.destinationBlockchainAddress to an arbitrary JSON value.
You should usually call Builder.destinationBlockchainAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder transferId(String transferId)
The identifier of the Blockchain On-Ramp Transfer that led to this Pending Transaction.
-
transferId
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.BlockchainOnrampTransferInstruction build()
Returns an immutable instance of BlockchainOnrampTransferInstruction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .destinationBlockchainAddress() .transferId()
-
-
-
-