Class PendingTransaction.Source.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BuilderA builder for Source.
-
-
Method Summary
-
-
Method Detail
-
category
final PendingTransaction.Source.Builder category(PendingTransaction.Source.Category category)
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final PendingTransaction.Source.Builder category(JsonField<PendingTransaction.Source.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountTransferInstruction
final PendingTransaction.Source.Builder accountTransferInstruction(PendingTransaction.Source.AccountTransferInstruction accountTransferInstruction)
An Account Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_instruction.
-
accountTransferInstruction
final PendingTransaction.Source.Builder accountTransferInstruction(Optional<PendingTransaction.Source.AccountTransferInstruction> accountTransferInstruction)
Alias for calling Builder.accountTransferInstruction with
accountTransferInstruction.orElse(null).
-
accountTransferInstruction
final PendingTransaction.Source.Builder accountTransferInstruction(JsonField<PendingTransaction.Source.AccountTransferInstruction> accountTransferInstruction)
Sets Builder.accountTransferInstruction to an arbitrary JSON value.
You should usually call Builder.accountTransferInstruction with a well-typed AccountTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achTransferInstruction
final PendingTransaction.Source.Builder achTransferInstruction(PendingTransaction.Source.AchTransferInstruction achTransferInstruction)
An ACH Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_instruction.
-
achTransferInstruction
final PendingTransaction.Source.Builder achTransferInstruction(Optional<PendingTransaction.Source.AchTransferInstruction> achTransferInstruction)
Alias for calling Builder.achTransferInstruction with
achTransferInstruction.orElse(null).
-
achTransferInstruction
final PendingTransaction.Source.Builder achTransferInstruction(JsonField<PendingTransaction.Source.AchTransferInstruction> achTransferInstruction)
Sets Builder.achTransferInstruction to an arbitrary JSON value.
You should usually call Builder.achTransferInstruction with a well-typed AchTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
blockchainOfframpTransferInstruction
final PendingTransaction.Source.Builder blockchainOfframpTransferInstruction(PendingTransaction.Source.BlockchainOfframpTransferInstruction blockchainOfframpTransferInstruction)
A Blockchain Off-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_instruction.
-
blockchainOfframpTransferInstruction
final PendingTransaction.Source.Builder blockchainOfframpTransferInstruction(Optional<PendingTransaction.Source.BlockchainOfframpTransferInstruction> blockchainOfframpTransferInstruction)
Alias for calling Builder.blockchainOfframpTransferInstruction with
blockchainOfframpTransferInstruction.orElse(null).
-
blockchainOfframpTransferInstruction
final PendingTransaction.Source.Builder blockchainOfframpTransferInstruction(JsonField<PendingTransaction.Source.BlockchainOfframpTransferInstruction> blockchainOfframpTransferInstruction)
Sets Builder.blockchainOfframpTransferInstruction to an arbitrary JSON value.
You should usually call Builder.blockchainOfframpTransferInstruction with a well-typed BlockchainOfframpTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
blockchainOnrampTransferInstruction
final PendingTransaction.Source.Builder blockchainOnrampTransferInstruction(PendingTransaction.Source.BlockchainOnrampTransferInstruction blockchainOnrampTransferInstruction)
A Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_instruction.
-
blockchainOnrampTransferInstruction
final PendingTransaction.Source.Builder blockchainOnrampTransferInstruction(Optional<PendingTransaction.Source.BlockchainOnrampTransferInstruction> blockchainOnrampTransferInstruction)
Alias for calling Builder.blockchainOnrampTransferInstruction with
blockchainOnrampTransferInstruction.orElse(null).
-
blockchainOnrampTransferInstruction
final PendingTransaction.Source.Builder blockchainOnrampTransferInstruction(JsonField<PendingTransaction.Source.BlockchainOnrampTransferInstruction> blockchainOnrampTransferInstruction)
Sets Builder.blockchainOnrampTransferInstruction to an arbitrary JSON value.
You should usually call Builder.blockchainOnrampTransferInstruction with a well-typed BlockchainOnrampTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorization
final PendingTransaction.Source.Builder cardAuthorization(PendingTransaction.Source.CardAuthorization cardAuthorization)
A Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.
-
cardAuthorization
final PendingTransaction.Source.Builder cardAuthorization(Optional<PendingTransaction.Source.CardAuthorization> cardAuthorization)
Alias for calling Builder.cardAuthorization with
cardAuthorization.orElse(null).
-
cardAuthorization
final PendingTransaction.Source.Builder cardAuthorization(JsonField<PendingTransaction.Source.CardAuthorization> cardAuthorization)
Sets Builder.cardAuthorization to an arbitrary JSON value.
You should usually call Builder.cardAuthorization with a well-typed CardAuthorization value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPushTransferInstruction
final PendingTransaction.Source.Builder cardPushTransferInstruction(PendingTransaction.Source.CardPushTransferInstruction cardPushTransferInstruction)
A Card Push Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_instruction.
-
cardPushTransferInstruction
final PendingTransaction.Source.Builder cardPushTransferInstruction(Optional<PendingTransaction.Source.CardPushTransferInstruction> cardPushTransferInstruction)
Alias for calling Builder.cardPushTransferInstruction with
cardPushTransferInstruction.orElse(null).
-
cardPushTransferInstruction
final PendingTransaction.Source.Builder cardPushTransferInstruction(JsonField<PendingTransaction.Source.CardPushTransferInstruction> cardPushTransferInstruction)
Sets Builder.cardPushTransferInstruction to an arbitrary JSON value.
You should usually call Builder.cardPushTransferInstruction with a well-typed CardPushTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositInstruction
final PendingTransaction.Source.Builder checkDepositInstruction(PendingTransaction.Source.CheckDepositInstruction checkDepositInstruction)
A Check Deposit Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_instruction.
-
checkDepositInstruction
final PendingTransaction.Source.Builder checkDepositInstruction(Optional<PendingTransaction.Source.CheckDepositInstruction> checkDepositInstruction)
Alias for calling Builder.checkDepositInstruction with
checkDepositInstruction.orElse(null).
-
checkDepositInstruction
final PendingTransaction.Source.Builder checkDepositInstruction(JsonField<PendingTransaction.Source.CheckDepositInstruction> checkDepositInstruction)
Sets Builder.checkDepositInstruction to an arbitrary JSON value.
You should usually call Builder.checkDepositInstruction with a well-typed CheckDepositInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkTransferInstruction
final PendingTransaction.Source.Builder checkTransferInstruction(PendingTransaction.Source.CheckTransferInstruction checkTransferInstruction)
A Check Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_instruction.
-
checkTransferInstruction
final PendingTransaction.Source.Builder checkTransferInstruction(Optional<PendingTransaction.Source.CheckTransferInstruction> checkTransferInstruction)
Alias for calling Builder.checkTransferInstruction with
checkTransferInstruction.orElse(null).
-
checkTransferInstruction
final PendingTransaction.Source.Builder checkTransferInstruction(JsonField<PendingTransaction.Source.CheckTransferInstruction> checkTransferInstruction)
Sets Builder.checkTransferInstruction to an arbitrary JSON value.
You should usually call Builder.checkTransferInstruction with a well-typed CheckTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fednowTransferInstruction
final PendingTransaction.Source.Builder fednowTransferInstruction(PendingTransaction.Source.FednowTransferInstruction fednowTransferInstruction)
A FedNow Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_instruction.
-
fednowTransferInstruction
final PendingTransaction.Source.Builder fednowTransferInstruction(Optional<PendingTransaction.Source.FednowTransferInstruction> fednowTransferInstruction)
Alias for calling Builder.fednowTransferInstruction with
fednowTransferInstruction.orElse(null).
-
fednowTransferInstruction
final PendingTransaction.Source.Builder fednowTransferInstruction(JsonField<PendingTransaction.Source.FednowTransferInstruction> fednowTransferInstruction)
Sets Builder.fednowTransferInstruction to an arbitrary JSON value.
You should usually call Builder.fednowTransferInstruction with a well-typed FednowTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundFundsHold
final PendingTransaction.Source.Builder inboundFundsHold(PendingTransaction.Source.InboundFundsHold inboundFundsHold)
An Inbound Funds Hold object. This field will be present in the JSON response if and only if
categoryis equal toinbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
-
inboundFundsHold
final PendingTransaction.Source.Builder inboundFundsHold(Optional<PendingTransaction.Source.InboundFundsHold> inboundFundsHold)
Alias for calling Builder.inboundFundsHold with
inboundFundsHold.orElse(null).
-
inboundFundsHold
final PendingTransaction.Source.Builder inboundFundsHold(JsonField<PendingTransaction.Source.InboundFundsHold> inboundFundsHold)
Sets Builder.inboundFundsHold to an arbitrary JSON value.
You should usually call Builder.inboundFundsHold with a well-typed InboundFundsHold value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireTransferReversal
final PendingTransaction.Source.Builder inboundWireTransferReversal(PendingTransaction.Source.InboundWireTransferReversal inboundWireTransferReversal)
An Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.
-
inboundWireTransferReversal
final PendingTransaction.Source.Builder inboundWireTransferReversal(Optional<PendingTransaction.Source.InboundWireTransferReversal> inboundWireTransferReversal)
Alias for calling Builder.inboundWireTransferReversal with
inboundWireTransferReversal.orElse(null).
-
inboundWireTransferReversal
final PendingTransaction.Source.Builder inboundWireTransferReversal(JsonField<PendingTransaction.Source.InboundWireTransferReversal> inboundWireTransferReversal)
Sets Builder.inboundWireTransferReversal to an arbitrary JSON value.
You should usually call Builder.inboundWireTransferReversal with a well-typed InboundWireTransferReversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
other
final PendingTransaction.Source.Builder other(PendingTransaction.Source.Other other)
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
other
final PendingTransaction.Source.Builder other(Optional<PendingTransaction.Source.Other> other)
Alias for calling Builder.other with
other.orElse(null).
-
other
final PendingTransaction.Source.Builder other(JsonField<PendingTransaction.Source.Other> other)
Sets Builder.other to an arbitrary JSON value.
You should usually call Builder.other with a well-typed Other value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
realTimePaymentsTransferInstruction
final PendingTransaction.Source.Builder realTimePaymentsTransferInstruction(PendingTransaction.Source.RealTimePaymentsTransferInstruction realTimePaymentsTransferInstruction)
A Real-Time Payments Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_instruction.
-
realTimePaymentsTransferInstruction
final PendingTransaction.Source.Builder realTimePaymentsTransferInstruction(Optional<PendingTransaction.Source.RealTimePaymentsTransferInstruction> realTimePaymentsTransferInstruction)
Alias for calling Builder.realTimePaymentsTransferInstruction with
realTimePaymentsTransferInstruction.orElse(null).
-
realTimePaymentsTransferInstruction
final PendingTransaction.Source.Builder realTimePaymentsTransferInstruction(JsonField<PendingTransaction.Source.RealTimePaymentsTransferInstruction> realTimePaymentsTransferInstruction)
Sets Builder.realTimePaymentsTransferInstruction to an arbitrary JSON value.
You should usually call Builder.realTimePaymentsTransferInstruction with a well-typed RealTimePaymentsTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
swiftTransferInstruction
final PendingTransaction.Source.Builder swiftTransferInstruction(PendingTransaction.Source.SwiftTransferInstruction swiftTransferInstruction)
A Swift Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_instruction.
-
swiftTransferInstruction
final PendingTransaction.Source.Builder swiftTransferInstruction(Optional<PendingTransaction.Source.SwiftTransferInstruction> swiftTransferInstruction)
Alias for calling Builder.swiftTransferInstruction with
swiftTransferInstruction.orElse(null).
-
swiftTransferInstruction
final PendingTransaction.Source.Builder swiftTransferInstruction(JsonField<PendingTransaction.Source.SwiftTransferInstruction> swiftTransferInstruction)
Sets Builder.swiftTransferInstruction to an arbitrary JSON value.
You should usually call Builder.swiftTransferInstruction with a well-typed SwiftTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userInitiatedHold
final PendingTransaction.Source.Builder userInitiatedHold(PendingTransaction.Source.UserInitiatedHold userInitiatedHold)
An User Initiated Hold object. This field will be present in the JSON response if and only if
categoryis equal touser_initiated_hold. Created when a user initiates a hold on funds in their account.
-
userInitiatedHold
final PendingTransaction.Source.Builder userInitiatedHold(Optional<PendingTransaction.Source.UserInitiatedHold> userInitiatedHold)
Alias for calling Builder.userInitiatedHold with
userInitiatedHold.orElse(null).
-
userInitiatedHold
final PendingTransaction.Source.Builder userInitiatedHold(JsonField<PendingTransaction.Source.UserInitiatedHold> userInitiatedHold)
Sets Builder.userInitiatedHold to an arbitrary JSON value.
You should usually call Builder.userInitiatedHold with a well-typed UserInitiatedHold value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireTransferInstruction
final PendingTransaction.Source.Builder wireTransferInstruction(PendingTransaction.Source.WireTransferInstruction wireTransferInstruction)
A Wire Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_instruction.
-
wireTransferInstruction
final PendingTransaction.Source.Builder wireTransferInstruction(Optional<PendingTransaction.Source.WireTransferInstruction> wireTransferInstruction)
Alias for calling Builder.wireTransferInstruction with
wireTransferInstruction.orElse(null).
-
wireTransferInstruction
final PendingTransaction.Source.Builder wireTransferInstruction(JsonField<PendingTransaction.Source.WireTransferInstruction> wireTransferInstruction)
Sets Builder.wireTransferInstruction to an arbitrary JSON value.
You should usually call Builder.wireTransferInstruction with a well-typed WireTransferInstruction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source build()
Returns an immutable instance of Source.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category()
-
-
-
-