Class PendingTransaction.Source.CardAuthorization

  • All Implemented Interfaces:

    
    public final class PendingTransaction.Source.CardAuthorization
    
                        

    A Card Authorization object. This field will be present in the JSON response if and only if category is equal to card_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.