Class PendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transit
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorization.AdditionalAmounts.TransitThe part of this transaction amount that was for transit-related services.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transit.BuilderA builder for Transit.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in minor units of the currencyfield.final Stringcurrency()The ISO 4217 code for the additional amount's currency. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transit.BuildertoBuilder()final PendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transitvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transit.Builderbuilder()Returns a mutable builder for constructing an instance of Transit. -
-
Method Detail
-
amount
final Long amount()
The amount in minor units of the
currencyfield. The amount is positive if it is added to the amount (such as an ATM surcharge fee) and negative if it is subtracted from the amount (such as a discount).
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transit.Builder toBuilder()
-
builder
final static PendingTransaction.Source.CardAuthorization.AdditionalAmounts.Transit.Builder builder()
Returns a mutable builder for constructing an instance of Transit.
The following fields are required:
.amount() .currency()
-
-
-
-