Class PendingTransaction.Source.CardAuthorization.Direction

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class PendingTransaction.Source.CardAuthorization.Direction
     implements Enum
                        

    The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.