Class PendingTransaction.Source.CardAuthorization.Healthcare
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorization.HealthcareThe healthcare-related fields for this authorization. Only present for specific programs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.Healthcare.BuilderA builder for Healthcare.
public final classPendingTransaction.Source.CardAuthorization.Healthcare.MerchantNinetyPercentEligibilityThe merchant's eligibility under the Internal Revenue Service's 90% Rule for Flexible Spending Account (FSA) and Health Savings Account (HSA) eligible products. The eligibility is determined based on the list of merchants maintained by the Special Interest Group for IIAS Standards (SIGIS).
-
Method Summary
-
-
Method Detail
-
merchantNinetyPercentEligibility
final PendingTransaction.Source.CardAuthorization.Healthcare.MerchantNinetyPercentEligibility merchantNinetyPercentEligibility()
The merchant's eligibility under the Internal Revenue Service's 90% Rule for Flexible Spending Account (FSA) and Health Savings Account (HSA) eligible products. The eligibility is determined based on the list of merchants maintained by the Special Interest Group for IIAS Standards (SIGIS).
-
_merchantNinetyPercentEligibility
final JsonField<PendingTransaction.Source.CardAuthorization.Healthcare.MerchantNinetyPercentEligibility> _merchantNinetyPercentEligibility()
Returns the raw JSON value of merchantNinetyPercentEligibility.
Unlike merchantNinetyPercentEligibility, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CardAuthorization.Healthcare.Builder toBuilder()
-
validate
final PendingTransaction.Source.CardAuthorization.Healthcare validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.CardAuthorization.Healthcare.Builder builder()
Returns a mutable builder for constructing an instance of Healthcare.
The following fields are required:
.merchantNinetyPercentEligibility()
-
-
-
-