Class PendingTransaction.Source.CardAuthorization.NetworkDetails
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorization.NetworkDetailsFields specific to the
network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.BuilderA builder for NetworkDetails.
public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.CategoryThe payment network used to process this card authorization.
public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.PulseFields specific to the
pulsenetwork.public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.VisaFields specific to the
visanetwork.
-
Method Summary
-
-
Method Detail
-
category
final PendingTransaction.Source.CardAuthorization.NetworkDetails.Category category()
The payment network used to process this card authorization.
-
pulse
final Optional<PendingTransaction.Source.CardAuthorization.NetworkDetails.Pulse> pulse()
Fields specific to the
pulsenetwork.
-
visa
final Optional<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa> visa()
Fields specific to the
visanetwork.
-
_category
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_pulse
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails.Pulse> _pulse()
Returns the raw JSON value of pulse.
Unlike pulse, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CardAuthorization.NetworkDetails.Builder toBuilder()
-
validate
final PendingTransaction.Source.CardAuthorization.NetworkDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.CardAuthorization.NetworkDetails.Builder builder()
Returns a mutable builder for constructing an instance of NetworkDetails.
The following fields are required:
.category() .pulse() .visa()
-
-
-
-