Enum PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value extends Enum<PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value>
An enum containing ProcessingCategory's known values, as well as an _UNKNOWN member.
An instance of ProcessingCategory can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_FUNDINGAccount funding transactions are transactions used to e.g., fund an account or transfer funds between accounts.
AUTOMATIC_FUEL_DISPENSERAutomatic fuel dispenser authorizations occur when a card is used at a gas pump, prior to the actual transaction amount being known. They are followed by an advice message that updates the amount of the pending transaction.
BILL_PAYMENTA transaction used to pay a bill.
ORIGINAL_CREDITOriginal credit transactions are used to send money to a cardholder.
PURCHASEA regular purchase.
QUASI_CASHQuasi-cash transactions represent purchases of items which may be convertible to cash.
REFUNDA refund card authorization, sometimes referred to as a credit voucher authorization, where funds are credited to the cardholder.
CASH_DISBURSEMENTCash disbursement transactions are used to withdraw cash from an ATM or a point of sale.
BALANCE_INQUIRYA balance inquiry transaction is used to check the balance of an account associated with a card.
UNKNOWNThe processing category is unknown.
_UNKNOWNAn enum member indicating that ProcessingCategory was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final PendingTransaction.Source.CardAuthorization.ProcessingCategory.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value>getEntries()An enum containing ProcessingCategory's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PendingTransaction.Source.CardAuthorization.ProcessingCategory.Value> getEntries()
An enum containing ProcessingCategory's known values, as well as an _UNKNOWN member.
An instance of ProcessingCategory can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-