Class PendingTransaction.Source.CardAuthorization.SchemeFee
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorization.SchemeFee
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.SchemeFee.BuilderA builder for SchemeFee.
public final classPendingTransaction.Source.CardAuthorization.SchemeFee.CurrencyThe ISO 4217 code for the fee reimbursement.
public final classPendingTransaction.Source.CardAuthorization.SchemeFee.FeeTypeThe type of fee being assessed.
-
Method Summary
Modifier and Type Method Description final Stringamount()The fee amount given as a string containing a decimal number. final OffsetDateTimecreatedAt()The ISO 8601 time at which the fee was created. final PendingTransaction.Source.CardAuthorization.SchemeFee.Currencycurrency()The ISO 4217 code for the fee reimbursement. final PendingTransaction.Source.CardAuthorization.SchemeFee.FeeTypefeeType()The type of fee being assessed. final Optional<String>fixedComponent()The fixed component of the fee, if applicable, given in major units of the fee amount. final Optional<String>variableRate()The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%). final JsonField<String>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<PendingTransaction.Source.CardAuthorization.SchemeFee.Currency>_currency()Returns the raw JSON value of currency. final JsonField<PendingTransaction.Source.CardAuthorization.SchemeFee.FeeType>_feeType()Returns the raw JSON value of feeType. final JsonField<String>_fixedComponent()Returns the raw JSON value of fixedComponent. final JsonField<String>_variableRate()Returns the raw JSON value of variableRate. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CardAuthorization.SchemeFee.BuildertoBuilder()final PendingTransaction.Source.CardAuthorization.SchemeFeevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CardAuthorization.SchemeFee.Builderbuilder()Returns a mutable builder for constructing an instance of SchemeFee. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the fee was created.
-
currency
final PendingTransaction.Source.CardAuthorization.SchemeFee.Currency currency()
The ISO 4217 code for the fee reimbursement.
-
feeType
final PendingTransaction.Source.CardAuthorization.SchemeFee.FeeType feeType()
The type of fee being assessed.
-
fixedComponent
final Optional<String> fixedComponent()
The fixed component of the fee, if applicable, given in major units of the fee amount.
-
variableRate
final Optional<String> variableRate()
The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).
-
_amount
final JsonField<String> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<PendingTransaction.Source.CardAuthorization.SchemeFee.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_feeType
final JsonField<PendingTransaction.Source.CardAuthorization.SchemeFee.FeeType> _feeType()
Returns the raw JSON value of feeType.
Unlike feeType, this method doesn't throw if the JSON field has an unexpected type.
-
_fixedComponent
final JsonField<String> _fixedComponent()
Returns the raw JSON value of fixedComponent.
Unlike fixedComponent, this method doesn't throw if the JSON field has an unexpected type.
-
_variableRate
final JsonField<String> _variableRate()
Returns the raw JSON value of variableRate.
Unlike variableRate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CardAuthorization.SchemeFee.Builder toBuilder()
-
validate
final PendingTransaction.Source.CardAuthorization.SchemeFee validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.CardAuthorization.SchemeFee.Builder builder()
Returns a mutable builder for constructing an instance of SchemeFee.
The following fields are required:
.amount() .createdAt() .currency() .feeType() .fixedComponent() .variableRate()
-
-
-
-