Class PendingTransaction.Source.CardAuthorization.Verification.CardholderName
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorization.Verification.CardholderNameCardholder name provided in the authorization request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.Verification.CardholderName.BuilderA builder for CardholderName.
-
Method Summary
Modifier and Type Method Description final Optional<String>providedFirstName()The first name provided for verification in the authorization request. final Optional<String>providedLastName()The last name provided for verification in the authorization request. final Optional<String>providedMiddleName()The middle name provided for verification in the authorization request. final JsonField<String>_providedFirstName()Returns the raw JSON value of providedFirstName. final JsonField<String>_providedLastName()Returns the raw JSON value of providedLastName. final JsonField<String>_providedMiddleName()Returns the raw JSON value of providedMiddleName. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CardAuthorization.Verification.CardholderName.BuildertoBuilder()final PendingTransaction.Source.CardAuthorization.Verification.CardholderNamevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CardAuthorization.Verification.CardholderName.Builderbuilder()Returns a mutable builder for constructing an instance of CardholderName. -
-
Method Detail
-
providedFirstName
final Optional<String> providedFirstName()
The first name provided for verification in the authorization request.
-
providedLastName
final Optional<String> providedLastName()
The last name provided for verification in the authorization request.
-
providedMiddleName
final Optional<String> providedMiddleName()
The middle name provided for verification in the authorization request.
-
_providedFirstName
final JsonField<String> _providedFirstName()
Returns the raw JSON value of providedFirstName.
Unlike providedFirstName, this method doesn't throw if the JSON field has an unexpected type.
-
_providedLastName
final JsonField<String> _providedLastName()
Returns the raw JSON value of providedLastName.
Unlike providedLastName, this method doesn't throw if the JSON field has an unexpected type.
-
_providedMiddleName
final JsonField<String> _providedMiddleName()
Returns the raw JSON value of providedMiddleName.
Unlike providedMiddleName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CardAuthorization.Verification.CardholderName.Builder toBuilder()
-
validate
final PendingTransaction.Source.CardAuthorization.Verification.CardholderName validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.CardAuthorization.Verification.CardholderName.Builder builder()
Returns a mutable builder for constructing an instance of CardholderName.
The following fields are required:
.providedFirstName() .providedLastName() .providedMiddleName()
-
-
-
-