Class PendingTransaction.Source.CardPushTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardPushTransferInstructionA Card Push Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardPushTransferInstruction.BuilderA builder for CardPushTransferInstruction.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringtransferId()The identifier of the Card Push Transfer that led to this Pending Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CardPushTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.CardPushTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CardPushTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of CardPushTransferInstruction. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the Card Push Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CardPushTransferInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.CardPushTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.CardPushTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of CardPushTransferInstruction.
The following fields are required:
.amount() .transferId()
-
-
-
-