Enum PendingTransaction.Source.Category.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PendingTransaction.Source.Category.Value extends Enum<PendingTransaction.Source.Category.Value>
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PendingTransaction.Source.Category.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_TRANSFER_INSTRUCTIONAccount Transfer Instruction: details will be under the
account_transfer_instructionobject.ACH_TRANSFER_INSTRUCTIONACH Transfer Instruction: details will be under the
ach_transfer_instructionobject.CARD_AUTHORIZATIONCard Authorization: details will be under the
card_authorizationobject.CHECK_DEPOSIT_INSTRUCTIONCheck Deposit Instruction: details will be under the
check_deposit_instructionobject.CHECK_TRANSFER_INSTRUCTIONCheck Transfer Instruction: details will be under the
check_transfer_instructionobject.FEDNOW_TRANSFER_INSTRUCTIONFedNow Transfer Instruction: details will be under the
fednow_transfer_instructionobject.INBOUND_FUNDS_HOLDInbound Funds Hold: details will be under the
inbound_funds_holdobject.USER_INITIATED_HOLDUser Initiated Hold: details will be under the
user_initiated_holdobject.REAL_TIME_PAYMENTS_TRANSFER_INSTRUCTIONReal-Time Payments Transfer Instruction: details will be under the
real_time_payments_transfer_instructionobject.WIRE_TRANSFER_INSTRUCTIONWire Transfer Instruction: details will be under the
wire_transfer_instructionobject.INBOUND_WIRE_TRANSFER_REVERSALInbound Wire Transfer Reversal: details will be under the
inbound_wire_transfer_reversalobject.SWIFT_TRANSFER_INSTRUCTIONSwift Transfer Instruction: details will be under the
swift_transfer_instructionobject.CARD_PUSH_TRANSFER_INSTRUCTIONCard Push Transfer Instruction: details will be under the
card_push_transfer_instructionobject.BLOCKCHAIN_ONRAMP_TRANSFER_INSTRUCTIONBlockchain On-Ramp Transfer Instruction: details will be under the
blockchain_onramp_transfer_instructionobject.BLOCKCHAIN_OFFRAMP_TRANSFER_INSTRUCTIONBlockchain Off-Ramp Transfer Instruction: details will be under the
blockchain_offramp_transfer_instructionobject.OTHERThe Pending Transaction was made for an undocumented or deprecated reason.
_UNKNOWNAn enum member indicating that Category was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final PendingTransaction.Source.Category.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PendingTransaction.Source.Category.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PendingTransaction.Source.Category.Value>getEntries()An enum containing Category's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final PendingTransaction.Source.Category.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PendingTransaction.Source.Category.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PendingTransaction.Source.Category.Value> getEntries()
An enum containing Category's known values, as well as an _UNKNOWN member.
An instance of Category can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-