Class PendingTransaction.Source.CheckDepositInstruction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CheckDepositInstruction.BuilderA builder for CheckDepositInstruction.
-
-
Method Summary
-
-
Method Detail
-
amount
final PendingTransaction.Source.CheckDepositInstruction.Builder amount(Long amount)
The pending amount in USD cents.
-
amount
final PendingTransaction.Source.CheckDepositInstruction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backImageFileId
final PendingTransaction.Source.CheckDepositInstruction.Builder backImageFileId(String backImageFileId)
The identifier of the File containing the image of the back of the check that was deposited.
-
backImageFileId
final PendingTransaction.Source.CheckDepositInstruction.Builder backImageFileId(Optional<String> backImageFileId)
Alias for calling Builder.backImageFileId with
backImageFileId.orElse(null).
-
backImageFileId
final PendingTransaction.Source.CheckDepositInstruction.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositId
final PendingTransaction.Source.CheckDepositInstruction.Builder checkDepositId(String checkDepositId)
The identifier of the Check Deposit.
-
checkDepositId
final PendingTransaction.Source.CheckDepositInstruction.Builder checkDepositId(Optional<String> checkDepositId)
Alias for calling Builder.checkDepositId with
checkDepositId.orElse(null).
-
checkDepositId
final PendingTransaction.Source.CheckDepositInstruction.Builder checkDepositId(JsonField<String> checkDepositId)
Sets Builder.checkDepositId to an arbitrary JSON value.
You should usually call Builder.checkDepositId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PendingTransaction.Source.CheckDepositInstruction.Builder currency(PendingTransaction.Source.CheckDepositInstruction.Currency currency)
The ISO 4217 code for the transaction's currency.
-
currency
final PendingTransaction.Source.CheckDepositInstruction.Builder currency(JsonField<PendingTransaction.Source.CheckDepositInstruction.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final PendingTransaction.Source.CheckDepositInstruction.Builder frontImageFileId(String frontImageFileId)
The identifier of the File containing the image of the front of the check that was deposited.
-
frontImageFileId
final PendingTransaction.Source.CheckDepositInstruction.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.CheckDepositInstruction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.CheckDepositInstruction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.CheckDepositInstruction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.CheckDepositInstruction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.CheckDepositInstruction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.CheckDepositInstruction build()
Returns an immutable instance of CheckDepositInstruction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .backImageFileId() .checkDepositId() .currency() .frontImageFileId()
-
-
-
-