Class PendingTransaction.Source.CheckTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CheckTransferInstructionA Check Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CheckTransferInstruction.BuilderA builder for CheckTransferInstruction.
public final classPendingTransaction.Source.CheckTransferInstruction.CurrencyThe ISO 4217 code for the check's currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final PendingTransaction.Source.CheckTransferInstruction.Currencycurrency()The ISO 4217 code for the check's currency. final StringtransferId()The identifier of the Check Transfer that led to this Pending Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<PendingTransaction.Source.CheckTransferInstruction.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CheckTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.CheckTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CheckTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of CheckTransferInstruction. -
-
Method Detail
-
currency
final PendingTransaction.Source.CheckTransferInstruction.Currency currency()
The ISO 4217 code for the check's currency.
-
transferId
final String transferId()
The identifier of the Check Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<PendingTransaction.Source.CheckTransferInstruction.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CheckTransferInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.CheckTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.CheckTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of CheckTransferInstruction.
The following fields are required:
.amount() .currency() .transferId()
-
-
-
-