Class PendingTransaction.Source.CheckTransferInstruction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CheckTransferInstruction.BuilderA builder for CheckTransferInstruction.
-
-
Method Summary
-
-
Method Detail
-
amount
final PendingTransaction.Source.CheckTransferInstruction.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final PendingTransaction.Source.CheckTransferInstruction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PendingTransaction.Source.CheckTransferInstruction.Builder currency(PendingTransaction.Source.CheckTransferInstruction.Currency currency)
The ISO 4217 code for the check's currency.
-
currency
final PendingTransaction.Source.CheckTransferInstruction.Builder currency(JsonField<PendingTransaction.Source.CheckTransferInstruction.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final PendingTransaction.Source.CheckTransferInstruction.Builder transferId(String transferId)
The identifier of the Check Transfer that led to this Pending Transaction.
-
transferId
final PendingTransaction.Source.CheckTransferInstruction.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.CheckTransferInstruction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.CheckTransferInstruction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.CheckTransferInstruction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.CheckTransferInstruction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.CheckTransferInstruction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.CheckTransferInstruction build()
Returns an immutable instance of CheckTransferInstruction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency() .transferId()
-
-
-
-