Class PendingTransaction.Source.InboundFundsHold

  • All Implemented Interfaces:

    
    public final class PendingTransaction.Source.InboundFundsHold
    
                        

    An Inbound Funds Hold object. This field will be present in the JSON response if and only if category is equal to inbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.