Class PendingTransaction.Source.InboundFundsHold.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.InboundFundsHold.BuilderA builder for InboundFundsHold.
-
-
Method Summary
-
-
Method Detail
-
id
final PendingTransaction.Source.InboundFundsHold.Builder id(String id)
The Inbound Funds Hold identifier.
-
id
final PendingTransaction.Source.InboundFundsHold.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final PendingTransaction.Source.InboundFundsHold.Builder amount(Long amount)
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
amount
final PendingTransaction.Source.InboundFundsHold.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
automaticallyReleasesAt
final PendingTransaction.Source.InboundFundsHold.Builder automaticallyReleasesAt(OffsetDateTime automaticallyReleasesAt)
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
automaticallyReleasesAt
final PendingTransaction.Source.InboundFundsHold.Builder automaticallyReleasesAt(JsonField<OffsetDateTime> automaticallyReleasesAt)
Sets Builder.automaticallyReleasesAt to an arbitrary JSON value.
You should usually call Builder.automaticallyReleasesAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final PendingTransaction.Source.InboundFundsHold.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the hold was created.
-
createdAt
final PendingTransaction.Source.InboundFundsHold.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final PendingTransaction.Source.InboundFundsHold.Builder currency(PendingTransaction.Source.InboundFundsHold.Currency currency)
The ISO 4217 code for the hold's currency.
-
currency
final PendingTransaction.Source.InboundFundsHold.Builder currency(JsonField<PendingTransaction.Source.InboundFundsHold.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
heldTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder heldTransactionId(String heldTransactionId)
The ID of the Transaction for which funds were held.
-
heldTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder heldTransactionId(Optional<String> heldTransactionId)
Alias for calling Builder.heldTransactionId with
heldTransactionId.orElse(null).
-
heldTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder heldTransactionId(JsonField<String> heldTransactionId)
Sets Builder.heldTransactionId to an arbitrary JSON value.
You should usually call Builder.heldTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder pendingTransactionId(String pendingTransactionId)
The ID of the Pending Transaction representing the held funds.
-
pendingTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final PendingTransaction.Source.InboundFundsHold.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
releasedAt
final PendingTransaction.Source.InboundFundsHold.Builder releasedAt(OffsetDateTime releasedAt)
When the hold was released (if it has been released).
-
releasedAt
final PendingTransaction.Source.InboundFundsHold.Builder releasedAt(Optional<OffsetDateTime> releasedAt)
Alias for calling Builder.releasedAt with
releasedAt.orElse(null).
-
releasedAt
final PendingTransaction.Source.InboundFundsHold.Builder releasedAt(JsonField<OffsetDateTime> releasedAt)
Sets Builder.releasedAt to an arbitrary JSON value.
You should usually call Builder.releasedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PendingTransaction.Source.InboundFundsHold.Builder status(PendingTransaction.Source.InboundFundsHold.Status status)
The status of the hold.
-
status
final PendingTransaction.Source.InboundFundsHold.Builder status(JsonField<PendingTransaction.Source.InboundFundsHold.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PendingTransaction.Source.InboundFundsHold.Builder type(PendingTransaction.Source.InboundFundsHold.Type type)
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
type
final PendingTransaction.Source.InboundFundsHold.Builder type(JsonField<PendingTransaction.Source.InboundFundsHold.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.InboundFundsHold.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.InboundFundsHold.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.InboundFundsHold.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.InboundFundsHold.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.InboundFundsHold.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.InboundFundsHold build()
Returns an immutable instance of InboundFundsHold.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .amount() .automaticallyReleasesAt() .createdAt() .currency() .heldTransactionId() .pendingTransactionId() .releasedAt() .status() .type()
-
-
-
-