Class PendingTransaction.Source.InboundWireTransferReversal
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.InboundWireTransferReversalAn Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.InboundWireTransferReversal.BuilderA builder for InboundWireTransferReversal.
-
Method Summary
Modifier and Type Method Description final StringinboundWireTransferId()The ID of the Inbound Wire Transfer that is being reversed. final JsonField<String>_inboundWireTransferId()Returns the raw JSON value of inboundWireTransferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.InboundWireTransferReversal.BuildertoBuilder()final PendingTransaction.Source.InboundWireTransferReversalvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.InboundWireTransferReversal.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransferReversal. -
-
Method Detail
-
inboundWireTransferId
final String inboundWireTransferId()
The ID of the Inbound Wire Transfer that is being reversed.
-
_inboundWireTransferId
final JsonField<String> _inboundWireTransferId()
Returns the raw JSON value of inboundWireTransferId.
Unlike inboundWireTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.InboundWireTransferReversal.Builder toBuilder()
-
validate
final PendingTransaction.Source.InboundWireTransferReversal validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.InboundWireTransferReversal.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransferReversal.
The following fields are required:
.inboundWireTransferId()
-
-
-
-