Class PendingTransaction.Source.OutboundCardPushTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.OutboundCardPushTransferInstructionAn Outbound Card Push Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tooutbound_card_push_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.OutboundCardPushTransferInstruction.BuilderA builder for OutboundCardPushTransferInstruction.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringtransferId()The identifier of the Outbound Card Push Transfer that led to this Pending Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.OutboundCardPushTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.OutboundCardPushTransferInstructionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.OutboundCardPushTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of OutboundCardPushTransferInstruction. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the Outbound Card Push Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.OutboundCardPushTransferInstruction validate()
-
builder
final static PendingTransaction.Source.OutboundCardPushTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of OutboundCardPushTransferInstruction.
The following fields are required:
.amount() .transferId()
-
-
-
-