Class PendingTransaction.Source.SwiftTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.SwiftTransferInstructionA Swift Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.SwiftTransferInstruction.BuilderA builder for SwiftTransferInstruction.
-
Method Summary
Modifier and Type Method Description final StringtransferId()The identifier of the Swift Transfer that led to this Pending Transaction. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.SwiftTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.SwiftTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.SwiftTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of SwiftTransferInstruction. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the Swift Transfer that led to this Pending Transaction.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.SwiftTransferInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.SwiftTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.SwiftTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of SwiftTransferInstruction.
The following fields are required:
.transferId()
-
-
-
-