Class PendingTransaction.Source.UserInitiatedHold

  • All Implemented Interfaces:

    
    public final class PendingTransaction.Source.UserInitiatedHold
    
                        

    An User Initiated Hold object. This field will be present in the JSON response if and only if category is equal to user_initiated_hold. Created when a user initiates a hold on funds in their account.