Class PendingTransaction.Source.WireTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.WireTransferInstructionA Wire Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.WireTransferInstruction.BuilderA builder for WireTransferInstruction.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number for the destination account. final Longamount()The transfer amount in USD cents. final StringmessageToRecipient()The message that will show on the recipient's bank statement. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final StringtransferId()The identifier of the Wire Transfer that led to this Pending Transaction. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.WireTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.WireTransferInstructionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.WireTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of WireTransferInstruction. -
-
Method Detail
-
accountNumber
final String accountNumber()
The account number for the destination account.
-
messageToRecipient
final String messageToRecipient()
The message that will show on the recipient's bank statement.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
transferId
final String transferId()
The identifier of the Wire Transfer that led to this Pending Transaction.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.WireTransferInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.WireTransferInstruction validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.WireTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of WireTransferInstruction.
The following fields are required:
.accountNumber() .amount() .messageToRecipient() .routingNumber() .transferId()
-
-
-
-