Class PendingTransaction.Source.WireTransferInstruction.Builder
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.WireTransferInstruction.BuilderA builder for WireTransferInstruction.
-
-
Method Summary
-
-
Method Detail
-
accountNumber
final PendingTransaction.Source.WireTransferInstruction.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final PendingTransaction.Source.WireTransferInstruction.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final PendingTransaction.Source.WireTransferInstruction.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final PendingTransaction.Source.WireTransferInstruction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final PendingTransaction.Source.WireTransferInstruction.Builder messageToRecipient(String messageToRecipient)
The message that will show on the recipient's bank statement.
-
messageToRecipient
final PendingTransaction.Source.WireTransferInstruction.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final PendingTransaction.Source.WireTransferInstruction.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final PendingTransaction.Source.WireTransferInstruction.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final PendingTransaction.Source.WireTransferInstruction.Builder transferId(String transferId)
The identifier of the Wire Transfer that led to this Pending Transaction.
-
transferId
final PendingTransaction.Source.WireTransferInstruction.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransaction.Source.WireTransferInstruction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransaction.Source.WireTransferInstruction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransaction.Source.WireTransferInstruction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransaction.Source.WireTransferInstruction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransaction.Source.WireTransferInstruction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransaction.Source.WireTransferInstruction build()
Returns an immutable instance of WireTransferInstruction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumber() .amount() .messageToRecipient() .routingNumber() .transferId()
-
-
-
-