Enum PendingTransaction.Status.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum PendingTransaction.Status.Value
    extends Enum<PendingTransaction.Status.Value>
                        

    An enum containing Status's known values, as well as an _UNKNOWN member.

    An instance of Status can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      PENDING

      The Pending Transaction is still awaiting confirmation.

      COMPLETE

      The Pending Transaction is confirmed. An associated Transaction exists for this object. The Pending Transaction will no longer count against your balance and can generally be hidden from UIs, etc.

      _UNKNOWN

      An enum member indicating that Status was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final PendingTransaction.Status.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<PendingTransaction.Status.Value> getEntries()

        An enum containing Status's known values, as well as an _UNKNOWN member.

        An instance of Status can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.