Class PendingTransactionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class PendingTransactionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final PendingTransactionCreateParams.Body.Builder accountId(String accountId)
The Account to place the hold on.
-
accountId
final PendingTransactionCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final PendingTransactionCreateParams.Body.Builder amount(Long amount)
The amount to hold in the minor unit of the account's currency. For dollars, for example, this is cents. This should be a negative amount - to hold $1.00 from the account, you would pass -100.
-
amount
final PendingTransactionCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final PendingTransactionCreateParams.Body.Builder description(String description)
The description you choose to give the hold.
-
description
final PendingTransactionCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PendingTransactionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PendingTransactionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PendingTransactionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PendingTransactionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PendingTransactionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PendingTransactionCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount()
-
-
-
-