Class PendingTransactionListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class PendingTransactionListPage implements Page<PendingTransaction>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionListPage.BuilderA builder for PendingTransactionListPage.
-
Method Summary
Modifier and Type Method Description final List<PendingTransaction>data()Delegates to PendingTransactionListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PendingTransactionListPageResponse, but gracefully handles missing data. List<PendingTransaction>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final PendingTransactionListParamsnextPageParams()PendingTransactionListPagenextPage()Returns the page after this one by making another request. final AutoPager<PendingTransaction>autoPager()final PendingTransactionListParamsparams()The parameters that were used to request this page. final PendingTransactionListPageResponseresponse()The response that this page was parsed from. final PendingTransactionListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransactionListPage.Builderbuilder()Returns a mutable builder for constructing an instance of PendingTransactionListPage. -
-
Method Detail
-
data
final List<PendingTransaction> data()
Delegates to PendingTransactionListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PendingTransactionListPageResponse, but gracefully handles missing data.
-
items
List<PendingTransaction> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final PendingTransactionListParams nextPageParams()
-
nextPage
PendingTransactionListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<PendingTransaction> autoPager()
-
params
final PendingTransactionListParams params()
The parameters that were used to request this page.
-
response
final PendingTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PendingTransactionListPage.Builder toBuilder()
-
builder
final static PendingTransactionListPage.Builder builder()
Returns a mutable builder for constructing an instance of PendingTransactionListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-