Class PendingTransactionListPage.Builder
-
- All Implemented Interfaces:
public final class PendingTransactionListPage.BuilderA builder for PendingTransactionListPage.
-
-
Method Summary
Modifier and Type Method Description final PendingTransactionListPage.Builderservice(PendingTransactionService service)final PendingTransactionListPage.Builderparams(PendingTransactionListParams params)The parameters that were used to request this page. final PendingTransactionListPage.Builderresponse(PendingTransactionListPageResponse response)The response that this page was parsed from. final PendingTransactionListPagebuild()Returns an immutable instance of PendingTransactionListPage. -
-
Method Detail
-
service
final PendingTransactionListPage.Builder service(PendingTransactionService service)
-
params
final PendingTransactionListPage.Builder params(PendingTransactionListParams params)
The parameters that were used to request this page.
-
response
final PendingTransactionListPage.Builder response(PendingTransactionListPageResponse response)
The response that this page was parsed from.
-
build
final PendingTransactionListPage build()
Returns an immutable instance of PendingTransactionListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-