Class PendingTransactionListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class PendingTransactionListPageAsync implements PageAsync<PendingTransaction>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionListPageAsync.BuilderA builder for PendingTransactionListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<PendingTransaction>data()Delegates to PendingTransactionListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PendingTransactionListPageResponse, but gracefully handles missing data. List<PendingTransaction>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final PendingTransactionListParamsnextPageParams()CompletableFuture<PendingTransactionListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<PendingTransaction>autoPager()final PendingTransactionListParamsparams()The parameters that were used to request this page. final PendingTransactionListPageResponseresponse()The response that this page was parsed from. final PendingTransactionListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransactionListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of PendingTransactionListPageAsync. -
-
Method Detail
-
data
final List<PendingTransaction> data()
Delegates to PendingTransactionListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PendingTransactionListPageResponse, but gracefully handles missing data.
-
items
List<PendingTransaction> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final PendingTransactionListParams nextPageParams()
-
nextPage
CompletableFuture<PendingTransactionListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<PendingTransaction> autoPager()
-
params
final PendingTransactionListParams params()
The parameters that were used to request this page.
-
response
final PendingTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PendingTransactionListPageAsync.Builder toBuilder()
-
builder
final static PendingTransactionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of PendingTransactionListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-