Class PendingTransactionListPageAsync.Builder
-
- All Implemented Interfaces:
public final class PendingTransactionListPageAsync.BuilderA builder for PendingTransactionListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final PendingTransactionListPageAsync.Builderservice(PendingTransactionServiceAsync service)final PendingTransactionListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final PendingTransactionListPageAsync.Builderparams(PendingTransactionListParams params)The parameters that were used to request this page. final PendingTransactionListPageAsync.Builderresponse(PendingTransactionListPageResponse response)The response that this page was parsed from. final PendingTransactionListPageAsyncbuild()Returns an immutable instance of PendingTransactionListPageAsync. -
-
Method Detail
-
service
final PendingTransactionListPageAsync.Builder service(PendingTransactionServiceAsync service)
-
streamHandlerExecutor
final PendingTransactionListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final PendingTransactionListPageAsync.Builder params(PendingTransactionListParams params)
The parameters that were used to request this page.
-
response
final PendingTransactionListPageAsync.Builder response(PendingTransactionListPageResponse response)
The response that this page was parsed from.
-
build
final PendingTransactionListPageAsync build()
Returns an immutable instance of PendingTransactionListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-