Class PendingTransactionListPageResponse
-
- All Implemented Interfaces:
public final class PendingTransactionListPageResponseA list of Pending Transaction objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionListPageResponse.BuilderA builder for PendingTransactionListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<PendingTransaction>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<PendingTransaction>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final PendingTransactionListPageResponse.BuildertoBuilder()final PendingTransactionListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransactionListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PendingTransactionListPageResponse. -
-
Method Detail
-
data
final List<PendingTransaction> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<PendingTransaction>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransactionListPageResponse.Builder toBuilder()
-
validate
final PendingTransactionListPageResponse validate()
-
builder
final static PendingTransactionListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of PendingTransactionListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-