Class PhysicalCardProfile
-
- All Implemented Interfaces:
public final class PhysicalCardProfileThis contains artwork and metadata relating to a Physical Card's appearance. For more information, see our guide on physical card artwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfile.BuilderA builder for PhysicalCardProfile.
public final classPhysicalCardProfile.CreatorThe creator of this Physical Card Profile.
public final classPhysicalCardProfile.StatusThe status of the Physical Card Profile.
public final classPhysicalCardProfile.TypeA constant representing the object's type. For this resource it will always be
physical_card_profile.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Profile identifier. final Optional<String>backImageFileId()The identifier of the File containing the physical card's back image. final Optional<String>carrierImageFileId()The identifier of the File containing the physical card's carrier image. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Physical Card Profile was created. final PhysicalCardProfile.Creatorcreator()The creator of this Physical Card Profile. final Stringdescription()A description you can use to identify the Physical Card Profile. final Optional<String>frontImageFileId()The identifier of the File containing the physical card's front image. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final BooleanisDefault()Whether this Physical Card Profile is the default for all cards in its Increase group. final StringprogramId()The identifier for the Program this Physical Card Profile belongs to. final PhysicalCardProfile.Statusstatus()The status of the Physical Card Profile. final PhysicalCardProfile.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_carrierImageFileId()Returns the raw JSON value of carrierImageFileId. final JsonField<String>_contactPhone()Returns the raw JSON value of contactPhone. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<PhysicalCardProfile.Creator>_creator()Returns the raw JSON value of creator. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<Boolean>_isDefault()Returns the raw JSON value of isDefault. final JsonField<String>_programId()Returns the raw JSON value of programId. final JsonField<PhysicalCardProfile.Status>_status()Returns the raw JSON value of status. final JsonField<PhysicalCardProfile.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfile.BuildertoBuilder()final PhysicalCardProfilevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfile.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardProfile. -
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the File containing the physical card's back image. This will be missing until the image has been post-processed.
-
carrierImageFileId
final Optional<String> carrierImageFileId()
The identifier of the File containing the physical card's carrier image. This will be missing until the image has been post-processed.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Physical Card Profile was created.
-
creator
final PhysicalCardProfile.Creator creator()
The creator of this Physical Card Profile.
-
description
final String description()
A description you can use to identify the Physical Card Profile.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the File containing the physical card's front image. This will be missing until the image has been post-processed.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
isDefault
final Boolean isDefault()
Whether this Physical Card Profile is the default for all cards in its Increase group.
-
programId
final String programId()
The identifier for the Program this Physical Card Profile belongs to.
-
status
final PhysicalCardProfile.Status status()
The status of the Physical Card Profile.
-
type
final PhysicalCardProfile.Type type()
A constant representing the object's type. For this resource it will always be
physical_card_profile.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
Returns the raw JSON value of carrierImageFileId.
Unlike carrierImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_contactPhone
final JsonField<String> _contactPhone()
Returns the raw JSON value of contactPhone.
Unlike contactPhone, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_creator
final JsonField<PhysicalCardProfile.Creator> _creator()
Returns the raw JSON value of creator.
Unlike creator, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_isDefault
final JsonField<Boolean> _isDefault()
Returns the raw JSON value of isDefault.
Unlike isDefault, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<PhysicalCardProfile.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PhysicalCardProfile.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardProfile.Builder toBuilder()
-
validate
final PhysicalCardProfile validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PhysicalCardProfile.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardProfile.
The following fields are required:
.id() .backImageFileId() .carrierImageFileId() .contactPhone() .createdAt() .creator() .description() .frontImageFileId() .idempotencyKey() .isDefault() .programId() .status() .type()
-
-
-
-