Enum PhysicalCardProfile.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PhysicalCardProfile.Status.Known extends Enum<PhysicalCardProfile.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PhysicalCardProfile.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_CREATINGThe Card Profile has not yet been processed by Increase.
PENDING_REVIEWINGThe card profile is awaiting review by Increase.
REJECTEDThere is an issue with the Physical Card Profile preventing it from use.
PENDING_SUBMITTINGThe card profile is awaiting submission to the fulfillment provider.
ACTIVEThe Physical Card Profile has been submitted to the fulfillment provider and is ready to use.
ARCHIVEDThe Physical Card Profile has been archived.
-
Method Summary
Modifier and Type Method Description final PhysicalCardProfile.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PhysicalCardProfile.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PhysicalCardProfile.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final PhysicalCardProfile.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PhysicalCardProfile.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PhysicalCardProfile.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-