Class PhysicalCardProfileCloneParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCloneParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCloneParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>carrierImageFileId()The identifier of the File containing the physical card's carrier image. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>description()A description you can use to identify the Card Profile. final Optional<String>frontImageFileId()The identifier of the File containing the physical card's front image. final Optional<PhysicalCardProfileCloneParams.FrontText>frontText()Text printed on the front of the card. final Optional<String>programId()The identifier of the Program to use for the cloned Physical Card Profile. final JsonField<String>_carrierImageFileId()Returns the raw JSON value of carrierImageFileId. final JsonField<String>_contactPhone()Returns the raw JSON value of contactPhone. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<PhysicalCardProfileCloneParams.FrontText>_frontText()Returns the raw JSON value of frontText. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfileCloneParams.Body.BuildertoBuilder()final PhysicalCardProfileCloneParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCloneParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
carrierImageFileId
final Optional<String> carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final Optional<String> description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the File containing the physical card's front image.
-
frontText
final Optional<PhysicalCardProfileCloneParams.FrontText> frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
programId
final Optional<String> programId()
The identifier of the Program to use for the cloned Physical Card Profile.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
Returns the raw JSON value of carrierImageFileId.
Unlike carrierImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_contactPhone
final JsonField<String> _contactPhone()
Returns the raw JSON value of contactPhone.
Unlike contactPhone, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontText
final JsonField<PhysicalCardProfileCloneParams.FrontText> _frontText()
Returns the raw JSON value of frontText.
Unlike frontText, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardProfileCloneParams.Body.Builder toBuilder()
-
validate
final PhysicalCardProfileCloneParams.Body validate()
-
builder
final static PhysicalCardProfileCloneParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-