Class PhysicalCardProfileCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
carrierImageFileId
final PhysicalCardProfileCreateParams.Body.Builder carrierImageFileId(String carrierImageFileId)
The identifier of the File containing the physical card's carrier image.
-
carrierImageFileId
final PhysicalCardProfileCreateParams.Body.Builder carrierImageFileId(JsonField<String> carrierImageFileId)
Sets Builder.carrierImageFileId to an arbitrary JSON value.
You should usually call Builder.carrierImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactPhone
final PhysicalCardProfileCreateParams.Body.Builder contactPhone(String contactPhone)
A phone number the user can contact to receive support for their card.
-
contactPhone
final PhysicalCardProfileCreateParams.Body.Builder contactPhone(JsonField<String> contactPhone)
Sets Builder.contactPhone to an arbitrary JSON value.
You should usually call Builder.contactPhone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final PhysicalCardProfileCreateParams.Body.Builder description(String description)
A description you can use to identify the Card Profile.
-
description
final PhysicalCardProfileCreateParams.Body.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final PhysicalCardProfileCreateParams.Body.Builder frontImageFileId(String frontImageFileId)
The identifier of the File containing the physical card's front image.
-
frontImageFileId
final PhysicalCardProfileCreateParams.Body.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final PhysicalCardProfileCreateParams.Body.Builder programId(String programId)
The identifier for the Program that this Physical Card Profile falls under.
-
programId
final PhysicalCardProfileCreateParams.Body.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardStockReference
final PhysicalCardProfileCreateParams.Body.Builder cardStockReference(String cardStockReference)
A reference ID provided by the fulfillment provider for the card stock used. Only used if you've ordered card stock separately.
-
cardStockReference
final PhysicalCardProfileCreateParams.Body.Builder cardStockReference(JsonField<String> cardStockReference)
Sets Builder.cardStockReference to an arbitrary JSON value.
You should usually call Builder.cardStockReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
carrierStockReference
final PhysicalCardProfileCreateParams.Body.Builder carrierStockReference(String carrierStockReference)
A reference ID provided by the fulfillment provider for the carrier stock used. Only used if you've ordered carrier stock separately.
-
carrierStockReference
final PhysicalCardProfileCreateParams.Body.Builder carrierStockReference(JsonField<String> carrierStockReference)
Sets Builder.carrierStockReference to an arbitrary JSON value.
You should usually call Builder.carrierStockReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontText
final PhysicalCardProfileCreateParams.Body.Builder frontText(PhysicalCardProfileCreateParams.FrontText frontText)
Text printed on the front of the card. Reach out to [email protected] for more information.
-
frontText
final PhysicalCardProfileCreateParams.Body.Builder frontText(JsonField<PhysicalCardProfileCreateParams.FrontText> frontText)
Sets Builder.frontText to an arbitrary JSON value.
You should usually call Builder.frontText with a well-typed FrontText value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardProfileCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardProfileCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardProfileCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardProfileCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardProfileCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardProfileCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.carrierImageFileId() .contactPhone() .description() .frontImageFileId() .programId()
-
-
-
-