Class PhysicalCardProfileCreateParams.FrontText
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCreateParams.FrontTextText printed on the front of the card. Reach out to [email protected] for more information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCreateParams.FrontText.BuilderA builder for FrontText.
-
Method Summary
Modifier and Type Method Description final Stringline1()The first line of text on the front of the card. final Optional<String>line2()The second line of text on the front of the card. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final Map<String, JsonValue>_additionalProperties()final PhysicalCardProfileCreateParams.FrontText.BuildertoBuilder()final PhysicalCardProfileCreateParams.FrontTextvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCreateParams.FrontText.Builderbuilder()Returns a mutable builder for constructing an instance of FrontText. -
-
Method Detail
-
line2
final Optional<String> line2()
The second line of text on the front of the card. Providing a second line moves the first line slightly higher and prints the second line in the spot where the first line would have otherwise been printed.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardProfileCreateParams.FrontText.Builder toBuilder()
-
validate
final PhysicalCardProfileCreateParams.FrontText validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PhysicalCardProfileCreateParams.FrontText.Builder builder()
Returns a mutable builder for constructing an instance of FrontText.
The following fields are required:
.line1()
-
-
-
-