Class PhysicalCardProfileCreateParams.FrontText.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfileCreateParams.FrontText.BuilderA builder for FrontText.
-
-
Method Summary
-
-
Method Detail
-
line1
final PhysicalCardProfileCreateParams.FrontText.Builder line1(String line1)
The first line of text on the front of the card.
-
line1
final PhysicalCardProfileCreateParams.FrontText.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final PhysicalCardProfileCreateParams.FrontText.Builder line2(String line2)
The second line of text on the front of the card. Providing a second line moves the first line slightly higher and prints the second line in the spot where the first line would have otherwise been printed.
-
line2
final PhysicalCardProfileCreateParams.FrontText.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardProfileCreateParams.FrontText.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardProfileCreateParams.FrontText.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardProfileCreateParams.FrontText.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardProfileCreateParams.FrontText.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardProfileCreateParams.FrontText.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardProfileCreateParams.FrontText build()
Returns an immutable instance of FrontText.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.line1()
-
-
-
-