Class PhysicalCardProfileListPage.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfileListPage.BuilderA builder for PhysicalCardProfileListPage.
-
-
Method Summary
Modifier and Type Method Description final PhysicalCardProfileListPage.Builderservice(PhysicalCardProfileService service)final PhysicalCardProfileListPage.Builderparams(PhysicalCardProfileListParams params)The parameters that were used to request this page. final PhysicalCardProfileListPage.Builderresponse(PhysicalCardProfileListPageResponse response)The response that this page was parsed from. final PhysicalCardProfileListPagebuild()Returns an immutable instance of PhysicalCardProfileListPage. -
-
Method Detail
-
service
final PhysicalCardProfileListPage.Builder service(PhysicalCardProfileService service)
-
params
final PhysicalCardProfileListPage.Builder params(PhysicalCardProfileListParams params)
The parameters that were used to request this page.
-
response
final PhysicalCardProfileListPage.Builder response(PhysicalCardProfileListPageResponse response)
The response that this page was parsed from.
-
build
final PhysicalCardProfileListPage build()
Returns an immutable instance of PhysicalCardProfileListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-