Class PhysicalCardProfileListPageAsync
-
- All Implemented Interfaces:
public final class PhysicalCardProfileListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileListPageAsync.BuilderA builder for PhysicalCardProfileListPageAsync.
public final classPhysicalCardProfileListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<PhysicalCardProfile>data()Delegates to PhysicalCardProfileListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PhysicalCardProfileListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<PhysicalCardProfileListParams>getNextPageParams()final CompletableFuture<Optional<PhysicalCardProfileListPageAsync>>getNextPage()final PhysicalCardProfileListPageAsync.AutoPagerautoPager()final PhysicalCardProfileListParamsparams()The parameters that were used to request this page. final PhysicalCardProfileListPageResponseresponse()The response that this page was parsed from. final PhysicalCardProfileListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardProfileListPageAsync. -
-
Method Detail
-
data
final List<PhysicalCardProfile> data()
Delegates to PhysicalCardProfileListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PhysicalCardProfileListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<PhysicalCardProfileListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<PhysicalCardProfileListPageAsync>> getNextPage()
-
autoPager
final PhysicalCardProfileListPageAsync.AutoPager autoPager()
-
params
final PhysicalCardProfileListParams params()
The parameters that were used to request this page.
-
response
final PhysicalCardProfileListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PhysicalCardProfileListPageAsync.Builder toBuilder()
-
builder
final static PhysicalCardProfileListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardProfileListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-