Class PhysicalCardProfileListPageAsync.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfileListPageAsync.BuilderA builder for PhysicalCardProfileListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final PhysicalCardProfileListPageAsync.Builderservice(PhysicalCardProfileServiceAsync service)final PhysicalCardProfileListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final PhysicalCardProfileListPageAsync.Builderparams(PhysicalCardProfileListParams params)The parameters that were used to request this page. final PhysicalCardProfileListPageAsync.Builderresponse(PhysicalCardProfileListPageResponse response)The response that this page was parsed from. final PhysicalCardProfileListPageAsyncbuild()Returns an immutable instance of PhysicalCardProfileListPageAsync. -
-
Method Detail
-
service
final PhysicalCardProfileListPageAsync.Builder service(PhysicalCardProfileServiceAsync service)
-
streamHandlerExecutor
final PhysicalCardProfileListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final PhysicalCardProfileListPageAsync.Builder params(PhysicalCardProfileListParams params)
The parameters that were used to request this page.
-
response
final PhysicalCardProfileListPageAsync.Builder response(PhysicalCardProfileListPageResponse response)
The response that this page was parsed from.
-
build
final PhysicalCardProfileListPageAsync build()
Returns an immutable instance of PhysicalCardProfileListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-