Class PhysicalCardProfileListPageResponse.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfileListPageResponse.BuilderA builder for PhysicalCardProfileListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final PhysicalCardProfileListPageResponse.Builder data(List<PhysicalCardProfile> data)
The contents of the list.
-
data
final PhysicalCardProfileListPageResponse.Builder data(JsonField<List<PhysicalCardProfile>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<PhysicalCardProfile>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final PhysicalCardProfileListPageResponse.Builder addData(PhysicalCardProfile data)
Adds a single PhysicalCardProfile to Builder.data.
-
nextCursor
final PhysicalCardProfileListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final PhysicalCardProfileListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final PhysicalCardProfileListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardProfileListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardProfileListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardProfileListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardProfileListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardProfileListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardProfileListPageResponse build()
Returns an immutable instance of PhysicalCardProfileListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-