Class PhysicalCardProfileRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardProfileRetrieveParams implements Params
Retrieve a Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileRetrieveParams.BuilderA builder for PhysicalCardProfileRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>physicalCardProfileId()The identifier of the Card Profile. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PhysicalCardProfileRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileRetrieveParamsnone()final static PhysicalCardProfileRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardProfileRetrieveParams. -
-
Method Detail
-
physicalCardProfileId
final Optional<String> physicalCardProfileId()
The identifier of the Card Profile.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PhysicalCardProfileRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static PhysicalCardProfileRetrieveParams none()
-
builder
final static PhysicalCardProfileRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardProfileRetrieveParams.
-
-
-
-