Class PhysicalCard
-
- All Implemented Interfaces:
public final class PhysicalCardCustom physical Visa cards that are shipped to your customers. The artwork is configurable by a connected /documentation/api#card-profiles. The same Card can be used for multiple Physical Cards. Printing cards incurs a fee. Please contact [email protected] for pricing!
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.BuilderA builder for PhysicalCard.
public final classPhysicalCard.CardholderDetails about the cardholder, as it appears on the printed card.
public final classPhysicalCard.ShipmentThe details used to ship this physical card.
public final classPhysicalCard.StatusThe status of the Physical Card.
public final classPhysicalCard.TypeA constant representing the object's type. For this resource it will always be
physical_card.
-
Method Summary
Modifier and Type Method Description final Stringid()The physical card identifier. final StringcardId()The identifier for the Card this Physical Card represents. final PhysicalCard.Cardholdercardholder()Details about the cardholder, as it appears on the printed card. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the Physical Card was created. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>physicalCardProfileId()The Physical Card Profile used for this Physical Card. final PhysicalCard.Shipmentshipment()The details used to ship this physical card. final PhysicalCard.Statusstatus()The status of the Physical Card. final PhysicalCard.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<PhysicalCard.Cardholder>_cardholder()Returns the raw JSON value of cardholder. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_physicalCardProfileId()Returns the raw JSON value of physicalCardProfileId. final JsonField<PhysicalCard.Shipment>_shipment()Returns the raw JSON value of shipment. final JsonField<PhysicalCard.Status>_status()Returns the raw JSON value of status. final JsonField<PhysicalCard.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final PhysicalCard.BuildertoBuilder()final PhysicalCardvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCard.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCard. -
-
Method Detail
-
cardholder
final PhysicalCard.Cardholder cardholder()
Details about the cardholder, as it appears on the printed card.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Physical Card was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
physicalCardProfileId
final Optional<String> physicalCardProfileId()
The Physical Card Profile used for this Physical Card.
-
shipment
final PhysicalCard.Shipment shipment()
The details used to ship this physical card.
-
status
final PhysicalCard.Status status()
The status of the Physical Card.
-
type
final PhysicalCard.Type type()
A constant representing the object's type. For this resource it will always be
physical_card.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<PhysicalCard.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardProfileId
final JsonField<String> _physicalCardProfileId()
Returns the raw JSON value of physicalCardProfileId.
Unlike physicalCardProfileId, this method doesn't throw if the JSON field has an unexpected type.
-
_shipment
final JsonField<PhysicalCard.Shipment> _shipment()
Returns the raw JSON value of shipment.
Unlike shipment, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<PhysicalCard.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PhysicalCard.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCard.Builder toBuilder()
-
validate
final PhysicalCard validate()
-
builder
final static PhysicalCard.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCard.
The following fields are required:
.id() .cardId() .cardholder() .createdAt() .idempotencyKey() .physicalCardProfileId() .shipment() .status() .type()
-
-
-
-