Class PhysicalCard.Builder
-
- All Implemented Interfaces:
public final class PhysicalCard.BuilderA builder for PhysicalCard.
-
-
Method Summary
Modifier and Type Method Description final PhysicalCard.Builderid(String id)The physical card identifier. final PhysicalCard.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final PhysicalCard.BuildercardId(String cardId)The identifier for the Card this Physical Card represents. final PhysicalCard.BuildercardId(JsonField<String> cardId)Sets Builder.cardId to an arbitrary JSON value. final PhysicalCard.Buildercardholder(PhysicalCard.Cardholder cardholder)Details about the cardholder, as it appears on the printed card. final PhysicalCard.Buildercardholder(JsonField<PhysicalCard.Cardholder> cardholder)Sets Builder.cardholder to an arbitrary JSON value. final PhysicalCard.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the Physical Card was created. final PhysicalCard.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final PhysicalCard.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final PhysicalCard.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final PhysicalCard.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final PhysicalCard.BuilderphysicalCardProfileId(String physicalCardProfileId)The Physical Card Profile used for this Physical Card. final PhysicalCard.BuilderphysicalCardProfileId(Optional<String> physicalCardProfileId)Alias for calling Builder.physicalCardProfileId with physicalCardProfileId.orElse(null).final PhysicalCard.BuilderphysicalCardProfileId(JsonField<String> physicalCardProfileId)Sets Builder.physicalCardProfileId to an arbitrary JSON value. final PhysicalCard.Buildershipment(PhysicalCard.Shipment shipment)The details used to ship this physical card. final PhysicalCard.Buildershipment(JsonField<PhysicalCard.Shipment> shipment)Sets Builder.shipment to an arbitrary JSON value. final PhysicalCard.Builderstatus(PhysicalCard.Status status)The status of the Physical Card. final PhysicalCard.Builderstatus(JsonField<PhysicalCard.Status> status)Sets Builder.status to an arbitrary JSON value. final PhysicalCard.Buildertype(PhysicalCard.Type type)A constant representing the object's type. final PhysicalCard.Buildertype(JsonField<PhysicalCard.Type> type)Sets Builder.type to an arbitrary JSON value. final PhysicalCard.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final PhysicalCard.BuilderputAdditionalProperty(String key, JsonValue value)final PhysicalCard.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final PhysicalCard.BuilderremoveAdditionalProperty(String key)final PhysicalCard.BuilderremoveAllAdditionalProperties(Set<String> keys)final PhysicalCardbuild()Returns an immutable instance of PhysicalCard. -
-
Method Detail
-
id
final PhysicalCard.Builder id(String id)
The physical card identifier.
-
id
final PhysicalCard.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final PhysicalCard.Builder cardId(String cardId)
The identifier for the Card this Physical Card represents.
-
cardId
final PhysicalCard.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholder
final PhysicalCard.Builder cardholder(PhysicalCard.Cardholder cardholder)
Details about the cardholder, as it appears on the printed card.
-
cardholder
final PhysicalCard.Builder cardholder(JsonField<PhysicalCard.Cardholder> cardholder)
Sets Builder.cardholder to an arbitrary JSON value.
You should usually call Builder.cardholder with a well-typed Cardholder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final PhysicalCard.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Physical Card was created.
-
createdAt
final PhysicalCard.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final PhysicalCard.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final PhysicalCard.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final PhysicalCard.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCardProfileId
final PhysicalCard.Builder physicalCardProfileId(String physicalCardProfileId)
The Physical Card Profile used for this Physical Card.
-
physicalCardProfileId
final PhysicalCard.Builder physicalCardProfileId(Optional<String> physicalCardProfileId)
Alias for calling Builder.physicalCardProfileId with
physicalCardProfileId.orElse(null).
-
physicalCardProfileId
final PhysicalCard.Builder physicalCardProfileId(JsonField<String> physicalCardProfileId)
Sets Builder.physicalCardProfileId to an arbitrary JSON value.
You should usually call Builder.physicalCardProfileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shipment
final PhysicalCard.Builder shipment(PhysicalCard.Shipment shipment)
The details used to ship this physical card.
-
shipment
final PhysicalCard.Builder shipment(JsonField<PhysicalCard.Shipment> shipment)
Sets Builder.shipment to an arbitrary JSON value.
You should usually call Builder.shipment with a well-typed Shipment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PhysicalCard.Builder status(PhysicalCard.Status status)
The status of the Physical Card.
-
status
final PhysicalCard.Builder status(JsonField<PhysicalCard.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PhysicalCard.Builder type(PhysicalCard.Type type)
A constant representing the object's type. For this resource it will always be
physical_card.
-
type
final PhysicalCard.Builder type(JsonField<PhysicalCard.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCard.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCard.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCard.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCard.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCard.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCard build()
Returns an immutable instance of PhysicalCard.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .cardId() .cardholder() .createdAt() .idempotencyKey() .physicalCardProfileId() .shipment() .status() .type()
-
-
-
-