Class PhysicalCard.Shipment.Address
-
- All Implemented Interfaces:
public final class PhysicalCard.Shipment.AddressThe location to where the card's packing label is addressed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.Shipment.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the shipping address. final Stringcountry()The country of the shipping address. final Stringline1()The first line of the shipping address. final Optional<String>line2()The second line of the shipping address. final Optional<String>line3()The third line of the shipping address. final Stringname()The name of the recipient. final StringpostalCode()The postal code of the shipping address. final Stringstate()The state of the shipping address. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_line3()Returns the raw JSON value of line3. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final PhysicalCard.Shipment.Address.BuildertoBuilder()final PhysicalCard.Shipment.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCard.Shipment.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
postalCode
final String postalCode()
The postal code of the shipping address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_line3
final JsonField<String> _line3()
Returns the raw JSON value of line3.
Unlike line3, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCard.Shipment.Address.Builder toBuilder()
-
validate
final PhysicalCard.Shipment.Address validate()
-
builder
final static PhysicalCard.Shipment.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .country() .line1() .line2() .line3() .name() .postalCode() .state()
-
-
-
-