Class PhysicalCard.Shipment.Builder
-
- All Implemented Interfaces:
public final class PhysicalCard.Shipment.BuilderA builder for Shipment.
-
-
Method Summary
-
-
Method Detail
-
address
final PhysicalCard.Shipment.Builder address(PhysicalCard.Shipment.Address address)
The location to where the card's packing label is addressed.
-
address
final PhysicalCard.Shipment.Builder address(JsonField<PhysicalCard.Shipment.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
method
final PhysicalCard.Shipment.Builder method(PhysicalCard.Shipment.Method method)
The shipping method.
-
method
final PhysicalCard.Shipment.Builder method(JsonField<PhysicalCard.Shipment.Method> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed Method value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schedule
final PhysicalCard.Shipment.Builder schedule(PhysicalCard.Shipment.Schedule schedule)
When this physical card should be produced by the card printer. The default timeline is the day after the card printer receives the order, except for
FEDEX_PRIORITY_OVERNIGHTcards, which default toSAME_DAY. To use faster production methods, please reach out to [email protected].
-
schedule
final PhysicalCard.Shipment.Builder schedule(JsonField<PhysicalCard.Shipment.Schedule> schedule)
Sets Builder.schedule to an arbitrary JSON value.
You should usually call Builder.schedule with a well-typed Schedule value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PhysicalCard.Shipment.Builder status(PhysicalCard.Shipment.Status status)
The status of this shipment.
-
status
final PhysicalCard.Shipment.Builder status(JsonField<PhysicalCard.Shipment.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tracking
final PhysicalCard.Shipment.Builder tracking(PhysicalCard.Shipment.Tracking tracking)
Tracking details for the shipment.
-
tracking
final PhysicalCard.Shipment.Builder tracking(Optional<PhysicalCard.Shipment.Tracking> tracking)
Alias for calling Builder.tracking with
tracking.orElse(null).
-
tracking
final PhysicalCard.Shipment.Builder tracking(JsonField<PhysicalCard.Shipment.Tracking> tracking)
Sets Builder.tracking to an arbitrary JSON value.
You should usually call Builder.tracking with a well-typed Tracking value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCard.Shipment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCard.Shipment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCard.Shipment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCard.Shipment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCard.Shipment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCard.Shipment build()
Returns an immutable instance of Shipment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .method() .schedule() .status() .tracking()
-
-
-
-