Enum PhysicalCard.Shipment.Schedule.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum PhysicalCard.Shipment.Schedule.Value
    extends Enum<PhysicalCard.Shipment.Schedule.Value>
                        

    An enum containing Schedule's known values, as well as an _UNKNOWN member.

    An instance of Schedule can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      NEXT_DAY

      The physical card will be shipped one business day after the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Wednesday.

      SAME_DAY

      The physical card will be shipped on the same business day that the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Tuesday.

      _UNKNOWN

      An enum member indicating that Schedule was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final PhysicalCard.Shipment.Schedule.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • getEntries

         final EnumEntries<PhysicalCard.Shipment.Schedule.Value> getEntries()

        An enum containing Schedule's known values, as well as an _UNKNOWN member.

        An instance of Schedule can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.