Enum PhysicalCard.Shipment.Status.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PhysicalCard.Shipment.Status.Value extends Enum<PhysicalCard.Shipment.Status.Value>
An enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PhysicalCard.Shipment.Status.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDINGThe physical card has not yet been shipped.
CANCELEDThe physical card shipment was canceled prior to submission.
SUBMITTEDThe physical card shipment has been submitted to the card fulfillment provider.
ACKNOWLEDGEDThe physical card shipment has been acknowledged by the card fulfillment provider and will be processed in their next batch.
REJECTEDThe physical card shipment was rejected by the card printer due to an error.
SHIPPEDThe physical card has been shipped.
RETURNEDThe physical card shipment was returned to the sender and destroyed by the production facility.
_UNKNOWNAn enum member indicating that Status was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final PhysicalCard.Shipment.Status.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PhysicalCard.Shipment.Status.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PhysicalCard.Shipment.Status.Value>getEntries()An enum containing Status's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final PhysicalCard.Shipment.Status.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PhysicalCard.Shipment.Status.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PhysicalCard.Shipment.Status.Value> getEntries()
An enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-