Class PhysicalCard.Shipment.Tracking.Update
-
- All Implemented Interfaces:
public final class PhysicalCard.Shipment.Tracking.Update
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.Shipment.Tracking.Update.BuilderA builder for Update.
public final classPhysicalCard.Shipment.Tracking.Update.CategoryThe type of tracking event.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>carrierEstimatedDeliveryAt()The ISO 8601 date and time when the carrier expects the card to be delivered. final PhysicalCard.Shipment.Tracking.Update.Categorycategory()The type of tracking event. final Optional<String>city()The city where the event took place. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the tracking event took place. final Optional<String>postalCode()The postal code where the event took place. final Optional<String>state()The state where the event took place. final JsonField<OffsetDateTime>_carrierEstimatedDeliveryAt()Returns the raw JSON value of carrierEstimatedDeliveryAt. final JsonField<PhysicalCard.Shipment.Tracking.Update.Category>_category()Returns the raw JSON value of category. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final PhysicalCard.Shipment.Tracking.Update.BuildertoBuilder()final PhysicalCard.Shipment.Tracking.Updatevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCard.Shipment.Tracking.Update.Builderbuilder()Returns a mutable builder for constructing an instance of Update. -
-
Method Detail
-
carrierEstimatedDeliveryAt
final Optional<OffsetDateTime> carrierEstimatedDeliveryAt()
The ISO 8601 date and time when the carrier expects the card to be delivered.
-
category
final PhysicalCard.Shipment.Tracking.Update.Category category()
The type of tracking event.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the tracking event took place.
-
postalCode
final Optional<String> postalCode()
The postal code where the event took place.
-
_carrierEstimatedDeliveryAt
final JsonField<OffsetDateTime> _carrierEstimatedDeliveryAt()
Returns the raw JSON value of carrierEstimatedDeliveryAt.
Unlike carrierEstimatedDeliveryAt, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<PhysicalCard.Shipment.Tracking.Update.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCard.Shipment.Tracking.Update.Builder toBuilder()
-
validate
final PhysicalCard.Shipment.Tracking.Update validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PhysicalCard.Shipment.Tracking.Update.Builder builder()
Returns a mutable builder for constructing an instance of Update.
The following fields are required:
.carrierEstimatedDeliveryAt() .category() .city() .createdAt() .postalCode() .state()
-
-
-
-