Class PhysicalCardCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardCreateParams implements Params
Create a Physical Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.BuilderA builder for PhysicalCardCreateParams.
public final classPhysicalCardCreateParams.Bodypublic final classPhysicalCardCreateParams.CardholderDetails about the cardholder, as it will appear on the physical card.
public final classPhysicalCardCreateParams.ShipmentThe details used to ship this physical card.
-
Method Summary
Modifier and Type Method Description final StringcardId()The underlying card representing this physical card. final PhysicalCardCreateParams.Cardholdercardholder()Details about the cardholder, as it will appear on the physical card. final PhysicalCardCreateParams.Shipmentshipment()The details used to ship this physical card. final Optional<String>physicalCardProfileId()The physical card profile to use for this physical card. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<PhysicalCardCreateParams.Cardholder>_cardholder()Returns the raw JSON value of cardholder. final JsonField<PhysicalCardCreateParams.Shipment>_shipment()Returns the raw JSON value of shipment. final JsonField<String>_physicalCardProfileId()Returns the raw JSON value of physicalCardProfileId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PhysicalCardCreateParams.BuildertoBuilder()final PhysicalCardCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardCreateParams. -
-
Method Detail
-
cardholder
final PhysicalCardCreateParams.Cardholder cardholder()
Details about the cardholder, as it will appear on the physical card.
-
shipment
final PhysicalCardCreateParams.Shipment shipment()
The details used to ship this physical card.
-
physicalCardProfileId
final Optional<String> physicalCardProfileId()
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<PhysicalCardCreateParams.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_shipment
final JsonField<PhysicalCardCreateParams.Shipment> _shipment()
Returns the raw JSON value of shipment.
Unlike shipment, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardProfileId
final JsonField<String> _physicalCardProfileId()
Returns the raw JSON value of physicalCardProfileId.
Unlike physicalCardProfileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PhysicalCardCreateParams.Builder toBuilder()
-
_body
final PhysicalCardCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PhysicalCardCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardCreateParams.
The following fields are required:
.cardId() .cardholder() .shipment()
-
-
-
-