Class PhysicalCardCreateParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardId()The underlying card representing this physical card. final PhysicalCardCreateParams.Cardholdercardholder()Details about the cardholder, as it will appear on the physical card. final PhysicalCardCreateParams.Shipmentshipment()The details used to ship this physical card. final Optional<String>physicalCardProfileId()The physical card profile to use for this physical card. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<PhysicalCardCreateParams.Cardholder>_cardholder()Returns the raw JSON value of cardholder. final JsonField<PhysicalCardCreateParams.Shipment>_shipment()Returns the raw JSON value of shipment. final JsonField<String>_physicalCardProfileId()Returns the raw JSON value of physicalCardProfileId. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Body.BuildertoBuilder()final PhysicalCardCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
cardholder
final PhysicalCardCreateParams.Cardholder cardholder()
Details about the cardholder, as it will appear on the physical card.
-
shipment
final PhysicalCardCreateParams.Shipment shipment()
The details used to ship this physical card.
-
physicalCardProfileId
final Optional<String> physicalCardProfileId()
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholder
final JsonField<PhysicalCardCreateParams.Cardholder> _cardholder()
Returns the raw JSON value of cardholder.
Unlike cardholder, this method doesn't throw if the JSON field has an unexpected type.
-
_shipment
final JsonField<PhysicalCardCreateParams.Shipment> _shipment()
Returns the raw JSON value of shipment.
Unlike shipment, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardProfileId
final JsonField<String> _physicalCardProfileId()
Returns the raw JSON value of physicalCardProfileId.
Unlike physicalCardProfileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardCreateParams.Body.Builder toBuilder()
-
validate
final PhysicalCardCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PhysicalCardCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.cardId() .cardholder() .shipment()
-
-
-
-