Class PhysicalCardCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
cardId
final PhysicalCardCreateParams.Body.Builder cardId(String cardId)
The underlying card representing this physical card.
-
cardId
final PhysicalCardCreateParams.Body.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholder
final PhysicalCardCreateParams.Body.Builder cardholder(PhysicalCardCreateParams.Cardholder cardholder)
Details about the cardholder, as it will appear on the physical card.
-
cardholder
final PhysicalCardCreateParams.Body.Builder cardholder(JsonField<PhysicalCardCreateParams.Cardholder> cardholder)
Sets Builder.cardholder to an arbitrary JSON value.
You should usually call Builder.cardholder with a well-typed Cardholder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shipment
final PhysicalCardCreateParams.Body.Builder shipment(PhysicalCardCreateParams.Shipment shipment)
The details used to ship this physical card.
-
shipment
final PhysicalCardCreateParams.Body.Builder shipment(JsonField<PhysicalCardCreateParams.Shipment> shipment)
Sets Builder.shipment to an arbitrary JSON value.
You should usually call Builder.shipment with a well-typed Shipment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCardProfileId
final PhysicalCardCreateParams.Body.Builder physicalCardProfileId(String physicalCardProfileId)
The physical card profile to use for this physical card. The latest default physical card profile will be used if not provided.
-
physicalCardProfileId
final PhysicalCardCreateParams.Body.Builder physicalCardProfileId(JsonField<String> physicalCardProfileId)
Sets Builder.physicalCardProfileId to an arbitrary JSON value.
You should usually call Builder.physicalCardProfileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardId() .cardholder() .shipment()
-
-
-
-