Class PhysicalCardCreateParams.Cardholder
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.CardholderDetails about the cardholder, as it will appear on the physical card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Cardholder.BuilderA builder for Cardholder.
-
Method Summary
Modifier and Type Method Description final StringfirstName()The cardholder's first name. final StringlastName()The cardholder's last name. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Cardholder.BuildertoBuilder()final PhysicalCardCreateParams.Cardholdervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Cardholder.Builderbuilder()Returns a mutable builder for constructing an instance of Cardholder. -
-
Method Detail
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardCreateParams.Cardholder.Builder toBuilder()
-
validate
final PhysicalCardCreateParams.Cardholder validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PhysicalCardCreateParams.Cardholder.Builder builder()
Returns a mutable builder for constructing an instance of Cardholder.
The following fields are required:
.firstName() .lastName()
-
-
-
-