Class PhysicalCardCreateParams.Cardholder.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Cardholder.BuilderA builder for Cardholder.
-
-
Method Summary
-
-
Method Detail
-
firstName
final PhysicalCardCreateParams.Cardholder.Builder firstName(String firstName)
The cardholder's first name.
-
firstName
final PhysicalCardCreateParams.Cardholder.Builder firstName(JsonField<String> firstName)
Sets Builder.firstName to an arbitrary JSON value.
You should usually call Builder.firstName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lastName
final PhysicalCardCreateParams.Cardholder.Builder lastName(String lastName)
The cardholder's last name.
-
lastName
final PhysicalCardCreateParams.Cardholder.Builder lastName(JsonField<String> lastName)
Sets Builder.lastName to an arbitrary JSON value.
You should usually call Builder.lastName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardCreateParams.Cardholder.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardCreateParams.Cardholder.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardCreateParams.Cardholder.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardCreateParams.Cardholder.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardCreateParams.Cardholder.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardCreateParams.Cardholder build()
Returns an immutable instance of Cardholder.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.firstName() .lastName()
-
-
-
-