Class PhysicalCardCreateParams.Shipment
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.ShipmentThe details used to ship this physical card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Shipment.BuilderA builder for Shipment.
public final classPhysicalCardCreateParams.Shipment.AddressThe address to where the card should be shipped.
public final classPhysicalCardCreateParams.Shipment.MethodThe shipping method to use.
public final classPhysicalCardCreateParams.Shipment.ScheduleWhen this physical card should be produced by the card printer. The default timeline is the day after the card printer receives the order, except for
FEDEX_PRIORITY_OVERNIGHTcards, which default toSAME_DAY. To use faster production methods, please reach out to [email protected].
-
Method Summary
-
-
Method Detail
-
address
final PhysicalCardCreateParams.Shipment.Address address()
The address to where the card should be shipped.
-
method
final PhysicalCardCreateParams.Shipment.Method method()
The shipping method to use.
-
schedule
final Optional<PhysicalCardCreateParams.Shipment.Schedule> schedule()
When this physical card should be produced by the card printer. The default timeline is the day after the card printer receives the order, except for
FEDEX_PRIORITY_OVERNIGHTcards, which default toSAME_DAY. To use faster production methods, please reach out to [email protected].
-
_address
final JsonField<PhysicalCardCreateParams.Shipment.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<PhysicalCardCreateParams.Shipment.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_schedule
final JsonField<PhysicalCardCreateParams.Shipment.Schedule> _schedule()
Returns the raw JSON value of schedule.
Unlike schedule, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardCreateParams.Shipment.Builder toBuilder()
-
validate
final PhysicalCardCreateParams.Shipment validate()
-
builder
final static PhysicalCardCreateParams.Shipment.Builder builder()
Returns a mutable builder for constructing an instance of Shipment.
The following fields are required:
.address() .method()
-
-
-
-