Class PhysicalCardCreateParams.Shipment.Address
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Shipment.AddressThe address to where the card should be shipped.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Shipment.Address.BuilderA builder for Address.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city of the shipping address. final Stringline1()The first line of the shipping address. final Stringname()The name of the recipient. final StringpostalCode()The postal code of the shipping address. final Stringstate()The state of the shipping address. final Optional<String>country()The two-character ISO 3166-1 code of the country where the card should be shipped (e.g. final Optional<String>line2()The second line of the shipping address. final Optional<String>line3()The third line of the shipping address. final Optional<String>phoneNumber()The phone number of the recipient. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_line3()Returns the raw JSON value of line3. final JsonField<String>_phoneNumber()Returns the raw JSON value of phoneNumber. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Shipment.Address.BuildertoBuilder()final PhysicalCardCreateParams.Shipment.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Shipment.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
postalCode
final String postalCode()
The postal code of the shipping address.
-
country
final Optional<String> country()
The two-character ISO 3166-1 code of the country where the card should be shipped (e.g.,
US). Please reach out to [email protected] to ship cards internationally.
-
phoneNumber
final Optional<String> phoneNumber()
The phone number of the recipient.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_line3
final JsonField<String> _line3()
Returns the raw JSON value of line3.
Unlike line3, this method doesn't throw if the JSON field has an unexpected type.
-
_phoneNumber
final JsonField<String> _phoneNumber()
Returns the raw JSON value of phoneNumber.
Unlike phoneNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardCreateParams.Shipment.Address.Builder toBuilder()
-
validate
final PhysicalCardCreateParams.Shipment.Address validate()
-
builder
final static PhysicalCardCreateParams.Shipment.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.city() .line1() .name() .postalCode() .state()
-
-
-
-