Class PhysicalCardCreateParams.Shipment.Address.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Shipment.Address.BuilderA builder for Address.
-
-
Method Summary
-
-
Method Detail
-
city
final PhysicalCardCreateParams.Shipment.Address.Builder city(String city)
The city of the shipping address.
-
city
final PhysicalCardCreateParams.Shipment.Address.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final PhysicalCardCreateParams.Shipment.Address.Builder line1(String line1)
The first line of the shipping address.
-
line1
final PhysicalCardCreateParams.Shipment.Address.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final PhysicalCardCreateParams.Shipment.Address.Builder name(String name)
The name of the recipient.
-
name
final PhysicalCardCreateParams.Shipment.Address.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final PhysicalCardCreateParams.Shipment.Address.Builder postalCode(String postalCode)
The postal code of the shipping address.
-
postalCode
final PhysicalCardCreateParams.Shipment.Address.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final PhysicalCardCreateParams.Shipment.Address.Builder state(String state)
The US state of the shipping address.
-
state
final PhysicalCardCreateParams.Shipment.Address.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final PhysicalCardCreateParams.Shipment.Address.Builder line2(String line2)
The second line of the shipping address.
-
line2
final PhysicalCardCreateParams.Shipment.Address.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line3
final PhysicalCardCreateParams.Shipment.Address.Builder line3(String line3)
The third line of the shipping address.
-
line3
final PhysicalCardCreateParams.Shipment.Address.Builder line3(JsonField<String> line3)
Sets Builder.line3 to an arbitrary JSON value.
You should usually call Builder.line3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phoneNumber
final PhysicalCardCreateParams.Shipment.Address.Builder phoneNumber(String phoneNumber)
The phone number of the recipient.
-
phoneNumber
final PhysicalCardCreateParams.Shipment.Address.Builder phoneNumber(JsonField<String> phoneNumber)
Sets Builder.phoneNumber to an arbitrary JSON value.
You should usually call Builder.phoneNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardCreateParams.Shipment.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardCreateParams.Shipment.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardCreateParams.Shipment.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardCreateParams.Shipment.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardCreateParams.Shipment.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardCreateParams.Shipment.Address build()
Returns an immutable instance of Address.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .line1() .name() .postalCode() .state()
-
-
-
-