Class PhysicalCardCreateParams.Shipment.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Shipment.BuilderA builder for Shipment.
-
-
Method Summary
-
-
Method Detail
-
address
final PhysicalCardCreateParams.Shipment.Builder address(PhysicalCardCreateParams.Shipment.Address address)
The address to where the card should be shipped.
-
address
final PhysicalCardCreateParams.Shipment.Builder address(JsonField<PhysicalCardCreateParams.Shipment.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
method
final PhysicalCardCreateParams.Shipment.Builder method(PhysicalCardCreateParams.Shipment.Method method)
The shipping method to use.
-
method
final PhysicalCardCreateParams.Shipment.Builder method(JsonField<PhysicalCardCreateParams.Shipment.Method> method)
Sets Builder.method to an arbitrary JSON value.
You should usually call Builder.method with a well-typed Method value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardCreateParams.Shipment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardCreateParams.Shipment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardCreateParams.Shipment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardCreateParams.Shipment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardCreateParams.Shipment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardCreateParams.Shipment build()
Returns an immutable instance of Shipment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.address() .method()
-
-
-
-