Enum PhysicalCardCreateParams.Shipment.Method.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PhysicalCardCreateParams.Shipment.Method.Known extends Enum<PhysicalCardCreateParams.Shipment.Method.Known>
An enum containing Method's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PhysicalCardCreateParams.Shipment.Method.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description USPSUSPS Post.
FEDEX_PRIORITY_OVERNIGHTFedEx Priority Overnight, no signature.
FEDEX_2_DAYFedEx 2-day.
DHL_WORLDWIDE_EXPRESSDHL Worldwide Express, international shipping only.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Shipment.Method.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PhysicalCardCreateParams.Shipment.Method.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PhysicalCardCreateParams.Shipment.Method.Known>getEntries()An enum containing Method's known values. -
-
Method Detail
-
valueOf
final PhysicalCardCreateParams.Shipment.Method.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PhysicalCardCreateParams.Shipment.Method.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PhysicalCardCreateParams.Shipment.Method.Known> getEntries()
An enum containing Method's known values.
-
-
-
-