Enum PhysicalCardCreateParams.Shipment.Method.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PhysicalCardCreateParams.Shipment.Method.Value extends Enum<PhysicalCardCreateParams.Shipment.Method.Value>
An enum containing Method's known values, as well as an _UNKNOWN member.
An instance of Method can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PhysicalCardCreateParams.Shipment.Method.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description USPSUSPS Post.
FEDEX_PRIORITY_OVERNIGHTFedEx Priority Overnight, no signature.
FEDEX_2_DAYFedEx 2-day.
DHL_WORLDWIDE_EXPRESSDHL Worldwide Express, international shipping only.
_UNKNOWNAn enum member indicating that Method was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Shipment.Method.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PhysicalCardCreateParams.Shipment.Method.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PhysicalCardCreateParams.Shipment.Method.Value>getEntries()An enum containing Method's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final PhysicalCardCreateParams.Shipment.Method.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PhysicalCardCreateParams.Shipment.Method.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PhysicalCardCreateParams.Shipment.Method.Value> getEntries()
An enum containing Method's known values, as well as an _UNKNOWN member.
An instance of Method can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-