Class PhysicalCardCreateParams.Shipment.Schedule

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class PhysicalCardCreateParams.Shipment.Schedule
     implements Enum
                        

    When this physical card should be produced by the card printer. The default timeline is the day after the card printer receives the order, except for FEDEX_PRIORITY_OVERNIGHT cards, which default to SAME_DAY. To use faster production methods, please reach out to [email protected].