Enum PhysicalCardCreateParams.Shipment.Schedule.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PhysicalCardCreateParams.Shipment.Schedule.Known extends Enum<PhysicalCardCreateParams.Shipment.Schedule.Known>
An enum containing Schedule's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PhysicalCardCreateParams.Shipment.Schedule.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NEXT_DAYThe physical card will be shipped one business day after the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Wednesday.
SAME_DAYThe physical card will be shipped on the same business day that the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Tuesday.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Shipment.Schedule.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PhysicalCardCreateParams.Shipment.Schedule.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PhysicalCardCreateParams.Shipment.Schedule.Known>getEntries()An enum containing Schedule's known values. -
-
Method Detail
-
valueOf
final PhysicalCardCreateParams.Shipment.Schedule.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PhysicalCardCreateParams.Shipment.Schedule.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PhysicalCardCreateParams.Shipment.Schedule.Known> getEntries()
An enum containing Schedule's known values.
-
-
-
-