Enum PhysicalCardCreateParams.Shipment.Schedule.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum PhysicalCardCreateParams.Shipment.Schedule.Value extends Enum<PhysicalCardCreateParams.Shipment.Schedule.Value>
An enum containing Schedule's known values, as well as an _UNKNOWN member.
An instance of Schedule can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<PhysicalCardCreateParams.Shipment.Schedule.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NEXT_DAYThe physical card will be shipped one business day after the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Wednesday.
SAME_DAYThe physical card will be shipped on the same business day that the order is received by the card printer. A card that is submitted to Increase on a Monday evening (Pacific Time) will ship out on Tuesday.
_UNKNOWNAn enum member indicating that Schedule was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Shipment.Schedule.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<PhysicalCardCreateParams.Shipment.Schedule.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<PhysicalCardCreateParams.Shipment.Schedule.Value>getEntries()An enum containing Schedule's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final PhysicalCardCreateParams.Shipment.Schedule.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<PhysicalCardCreateParams.Shipment.Schedule.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<PhysicalCardCreateParams.Shipment.Schedule.Value> getEntries()
An enum containing Schedule's known values, as well as an _UNKNOWN member.
An instance of Schedule can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-