Class PhysicalCardListPage.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardListPage.BuilderA builder for PhysicalCardListPage.
-
-
Method Summary
Modifier and Type Method Description final PhysicalCardListPage.Builderservice(PhysicalCardService service)final PhysicalCardListPage.Builderparams(PhysicalCardListParams params)The parameters that were used to request this page. final PhysicalCardListPage.Builderresponse(PhysicalCardListPageResponse response)The response that this page was parsed from. final PhysicalCardListPagebuild()Returns an immutable instance of PhysicalCardListPage. -
-
Method Detail
-
service
final PhysicalCardListPage.Builder service(PhysicalCardService service)
-
params
final PhysicalCardListPage.Builder params(PhysicalCardListParams params)
The parameters that were used to request this page.
-
response
final PhysicalCardListPage.Builder response(PhysicalCardListPageResponse response)
The response that this page was parsed from.
-
build
final PhysicalCardListPage build()
Returns an immutable instance of PhysicalCardListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-