Class PhysicalCardListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class PhysicalCardListPageAsync implements PageAsync<PhysicalCard>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardListPageAsync.BuilderA builder for PhysicalCardListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<PhysicalCard>data()Delegates to PhysicalCardListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PhysicalCardListPageResponse, but gracefully handles missing data. List<PhysicalCard>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final PhysicalCardListParamsnextPageParams()CompletableFuture<PhysicalCardListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<PhysicalCard>autoPager()final PhysicalCardListParamsparams()The parameters that were used to request this page. final PhysicalCardListPageResponseresponse()The response that this page was parsed from. final PhysicalCardListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardListPageAsync. -
-
Method Detail
-
data
final List<PhysicalCard> data()
Delegates to PhysicalCardListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PhysicalCardListPageResponse, but gracefully handles missing data.
-
items
List<PhysicalCard> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final PhysicalCardListParams nextPageParams()
-
nextPage
CompletableFuture<PhysicalCardListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<PhysicalCard> autoPager()
-
params
final PhysicalCardListParams params()
The parameters that were used to request this page.
-
response
final PhysicalCardListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PhysicalCardListPageAsync.Builder toBuilder()
-
builder
final static PhysicalCardListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-