Class PhysicalCardListPageAsync.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardListPageAsync.BuilderA builder for PhysicalCardListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final PhysicalCardListPageAsync.Builderservice(PhysicalCardServiceAsync service)final PhysicalCardListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final PhysicalCardListPageAsync.Builderparams(PhysicalCardListParams params)The parameters that were used to request this page. final PhysicalCardListPageAsync.Builderresponse(PhysicalCardListPageResponse response)The response that this page was parsed from. final PhysicalCardListPageAsyncbuild()Returns an immutable instance of PhysicalCardListPageAsync. -
-
Method Detail
-
service
final PhysicalCardListPageAsync.Builder service(PhysicalCardServiceAsync service)
-
streamHandlerExecutor
final PhysicalCardListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final PhysicalCardListPageAsync.Builder params(PhysicalCardListParams params)
The parameters that were used to request this page.
-
response
final PhysicalCardListPageAsync.Builder response(PhysicalCardListPageResponse response)
The response that this page was parsed from.
-
build
final PhysicalCardListPageAsync build()
Returns an immutable instance of PhysicalCardListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-