Class PhysicalCardListPageResponse
-
- All Implemented Interfaces:
public final class PhysicalCardListPageResponseA list of Physical Card objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardListPageResponse.BuilderA builder for PhysicalCardListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<PhysicalCard>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<PhysicalCard>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final PhysicalCardListPageResponse.BuildertoBuilder()final PhysicalCardListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardListPageResponse. -
-
Method Detail
-
data
final List<PhysicalCard> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<PhysicalCard>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardListPageResponse.Builder toBuilder()
-
validate
final PhysicalCardListPageResponse validate()
-
builder
final static PhysicalCardListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-