Class PhysicalCardUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardUpdateParams implements Params
Update a Physical Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardUpdateParams.BuilderA builder for PhysicalCardUpdateParams.
public final classPhysicalCardUpdateParams.Bodypublic final classPhysicalCardUpdateParams.StatusThe status to update the Physical Card to.
-
Method Summary
Modifier and Type Method Description final Optional<String>physicalCardId()The Physical Card identifier. final PhysicalCardUpdateParams.Statusstatus()The status to update the Physical Card to. final JsonField<PhysicalCardUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PhysicalCardUpdateParams.BuildertoBuilder()final PhysicalCardUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardUpdateParams. -
-
Method Detail
-
physicalCardId
final Optional<String> physicalCardId()
The Physical Card identifier.
-
status
final PhysicalCardUpdateParams.Status status()
The status to update the Physical Card to.
-
_status
final JsonField<PhysicalCardUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PhysicalCardUpdateParams.Builder toBuilder()
-
_body
final PhysicalCardUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PhysicalCardUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardUpdateParams.
The following fields are required:
.status()
-
-
-
-