Class PhysicalCardUpdateParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final PhysicalCardUpdateParams.Statusstatus()The status to update the Physical Card to. final JsonField<PhysicalCardUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final PhysicalCardUpdateParams.Body.BuildertoBuilder()final PhysicalCardUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
status
final PhysicalCardUpdateParams.Status status()
The status to update the Physical Card to.
-
_status
final JsonField<PhysicalCardUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardUpdateParams.Body.Builder toBuilder()
-
validate
final PhysicalCardUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PhysicalCardUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.status()
-
-
-
-