Class Program
-
- All Implemented Interfaces:
public final class ProgramPrograms determine the compliance and commercial terms of Accounts. By default, you have a Commercial Banking program for managing your own funds. If you are lending or managing funds on behalf of your customers, or otherwise engaged in regulated activity, we will work together to create additional Programs for you.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgram.BuilderA builder for Program.
public final classProgram.BankThe Bank the Program is with.
public final classProgram.LendingThe lending details for the program.
public final classProgram.TypeA constant representing the object's type. For this resource it will always be
program.
-
Method Summary
Modifier and Type Method Description final Stringid()The Program identifier. final Program.Bankbank()The Bank the Program is with. final Optional<String>billingAccountId()The Program billing account. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Program was created. final Optional<String>defaultDigitalCardProfileId()The default configuration for digital cards attached to this Program. final StringinterestRate()The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. final Optional<Program.Lending>lending()The lending details for the program. final Stringname()The name of the Program. final Program.Typetype()A constant representing the object's type. final OffsetDateTimeupdatedAt()The ISO 8601 time at which the Program was last updated. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Program.Bank>_bank()Returns the raw JSON value of bank. final JsonField<String>_billingAccountId()Returns the raw JSON value of billingAccountId. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_defaultDigitalCardProfileId()Returns the raw JSON value of defaultDigitalCardProfileId. final JsonField<String>_interestRate()Returns the raw JSON value of interestRate. final JsonField<Program.Lending>_lending()Returns the raw JSON value of lending. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Program.Type>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final Program.BuildertoBuilder()final Programvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Program.Builderbuilder()Returns a mutable builder for constructing an instance of Program. -
-
Method Detail
-
bank
final Program.Bank bank()
The Bank the Program is with.
-
billingAccountId
final Optional<String> billingAccountId()
The Program billing account.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Program was created.
-
defaultDigitalCardProfileId
final Optional<String> defaultDigitalCardProfileId()
The default configuration for digital cards attached to this Program.
-
interestRate
final String interestRate()
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
lending
final Optional<Program.Lending> lending()
The lending details for the program.
-
type
final Program.Type type()
A constant representing the object's type. For this resource it will always be
program.
-
updatedAt
final OffsetDateTime updatedAt()
The ISO 8601 time at which the Program was last updated.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_bank
final JsonField<Program.Bank> _bank()
Returns the raw JSON value of bank.
Unlike bank, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAccountId
final JsonField<String> _billingAccountId()
Returns the raw JSON value of billingAccountId.
Unlike billingAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_defaultDigitalCardProfileId
final JsonField<String> _defaultDigitalCardProfileId()
Returns the raw JSON value of defaultDigitalCardProfileId.
Unlike defaultDigitalCardProfileId, this method doesn't throw if the JSON field has an unexpected type.
-
_interestRate
final JsonField<String> _interestRate()
Returns the raw JSON value of interestRate.
Unlike interestRate, this method doesn't throw if the JSON field has an unexpected type.
-
_lending
final JsonField<Program.Lending> _lending()
Returns the raw JSON value of lending.
Unlike lending, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Program.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Program.Builder toBuilder()
-
builder
final static Program.Builder builder()
Returns a mutable builder for constructing an instance of Program.
The following fields are required:
.id() .bank() .billingAccountId() .createdAt() .defaultDigitalCardProfileId() .interestRate() .lending() .name() .type() .updatedAt()
-
-
-
-