Enum Program.Bank.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Program.Bank.Value extends Enum<Program.Bank.Value>
An enum containing Bank's known values, as well as an _UNKNOWN member.
An instance of Bank can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Program.Bank.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CORE_BANKCore Bank
FIRST_INTERNET_BANKFirst Internet Bank of Indiana
GRASSHOPPER_BANKGrasshopper Bank
_UNKNOWNAn enum member indicating that Bank was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Program.Bank.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Program.Bank.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Program.Bank.Value>getEntries()An enum containing Bank's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Program.Bank.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Program.Bank.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Program.Bank.Value> getEntries()
An enum containing Bank's known values, as well as an _UNKNOWN member.
An instance of Bank can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-