Class Program.Builder
-
- All Implemented Interfaces:
public final class Program.BuilderA builder for Program.
-
-
Method Summary
Modifier and Type Method Description final Program.Builderid(String id)The Program identifier. final Program.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Program.Builderbank(Program.Bank bank)The Bank the Program is with. final Program.Builderbank(JsonField<Program.Bank> bank)Sets Builder.bank to an arbitrary JSON value. final Program.BuilderbillingAccountId(String billingAccountId)The Program billing account. final Program.BuilderbillingAccountId(Optional<String> billingAccountId)Alias for calling Builder.billingAccountId with billingAccountId.orElse(null).final Program.BuilderbillingAccountId(JsonField<String> billingAccountId)Sets Builder.billingAccountId to an arbitrary JSON value. final Program.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Program was created. final Program.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Program.BuilderdefaultDigitalCardProfileId(String defaultDigitalCardProfileId)The default configuration for digital cards attached to this Program. final Program.BuilderdefaultDigitalCardProfileId(Optional<String> defaultDigitalCardProfileId)Alias for calling Builder.defaultDigitalCardProfileId with defaultDigitalCardProfileId.orElse(null).final Program.BuilderdefaultDigitalCardProfileId(JsonField<String> defaultDigitalCardProfileId)Sets Builder.defaultDigitalCardProfileId to an arbitrary JSON value. final Program.BuilderinterestRate(String interestRate)The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. final Program.BuilderinterestRate(JsonField<String> interestRate)Sets Builder.interestRate to an arbitrary JSON value. final Program.Builderlending(Program.Lending lending)The lending details for the program. final Program.Builderlending(Optional<Program.Lending> lending)Alias for calling Builder.lending with lending.orElse(null).final Program.Builderlending(JsonField<Program.Lending> lending)Sets Builder.lending to an arbitrary JSON value. final Program.Buildername(String name)The name of the Program. final Program.Buildername(JsonField<String> name)Sets Builder.name to an arbitrary JSON value. final Program.Buildertype(Program.Type type)A constant representing the object's type. final Program.Buildertype(JsonField<Program.Type> type)Sets Builder.type to an arbitrary JSON value. final Program.BuilderupdatedAt(OffsetDateTime updatedAt)The ISO 8601 time at which the Program was last updated. final Program.BuilderupdatedAt(JsonField<OffsetDateTime> updatedAt)Sets Builder.updatedAt to an arbitrary JSON value. final Program.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Program.BuilderputAdditionalProperty(String key, JsonValue value)final Program.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Program.BuilderremoveAdditionalProperty(String key)final Program.BuilderremoveAllAdditionalProperties(Set<String> keys)final Programbuild()Returns an immutable instance of Program. -
-
Method Detail
-
id
final Program.Builder id(String id)
The Program identifier.
-
id
final Program.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bank
final Program.Builder bank(Program.Bank bank)
The Bank the Program is with.
-
bank
final Program.Builder bank(JsonField<Program.Bank> bank)
Sets Builder.bank to an arbitrary JSON value.
You should usually call Builder.bank with a well-typed Bank value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAccountId
final Program.Builder billingAccountId(String billingAccountId)
The Program billing account.
-
billingAccountId
final Program.Builder billingAccountId(Optional<String> billingAccountId)
Alias for calling Builder.billingAccountId with
billingAccountId.orElse(null).
-
billingAccountId
final Program.Builder billingAccountId(JsonField<String> billingAccountId)
Sets Builder.billingAccountId to an arbitrary JSON value.
You should usually call Builder.billingAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Program.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Program was created.
-
createdAt
final Program.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
defaultDigitalCardProfileId
final Program.Builder defaultDigitalCardProfileId(String defaultDigitalCardProfileId)
The default configuration for digital cards attached to this Program.
-
defaultDigitalCardProfileId
final Program.Builder defaultDigitalCardProfileId(Optional<String> defaultDigitalCardProfileId)
Alias for calling Builder.defaultDigitalCardProfileId with
defaultDigitalCardProfileId.orElse(null).
-
defaultDigitalCardProfileId
final Program.Builder defaultDigitalCardProfileId(JsonField<String> defaultDigitalCardProfileId)
Sets Builder.defaultDigitalCardProfileId to an arbitrary JSON value.
You should usually call Builder.defaultDigitalCardProfileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestRate
final Program.Builder interestRate(String interestRate)
The Interest Rate currently being earned on the accounts in this program, as a string containing a decimal number. For example, a 1% interest rate would be represented as "0.01".
-
interestRate
final Program.Builder interestRate(JsonField<String> interestRate)
Sets Builder.interestRate to an arbitrary JSON value.
You should usually call Builder.interestRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lending
final Program.Builder lending(Program.Lending lending)
The lending details for the program.
-
lending
final Program.Builder lending(Optional<Program.Lending> lending)
Alias for calling Builder.lending with
lending.orElse(null).
-
lending
final Program.Builder lending(JsonField<Program.Lending> lending)
Sets Builder.lending to an arbitrary JSON value.
You should usually call Builder.lending with a well-typed Lending value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final Program.Builder name(String name)
The name of the Program.
-
name
final Program.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Program.Builder type(Program.Type type)
A constant representing the object's type. For this resource it will always be
program.
-
type
final Program.Builder type(JsonField<Program.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final Program.Builder updatedAt(OffsetDateTime updatedAt)
The ISO 8601 time at which the Program was last updated.
-
updatedAt
final Program.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Program.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Program.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Program.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Program.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Program.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Program build()
Returns an immutable instance of Program.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .bank() .billingAccountId() .createdAt() .defaultDigitalCardProfileId() .interestRate() .lending() .name() .type() .updatedAt()
-
-
-
-