Package com.increase.api.models.programs
Class ProgramListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class ProgramListPage implements Page<Program>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramListPage.BuilderA builder for ProgramListPage.
-
Method Summary
Modifier and Type Method Description final List<Program>data()Delegates to ProgramListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ProgramListPageResponse, but gracefully handles missing data. List<Program>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final ProgramListParamsnextPageParams()ProgramListPagenextPage()Returns the page after this one by making another request. final AutoPager<Program>autoPager()final ProgramListParamsparams()The parameters that were used to request this page. final ProgramListPageResponseresponse()The response that this page was parsed from. final ProgramListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramListPage.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramListPage. -
-
Method Detail
-
data
final List<Program> data()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ProgramListParams nextPageParams()
-
nextPage
ProgramListPage nextPage()
Returns the page after this one by making another request.
-
params
final ProgramListParams params()
The parameters that were used to request this page.
-
response
final ProgramListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ProgramListPage.Builder toBuilder()
-
builder
final static ProgramListPage.Builder builder()
Returns a mutable builder for constructing an instance of ProgramListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-