Package com.increase.api.models.programs
Class ProgramListPage.Builder
-
- All Implemented Interfaces:
public final class ProgramListPage.BuilderA builder for ProgramListPage.
-
-
Method Summary
Modifier and Type Method Description final ProgramListPage.Builderservice(ProgramService service)final ProgramListPage.Builderparams(ProgramListParams params)The parameters that were used to request this page. final ProgramListPage.Builderresponse(ProgramListPageResponse response)The response that this page was parsed from. final ProgramListPagebuild()Returns an immutable instance of ProgramListPage. -
-
Method Detail
-
service
final ProgramListPage.Builder service(ProgramService service)
-
params
final ProgramListPage.Builder params(ProgramListParams params)
The parameters that were used to request this page.
-
response
final ProgramListPage.Builder response(ProgramListPageResponse response)
The response that this page was parsed from.
-
build
final ProgramListPage build()
Returns an immutable instance of ProgramListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-