Package com.increase.api.models.programs
Class ProgramListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class ProgramListPageAsync implements PageAsync<Program>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramListPageAsync.BuilderA builder for ProgramListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<Program>data()Delegates to ProgramListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ProgramListPageResponse, but gracefully handles missing data. List<Program>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final ProgramListParamsnextPageParams()CompletableFuture<ProgramListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<Program>autoPager()final ProgramListParamsparams()The parameters that were used to request this page. final ProgramListPageResponseresponse()The response that this page was parsed from. final ProgramListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramListPageAsync. -
-
Method Detail
-
data
final List<Program> data()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final ProgramListParams nextPageParams()
-
nextPage
CompletableFuture<ProgramListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<Program> autoPager()
-
params
final ProgramListParams params()
The parameters that were used to request this page.
-
response
final ProgramListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ProgramListPageAsync.Builder toBuilder()
-
builder
final static ProgramListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ProgramListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-