Package com.increase.api.models.programs
Class ProgramListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ProgramListPageAsync.BuilderA builder for ProgramListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ProgramListPageAsync.Builderservice(ProgramServiceAsync service)final ProgramListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final ProgramListPageAsync.Builderparams(ProgramListParams params)The parameters that were used to request this page. final ProgramListPageAsync.Builderresponse(ProgramListPageResponse response)The response that this page was parsed from. final ProgramListPageAsyncbuild()Returns an immutable instance of ProgramListPageAsync. -
-
Method Detail
-
service
final ProgramListPageAsync.Builder service(ProgramServiceAsync service)
-
streamHandlerExecutor
final ProgramListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final ProgramListPageAsync.Builder params(ProgramListParams params)
The parameters that were used to request this page.
-
response
final ProgramListPageAsync.Builder response(ProgramListPageResponse response)
The response that this page was parsed from.
-
build
final ProgramListPageAsync build()
Returns an immutable instance of ProgramListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-