Package com.increase.api.models.programs
Class ProgramListPageAsync.Response
-
- All Implemented Interfaces:
public final class ProgramListPageAsync.Response
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramListPageAsync.Response.Builder
-
Method Summary
Modifier and Type Method Description final List<Program>data()final Optional<String>nextCursor()final Optional<JsonField<List<Program>>>_data()final Optional<JsonField<String>>_nextCursor()final Map<String, JsonValue>_additionalProperties()final ProgramListPageAsync.Responsevalidate()final BooleanisValid()final ProgramListPageAsync.Response.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramListPageAsync.Response.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramListPageAsync. -
-
Method Detail
-
nextCursor
final Optional<String> nextCursor()
-
_nextCursor
final Optional<JsonField<String>> _nextCursor()
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ProgramListPageAsync.Response validate()
-
toBuilder
final ProgramListPageAsync.Response.Builder toBuilder()
-
builder
final static ProgramListPageAsync.Response.Builder builder()
Returns a mutable builder for constructing an instance of ProgramListPageAsync.
-
-
-
-