Class ProgramListResponse.Builder
-
- All Implemented Interfaces:
public final class ProgramListResponse.BuilderA builder for ProgramListResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final ProgramListResponse.Builder data(List<Program> data)
The contents of the list.
-
data
final ProgramListResponse.Builder data(JsonField<List<Program>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Program>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final ProgramListResponse.Builder addData(Program data)
Adds a single Program to Builder.data.
-
nextCursor
final ProgramListResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final ProgramListResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final ProgramListResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProgramListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProgramListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProgramListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProgramListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProgramListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProgramListResponse build()
Returns an immutable instance of ProgramListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-