Package com.increase.api.models.programs
Class ProgramRetrieveParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ProgramRetrieveParams implements Params
Retrieve a Program
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramRetrieveParams.BuilderA builder for ProgramRetrieveParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>programId()The identifier of the Program to retrieve. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ProgramRetrieveParams.BuildertoBuilder()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramRetrieveParamsnone()final static ProgramRetrieveParams.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramRetrieveParams. -
-
Method Detail
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ProgramRetrieveParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static ProgramRetrieveParams none()
-
builder
final static ProgramRetrieveParams.Builder builder()
Returns a mutable builder for constructing an instance of ProgramRetrieveParams.
-
-
-
-