Package com.increase.api.models.programs
See: Description
-
Class Summary Class Description Builder A builder for Program. Bank The Bank the Program is with. Type A constant representing the object's type. Program Programs determine the compliance and commercial terms of Accounts. Builder Response AutoPager ProgramListPage List Programs Builder Response AutoPager ProgramListPageAsync List Programs Builder A builder for ProgramListParams. ProgramListParams List Programs Builder A builder for ProgramRetrieveParams. ProgramRetrieveParams Retrieve a Program