Class ProofOfAuthorizationRequest
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestA request for proof of authorization for one or more ACH debit transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequest.BuilderA builder for ProofOfAuthorizationRequest.
public final classProofOfAuthorizationRequest.AchTransferpublic final classProofOfAuthorizationRequest.TypeA constant representing the object's type. For this resource it will always be
proof_of_authorization_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Proof of Authorization Request identifier. final List<ProofOfAuthorizationRequest.AchTransfer>achTransfers()The ACH Transfers associated with the request. final OffsetDateTimecreatedAt()The time the Proof of Authorization Request was created. final OffsetDateTimedueOn()The time the Proof of Authorization Request is due. final ProofOfAuthorizationRequest.Typetype()A constant representing the object's type. final OffsetDateTimeupdatedAt()The time the Proof of Authorization Request was last updated. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<ProofOfAuthorizationRequest.AchTransfer>>_achTransfers()Returns the raw JSON value of achTransfers. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<OffsetDateTime>_dueOn()Returns the raw JSON value of dueOn. final JsonField<ProofOfAuthorizationRequest.Type>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final ProofOfAuthorizationRequest.BuildertoBuilder()final ProofOfAuthorizationRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProofOfAuthorizationRequest.Builderbuilder()Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequest. -
-
Method Detail
-
achTransfers
final List<ProofOfAuthorizationRequest.AchTransfer> achTransfers()
The ACH Transfers associated with the request.
-
createdAt
final OffsetDateTime createdAt()
The time the Proof of Authorization Request was created.
-
dueOn
final OffsetDateTime dueOn()
The time the Proof of Authorization Request is due.
-
type
final ProofOfAuthorizationRequest.Type type()
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request.
-
updatedAt
final OffsetDateTime updatedAt()
The time the Proof of Authorization Request was last updated.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_achTransfers
final JsonField<List<ProofOfAuthorizationRequest.AchTransfer>> _achTransfers()
Returns the raw JSON value of achTransfers.
Unlike achTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_dueOn
final JsonField<OffsetDateTime> _dueOn()
Returns the raw JSON value of dueOn.
Unlike dueOn, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProofOfAuthorizationRequest.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProofOfAuthorizationRequest.Builder toBuilder()
-
validate
final ProofOfAuthorizationRequest validate()
-
builder
final static ProofOfAuthorizationRequest.Builder builder()
Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequest.
The following fields are required:
.id() .achTransfers() .createdAt() .dueOn() .type() .updatedAt()
-
-
-
-