Class ProofOfAuthorizationRequest.Builder
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequest.BuilderA builder for ProofOfAuthorizationRequest.
-
-
Method Summary
-
-
Method Detail
-
id
final ProofOfAuthorizationRequest.Builder id(String id)
The Proof of Authorization Request identifier.
-
id
final ProofOfAuthorizationRequest.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achTransfers
final ProofOfAuthorizationRequest.Builder achTransfers(List<ProofOfAuthorizationRequest.AchTransfer> achTransfers)
The ACH Transfers associated with the request.
-
achTransfers
final ProofOfAuthorizationRequest.Builder achTransfers(JsonField<List<ProofOfAuthorizationRequest.AchTransfer>> achTransfers)
Sets Builder.achTransfers to an arbitrary JSON value.
You should usually call Builder.achTransfers with a well-typed
List<AchTransfer>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAchTransfer
final ProofOfAuthorizationRequest.Builder addAchTransfer(ProofOfAuthorizationRequest.AchTransfer achTransfer)
Adds a single AchTransfer to achTransfers.
-
createdAt
final ProofOfAuthorizationRequest.Builder createdAt(OffsetDateTime createdAt)
The time the Proof of Authorization Request was created.
-
createdAt
final ProofOfAuthorizationRequest.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dueOn
final ProofOfAuthorizationRequest.Builder dueOn(OffsetDateTime dueOn)
The time the Proof of Authorization Request is due.
-
dueOn
final ProofOfAuthorizationRequest.Builder dueOn(JsonField<OffsetDateTime> dueOn)
Sets Builder.dueOn to an arbitrary JSON value.
You should usually call Builder.dueOn with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ProofOfAuthorizationRequest.Builder type(ProofOfAuthorizationRequest.Type type)
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request.
-
type
final ProofOfAuthorizationRequest.Builder type(JsonField<ProofOfAuthorizationRequest.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final ProofOfAuthorizationRequest.Builder updatedAt(OffsetDateTime updatedAt)
The time the Proof of Authorization Request was last updated.
-
updatedAt
final ProofOfAuthorizationRequest.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProofOfAuthorizationRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProofOfAuthorizationRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProofOfAuthorizationRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProofOfAuthorizationRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProofOfAuthorizationRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProofOfAuthorizationRequest build()
Returns an immutable instance of ProofOfAuthorizationRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .achTransfers() .createdAt() .dueOn() .type() .updatedAt()
-
-
-
-