Class ProofOfAuthorizationRequestListPage
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestListPage.BuilderA builder for ProofOfAuthorizationRequestListPage.
public final classProofOfAuthorizationRequestListPage.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<ProofOfAuthorizationRequest> data()
Delegates to ProofOfAuthorizationRequestListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ProofOfAuthorizationRequestListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ProofOfAuthorizationRequestListParams> getNextPageParams()
-
getNextPage
final Optional<ProofOfAuthorizationRequestListPage> getNextPage()
-
autoPager
final ProofOfAuthorizationRequestListPage.AutoPager autoPager()
-
params
final ProofOfAuthorizationRequestListParams params()
The parameters that were used to request this page.
-
response
final ProofOfAuthorizationRequestListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ProofOfAuthorizationRequestListPage.Builder toBuilder()
-
builder
final static ProofOfAuthorizationRequestListPage.Builder builder()
Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequestListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-