Class ProofOfAuthorizationRequestListPageAsync
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestListPageAsync.BuilderA builder for ProofOfAuthorizationRequestListPageAsync.
public final classProofOfAuthorizationRequestListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<ProofOfAuthorizationRequest> data()
Delegates to ProofOfAuthorizationRequestListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ProofOfAuthorizationRequestListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ProofOfAuthorizationRequestListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<ProofOfAuthorizationRequestListPageAsync>> getNextPage()
-
autoPager
final ProofOfAuthorizationRequestListPageAsync.AutoPager autoPager()
-
params
final ProofOfAuthorizationRequestListParams params()
The parameters that were used to request this page.
-
response
final ProofOfAuthorizationRequestListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ProofOfAuthorizationRequestListPageAsync.Builder toBuilder()
-
builder
final static ProofOfAuthorizationRequestListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequestListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-