Class ProofOfAuthorizationRequestListPageAsync.Builder
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestListPageAsync.BuilderA builder for ProofOfAuthorizationRequestListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final ProofOfAuthorizationRequestListPageAsync.Builderservice(ProofOfAuthorizationRequestServiceAsync service)final ProofOfAuthorizationRequestListPageAsync.Builderparams(ProofOfAuthorizationRequestListParams params)The parameters that were used to request this page. final ProofOfAuthorizationRequestListPageAsync.Builderresponse(ProofOfAuthorizationRequestListPageResponse response)The response that this page was parsed from. final ProofOfAuthorizationRequestListPageAsyncbuild()Returns an immutable instance of ProofOfAuthorizationRequestListPageAsync. -
-
Method Detail
-
service
final ProofOfAuthorizationRequestListPageAsync.Builder service(ProofOfAuthorizationRequestServiceAsync service)
-
params
final ProofOfAuthorizationRequestListPageAsync.Builder params(ProofOfAuthorizationRequestListParams params)
The parameters that were used to request this page.
-
response
final ProofOfAuthorizationRequestListPageAsync.Builder response(ProofOfAuthorizationRequestListPageResponse response)
The response that this page was parsed from.
-
build
final ProofOfAuthorizationRequestListPageAsync build()
Returns an immutable instance of ProofOfAuthorizationRequestListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-