Class ProofOfAuthorizationRequestListPageResponse
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestListPageResponseA list of Proof of Authorization Request objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestListPageResponse.BuilderA builder for ProofOfAuthorizationRequestListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<ProofOfAuthorizationRequest>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<ProofOfAuthorizationRequest>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final ProofOfAuthorizationRequestListPageResponse.BuildertoBuilder()final ProofOfAuthorizationRequestListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProofOfAuthorizationRequestListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequestListPageResponse. -
-
Method Detail
-
data
final List<ProofOfAuthorizationRequest> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<ProofOfAuthorizationRequest>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProofOfAuthorizationRequestListPageResponse.Builder toBuilder()
-
validate
final ProofOfAuthorizationRequestListPageResponse validate()
-
builder
final static ProofOfAuthorizationRequestListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequestListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-