Class ProofOfAuthorizationRequestSubmission
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestSubmissionInformation submitted in response to a proof of authorization request. Per Nacha's guidance on proof of authorization, the originator must ensure that the authorization complies with applicable legal requirements, is readily identifiable as an authorization, and has clear and readily understandable terms.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestSubmission.BuilderA builder for ProofOfAuthorizationRequestSubmission.
public final classProofOfAuthorizationRequestSubmission.AdditionalEvidenceFilepublic final classProofOfAuthorizationRequestSubmission.StatusStatus of the proof of authorization request submission.
public final classProofOfAuthorizationRequestSubmission.TypeA constant representing the object's type. For this resource it will always be
proof_of_authorization_request_submission.
-
Method Summary
-
-
Method Detail
-
additionalEvidenceFiles
final List<ProofOfAuthorizationRequestSubmission.AdditionalEvidenceFile> additionalEvidenceFiles()
Files containing additional evidence.
-
authorizationTerms
final String authorizationTerms()
Terms of authorization.
-
authorizedAt
final OffsetDateTime authorizedAt()
Time of authorization.
-
authorizerCompany
final Optional<String> authorizerCompany()
Company of the authorizer.
-
authorizerEmail
final Optional<String> authorizerEmail()
Email of the authorizer.
-
authorizerIpAddress
final Optional<String> authorizerIpAddress()
IP address of the authorizer.
-
authorizerName
final Optional<String> authorizerName()
Name of the authorizer.
-
createdAt
final OffsetDateTime createdAt()
The time the Proof of Authorization Request Submission was created.
-
customerHasBeenOffboarded
final Optional<Boolean> customerHasBeenOffboarded()
Whether the customer has been offboarded.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
proofOfAuthorizationRequestId
final String proofOfAuthorizationRequestId()
ID of the proof of authorization request.
-
status
final ProofOfAuthorizationRequestSubmission.Status status()
Status of the proof of authorization request submission.
-
type
final ProofOfAuthorizationRequestSubmission.Type type()
A constant representing the object's type. For this resource it will always be
proof_of_authorization_request_submission.
-
updatedAt
final OffsetDateTime updatedAt()
The time the Proof of Authorization Request Submission was last updated.
-
validatedAccountOwnershipViaCredential
final Optional<Boolean> validatedAccountOwnershipViaCredential()
Whether account ownership was validated via credential (for instance, Plaid).
-
validatedAccountOwnershipWithAccountStatement
final Optional<Boolean> validatedAccountOwnershipWithAccountStatement()
Whether account ownership was validated with an account statement.
-
validatedAccountOwnershipWithMicrodeposit
final Optional<Boolean> validatedAccountOwnershipWithMicrodeposit()
Whether account ownership was validated with microdeposit.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalEvidenceFiles
final JsonField<List<ProofOfAuthorizationRequestSubmission.AdditionalEvidenceFile>> _additionalEvidenceFiles()
Returns the raw JSON value of additionalEvidenceFiles.
Unlike additionalEvidenceFiles, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationTerms
final JsonField<String> _authorizationTerms()
Returns the raw JSON value of authorizationTerms.
Unlike authorizationTerms, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizedAt
final JsonField<OffsetDateTime> _authorizedAt()
Returns the raw JSON value of authorizedAt.
Unlike authorizedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerCompany
final JsonField<String> _authorizerCompany()
Returns the raw JSON value of authorizerCompany.
Unlike authorizerCompany, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerEmail
final JsonField<String> _authorizerEmail()
Returns the raw JSON value of authorizerEmail.
Unlike authorizerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerIpAddress
final JsonField<String> _authorizerIpAddress()
Returns the raw JSON value of authorizerIpAddress.
Unlike authorizerIpAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerName
final JsonField<String> _authorizerName()
Returns the raw JSON value of authorizerName.
Unlike authorizerName, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_customerHasBeenOffboarded
final JsonField<Boolean> _customerHasBeenOffboarded()
Returns the raw JSON value of customerHasBeenOffboarded.
Unlike customerHasBeenOffboarded, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_proofOfAuthorizationRequestId
final JsonField<String> _proofOfAuthorizationRequestId()
Returns the raw JSON value of proofOfAuthorizationRequestId.
Unlike proofOfAuthorizationRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ProofOfAuthorizationRequestSubmission.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ProofOfAuthorizationRequestSubmission.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_validatedAccountOwnershipViaCredential
final JsonField<Boolean> _validatedAccountOwnershipViaCredential()
Returns the raw JSON value of validatedAccountOwnershipViaCredential.
Unlike validatedAccountOwnershipViaCredential, this method doesn't throw if the JSON field has an unexpected type.
-
_validatedAccountOwnershipWithAccountStatement
final JsonField<Boolean> _validatedAccountOwnershipWithAccountStatement()
Returns the raw JSON value of validatedAccountOwnershipWithAccountStatement.
Unlike validatedAccountOwnershipWithAccountStatement, this method doesn't throw if the JSON field has an unexpected type.
-
_validatedAccountOwnershipWithMicrodeposit
final JsonField<Boolean> _validatedAccountOwnershipWithMicrodeposit()
Returns the raw JSON value of validatedAccountOwnershipWithMicrodeposit.
Unlike validatedAccountOwnershipWithMicrodeposit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProofOfAuthorizationRequestSubmission.Builder toBuilder()
-
validate
final ProofOfAuthorizationRequestSubmission validate()
-
builder
final static ProofOfAuthorizationRequestSubmission.Builder builder()
Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequestSubmission.
The following fields are required:
.id() .additionalEvidenceFiles() .authorizationTerms() .authorizedAt() .authorizerCompany() .authorizerEmail() .authorizerIpAddress() .authorizerName() .createdAt() .customerHasBeenOffboarded() .idempotencyKey() .proofOfAuthorizationRequestId() .status() .type() .updatedAt() .validatedAccountOwnershipViaCredential() .validatedAccountOwnershipWithAccountStatement() .validatedAccountOwnershipWithMicrodeposit()
-
-
-
-