Class ProofOfAuthorizationRequestSubmissionCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ProofOfAuthorizationRequestSubmissionCreateParams implements Params
Submit Proof of Authorization
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestSubmissionCreateParams.BuilderA builder for ProofOfAuthorizationRequestSubmissionCreateParams.
public final classProofOfAuthorizationRequestSubmissionCreateParams.Body
-
Method Summary
-
-
Method Detail
-
authorizationTerms
final String authorizationTerms()
Terms of authorization.
-
authorizedAt
final OffsetDateTime authorizedAt()
Time of authorization.
-
authorizerEmail
final String authorizerEmail()
Email of the authorizer.
-
authorizerName
final String authorizerName()
Name of the authorizer.
-
customerHasBeenOffboarded
final Boolean customerHasBeenOffboarded()
Whether the customer has been offboarded or suspended.
-
proofOfAuthorizationRequestId
final String proofOfAuthorizationRequestId()
ID of the proof of authorization request.
-
validatedAccountOwnershipViaCredential
final Boolean validatedAccountOwnershipViaCredential()
Whether the account ownership was validated via credential (e.g. Plaid).
-
validatedAccountOwnershipWithAccountStatement
final Boolean validatedAccountOwnershipWithAccountStatement()
Whether the account ownership was validated with an account statement.
-
validatedAccountOwnershipWithMicrodeposit
final Boolean validatedAccountOwnershipWithMicrodeposit()
Whether the account ownership was validated with a microdeposit.
-
additionalEvidenceFileId
final Optional<String> additionalEvidenceFileId()
File containing additional evidence.
-
authorizerCompany
final Optional<String> authorizerCompany()
Company of the authorizer.
-
authorizerIpAddress
final Optional<String> authorizerIpAddress()
IP address of the authorizer.
-
_authorizationTerms
final JsonField<String> _authorizationTerms()
Returns the raw JSON value of authorizationTerms.
Unlike authorizationTerms, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizedAt
final JsonField<OffsetDateTime> _authorizedAt()
Returns the raw JSON value of authorizedAt.
Unlike authorizedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerEmail
final JsonField<String> _authorizerEmail()
Returns the raw JSON value of authorizerEmail.
Unlike authorizerEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerName
final JsonField<String> _authorizerName()
Returns the raw JSON value of authorizerName.
Unlike authorizerName, this method doesn't throw if the JSON field has an unexpected type.
-
_customerHasBeenOffboarded
final JsonField<Boolean> _customerHasBeenOffboarded()
Returns the raw JSON value of customerHasBeenOffboarded.
Unlike customerHasBeenOffboarded, this method doesn't throw if the JSON field has an unexpected type.
-
_proofOfAuthorizationRequestId
final JsonField<String> _proofOfAuthorizationRequestId()
Returns the raw JSON value of proofOfAuthorizationRequestId.
Unlike proofOfAuthorizationRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_validatedAccountOwnershipViaCredential
final JsonField<Boolean> _validatedAccountOwnershipViaCredential()
Returns the raw JSON value of validatedAccountOwnershipViaCredential.
Unlike validatedAccountOwnershipViaCredential, this method doesn't throw if the JSON field has an unexpected type.
-
_validatedAccountOwnershipWithAccountStatement
final JsonField<Boolean> _validatedAccountOwnershipWithAccountStatement()
Returns the raw JSON value of validatedAccountOwnershipWithAccountStatement.
Unlike validatedAccountOwnershipWithAccountStatement, this method doesn't throw if the JSON field has an unexpected type.
-
_validatedAccountOwnershipWithMicrodeposit
final JsonField<Boolean> _validatedAccountOwnershipWithMicrodeposit()
Returns the raw JSON value of validatedAccountOwnershipWithMicrodeposit.
Unlike validatedAccountOwnershipWithMicrodeposit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalEvidenceFileId
final JsonField<String> _additionalEvidenceFileId()
Returns the raw JSON value of additionalEvidenceFileId.
Unlike additionalEvidenceFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerCompany
final JsonField<String> _authorizerCompany()
Returns the raw JSON value of authorizerCompany.
Unlike authorizerCompany, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizerIpAddress
final JsonField<String> _authorizerIpAddress()
Returns the raw JSON value of authorizerIpAddress.
Unlike authorizerIpAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final ProofOfAuthorizationRequestSubmissionCreateParams.Builder toBuilder()
-
_body
final ProofOfAuthorizationRequestSubmissionCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ProofOfAuthorizationRequestSubmissionCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ProofOfAuthorizationRequestSubmissionCreateParams.
The following fields are required:
.authorizationTerms() .authorizedAt() .authorizerEmail() .authorizerName() .customerHasBeenOffboarded() .proofOfAuthorizationRequestId() .validatedAccountOwnershipViaCredential() .validatedAccountOwnershipWithAccountStatement() .validatedAccountOwnershipWithMicrodeposit()
-
-
-
-