Class ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ProofOfAuthorizationRequestSubmissionCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
authorizationTerms
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizationTerms(String authorizationTerms)
Terms of authorization.
-
authorizationTerms
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizationTerms(JsonField<String> authorizationTerms)
Sets Builder.authorizationTerms to an arbitrary JSON value.
You should usually call Builder.authorizationTerms with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizedAt
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizedAt(OffsetDateTime authorizedAt)
Time of authorization.
-
authorizedAt
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizedAt(JsonField<OffsetDateTime> authorizedAt)
Sets Builder.authorizedAt to an arbitrary JSON value.
You should usually call Builder.authorizedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizerEmail
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerEmail(String authorizerEmail)
Email of the authorizer.
-
authorizerEmail
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerEmail(JsonField<String> authorizerEmail)
Sets Builder.authorizerEmail to an arbitrary JSON value.
You should usually call Builder.authorizerEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizerName
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerName(String authorizerName)
Name of the authorizer.
-
authorizerName
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerName(JsonField<String> authorizerName)
Sets Builder.authorizerName to an arbitrary JSON value.
You should usually call Builder.authorizerName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerHasBeenOffboarded
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder customerHasBeenOffboarded(Boolean customerHasBeenOffboarded)
Whether the customer has been offboarded or suspended.
-
customerHasBeenOffboarded
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder customerHasBeenOffboarded(JsonField<Boolean> customerHasBeenOffboarded)
Sets Builder.customerHasBeenOffboarded to an arbitrary JSON value.
You should usually call Builder.customerHasBeenOffboarded with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
proofOfAuthorizationRequestId
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder proofOfAuthorizationRequestId(String proofOfAuthorizationRequestId)
ID of the proof of authorization request.
-
proofOfAuthorizationRequestId
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder proofOfAuthorizationRequestId(JsonField<String> proofOfAuthorizationRequestId)
Sets Builder.proofOfAuthorizationRequestId to an arbitrary JSON value.
You should usually call Builder.proofOfAuthorizationRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
validatedAccountOwnershipViaCredential
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder validatedAccountOwnershipViaCredential(Boolean validatedAccountOwnershipViaCredential)
Whether the account ownership was validated via credential (e.g. Plaid).
-
validatedAccountOwnershipViaCredential
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder validatedAccountOwnershipViaCredential(JsonField<Boolean> validatedAccountOwnershipViaCredential)
Sets Builder.validatedAccountOwnershipViaCredential to an arbitrary JSON value.
You should usually call Builder.validatedAccountOwnershipViaCredential with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
validatedAccountOwnershipWithAccountStatement
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder validatedAccountOwnershipWithAccountStatement(Boolean validatedAccountOwnershipWithAccountStatement)
Whether the account ownership was validated with an account statement.
-
validatedAccountOwnershipWithAccountStatement
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder validatedAccountOwnershipWithAccountStatement(JsonField<Boolean> validatedAccountOwnershipWithAccountStatement)
Sets Builder.validatedAccountOwnershipWithAccountStatement to an arbitrary JSON value.
You should usually call Builder.validatedAccountOwnershipWithAccountStatement with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
validatedAccountOwnershipWithMicrodeposit
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder validatedAccountOwnershipWithMicrodeposit(Boolean validatedAccountOwnershipWithMicrodeposit)
Whether the account ownership was validated with a microdeposit.
-
validatedAccountOwnershipWithMicrodeposit
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder validatedAccountOwnershipWithMicrodeposit(JsonField<Boolean> validatedAccountOwnershipWithMicrodeposit)
Sets Builder.validatedAccountOwnershipWithMicrodeposit to an arbitrary JSON value.
You should usually call Builder.validatedAccountOwnershipWithMicrodeposit with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalEvidenceFileId
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder additionalEvidenceFileId(String additionalEvidenceFileId)
File containing additional evidence.
-
additionalEvidenceFileId
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder additionalEvidenceFileId(JsonField<String> additionalEvidenceFileId)
Sets Builder.additionalEvidenceFileId to an arbitrary JSON value.
You should usually call Builder.additionalEvidenceFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizerCompany
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerCompany(String authorizerCompany)
Company of the authorizer.
-
authorizerCompany
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerCompany(JsonField<String> authorizerCompany)
Sets Builder.authorizerCompany to an arbitrary JSON value.
You should usually call Builder.authorizerCompany with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authorizerIpAddress
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerIpAddress(String authorizerIpAddress)
IP address of the authorizer.
-
authorizerIpAddress
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder authorizerIpAddress(JsonField<String> authorizerIpAddress)
Sets Builder.authorizerIpAddress to an arbitrary JSON value.
You should usually call Builder.authorizerIpAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProofOfAuthorizationRequestSubmissionCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProofOfAuthorizationRequestSubmissionCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.authorizationTerms() .authorizedAt() .authorizerEmail() .authorizerName() .customerHasBeenOffboarded() .proofOfAuthorizationRequestId() .validatedAccountOwnershipViaCredential() .validatedAccountOwnershipWithAccountStatement() .validatedAccountOwnershipWithMicrodeposit()
-
-
-
-