Class RealTimeDecision.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.BuilderA builder for RealTimeDecision.
-
-
Method Summary
-
-
Method Detail
-
id
final RealTimeDecision.Builder id(String id)
The Real-Time Decision identifier.
-
id
final RealTimeDecision.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthentication
final RealTimeDecision.Builder cardAuthentication(RealTimeDecision.CardAuthentication cardAuthentication)
Fields related to a 3DS authentication attempt.
-
cardAuthentication
final RealTimeDecision.Builder cardAuthentication(Optional<RealTimeDecision.CardAuthentication> cardAuthentication)
Alias for calling Builder.cardAuthentication with
cardAuthentication.orElse(null).
-
cardAuthentication
final RealTimeDecision.Builder cardAuthentication(JsonField<RealTimeDecision.CardAuthentication> cardAuthentication)
Sets Builder.cardAuthentication to an arbitrary JSON value.
You should usually call Builder.cardAuthentication with a well-typed CardAuthentication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthenticationChallenge
final RealTimeDecision.Builder cardAuthenticationChallenge(RealTimeDecision.CardAuthenticationChallenge cardAuthenticationChallenge)
Fields related to a 3DS authentication attempt.
-
cardAuthenticationChallenge
final RealTimeDecision.Builder cardAuthenticationChallenge(Optional<RealTimeDecision.CardAuthenticationChallenge> cardAuthenticationChallenge)
Alias for calling Builder.cardAuthenticationChallenge with
cardAuthenticationChallenge.orElse(null).
-
cardAuthenticationChallenge
final RealTimeDecision.Builder cardAuthenticationChallenge(JsonField<RealTimeDecision.CardAuthenticationChallenge> cardAuthenticationChallenge)
Sets Builder.cardAuthenticationChallenge to an arbitrary JSON value.
You should usually call Builder.cardAuthenticationChallenge with a well-typed CardAuthenticationChallenge value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorization
final RealTimeDecision.Builder cardAuthorization(RealTimeDecision.CardAuthorization cardAuthorization)
Fields related to a card authorization.
-
cardAuthorization
final RealTimeDecision.Builder cardAuthorization(Optional<RealTimeDecision.CardAuthorization> cardAuthorization)
Alias for calling Builder.cardAuthorization with
cardAuthorization.orElse(null).
-
cardAuthorization
final RealTimeDecision.Builder cardAuthorization(JsonField<RealTimeDecision.CardAuthorization> cardAuthorization)
Sets Builder.cardAuthorization to an arbitrary JSON value.
You should usually call Builder.cardAuthorization with a well-typed CardAuthorization value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final RealTimeDecision.Builder category(RealTimeDecision.Category category)
The category of the Real-Time Decision.
-
category
final RealTimeDecision.Builder category(JsonField<RealTimeDecision.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final RealTimeDecision.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Real-Time Decision was created.
-
createdAt
final RealTimeDecision.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletAuthentication
final RealTimeDecision.Builder digitalWalletAuthentication(RealTimeDecision.DigitalWalletAuthentication digitalWalletAuthentication)
Fields related to a digital wallet authentication attempt.
-
digitalWalletAuthentication
final RealTimeDecision.Builder digitalWalletAuthentication(Optional<RealTimeDecision.DigitalWalletAuthentication> digitalWalletAuthentication)
Alias for calling Builder.digitalWalletAuthentication with
digitalWalletAuthentication.orElse(null).
-
digitalWalletAuthentication
final RealTimeDecision.Builder digitalWalletAuthentication(JsonField<RealTimeDecision.DigitalWalletAuthentication> digitalWalletAuthentication)
Sets Builder.digitalWalletAuthentication to an arbitrary JSON value.
You should usually call Builder.digitalWalletAuthentication with a well-typed DigitalWalletAuthentication value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletToken
final RealTimeDecision.Builder digitalWalletToken(RealTimeDecision.DigitalWalletToken digitalWalletToken)
Fields related to a digital wallet token provisioning attempt.
-
digitalWalletToken
final RealTimeDecision.Builder digitalWalletToken(Optional<RealTimeDecision.DigitalWalletToken> digitalWalletToken)
Alias for calling Builder.digitalWalletToken with
digitalWalletToken.orElse(null).
-
digitalWalletToken
final RealTimeDecision.Builder digitalWalletToken(JsonField<RealTimeDecision.DigitalWalletToken> digitalWalletToken)
Sets Builder.digitalWalletToken to an arbitrary JSON value.
You should usually call Builder.digitalWalletToken with a well-typed DigitalWalletToken value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final RealTimeDecision.Builder status(RealTimeDecision.Status status)
The status of the Real-Time Decision.
-
status
final RealTimeDecision.Builder status(JsonField<RealTimeDecision.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timeoutAt
final RealTimeDecision.Builder timeoutAt(OffsetDateTime timeoutAt)
The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision.
-
timeoutAt
final RealTimeDecision.Builder timeoutAt(JsonField<OffsetDateTime> timeoutAt)
Sets Builder.timeoutAt to an arbitrary JSON value.
You should usually call Builder.timeoutAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final RealTimeDecision.Builder type(RealTimeDecision.Type type)
A constant representing the object's type. For this resource it will always be
real_time_decision.
-
type
final RealTimeDecision.Builder type(JsonField<RealTimeDecision.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealTimeDecision.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision build()
Returns an immutable instance of RealTimeDecision.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .cardAuthentication() .cardAuthenticationChallenge() .cardAuthorization() .category() .createdAt() .digitalWalletAuthentication() .digitalWalletToken() .status() .timeoutAt() .type()
-
-
-
-