Class RealTimeDecision.CardAuthentication.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthentication.BuilderA builder for CardAuthentication.
-
-
Method Summary
-
-
Method Detail
-
accessControlServerTransactionId
final RealTimeDecision.CardAuthentication.Builder accessControlServerTransactionId(String accessControlServerTransactionId)
A unique identifier assigned by the Access Control Server (us) for this transaction.
-
accessControlServerTransactionId
final RealTimeDecision.CardAuthentication.Builder accessControlServerTransactionId(JsonField<String> accessControlServerTransactionId)
Sets Builder.accessControlServerTransactionId to an arbitrary JSON value.
You should usually call Builder.accessControlServerTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final RealTimeDecision.CardAuthentication.Builder accountId(String accountId)
The identifier of the Account the card belongs to.
-
accountId
final RealTimeDecision.CardAuthentication.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressCity
final RealTimeDecision.CardAuthentication.Builder billingAddressCity(String billingAddressCity)
The city of the cardholder billing address associated with the card used for this purchase.
-
billingAddressCity
final RealTimeDecision.CardAuthentication.Builder billingAddressCity(Optional<String> billingAddressCity)
Alias for calling Builder.billingAddressCity with
billingAddressCity.orElse(null).
-
billingAddressCity
final RealTimeDecision.CardAuthentication.Builder billingAddressCity(JsonField<String> billingAddressCity)
Sets Builder.billingAddressCity to an arbitrary JSON value.
You should usually call Builder.billingAddressCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressCountry
final RealTimeDecision.CardAuthentication.Builder billingAddressCountry(String billingAddressCountry)
The country of the cardholder billing address associated with the card used for this purchase.
-
billingAddressCountry
final RealTimeDecision.CardAuthentication.Builder billingAddressCountry(Optional<String> billingAddressCountry)
Alias for calling Builder.billingAddressCountry with
billingAddressCountry.orElse(null).
-
billingAddressCountry
final RealTimeDecision.CardAuthentication.Builder billingAddressCountry(JsonField<String> billingAddressCountry)
Sets Builder.billingAddressCountry to an arbitrary JSON value.
You should usually call Builder.billingAddressCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressLine1
final RealTimeDecision.CardAuthentication.Builder billingAddressLine1(String billingAddressLine1)
The first line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine1
final RealTimeDecision.CardAuthentication.Builder billingAddressLine1(Optional<String> billingAddressLine1)
Alias for calling Builder.billingAddressLine1 with
billingAddressLine1.orElse(null).
-
billingAddressLine1
final RealTimeDecision.CardAuthentication.Builder billingAddressLine1(JsonField<String> billingAddressLine1)
Sets Builder.billingAddressLine1 to an arbitrary JSON value.
You should usually call Builder.billingAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressLine2
final RealTimeDecision.CardAuthentication.Builder billingAddressLine2(String billingAddressLine2)
The second line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine2
final RealTimeDecision.CardAuthentication.Builder billingAddressLine2(Optional<String> billingAddressLine2)
Alias for calling Builder.billingAddressLine2 with
billingAddressLine2.orElse(null).
-
billingAddressLine2
final RealTimeDecision.CardAuthentication.Builder billingAddressLine2(JsonField<String> billingAddressLine2)
Sets Builder.billingAddressLine2 to an arbitrary JSON value.
You should usually call Builder.billingAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressLine3
final RealTimeDecision.CardAuthentication.Builder billingAddressLine3(String billingAddressLine3)
The third line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine3
final RealTimeDecision.CardAuthentication.Builder billingAddressLine3(Optional<String> billingAddressLine3)
Alias for calling Builder.billingAddressLine3 with
billingAddressLine3.orElse(null).
-
billingAddressLine3
final RealTimeDecision.CardAuthentication.Builder billingAddressLine3(JsonField<String> billingAddressLine3)
Sets Builder.billingAddressLine3 to an arbitrary JSON value.
You should usually call Builder.billingAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressPostalCode
final RealTimeDecision.CardAuthentication.Builder billingAddressPostalCode(String billingAddressPostalCode)
The postal code of the cardholder billing address associated with the card used for this purchase.
-
billingAddressPostalCode
final RealTimeDecision.CardAuthentication.Builder billingAddressPostalCode(Optional<String> billingAddressPostalCode)
Alias for calling Builder.billingAddressPostalCode with
billingAddressPostalCode.orElse(null).
-
billingAddressPostalCode
final RealTimeDecision.CardAuthentication.Builder billingAddressPostalCode(JsonField<String> billingAddressPostalCode)
Sets Builder.billingAddressPostalCode to an arbitrary JSON value.
You should usually call Builder.billingAddressPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressState
final RealTimeDecision.CardAuthentication.Builder billingAddressState(String billingAddressState)
The US state of the cardholder billing address associated with the card used for this purchase.
-
billingAddressState
final RealTimeDecision.CardAuthentication.Builder billingAddressState(Optional<String> billingAddressState)
Alias for calling Builder.billingAddressState with
billingAddressState.orElse(null).
-
billingAddressState
final RealTimeDecision.CardAuthentication.Builder billingAddressState(JsonField<String> billingAddressState)
Sets Builder.billingAddressState to an arbitrary JSON value.
You should usually call Builder.billingAddressState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final RealTimeDecision.CardAuthentication.Builder cardId(String cardId)
The identifier of the Card.
-
cardId
final RealTimeDecision.CardAuthentication.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderEmail
final RealTimeDecision.CardAuthentication.Builder cardholderEmail(String cardholderEmail)
The email address of the cardholder.
-
cardholderEmail
final RealTimeDecision.CardAuthentication.Builder cardholderEmail(Optional<String> cardholderEmail)
Alias for calling Builder.cardholderEmail with
cardholderEmail.orElse(null).
-
cardholderEmail
final RealTimeDecision.CardAuthentication.Builder cardholderEmail(JsonField<String> cardholderEmail)
Sets Builder.cardholderEmail to an arbitrary JSON value.
You should usually call Builder.cardholderEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderName
final RealTimeDecision.CardAuthentication.Builder cardholderName(String cardholderName)
The name of the cardholder.
-
cardholderName
final RealTimeDecision.CardAuthentication.Builder cardholderName(Optional<String> cardholderName)
Alias for calling Builder.cardholderName with
cardholderName.orElse(null).
-
cardholderName
final RealTimeDecision.CardAuthentication.Builder cardholderName(JsonField<String> cardholderName)
Sets Builder.cardholderName to an arbitrary JSON value.
You should usually call Builder.cardholderName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decision
final RealTimeDecision.CardAuthentication.Builder decision(RealTimeDecision.CardAuthentication.Decision decision)
Whether or not the authentication attempt was approved.
-
decision
final RealTimeDecision.CardAuthentication.Builder decision(Optional<RealTimeDecision.CardAuthentication.Decision> decision)
Alias for calling Builder.decision with
decision.orElse(null).
-
decision
final RealTimeDecision.CardAuthentication.Builder decision(JsonField<RealTimeDecision.CardAuthentication.Decision> decision)
Sets Builder.decision to an arbitrary JSON value.
You should usually call Builder.decision with a well-typed Decision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
deviceChannel
final RealTimeDecision.CardAuthentication.Builder deviceChannel(RealTimeDecision.CardAuthentication.DeviceChannel deviceChannel)
The device channel of the card authentication attempt.
-
deviceChannel
final RealTimeDecision.CardAuthentication.Builder deviceChannel(JsonField<RealTimeDecision.CardAuthentication.DeviceChannel> deviceChannel)
Sets Builder.deviceChannel to an arbitrary JSON value.
You should usually call Builder.deviceChannel with a well-typed DeviceChannel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
directoryServerTransactionId
final RealTimeDecision.CardAuthentication.Builder directoryServerTransactionId(String directoryServerTransactionId)
A unique identifier assigned by the Directory Server (the card network) for this transaction.
-
directoryServerTransactionId
final RealTimeDecision.CardAuthentication.Builder directoryServerTransactionId(JsonField<String> directoryServerTransactionId)
Sets Builder.directoryServerTransactionId to an arbitrary JSON value.
You should usually call Builder.directoryServerTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final RealTimeDecision.CardAuthentication.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final RealTimeDecision.CardAuthentication.Builder merchantAcceptorId(Optional<String> merchantAcceptorId)
Alias for calling Builder.merchantAcceptorId with
merchantAcceptorId.orElse(null).
-
merchantAcceptorId
final RealTimeDecision.CardAuthentication.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final RealTimeDecision.CardAuthentication.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final RealTimeDecision.CardAuthentication.Builder merchantCategoryCode(Optional<String> merchantCategoryCode)
Alias for calling Builder.merchantCategoryCode with
merchantCategoryCode.orElse(null).
-
merchantCategoryCode
final RealTimeDecision.CardAuthentication.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final RealTimeDecision.CardAuthentication.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final RealTimeDecision.CardAuthentication.Builder merchantCountry(Optional<String> merchantCountry)
Alias for calling Builder.merchantCountry with
merchantCountry.orElse(null).
-
merchantCountry
final RealTimeDecision.CardAuthentication.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final RealTimeDecision.CardAuthentication.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final RealTimeDecision.CardAuthentication.Builder merchantName(Optional<String> merchantName)
Alias for calling Builder.merchantName with
merchantName.orElse(null).
-
merchantName
final RealTimeDecision.CardAuthentication.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageCategory
final RealTimeDecision.CardAuthentication.Builder messageCategory(RealTimeDecision.CardAuthentication.MessageCategory messageCategory)
The message category of the card authentication attempt.
-
messageCategory
final RealTimeDecision.CardAuthentication.Builder messageCategory(JsonField<RealTimeDecision.CardAuthentication.MessageCategory> messageCategory)
Sets Builder.messageCategory to an arbitrary JSON value.
You should usually call Builder.messageCategory with a well-typed MessageCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
priorAuthenticatedCardPaymentId
final RealTimeDecision.CardAuthentication.Builder priorAuthenticatedCardPaymentId(String priorAuthenticatedCardPaymentId)
The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction.
-
priorAuthenticatedCardPaymentId
final RealTimeDecision.CardAuthentication.Builder priorAuthenticatedCardPaymentId(Optional<String> priorAuthenticatedCardPaymentId)
Alias for calling Builder.priorAuthenticatedCardPaymentId with
priorAuthenticatedCardPaymentId.orElse(null).
-
priorAuthenticatedCardPaymentId
final RealTimeDecision.CardAuthentication.Builder priorAuthenticatedCardPaymentId(JsonField<String> priorAuthenticatedCardPaymentId)
Sets Builder.priorAuthenticatedCardPaymentId to an arbitrary JSON value.
You should usually call Builder.priorAuthenticatedCardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestorAuthenticationIndicator
final RealTimeDecision.CardAuthentication.Builder requestorAuthenticationIndicator(RealTimeDecision.CardAuthentication.RequestorAuthenticationIndicator requestorAuthenticationIndicator)
The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.
-
requestorAuthenticationIndicator
final RealTimeDecision.CardAuthentication.Builder requestorAuthenticationIndicator(Optional<RealTimeDecision.CardAuthentication.RequestorAuthenticationIndicator> requestorAuthenticationIndicator)
Alias for calling Builder.requestorAuthenticationIndicator with
requestorAuthenticationIndicator.orElse(null).
-
requestorAuthenticationIndicator
final RealTimeDecision.CardAuthentication.Builder requestorAuthenticationIndicator(JsonField<RealTimeDecision.CardAuthentication.RequestorAuthenticationIndicator> requestorAuthenticationIndicator)
Sets Builder.requestorAuthenticationIndicator to an arbitrary JSON value.
You should usually call Builder.requestorAuthenticationIndicator with a well-typed RequestorAuthenticationIndicator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestorChallengeIndicator
final RealTimeDecision.CardAuthentication.Builder requestorChallengeIndicator(RealTimeDecision.CardAuthentication.RequestorChallengeIndicator requestorChallengeIndicator)
Indicates whether a challenge is requested for this transaction.
-
requestorChallengeIndicator
final RealTimeDecision.CardAuthentication.Builder requestorChallengeIndicator(Optional<RealTimeDecision.CardAuthentication.RequestorChallengeIndicator> requestorChallengeIndicator)
Alias for calling Builder.requestorChallengeIndicator with
requestorChallengeIndicator.orElse(null).
-
requestorChallengeIndicator
final RealTimeDecision.CardAuthentication.Builder requestorChallengeIndicator(JsonField<RealTimeDecision.CardAuthentication.RequestorChallengeIndicator> requestorChallengeIndicator)
Sets Builder.requestorChallengeIndicator to an arbitrary JSON value.
You should usually call Builder.requestorChallengeIndicator with a well-typed RequestorChallengeIndicator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestorName
final RealTimeDecision.CardAuthentication.Builder requestorName(String requestorName)
The name of the 3DS requestor.
-
requestorName
final RealTimeDecision.CardAuthentication.Builder requestorName(JsonField<String> requestorName)
Sets Builder.requestorName to an arbitrary JSON value.
You should usually call Builder.requestorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestorUrl
final RealTimeDecision.CardAuthentication.Builder requestorUrl(String requestorUrl)
The URL of the 3DS requestor.
-
requestorUrl
final RealTimeDecision.CardAuthentication.Builder requestorUrl(JsonField<String> requestorUrl)
Sets Builder.requestorUrl to an arbitrary JSON value.
You should usually call Builder.requestorUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressCity
final RealTimeDecision.CardAuthentication.Builder shippingAddressCity(String shippingAddressCity)
The city of the shipping address associated with this purchase.
-
shippingAddressCity
final RealTimeDecision.CardAuthentication.Builder shippingAddressCity(Optional<String> shippingAddressCity)
Alias for calling Builder.shippingAddressCity with
shippingAddressCity.orElse(null).
-
shippingAddressCity
final RealTimeDecision.CardAuthentication.Builder shippingAddressCity(JsonField<String> shippingAddressCity)
Sets Builder.shippingAddressCity to an arbitrary JSON value.
You should usually call Builder.shippingAddressCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressCountry
final RealTimeDecision.CardAuthentication.Builder shippingAddressCountry(String shippingAddressCountry)
The country of the shipping address associated with this purchase.
-
shippingAddressCountry
final RealTimeDecision.CardAuthentication.Builder shippingAddressCountry(Optional<String> shippingAddressCountry)
Alias for calling Builder.shippingAddressCountry with
shippingAddressCountry.orElse(null).
-
shippingAddressCountry
final RealTimeDecision.CardAuthentication.Builder shippingAddressCountry(JsonField<String> shippingAddressCountry)
Sets Builder.shippingAddressCountry to an arbitrary JSON value.
You should usually call Builder.shippingAddressCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressLine1
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine1(String shippingAddressLine1)
The first line of the shipping address associated with this purchase.
-
shippingAddressLine1
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine1(Optional<String> shippingAddressLine1)
Alias for calling Builder.shippingAddressLine1 with
shippingAddressLine1.orElse(null).
-
shippingAddressLine1
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine1(JsonField<String> shippingAddressLine1)
Sets Builder.shippingAddressLine1 to an arbitrary JSON value.
You should usually call Builder.shippingAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressLine2
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine2(String shippingAddressLine2)
The second line of the shipping address associated with this purchase.
-
shippingAddressLine2
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine2(Optional<String> shippingAddressLine2)
Alias for calling Builder.shippingAddressLine2 with
shippingAddressLine2.orElse(null).
-
shippingAddressLine2
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine2(JsonField<String> shippingAddressLine2)
Sets Builder.shippingAddressLine2 to an arbitrary JSON value.
You should usually call Builder.shippingAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressLine3
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine3(String shippingAddressLine3)
The third line of the shipping address associated with this purchase.
-
shippingAddressLine3
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine3(Optional<String> shippingAddressLine3)
Alias for calling Builder.shippingAddressLine3 with
shippingAddressLine3.orElse(null).
-
shippingAddressLine3
final RealTimeDecision.CardAuthentication.Builder shippingAddressLine3(JsonField<String> shippingAddressLine3)
Sets Builder.shippingAddressLine3 to an arbitrary JSON value.
You should usually call Builder.shippingAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressPostalCode
final RealTimeDecision.CardAuthentication.Builder shippingAddressPostalCode(String shippingAddressPostalCode)
The postal code of the shipping address associated with this purchase.
-
shippingAddressPostalCode
final RealTimeDecision.CardAuthentication.Builder shippingAddressPostalCode(Optional<String> shippingAddressPostalCode)
Alias for calling Builder.shippingAddressPostalCode with
shippingAddressPostalCode.orElse(null).
-
shippingAddressPostalCode
final RealTimeDecision.CardAuthentication.Builder shippingAddressPostalCode(JsonField<String> shippingAddressPostalCode)
Sets Builder.shippingAddressPostalCode to an arbitrary JSON value.
You should usually call Builder.shippingAddressPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shippingAddressState
final RealTimeDecision.CardAuthentication.Builder shippingAddressState(String shippingAddressState)
The US state of the shipping address associated with this purchase.
-
shippingAddressState
final RealTimeDecision.CardAuthentication.Builder shippingAddressState(Optional<String> shippingAddressState)
Alias for calling Builder.shippingAddressState with
shippingAddressState.orElse(null).
-
shippingAddressState
final RealTimeDecision.CardAuthentication.Builder shippingAddressState(JsonField<String> shippingAddressState)
Sets Builder.shippingAddressState to an arbitrary JSON value.
You should usually call Builder.shippingAddressState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
threeDSecureServerTransactionId
final RealTimeDecision.CardAuthentication.Builder threeDSecureServerTransactionId(String threeDSecureServerTransactionId)
A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction.
-
threeDSecureServerTransactionId
final RealTimeDecision.CardAuthentication.Builder threeDSecureServerTransactionId(JsonField<String> threeDSecureServerTransactionId)
Sets Builder.threeDSecureServerTransactionId to an arbitrary JSON value.
You should usually call Builder.threeDSecureServerTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
upcomingCardPaymentId
final RealTimeDecision.CardAuthentication.Builder upcomingCardPaymentId(String upcomingCardPaymentId)
The identifier of the Card Payment this authentication attempt will belong to. Available in the API once the card authentication has completed.
-
upcomingCardPaymentId
final RealTimeDecision.CardAuthentication.Builder upcomingCardPaymentId(JsonField<String> upcomingCardPaymentId)
Sets Builder.upcomingCardPaymentId to an arbitrary JSON value.
You should usually call Builder.upcomingCardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealTimeDecision.CardAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.CardAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.CardAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.CardAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.CardAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.CardAuthentication build()
Returns an immutable instance of CardAuthentication.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accessControlServerTransactionId() .accountId() .billingAddressCity() .billingAddressCountry() .billingAddressLine1() .billingAddressLine2() .billingAddressLine3() .billingAddressPostalCode() .billingAddressState() .cardId() .cardholderEmail() .cardholderName() .decision() .deviceChannel() .directoryServerTransactionId() .merchantAcceptorId() .merchantCategoryCode() .merchantCountry() .merchantName() .messageCategory() .priorAuthenticatedCardPaymentId() .requestorAuthenticationIndicator() .requestorChallengeIndicator() .requestorName() .requestorUrl() .shippingAddressCity() .shippingAddressCountry() .shippingAddressLine1() .shippingAddressLine2() .shippingAddressLine3() .shippingAddressPostalCode() .shippingAddressState() .threeDSecureServerTransactionId() .upcomingCardPaymentId()
-
-
-
-