Class RealTimeDecision.CardAuthentication.DeviceChannel
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthentication.DeviceChannelThe device channel of the card authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthentication.DeviceChannel.BuilderA builder for DeviceChannel.
public final classRealTimeDecision.CardAuthentication.DeviceChannel.BrowserFields specific to the browser device channel.
public final classRealTimeDecision.CardAuthentication.DeviceChannel.CategoryThe category of the device channel.
public final classRealTimeDecision.CardAuthentication.DeviceChannel.MerchantInitiatedFields specific to merchant initiated transactions.
-
Method Summary
-
-
Method Detail
-
browser
final Optional<RealTimeDecision.CardAuthentication.DeviceChannel.Browser> browser()
Fields specific to the browser device channel.
-
category
final RealTimeDecision.CardAuthentication.DeviceChannel.Category category()
The category of the device channel.
-
merchantInitiated
final Optional<RealTimeDecision.CardAuthentication.DeviceChannel.MerchantInitiated> merchantInitiated()
Fields specific to merchant initiated transactions.
-
_browser
final JsonField<RealTimeDecision.CardAuthentication.DeviceChannel.Browser> _browser()
Returns the raw JSON value of browser.
Unlike browser, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<RealTimeDecision.CardAuthentication.DeviceChannel.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantInitiated
final JsonField<RealTimeDecision.CardAuthentication.DeviceChannel.MerchantInitiated> _merchantInitiated()
Returns the raw JSON value of merchantInitiated.
Unlike merchantInitiated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardAuthentication.DeviceChannel.Builder toBuilder()
-
validate
final RealTimeDecision.CardAuthentication.DeviceChannel validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealTimeDecision.CardAuthentication.DeviceChannel.Builder builder()
Returns a mutable builder for constructing an instance of DeviceChannel.
The following fields are required:
.browser() .category() .merchantInitiated()
-
-
-
-