Class RealTimeDecision.CardAuthentication.MessageCategory
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthentication.MessageCategoryThe message category of the card authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthentication.MessageCategory.BuilderA builder for MessageCategory.
public final classRealTimeDecision.CardAuthentication.MessageCategory.CategoryThe category of the card authentication attempt.
public final classRealTimeDecision.CardAuthentication.MessageCategory.NonPaymentFields specific to non-payment authentication attempts.
public final classRealTimeDecision.CardAuthentication.MessageCategory.PaymentFields specific to payment authentication attempts.
-
Method Summary
-
-
Method Detail
-
category
final RealTimeDecision.CardAuthentication.MessageCategory.Category category()
The category of the card authentication attempt.
-
nonPayment
final Optional<RealTimeDecision.CardAuthentication.MessageCategory.NonPayment> nonPayment()
Fields specific to non-payment authentication attempts.
-
payment
final Optional<RealTimeDecision.CardAuthentication.MessageCategory.Payment> payment()
Fields specific to payment authentication attempts.
-
_category
final JsonField<RealTimeDecision.CardAuthentication.MessageCategory.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_nonPayment
final JsonField<RealTimeDecision.CardAuthentication.MessageCategory.NonPayment> _nonPayment()
Returns the raw JSON value of nonPayment.
Unlike nonPayment, this method doesn't throw if the JSON field has an unexpected type.
-
_payment
final JsonField<RealTimeDecision.CardAuthentication.MessageCategory.Payment> _payment()
Returns the raw JSON value of payment.
Unlike payment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardAuthentication.MessageCategory.Builder toBuilder()
-
validate
final RealTimeDecision.CardAuthentication.MessageCategory validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealTimeDecision.CardAuthentication.MessageCategory.Builder builder()
Returns a mutable builder for constructing an instance of MessageCategory.
The following fields are required:
.category() .nonPayment() .payment()
-
-
-
-