Class RealTimeDecision.CardAuthenticationChallenge
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthenticationChallengeFields related to a 3DS authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthenticationChallenge.BuilderA builder for CardAuthenticationChallenge.
public final classRealTimeDecision.CardAuthenticationChallenge.ResultWhether or not the challenge was delivered to the cardholder.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the card belongs to. final StringcardId()The identifier of the Card that is being tokenized. final StringcardPaymentId()The identifier of the Card Payment this authentication challenge attempt belongs to. final StringoneTimeCode()The one-time code delivered to the cardholder. final Optional<RealTimeDecision.CardAuthenticationChallenge.Result>result()Whether or not the challenge was delivered to the cardholder. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<String>_oneTimeCode()Returns the raw JSON value of oneTimeCode. final JsonField<RealTimeDecision.CardAuthenticationChallenge.Result>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthenticationChallenge.BuildertoBuilder()final RealTimeDecision.CardAuthenticationChallengevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthenticationChallenge.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthenticationChallenge. -
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment this authentication challenge attempt belongs to.
-
oneTimeCode
final String oneTimeCode()
The one-time code delivered to the cardholder.
-
result
final Optional<RealTimeDecision.CardAuthenticationChallenge.Result> result()
Whether or not the challenge was delivered to the cardholder.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_oneTimeCode
final JsonField<String> _oneTimeCode()
Returns the raw JSON value of oneTimeCode.
Unlike oneTimeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<RealTimeDecision.CardAuthenticationChallenge.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardAuthenticationChallenge.Builder toBuilder()
-
validate
final RealTimeDecision.CardAuthenticationChallenge validate()
-
builder
final static RealTimeDecision.CardAuthenticationChallenge.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthenticationChallenge.
The following fields are required:
.accountId() .cardId() .cardPaymentId() .oneTimeCode() .result()
-
-
-
-