Class RealTimeDecision.CardAuthenticationChallenge.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthenticationChallenge.BuilderA builder for CardAuthenticationChallenge.
-
-
Method Summary
-
-
Method Detail
-
accountId
final RealTimeDecision.CardAuthenticationChallenge.Builder accountId(String accountId)
The identifier of the Account the card belongs to.
-
accountId
final RealTimeDecision.CardAuthenticationChallenge.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardPaymentId(String cardPaymentId)
The identifier of the Card Payment this authentication challenge attempt belongs to.
-
cardPaymentId
final RealTimeDecision.CardAuthenticationChallenge.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
oneTimeCode
final RealTimeDecision.CardAuthenticationChallenge.Builder oneTimeCode(String oneTimeCode)
The one-time code delivered to the cardholder.
-
oneTimeCode
final RealTimeDecision.CardAuthenticationChallenge.Builder oneTimeCode(JsonField<String> oneTimeCode)
Sets Builder.oneTimeCode to an arbitrary JSON value.
You should usually call Builder.oneTimeCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final RealTimeDecision.CardAuthenticationChallenge.Builder result(RealTimeDecision.CardAuthenticationChallenge.Result result)
Whether or not the challenge was delivered to the cardholder.
-
result
final RealTimeDecision.CardAuthenticationChallenge.Builder result(Optional<RealTimeDecision.CardAuthenticationChallenge.Result> result)
Alias for calling Builder.result with
result.orElse(null).
-
result
final RealTimeDecision.CardAuthenticationChallenge.Builder result(JsonField<RealTimeDecision.CardAuthenticationChallenge.Result> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealTimeDecision.CardAuthenticationChallenge.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.CardAuthenticationChallenge.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.CardAuthenticationChallenge.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.CardAuthenticationChallenge.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.CardAuthenticationChallenge.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.CardAuthenticationChallenge build()
Returns an immutable instance of CardAuthenticationChallenge.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .cardId() .cardPaymentId() .oneTimeCode() .result()
-
-
-
-