Class RealTimeDecision.CardAuthorization
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthorizationFields related to a card authorization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthorization.BuilderA builder for CardAuthorization.
public final classRealTimeDecision.CardAuthorization.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.public final classRealTimeDecision.CardAuthorization.DecisionWhether or not the authorization was approved.
public final classRealTimeDecision.CardAuthorization.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classRealTimeDecision.CardAuthorization.NetworkDetailsFields specific to the
network.public final classRealTimeDecision.CardAuthorization.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classRealTimeDecision.CardAuthorization.ProcessingCategoryThe processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
public final classRealTimeDecision.CardAuthorization.RequestDetailsFields specific to the type of request, such as an incremental authorization.
public final classRealTimeDecision.CardAuthorization.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the authorization will debit. final RealTimeDecision.CardAuthorization.AdditionalAmountsadditionalAmounts()Additional amounts associated with the card authorization, such as ATM surcharges fees. final StringcardId()The identifier of the Card that is being authorized. final Optional<RealTimeDecision.CardAuthorization.Decision>decision()Whether or not the authorization was approved. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final RealTimeDecision.CardAuthorization.Directiondirection()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final RealTimeDecision.CardAuthorization.NetworkDetailsnetworkDetails()Fields specific to the network.final RealTimeDecision.CardAuthorization.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final LongpresentmentAmount()The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. final StringpresentmentCurrency()The ISO 4217 code for the currency the user sees at the time of purchase. final RealTimeDecision.CardAuthorization.ProcessingCategoryprocessingCategory()The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser. final RealTimeDecision.CardAuthorization.RequestDetailsrequestDetails()Fields specific to the type of request, such as an incremental authorization. final LongsettlementAmount()The amount of the attempted authorization in the currency it will be settled in. final StringsettlementCurrency()The ISO 4217 code for the currency the transaction will be settled in. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final StringupcomingCardPaymentId()The identifier of the Card Payment this authorization will belong to. final RealTimeDecision.CardAuthorization.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<RealTimeDecision.CardAuthorization.AdditionalAmounts>_additionalAmounts()Returns the raw JSON value of additionalAmounts. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<RealTimeDecision.CardAuthorization.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<RealTimeDecision.CardAuthorization.Direction>_direction()Returns the raw JSON value of direction. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails>_networkDetails()Returns the raw JSON value of networkDetails. final JsonField<RealTimeDecision.CardAuthorization.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<Long>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_presentmentCurrency()Returns the raw JSON value of presentmentCurrency. final JsonField<RealTimeDecision.CardAuthorization.ProcessingCategory>_processingCategory()Returns the raw JSON value of processingCategory. final JsonField<RealTimeDecision.CardAuthorization.RequestDetails>_requestDetails()Returns the raw JSON value of requestDetails. final JsonField<Long>_settlementAmount()Returns the raw JSON value of settlementAmount. final JsonField<String>_settlementCurrency()Returns the raw JSON value of settlementCurrency. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final JsonField<String>_upcomingCardPaymentId()Returns the raw JSON value of upcomingCardPaymentId. final JsonField<RealTimeDecision.CardAuthorization.Verification>_verification()Returns the raw JSON value of verification. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthorization.BuildertoBuilder()final RealTimeDecision.CardAuthorizationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthorization.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthorization. -
-
Method Detail
-
additionalAmounts
final RealTimeDecision.CardAuthorization.AdditionalAmounts additionalAmounts()
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
decision
final Optional<RealTimeDecision.CardAuthorization.Decision> decision()
Whether or not the authorization was approved.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final RealTimeDecision.CardAuthorization.Direction direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final RealTimeDecision.CardAuthorization.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final RealTimeDecision.CardAuthorization.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final Long presentmentAmount()
The amount of the attempted authorization in the currency the card user sees at the time of purchase, in the minor unit of that currency. For dollars, for example, this is cents.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the currency the user sees at the time of purchase.
-
processingCategory
final RealTimeDecision.CardAuthorization.ProcessingCategory processingCategory()
The processing category describes the intent behind the authorization, such as whether it was used for bill payments or an automatic fuel dispenser.
-
requestDetails
final RealTimeDecision.CardAuthorization.RequestDetails requestDetails()
Fields specific to the type of request, such as an incremental authorization.
-
settlementAmount
final Long settlementAmount()
The amount of the attempted authorization in the currency it will be settled in. This currency is the same as that of the Account the card belongs to.
-
settlementCurrency
final String settlementCurrency()
The ISO 4217 code for the currency the transaction will be settled in.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
upcomingCardPaymentId
final String upcomingCardPaymentId()
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
-
verification
final RealTimeDecision.CardAuthorization.Verification verification()
Fields related to verification of cardholder-provided values.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalAmounts
final JsonField<RealTimeDecision.CardAuthorization.AdditionalAmounts> _additionalAmounts()
Returns the raw JSON value of additionalAmounts.
Unlike additionalAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_decision
final JsonField<RealTimeDecision.CardAuthorization.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<RealTimeDecision.CardAuthorization.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_networkDetails
final JsonField<RealTimeDecision.CardAuthorization.NetworkDetails> _networkDetails()
Returns the raw JSON value of networkDetails.
Unlike networkDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<RealTimeDecision.CardAuthorization.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
Returns the raw JSON value of presentmentCurrency.
Unlike presentmentCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_processingCategory
final JsonField<RealTimeDecision.CardAuthorization.ProcessingCategory> _processingCategory()
Returns the raw JSON value of processingCategory.
Unlike processingCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_requestDetails
final JsonField<RealTimeDecision.CardAuthorization.RequestDetails> _requestDetails()
Returns the raw JSON value of requestDetails.
Unlike requestDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementCurrency
final JsonField<String> _settlementCurrency()
Returns the raw JSON value of settlementCurrency.
Unlike settlementCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_upcomingCardPaymentId
final JsonField<String> _upcomingCardPaymentId()
Returns the raw JSON value of upcomingCardPaymentId.
Unlike upcomingCardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_verification
final JsonField<RealTimeDecision.CardAuthorization.Verification> _verification()
Returns the raw JSON value of verification.
Unlike verification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardAuthorization.Builder toBuilder()
-
validate
final RealTimeDecision.CardAuthorization validate()
-
builder
final static RealTimeDecision.CardAuthorization.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorization.
The following fields are required:
.accountId() .additionalAmounts() .cardId() .decision() .digitalWalletTokenId() .direction() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .presentmentAmount() .presentmentCurrency() .processingCategory() .requestDetails() .settlementAmount() .settlementCurrency() .terminalId() .upcomingCardPaymentId() .verification()
-
-
-
-