Class RealTimeDecision.CardAuthorization.Verification.CardVerificationCode
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthorization.Verification.CardVerificationCodeFields related to verification of the Card Verification Code, a 3-digit code on the back of the card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthorization.Verification.CardVerificationCode.BuilderA builder for CardVerificationCode.
public final classRealTimeDecision.CardAuthorization.Verification.CardVerificationCode.ResultThe result of verifying the Card Verification Code.
-
Method Summary
Modifier and Type Method Description final RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Resultresult()The result of verifying the Card Verification Code. final JsonField<RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Result>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.BuildertoBuilder()final RealTimeDecision.CardAuthorization.Verification.CardVerificationCodevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Builderbuilder()Returns a mutable builder for constructing an instance of CardVerificationCode. -
-
Method Detail
-
result
final RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Result result()
The result of verifying the Card Verification Code.
-
_result
final JsonField<RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Builder toBuilder()
-
validate
final RealTimeDecision.CardAuthorization.Verification.CardVerificationCode validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealTimeDecision.CardAuthorization.Verification.CardVerificationCode.Builder builder()
Returns a mutable builder for constructing an instance of CardVerificationCode.
The following fields are required:
.result()
-
-
-
-