Class RealTimeDecision.CardBalanceInquiry
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardBalanceInquiryFields related to a card balance inquiry.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardBalanceInquiry.BuilderA builder for CardBalanceInquiry.
public final classRealTimeDecision.CardBalanceInquiry.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.public final classRealTimeDecision.CardBalanceInquiry.ApprovalPresent if and only if
decisionisapprove. Contains information related to the approval of the balance inquiry.public final classRealTimeDecision.CardBalanceInquiry.DecisionWhether or not the authorization was approved.
public final classRealTimeDecision.CardBalanceInquiry.NetworkDetailsFields specific to the
network.public final classRealTimeDecision.CardBalanceInquiry.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classRealTimeDecision.CardBalanceInquiry.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the authorization will debit. final RealTimeDecision.CardBalanceInquiry.AdditionalAmountsadditionalAmounts()Additional amounts associated with the card authorization, such as ATM surcharges fees. final Optional<RealTimeDecision.CardBalanceInquiry.Approval>approval()Present if and only if decisionisapprove.final StringcardId()The identifier of the Card that is being authorized. final Optional<RealTimeDecision.CardBalanceInquiry.Decision>decision()Whether or not the authorization was approved. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final RealTimeDecision.CardBalanceInquiry.NetworkDetailsnetworkDetails()Fields specific to the network.final RealTimeDecision.CardBalanceInquiry.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final StringupcomingCardPaymentId()The identifier of the Card Payment this authorization will belong to. final RealTimeDecision.CardBalanceInquiry.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<RealTimeDecision.CardBalanceInquiry.AdditionalAmounts>_additionalAmounts()Returns the raw JSON value of additionalAmounts. final JsonField<RealTimeDecision.CardBalanceInquiry.Approval>_approval()Returns the raw JSON value of approval. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<RealTimeDecision.CardBalanceInquiry.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<RealTimeDecision.CardBalanceInquiry.NetworkDetails>_networkDetails()Returns the raw JSON value of networkDetails. final JsonField<RealTimeDecision.CardBalanceInquiry.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final JsonField<String>_upcomingCardPaymentId()Returns the raw JSON value of upcomingCardPaymentId. final JsonField<RealTimeDecision.CardBalanceInquiry.Verification>_verification()Returns the raw JSON value of verification. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardBalanceInquiry.BuildertoBuilder()final RealTimeDecision.CardBalanceInquiryvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardBalanceInquiry.Builderbuilder()Returns a mutable builder for constructing an instance of CardBalanceInquiry. -
-
Method Detail
-
additionalAmounts
final RealTimeDecision.CardBalanceInquiry.AdditionalAmounts additionalAmounts()
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
approval
final Optional<RealTimeDecision.CardBalanceInquiry.Approval> approval()
Present if and only if
decisionisapprove. Contains information related to the approval of the balance inquiry.
-
decision
final Optional<RealTimeDecision.CardBalanceInquiry.Decision> decision()
Whether or not the authorization was approved.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final RealTimeDecision.CardBalanceInquiry.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final RealTimeDecision.CardBalanceInquiry.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
upcomingCardPaymentId
final String upcomingCardPaymentId()
The identifier of the Card Payment this authorization will belong to. Available in the API once the card authorization has completed.
-
verification
final RealTimeDecision.CardBalanceInquiry.Verification verification()
Fields related to verification of cardholder-provided values.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalAmounts
final JsonField<RealTimeDecision.CardBalanceInquiry.AdditionalAmounts> _additionalAmounts()
Returns the raw JSON value of additionalAmounts.
Unlike additionalAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_approval
final JsonField<RealTimeDecision.CardBalanceInquiry.Approval> _approval()
Returns the raw JSON value of approval.
Unlike approval, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_decision
final JsonField<RealTimeDecision.CardBalanceInquiry.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_networkDetails
final JsonField<RealTimeDecision.CardBalanceInquiry.NetworkDetails> _networkDetails()
Returns the raw JSON value of networkDetails.
Unlike networkDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<RealTimeDecision.CardBalanceInquiry.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_upcomingCardPaymentId
final JsonField<String> _upcomingCardPaymentId()
Returns the raw JSON value of upcomingCardPaymentId.
Unlike upcomingCardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_verification
final JsonField<RealTimeDecision.CardBalanceInquiry.Verification> _verification()
Returns the raw JSON value of verification.
Unlike verification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardBalanceInquiry.Builder toBuilder()
-
validate
final RealTimeDecision.CardBalanceInquiry validate()
-
builder
final static RealTimeDecision.CardBalanceInquiry.Builder builder()
Returns a mutable builder for constructing an instance of CardBalanceInquiry.
The following fields are required:
.accountId() .additionalAmounts() .approval() .cardId() .decision() .digitalWalletTokenId() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .terminalId() .upcomingCardPaymentId() .verification()
-
-
-
-