Class RealTimeDecision.DigitalWalletAuthentication.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletAuthentication.BuilderA builder for DigitalWalletAuthentication.
-
-
Method Summary
-
-
Method Detail
-
cardId
final RealTimeDecision.DigitalWalletAuthentication.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.DigitalWalletAuthentication.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
channel
final RealTimeDecision.DigitalWalletAuthentication.Builder channel(RealTimeDecision.DigitalWalletAuthentication.Channel channel)
The channel to send the card user their one-time passcode.
-
channel
final RealTimeDecision.DigitalWalletAuthentication.Builder channel(JsonField<RealTimeDecision.DigitalWalletAuthentication.Channel> channel)
Sets Builder.channel to an arbitrary JSON value.
You should usually call Builder.channel with a well-typed Channel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final RealTimeDecision.DigitalWalletAuthentication.Builder digitalWallet(RealTimeDecision.DigitalWalletAuthentication.DigitalWallet digitalWallet)
The digital wallet app being used.
-
digitalWallet
final RealTimeDecision.DigitalWalletAuthentication.Builder digitalWallet(JsonField<RealTimeDecision.DigitalWalletAuthentication.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
email
final RealTimeDecision.DigitalWalletAuthentication.Builder email(String email)
The email to send the one-time passcode to if
channelis equal toemail.
-
email
final RealTimeDecision.DigitalWalletAuthentication.Builder email(Optional<String> email)
Alias for calling Builder.email with
email.orElse(null).
-
email
final RealTimeDecision.DigitalWalletAuthentication.Builder email(JsonField<String> email)
Sets Builder.email to an arbitrary JSON value.
You should usually call Builder.email with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
oneTimePasscode
final RealTimeDecision.DigitalWalletAuthentication.Builder oneTimePasscode(String oneTimePasscode)
The one-time passcode to send the card user.
-
oneTimePasscode
final RealTimeDecision.DigitalWalletAuthentication.Builder oneTimePasscode(JsonField<String> oneTimePasscode)
Sets Builder.oneTimePasscode to an arbitrary JSON value.
You should usually call Builder.oneTimePasscode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
phone
final RealTimeDecision.DigitalWalletAuthentication.Builder phone(String phone)
The phone number to send the one-time passcode to if
channelis equal tosms.
-
phone
final RealTimeDecision.DigitalWalletAuthentication.Builder phone(Optional<String> phone)
Alias for calling Builder.phone with
phone.orElse(null).
-
phone
final RealTimeDecision.DigitalWalletAuthentication.Builder phone(JsonField<String> phone)
Sets Builder.phone to an arbitrary JSON value.
You should usually call Builder.phone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
result
final RealTimeDecision.DigitalWalletAuthentication.Builder result(RealTimeDecision.DigitalWalletAuthentication.Result result)
Whether your application successfully delivered the one-time passcode.
-
result
final RealTimeDecision.DigitalWalletAuthentication.Builder result(Optional<RealTimeDecision.DigitalWalletAuthentication.Result> result)
Alias for calling Builder.result with
result.orElse(null).
-
result
final RealTimeDecision.DigitalWalletAuthentication.Builder result(JsonField<RealTimeDecision.DigitalWalletAuthentication.Result> result)
Sets Builder.result to an arbitrary JSON value.
You should usually call Builder.result with a well-typed Result value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealTimeDecision.DigitalWalletAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.DigitalWalletAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.DigitalWalletAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.DigitalWalletAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.DigitalWalletAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.DigitalWalletAuthentication build()
Returns an immutable instance of DigitalWalletAuthentication.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardId() .channel() .digitalWallet() .email() .oneTimePasscode() .phone() .result()
-
-
-
-