Class RealTimeDecision.DigitalWalletToken.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletToken.BuilderA builder for DigitalWalletToken.
-
-
Method Summary
-
-
Method Detail
-
cardId
final RealTimeDecision.DigitalWalletToken.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.DigitalWalletToken.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardProfileId
final RealTimeDecision.DigitalWalletToken.Builder cardProfileId(String cardProfileId)
The identifier of the Card Profile that was set via the real time decision. This will be null until the real time decision is responded to or if the real time decision did not set a card profile.
-
cardProfileId
final RealTimeDecision.DigitalWalletToken.Builder cardProfileId(Optional<String> cardProfileId)
Alias for calling Builder.cardProfileId with
cardProfileId.orElse(null).
-
cardProfileId
final RealTimeDecision.DigitalWalletToken.Builder cardProfileId(JsonField<String> cardProfileId)
Sets Builder.cardProfileId to an arbitrary JSON value.
You should usually call Builder.cardProfileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decision
final RealTimeDecision.DigitalWalletToken.Builder decision(RealTimeDecision.DigitalWalletToken.Decision decision)
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
decision
final RealTimeDecision.DigitalWalletToken.Builder decision(Optional<RealTimeDecision.DigitalWalletToken.Decision> decision)
Alias for calling Builder.decision with
decision.orElse(null).
-
decision
final RealTimeDecision.DigitalWalletToken.Builder decision(JsonField<RealTimeDecision.DigitalWalletToken.Decision> decision)
Sets Builder.decision to an arbitrary JSON value.
You should usually call Builder.decision with a well-typed Decision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
device
final RealTimeDecision.DigitalWalletToken.Builder device(RealTimeDecision.DigitalWalletToken.Device device)
Device that is being used to provision the digital wallet token.
-
device
final RealTimeDecision.DigitalWalletToken.Builder device(JsonField<RealTimeDecision.DigitalWalletToken.Device> device)
Sets Builder.device to an arbitrary JSON value.
You should usually call Builder.device with a well-typed Device value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWallet
final RealTimeDecision.DigitalWalletToken.Builder digitalWallet(RealTimeDecision.DigitalWalletToken.DigitalWallet digitalWallet)
The digital wallet app being used.
-
digitalWallet
final RealTimeDecision.DigitalWalletToken.Builder digitalWallet(JsonField<RealTimeDecision.DigitalWalletToken.DigitalWallet> digitalWallet)
Sets Builder.digitalWallet to an arbitrary JSON value.
You should usually call Builder.digitalWallet with a well-typed DigitalWallet value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealTimeDecision.DigitalWalletToken.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.DigitalWalletToken.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.DigitalWalletToken.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.DigitalWalletToken.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.DigitalWalletToken.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.DigitalWalletToken build()
Returns an immutable instance of DigitalWalletToken.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardId() .cardProfileId() .decision() .device() .digitalWallet()
-
-
-
-