Class RealTimePaymentsTransfer
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransferReal-Time Payments transfers move funds, within seconds, between your Increase account and any other account on the Real-Time Payments network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.BuilderA builder for RealTimePaymentsTransfer.
public final classRealTimePaymentsTransfer.AcknowledgementIf the transfer is acknowledged by the recipient bank, this will contain supplemental details.
public final classRealTimePaymentsTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classRealTimePaymentsTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classRealTimePaymentsTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classRealTimePaymentsTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.public final classRealTimePaymentsTransfer.RejectionIf the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
public final classRealTimePaymentsTransfer.StatusThe lifecycle status of the transfer.
public final classRealTimePaymentsTransfer.SubmissionAfter the transfer is submitted to Real-Time Payments, this will contain supplemental details.
public final classRealTimePaymentsTransfer.TypeA constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Real-Time Payments Transfer's identifier. final StringaccountId()The Account from which the transfer was sent. final StringaccountNumber()The destination account number. final Optional<RealTimePaymentsTransfer.Acknowledgement>acknowledgement()If the transfer is acknowledged by the recipient bank, this will contain supplemental details. final Longamount()The transfer amount in USD cents. final Optional<RealTimePaymentsTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<RealTimePaymentsTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<RealTimePaymentsTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final StringcreditorName()The name of the transfer's recipient. final RealTimePaymentsTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final Optional<String>debtorName()The name of the transfer's sender. final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<RealTimePaymentsTransfer.Rejection>rejection()If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details. final StringroutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final StringsourceAccountNumberId()The Account Number the recipient will see as having sent the transfer. final RealTimePaymentsTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<RealTimePaymentsTransfer.Submission>submission()After the transfer is submitted to Real-Time Payments, this will contain supplemental details. final Optional<String>transactionId()The Transaction funding the transfer once it is complete. final RealTimePaymentsTransfer.Typetype()A constant representing the object's type. final Optional<String>ultimateCreditorName()The name of the ultimate recipient of the transfer. final Optional<String>ultimateDebtorName()The name of the ultimate sender of the transfer. final StringunstructuredRemittanceInformation()Unstructured information that will show on the recipient's bank statement. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<RealTimePaymentsTransfer.Acknowledgement>_acknowledgement()Returns the raw JSON value of acknowledgement. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<RealTimePaymentsTransfer.Approval>_approval()Returns the raw JSON value of approval. final JsonField<RealTimePaymentsTransfer.Cancellation>_cancellation()Returns the raw JSON value of cancellation. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<RealTimePaymentsTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<RealTimePaymentsTransfer.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<RealTimePaymentsTransfer.Rejection>_rejection()Returns the raw JSON value of rejection. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<RealTimePaymentsTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<RealTimePaymentsTransfer.Submission>_submission()Returns the raw JSON value of submission. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<RealTimePaymentsTransfer.Type>_type()Returns the raw JSON value of type. final JsonField<String>_ultimateCreditorName()Returns the raw JSON value of ultimateCreditorName. final JsonField<String>_ultimateDebtorName()Returns the raw JSON value of ultimateDebtorName. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransfer.BuildertoBuilder()final RealTimePaymentsTransfervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of RealTimePaymentsTransfer. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
acknowledgement
final Optional<RealTimePaymentsTransfer.Acknowledgement> acknowledgement()
If the transfer is acknowledged by the recipient bank, this will contain supplemental details.
-
approval
final Optional<RealTimePaymentsTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
cancellation
final Optional<RealTimePaymentsTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<RealTimePaymentsTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
creditorName
final String creditorName()
The name of the transfer's recipient. This is set by the sender when creating the transfer.
-
currency
final RealTimePaymentsTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For real-time payments transfers this is always equal to
USD.
-
debtorName
final Optional<String> debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
rejection
final Optional<RealTimePaymentsTransfer.Rejection> rejection()
If the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
routingNumber
final String routingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number the recipient will see as having sent the transfer.
-
status
final RealTimePaymentsTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<RealTimePaymentsTransfer.Submission> submission()
After the transfer is submitted to Real-Time Payments, this will contain supplemental details.
-
transactionId
final Optional<String> transactionId()
The Transaction funding the transfer once it is complete.
-
type
final RealTimePaymentsTransfer.Type type()
A constant representing the object's type. For this resource it will always be
real_time_payments_transfer.
-
ultimateCreditorName
final Optional<String> ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final Optional<String> ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_acknowledgement
final JsonField<RealTimePaymentsTransfer.Acknowledgement> _acknowledgement()
Returns the raw JSON value of acknowledgement.
Unlike acknowledgement, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_approval
final JsonField<RealTimePaymentsTransfer.Approval> _approval()
Returns the raw JSON value of approval.
Unlike approval, this method doesn't throw if the JSON field has an unexpected type.
-
_cancellation
final JsonField<RealTimePaymentsTransfer.Cancellation> _cancellation()
Returns the raw JSON value of cancellation.
Unlike cancellation, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<RealTimePaymentsTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<RealTimePaymentsTransfer.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_rejection
final JsonField<RealTimePaymentsTransfer.Rejection> _rejection()
Returns the raw JSON value of rejection.
Unlike rejection, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RealTimePaymentsTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<RealTimePaymentsTransfer.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RealTimePaymentsTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_ultimateCreditorName
final JsonField<String> _ultimateCreditorName()
Returns the raw JSON value of ultimateCreditorName.
Unlike ultimateCreditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_ultimateDebtorName
final JsonField<String> _ultimateDebtorName()
Returns the raw JSON value of ultimateDebtorName.
Unlike ultimateDebtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimePaymentsTransfer.Builder toBuilder()
-
validate
final RealTimePaymentsTransfer validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealTimePaymentsTransfer.Builder builder()
Returns a mutable builder for constructing an instance of RealTimePaymentsTransfer.
The following fields are required:
.id() .accountId() .accountNumber() .acknowledgement() .amount() .approval() .cancellation() .createdAt() .createdBy() .creditorName() .currency() .debtorName() .externalAccountId() .idempotencyKey() .pendingTransactionId() .rejection() .routingNumber() .sourceAccountNumberId() .status() .submission() .transactionId() .type() .ultimateCreditorName() .ultimateDebtorName() .unstructuredRemittanceInformation()
-
-
-
-