Class RealTimePaymentsTransfer.Rejection
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransfer.RejectionIf the transfer is rejected by Real-Time Payments or the destination financial institution, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransfer.Rejection.BuilderA builder for Rejection.
public final classRealTimePaymentsTransfer.Rejection.RejectReasonCodeThe reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network.
-
Method Summary
-
-
Method Detail
-
rejectReasonAdditionalInformation
final Optional<String> rejectReasonAdditionalInformation()
Additional information about the rejection provided by the recipient bank when the
reject_reason_codeisNARRATIVE.
-
rejectReasonCode
final RealTimePaymentsTransfer.Rejection.RejectReasonCode rejectReasonCode()
The reason the transfer was rejected as provided by the recipient bank or the Real-Time Payments network.
-
rejectedAt
final Optional<OffsetDateTime> rejectedAt()
The ISO 8601 date and time at which the transfer was rejected.
-
_rejectReasonAdditionalInformation
final JsonField<String> _rejectReasonAdditionalInformation()
Returns the raw JSON value of rejectReasonAdditionalInformation.
Unlike rejectReasonAdditionalInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectReasonCode
final JsonField<RealTimePaymentsTransfer.Rejection.RejectReasonCode> _rejectReasonCode()
Returns the raw JSON value of rejectReasonCode.
Unlike rejectReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
Returns the raw JSON value of rejectedAt.
Unlike rejectedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimePaymentsTransfer.Rejection.Builder toBuilder()
-
validate
final RealTimePaymentsTransfer.Rejection validate()
-
builder
final static RealTimePaymentsTransfer.Rejection.Builder builder()
Returns a mutable builder for constructing an instance of Rejection.
The following fields are required:
.rejectReasonAdditionalInformation() .rejectReasonCode() .rejectedAt()
-
-
-
-