Enum RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value extends Enum<RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value>
An enum containing RejectReasonCode's known values, as well as an _UNKNOWN member.
An instance of RejectReasonCode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_CLOSEDThe destination account is closed. Corresponds to the Real-Time Payments reason code
AC04.ACCOUNT_BLOCKEDThe destination account is currently blocked from receiving transactions. Corresponds to the Real-Time Payments reason code
AC06.INVALID_CREDITOR_ACCOUNT_TYPEThe destination account is ineligible to receive Real-Time Payments transfers. Corresponds to the Real-Time Payments reason code
AC14.INVALID_CREDITOR_ACCOUNT_NUMBERThe destination account does not exist. Corresponds to the Real-Time Payments reason code
AC03.INVALID_CREDITOR_FINANCIAL_INSTITUTION_IDENTIFIERThe destination routing number is invalid. Corresponds to the Real-Time Payments reason code
RC04.END_CUSTOMER_DECEASEDThe destination account holder is deceased. Corresponds to the Real-Time Payments reason code
MD07.NARRATIVEThe reason is provided as narrative information in the additional information field.
TRANSACTION_FORBIDDENReal-Time Payments transfers are not allowed to the destination account. Corresponds to the Real-Time Payments reason code
AG01.TRANSACTION_TYPE_NOT_SUPPORTEDReal-Time Payments transfers are not enabled for the destination account. Corresponds to the Real-Time Payments reason code
AG03.UNEXPECTED_AMOUNTThe amount of the transfer is different than expected by the recipient. Corresponds to the Real-Time Payments reason code
AM09.AMOUNT_EXCEEDS_BANK_LIMITSThe amount is higher than the recipient is authorized to send or receive. Corresponds to the Real-Time Payments reason code
AM14.INVALID_CREDITOR_ADDRESSThe creditor's address is required, but missing or invalid. Corresponds to the Real-Time Payments reason code
BE04.UNKNOWN_END_CUSTOMERThe specified creditor is unknown. Corresponds to the Real-Time Payments reason code
BE06.INVALID_DEBTOR_ADDRESSThe debtor's address is required, but missing or invalid. Corresponds to the Real-Time Payments reason code
BE07.TIMEOUTThere was a timeout processing the transfer. Corresponds to the Real-Time Payments reason code
DS24.UNSUPPORTED_MESSAGE_FOR_RECIPIENTReal-Time Payments transfers are not enabled for the destination account. Corresponds to the Real-Time Payments reason code
NOAT.RECIPIENT_CONNECTION_NOT_AVAILABLEThe destination financial institution is currently not connected to Real-Time Payments. Corresponds to the Real-Time Payments reason code
9912.REAL_TIME_PAYMENTS_SUSPENDEDReal-Time Payments is currently unavailable. Corresponds to the Real-Time Payments reason code
9948.INSTRUCTED_AGENT_SIGNED_OFFThe destination financial institution is currently signed off of Real-Time Payments. Corresponds to the Real-Time Payments reason code
9910.PROCESSING_ERRORThe transfer was rejected due to an internal Increase issue. We have been notified.
OTHERSome other error or issue has occurred.
_UNKNOWNAn enum member indicating that RejectReasonCode was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final RealTimePaymentsTransfer.Rejection.RejectReasonCode.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value>getEntries()An enum containing RejectReasonCode's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<RealTimePaymentsTransfer.Rejection.RejectReasonCode.Value> getEntries()
An enum containing RejectReasonCode's known values, as well as an _UNKNOWN member.
An instance of RejectReasonCode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-