Class RealTimePaymentsTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class RealTimePaymentsTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringcreditorName()The name of the transfer's recipient. final StringremittanceInformation()Unstructured information that will show on the recipient's bank statement. final StringsourceAccountNumberId()The identifier of the Account Number from which to send the transfer. final Optional<String>debtorName()The name of the transfer's sender. final Optional<String>destinationAccountNumber()The destination account number. final Optional<String>destinationRoutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>ultimateCreditorName()The name of the ultimate recipient of the transfer. final Optional<String>ultimateDebtorName()The name of the ultimate sender of the transfer. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_remittanceInformation()Returns the raw JSON value of remittanceInformation. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_destinationAccountNumber()Returns the raw JSON value of destinationAccountNumber. final JsonField<String>_destinationRoutingNumber()Returns the raw JSON value of destinationRoutingNumber. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_ultimateCreditorName()Returns the raw JSON value of ultimateCreditorName. final JsonField<String>_ultimateDebtorName()Returns the raw JSON value of ultimateDebtorName. final Map<String, JsonValue>_additionalProperties()final RealTimePaymentsTransferCreateParams.Body.BuildertoBuilder()final RealTimePaymentsTransferCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransferCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
amount
final Long amount()
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
-
creditorName
final String creditorName()
The name of the transfer's recipient.
-
remittanceInformation
final String remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer.
-
debtorName
final Optional<String> debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
destinationAccountNumber
final Optional<String> destinationAccountNumber()
The destination account number.
-
destinationRoutingNumber
final Optional<String> destinationRoutingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
destination_account_numberanddestination_routing_numbermust be absent.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
ultimateCreditorName
final Optional<String> ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final Optional<String> ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Returns the raw JSON value of remittanceInformation.
Unlike remittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountNumber
final JsonField<String> _destinationAccountNumber()
Returns the raw JSON value of destinationAccountNumber.
Unlike destinationAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationRoutingNumber
final JsonField<String> _destinationRoutingNumber()
Returns the raw JSON value of destinationRoutingNumber.
Unlike destinationRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_ultimateCreditorName
final JsonField<String> _ultimateCreditorName()
Returns the raw JSON value of ultimateCreditorName.
Unlike ultimateCreditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_ultimateDebtorName
final JsonField<String> _ultimateDebtorName()
Returns the raw JSON value of ultimateDebtorName.
Unlike ultimateDebtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimePaymentsTransferCreateParams.Body.Builder toBuilder()
-
validate
final RealTimePaymentsTransferCreateParams.Body validate()
-
builder
final static RealTimePaymentsTransferCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .creditorName() .remittanceInformation() .sourceAccountNumberId()
-
-
-
-