Class RoutingNumberListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class RoutingNumberListPageAsync implements PageAsync<RoutingNumberListResponse>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberListPageAsync.BuilderA builder for RoutingNumberListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<RoutingNumberListResponse>data()Delegates to RoutingNumberListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to RoutingNumberListPageResponse, but gracefully handles missing data. List<RoutingNumberListResponse>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final RoutingNumberListParamsnextPageParams()CompletableFuture<RoutingNumberListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<RoutingNumberListResponse>autoPager()final RoutingNumberListParamsparams()The parameters that were used to request this page. final RoutingNumberListPageResponseresponse()The response that this page was parsed from. final RoutingNumberListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RoutingNumberListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of RoutingNumberListPageAsync. -
-
Method Detail
-
data
final List<RoutingNumberListResponse> data()
Delegates to RoutingNumberListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to RoutingNumberListPageResponse, but gracefully handles missing data.
-
items
List<RoutingNumberListResponse> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final RoutingNumberListParams nextPageParams()
-
nextPage
CompletableFuture<RoutingNumberListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<RoutingNumberListResponse> autoPager()
-
params
final RoutingNumberListParams params()
The parameters that were used to request this page.
-
response
final RoutingNumberListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final RoutingNumberListPageAsync.Builder toBuilder()
-
builder
final static RoutingNumberListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of RoutingNumberListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-