Class RoutingNumberListPageResponse.Builder
-
- All Implemented Interfaces:
public final class RoutingNumberListPageResponse.BuilderA builder for RoutingNumberListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final RoutingNumberListPageResponse.Builder data(List<RoutingNumberListResponse> data)
The contents of the list.
-
data
final RoutingNumberListPageResponse.Builder data(JsonField<List<RoutingNumberListResponse>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<RoutingNumberListResponse>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final RoutingNumberListPageResponse.Builder addData(RoutingNumberListResponse data)
Adds a single RoutingNumberListResponse to Builder.data.
-
nextCursor
final RoutingNumberListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final RoutingNumberListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final RoutingNumberListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RoutingNumberListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RoutingNumberListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RoutingNumberListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RoutingNumberListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RoutingNumberListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RoutingNumberListPageResponse build()
Returns an immutable instance of RoutingNumberListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-