Class RoutingNumberListParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class RoutingNumberListParams
     implements Params
                        

    You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. Since routing numbers uniquely identify a bank, this will always return 0 or 1 entry. In Sandbox, the only valid routing number for this method is 110000000.