Class RoutingNumberListResponse
-
- All Implemented Interfaces:
public final class RoutingNumberListResponseA list of Routing Number objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberListResponse.BuilderA builder for RoutingNumberListResponse.
public final classRoutingNumberListResponse.DataRouting numbers are used to identify your bank in a financial transaction.
-
Method Summary
Modifier and Type Method Description final List<RoutingNumberListResponse.Data>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<RoutingNumberListResponse.Data>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final RoutingNumberListResponse.BuildertoBuilder()final RoutingNumberListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RoutingNumberListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RoutingNumberListResponse. -
-
Method Detail
-
data
final List<RoutingNumberListResponse.Data> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<RoutingNumberListResponse.Data>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RoutingNumberListResponse.Builder toBuilder()
-
validate
final RoutingNumberListResponse validate()
-
builder
final static RoutingNumberListResponse.Builder builder()
Returns a mutable builder for constructing an instance of RoutingNumberListResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-