Enum RoutingNumberListResponse.FednowTransfers.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum RoutingNumberListResponse.FednowTransfers.Known extends Enum<RoutingNumberListResponse.FednowTransfers.Known>
An enum containing FednowTransfers's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<RoutingNumberListResponse.FednowTransfers.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description SUPPORTEDThe routing number can receive this transfer type.
NOT_SUPPORTEDThe routing number cannot receive this transfer type.
-
Method Summary
Modifier and Type Method Description final RoutingNumberListResponse.FednowTransfers.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<RoutingNumberListResponse.FednowTransfers.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<RoutingNumberListResponse.FednowTransfers.Known>getEntries()An enum containing FednowTransfers's known values. -
-
Method Detail
-
valueOf
final RoutingNumberListResponse.FednowTransfers.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<RoutingNumberListResponse.FednowTransfers.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<RoutingNumberListResponse.FednowTransfers.Known> getEntries()
An enum containing FednowTransfers's known values.
-
-
-
-