Enum RoutingNumberListResponse.FednowTransfers.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum RoutingNumberListResponse.FednowTransfers.Value extends Enum<RoutingNumberListResponse.FednowTransfers.Value>
An enum containing FednowTransfers's known values, as well as an _UNKNOWN member.
An instance of FednowTransfers can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<RoutingNumberListResponse.FednowTransfers.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description SUPPORTEDThe routing number can receive this transfer type.
NOT_SUPPORTEDThe routing number cannot receive this transfer type.
_UNKNOWNAn enum member indicating that FednowTransfers was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final RoutingNumberListResponse.FednowTransfers.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<RoutingNumberListResponse.FednowTransfers.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<RoutingNumberListResponse.FednowTransfers.Value>getEntries()An enum containing FednowTransfers's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final RoutingNumberListResponse.FednowTransfers.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<RoutingNumberListResponse.FednowTransfers.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<RoutingNumberListResponse.FednowTransfers.Value> getEntries()
An enum containing FednowTransfers's known values, as well as an _UNKNOWN member.
An instance of FednowTransfers can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-