Class AccountStatementCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountStatementCreateParams implements Params
Simulates an #account-statements being created for an account. In production, Account Statements are generated once per month.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementCreateParams.BuilderA builder for AccountStatementCreateParams.
public final classAccountStatementCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the statement is for. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountStatementCreateParams.BuildertoBuilder()final AccountStatementCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementCreateParams. -
-
Method Detail
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountStatementCreateParams.Builder toBuilder()
-
_body
final AccountStatementCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountStatementCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementCreateParams.
The following fields are required:
.accountId()
-
-
-
-