Class AchTransferCreateNotificationOfChangeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchTransferCreateNotificationOfChangeParams implements Params
Simulates receiving a Notification of Change for an #ach-transfers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateNotificationOfChangeParams.BuilderA builder for AchTransferCreateNotificationOfChangeParams.
public final classAchTransferCreateNotificationOfChangeParams.Bodypublic final classAchTransferCreateNotificationOfChangeParams.ChangeCodeThe reason for the notification of change.
-
Method Summary
Modifier and Type Method Description final Optional<String>achTransferId()The identifier of the ACH Transfer you wish to create a notification of change for. final AchTransferCreateNotificationOfChangeParams.ChangeCodechangeCode()The reason for the notification of change. final StringcorrectedData()The corrected data for the notification of change (e.g., a new routing number). final JsonField<AchTransferCreateNotificationOfChangeParams.ChangeCode>_changeCode()Returns the raw JSON value of changeCode. final JsonField<String>_correctedData()Returns the raw JSON value of correctedData. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final AchTransferCreateNotificationOfChangeParams.BuildertoBuilder()final AchTransferCreateNotificationOfChangeParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferCreateNotificationOfChangeParams.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransferCreateNotificationOfChangeParams. -
-
Method Detail
-
achTransferId
final Optional<String> achTransferId()
The identifier of the ACH Transfer you wish to create a notification of change for.
-
changeCode
final AchTransferCreateNotificationOfChangeParams.ChangeCode changeCode()
The reason for the notification of change.
-
correctedData
final String correctedData()
The corrected data for the notification of change (e.g., a new routing number).
-
_changeCode
final JsonField<AchTransferCreateNotificationOfChangeParams.ChangeCode> _changeCode()
Returns the raw JSON value of changeCode.
Unlike changeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedData
final JsonField<String> _correctedData()
Returns the raw JSON value of correctedData.
Unlike correctedData, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final AchTransferCreateNotificationOfChangeParams.Builder toBuilder()
-
_body
final AchTransferCreateNotificationOfChangeParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AchTransferCreateNotificationOfChangeParams.Builder builder()
Returns a mutable builder for constructing an instance of AchTransferCreateNotificationOfChangeParams.
The following fields are required:
.changeCode() .correctedData()
-
-
-
-