Class AchTransferCreateNotificationOfChangeParams.Body
-
- All Implemented Interfaces:
public final class AchTransferCreateNotificationOfChangeParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateNotificationOfChangeParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final AchTransferCreateNotificationOfChangeParams.ChangeCodechangeCode()The reason for the notification of change. final StringcorrectedData()The corrected data for the notification of change (e.g., a new routing number). final JsonField<AchTransferCreateNotificationOfChangeParams.ChangeCode>_changeCode()Returns the raw JSON value of changeCode. final JsonField<String>_correctedData()Returns the raw JSON value of correctedData. final Map<String, JsonValue>_additionalProperties()final AchTransferCreateNotificationOfChangeParams.Body.BuildertoBuilder()final AchTransferCreateNotificationOfChangeParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferCreateNotificationOfChangeParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
changeCode
final AchTransferCreateNotificationOfChangeParams.ChangeCode changeCode()
The reason for the notification of change.
-
correctedData
final String correctedData()
The corrected data for the notification of change (e.g., a new routing number).
-
_changeCode
final JsonField<AchTransferCreateNotificationOfChangeParams.ChangeCode> _changeCode()
Returns the raw JSON value of changeCode.
Unlike changeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedData
final JsonField<String> _correctedData()
Returns the raw JSON value of correctedData.
Unlike correctedData, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransferCreateNotificationOfChangeParams.Body.Builder toBuilder()
-
validate
final AchTransferCreateNotificationOfChangeParams.Body validate()
-
builder
final static AchTransferCreateNotificationOfChangeParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.changeCode() .correctedData()
-
-
-
-