Class AchTransferSubmitParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchTransferSubmitParams implements Params
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferSubmitParams.BuilderA builder for AchTransferSubmitParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>achTransferId()The identifier of the ACH Transfer you wish to submit. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final AchTransferSubmitParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferSubmitParamsnone()final static AchTransferSubmitParams.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransferSubmitParams. -
-
Method Detail
-
achTransferId
final Optional<String> achTransferId()
The identifier of the ACH Transfer you wish to submit.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final AchTransferSubmitParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AchTransferSubmitParams none()
-
builder
final static AchTransferSubmitParams.Builder builder()
Returns a mutable builder for constructing an instance of AchTransferSubmitParams.
-
-
-
-