Class CardAuthenticationChallengeAttemptsParams.Body
-
- All Implemented Interfaces:
public final class CardAuthenticationChallengeAttemptsParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthenticationChallengeAttemptsParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringoneTimeCode()The one-time code to be validated. final JsonField<String>_oneTimeCode()Returns the raw JSON value of oneTimeCode. final Map<String, JsonValue>_additionalProperties()final CardAuthenticationChallengeAttemptsParams.Body.BuildertoBuilder()final CardAuthenticationChallengeAttemptsParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthenticationChallengeAttemptsParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
oneTimeCode
final String oneTimeCode()
The one-time code to be validated.
-
_oneTimeCode
final JsonField<String> _oneTimeCode()
Returns the raw JSON value of oneTimeCode.
Unlike oneTimeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthenticationChallengeAttemptsParams.Body.Builder toBuilder()
-
validate
final CardAuthenticationChallengeAttemptsParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthenticationChallengeAttemptsParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.oneTimeCode()
-
-
-
-