Class CardAuthenticationChallengeAttemptsParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardAuthenticationChallengeAttemptsParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
oneTimeCode
final CardAuthenticationChallengeAttemptsParams.Body.Builder oneTimeCode(String oneTimeCode)
The one-time code to be validated.
-
oneTimeCode
final CardAuthenticationChallengeAttemptsParams.Body.Builder oneTimeCode(JsonField<String> oneTimeCode)
Sets Builder.oneTimeCode to an arbitrary JSON value.
You should usually call Builder.oneTimeCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthenticationChallengeAttemptsParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthenticationChallengeAttemptsParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthenticationChallengeAttemptsParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthenticationChallengeAttemptsParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthenticationChallengeAttemptsParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthenticationChallengeAttemptsParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.oneTimeCode()
-
-
-
-