Class CardAuthenticationChallengesParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardAuthenticationChallengesParams implements Params
Simulates starting a Card Authentication Challenge for an existing Card Authentication. This updates the
card_authenticationsobject under the #card_payments. To attempt the challenge, use the/simulations/card_authentications/:card_payment_id/challenge_attemptsendpoint or navigate to https://dashboard.increase.com/card_authentication_simulation/:card_payment_id.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthenticationChallengesParams.BuilderA builder for CardAuthenticationChallengesParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>cardPaymentId()The identifier of the Card Payment to be challenged. final Map<String, JsonValue>_additionalBodyProperties()Additional body properties to send with the request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardAuthenticationChallengesParams.BuildertoBuilder()final Optional<Map<String, JsonValue>>_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthenticationChallengesParamsnone()final static CardAuthenticationChallengesParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthenticationChallengesParams. -
-
Method Detail
-
cardPaymentId
final Optional<String> cardPaymentId()
The identifier of the Card Payment to be challenged.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
Additional body properties to send with the request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardAuthenticationChallengesParams.Builder toBuilder()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardAuthenticationChallengesParams none()
-
builder
final static CardAuthenticationChallengesParams.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthenticationChallengesParams.
-
-
-
-