Class CardAuthenticationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardAuthenticationCreateParams implements Params
Simulates a Card Authentication attempt on a #cards. The attempt always results in a #card_payments being created, either with a status that allows further action or a terminal failed status.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthenticationCreateParams.BuilderA builder for CardAuthenticationCreateParams.
public final classCardAuthenticationCreateParams.Bodypublic final classCardAuthenticationCreateParams.CategoryThe category of the card authentication attempt.
public final classCardAuthenticationCreateParams.DeviceChannelThe device channel of the card authentication attempt.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to be authorized. final Optional<CardAuthenticationCreateParams.Category>category()The category of the card authentication attempt. final Optional<CardAuthenticationCreateParams.DeviceChannel>deviceChannel()The device channel of the card authentication attempt. final Optional<String>merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final Optional<String>merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCountry()The country the merchant resides in. final Optional<String>merchantName()The name of the merchant final Optional<Long>purchaseAmount()The purchase amount in cents. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<CardAuthenticationCreateParams.Category>_category()Returns the raw JSON value of category. final JsonField<CardAuthenticationCreateParams.DeviceChannel>_deviceChannel()Returns the raw JSON value of deviceChannel. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<Long>_purchaseAmount()Returns the raw JSON value of purchaseAmount. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardAuthenticationCreateParams.BuildertoBuilder()final CardAuthenticationCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthenticationCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthenticationCreateParams. -
-
Method Detail
-
category
final Optional<CardAuthenticationCreateParams.Category> category()
The category of the card authentication attempt.
-
deviceChannel
final Optional<CardAuthenticationCreateParams.DeviceChannel> deviceChannel()
The device channel of the card authentication attempt.
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Optional<String> merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantName
final Optional<String> merchantName()
The name of the merchant
-
purchaseAmount
final Optional<Long> purchaseAmount()
The purchase amount in cents.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<CardAuthenticationCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_deviceChannel
final JsonField<CardAuthenticationCreateParams.DeviceChannel> _deviceChannel()
Returns the raw JSON value of deviceChannel.
Unlike deviceChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseAmount
final JsonField<Long> _purchaseAmount()
Returns the raw JSON value of purchaseAmount.
Unlike purchaseAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardAuthenticationCreateParams.Builder toBuilder()
-
_body
final CardAuthenticationCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardAuthenticationCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthenticationCreateParams.
The following fields are required:
.cardId()
-
-
-
-