Class CardAuthenticationCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardAuthenticationCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
cardId
final CardAuthenticationCreateParams.Body.Builder cardId(String cardId)
The identifier of the Card to be authorized.
-
cardId
final CardAuthenticationCreateParams.Body.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final CardAuthenticationCreateParams.Body.Builder category(CardAuthenticationCreateParams.Category category)
The category of the card authentication attempt.
-
category
final CardAuthenticationCreateParams.Body.Builder category(JsonField<CardAuthenticationCreateParams.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
deviceChannel
final CardAuthenticationCreateParams.Body.Builder deviceChannel(CardAuthenticationCreateParams.DeviceChannel deviceChannel)
The device channel of the card authentication attempt.
-
deviceChannel
final CardAuthenticationCreateParams.Body.Builder deviceChannel(JsonField<CardAuthenticationCreateParams.DeviceChannel> deviceChannel)
Sets Builder.deviceChannel to an arbitrary JSON value.
You should usually call Builder.deviceChannel with a well-typed DeviceChannel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final CardAuthenticationCreateParams.Body.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardAuthenticationCreateParams.Body.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardAuthenticationCreateParams.Body.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardAuthenticationCreateParams.Body.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final CardAuthenticationCreateParams.Body.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardAuthenticationCreateParams.Body.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final CardAuthenticationCreateParams.Body.Builder merchantName(String merchantName)
The name of the merchant
-
merchantName
final CardAuthenticationCreateParams.Body.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseAmount
final CardAuthenticationCreateParams.Body.Builder purchaseAmount(Long purchaseAmount)
The purchase amount in cents.
-
purchaseAmount
final CardAuthenticationCreateParams.Body.Builder purchaseAmount(JsonField<Long> purchaseAmount)
Sets Builder.purchaseAmount to an arbitrary JSON value.
You should usually call Builder.purchaseAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthenticationCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthenticationCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthenticationCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthenticationCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthenticationCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthenticationCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.cardId()
-
-
-
-