Enum CardAuthenticationCreateParams.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardAuthenticationCreateParams.Category.Known extends Enum<CardAuthenticationCreateParams.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardAuthenticationCreateParams.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PAYMENT_AUTHENTICATIONThe authentication attempt is for a payment.
NON_PAYMENT_AUTHENTICATIONThe authentication attempt is not for a payment.
-
Method Summary
Modifier and Type Method Description final CardAuthenticationCreateParams.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardAuthenticationCreateParams.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardAuthenticationCreateParams.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final CardAuthenticationCreateParams.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardAuthenticationCreateParams.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardAuthenticationCreateParams.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-