Enum CardAuthenticationCreateParams.DeviceChannel.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardAuthenticationCreateParams.DeviceChannel.Known extends Enum<CardAuthenticationCreateParams.DeviceChannel.Known>
An enum containing DeviceChannel's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardAuthenticationCreateParams.DeviceChannel.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description APPThe authentication attempt was made from an app.
BROWSERThe authentication attempt was made from a browser.
THREE_DS_REQUESTOR_INITIATEDThe authentication attempt was initiated by the 3DS Requestor.
-
Method Summary
Modifier and Type Method Description final CardAuthenticationCreateParams.DeviceChannel.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardAuthenticationCreateParams.DeviceChannel.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardAuthenticationCreateParams.DeviceChannel.Known>getEntries()An enum containing DeviceChannel's known values. -
-
Method Detail
-
valueOf
final CardAuthenticationCreateParams.DeviceChannel.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardAuthenticationCreateParams.DeviceChannel.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardAuthenticationCreateParams.DeviceChannel.Known> getEntries()
An enum containing DeviceChannel's known values.
-
-
-
-