Enum CardAuthenticationCreateParams.DeviceChannel.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardAuthenticationCreateParams.DeviceChannel.Value extends Enum<CardAuthenticationCreateParams.DeviceChannel.Value>
An enum containing DeviceChannel's known values, as well as an _UNKNOWN member.
An instance of DeviceChannel can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardAuthenticationCreateParams.DeviceChannel.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description APPThe authentication attempt was made from an app.
BROWSERThe authentication attempt was made from a browser.
THREE_DS_REQUESTOR_INITIATEDThe authentication attempt was initiated by the 3DS Requestor.
_UNKNOWNAn enum member indicating that DeviceChannel was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardAuthenticationCreateParams.DeviceChannel.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardAuthenticationCreateParams.DeviceChannel.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardAuthenticationCreateParams.DeviceChannel.Value>getEntries()An enum containing DeviceChannel's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardAuthenticationCreateParams.DeviceChannel.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardAuthenticationCreateParams.DeviceChannel.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardAuthenticationCreateParams.DeviceChannel.Value> getEntries()
An enum containing DeviceChannel's known values, as well as an _UNKNOWN member.
An instance of DeviceChannel can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-