Class CardAuthorizationCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class CardAuthorizationCreateParams
     implements Params
                        

    Simulates a purchase authorization on a #cards. Depending on the balance available to the card and the amount submitted, the authorization activity will result in a #pending-transactions of type card_authorization or a #declined-transactions of type card_decline. You can pass either a Card id or a #digital-wallet-tokens id to simulate the two different ways purchases can be made.