Class CardAuthorizationCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final CardAuthorizationCreateParams.Body.Builder amount(Long amount)
The authorization amount in cents.
-
amount
final CardAuthorizationCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
authenticatedCardPaymentId
final CardAuthorizationCreateParams.Body.Builder authenticatedCardPaymentId(String authenticatedCardPaymentId)
The identifier of a Card Payment with a
card_authenticationif you want to simulate an authenticated authorization.
-
authenticatedCardPaymentId
final CardAuthorizationCreateParams.Body.Builder authenticatedCardPaymentId(JsonField<String> authenticatedCardPaymentId)
Sets Builder.authenticatedCardPaymentId to an arbitrary JSON value.
You should usually call Builder.authenticatedCardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final CardAuthorizationCreateParams.Body.Builder cardId(String cardId)
The identifier of the Card to be authorized.
-
cardId
final CardAuthorizationCreateParams.Body.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
declineReason
final CardAuthorizationCreateParams.Body.Builder declineReason(CardAuthorizationCreateParams.DeclineReason declineReason)
Forces a card decline with a specific reason. No real time decision will be sent.
-
declineReason
final CardAuthorizationCreateParams.Body.Builder declineReason(JsonField<CardAuthorizationCreateParams.DeclineReason> declineReason)
Sets Builder.declineReason to an arbitrary JSON value.
You should usually call Builder.declineReason with a well-typed DeclineReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenId
final CardAuthorizationCreateParams.Body.Builder digitalWalletTokenId(String digitalWalletTokenId)
The identifier of the Digital Wallet Token to be authorized.
-
digitalWalletTokenId
final CardAuthorizationCreateParams.Body.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
Sets Builder.digitalWalletTokenId to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventSubscriptionId
final CardAuthorizationCreateParams.Body.Builder eventSubscriptionId(String eventSubscriptionId)
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
eventSubscriptionId
final CardAuthorizationCreateParams.Body.Builder eventSubscriptionId(JsonField<String> eventSubscriptionId)
Sets Builder.eventSubscriptionId to an arbitrary JSON value.
You should usually call Builder.eventSubscriptionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final CardAuthorizationCreateParams.Body.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardAuthorizationCreateParams.Body.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardAuthorizationCreateParams.Body.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardAuthorizationCreateParams.Body.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCity
final CardAuthorizationCreateParams.Body.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final CardAuthorizationCreateParams.Body.Builder merchantCity(JsonField<String> merchantCity)
Sets Builder.merchantCity to an arbitrary JSON value.
You should usually call Builder.merchantCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final CardAuthorizationCreateParams.Body.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardAuthorizationCreateParams.Body.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantDescriptor
final CardAuthorizationCreateParams.Body.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final CardAuthorizationCreateParams.Body.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
Sets Builder.merchantDescriptor to an arbitrary JSON value.
You should usually call Builder.merchantDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final CardAuthorizationCreateParams.Body.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final CardAuthorizationCreateParams.Body.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkDetails
final CardAuthorizationCreateParams.Body.Builder networkDetails(CardAuthorizationCreateParams.NetworkDetails networkDetails)
Fields specific to a given card network.
-
networkDetails
final CardAuthorizationCreateParams.Body.Builder networkDetails(JsonField<CardAuthorizationCreateParams.NetworkDetails> networkDetails)
Sets Builder.networkDetails to an arbitrary JSON value.
You should usually call Builder.networkDetails with a well-typed NetworkDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final CardAuthorizationCreateParams.Body.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
networkRiskScore
final CardAuthorizationCreateParams.Body.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCardId
final CardAuthorizationCreateParams.Body.Builder physicalCardId(String physicalCardId)
The identifier of the Physical Card to be authorized.
-
physicalCardId
final CardAuthorizationCreateParams.Body.Builder physicalCardId(JsonField<String> physicalCardId)
Sets Builder.physicalCardId to an arbitrary JSON value.
You should usually call Builder.physicalCardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
processingCategory
final CardAuthorizationCreateParams.Body.Builder processingCategory(CardAuthorizationCreateParams.ProcessingCategory processingCategory)
Fields specific to a specific type of authorization, such as Automatic Fuel Dispensers, Refund Authorizations, or Cash Disbursements.
-
processingCategory
final CardAuthorizationCreateParams.Body.Builder processingCategory(JsonField<CardAuthorizationCreateParams.ProcessingCategory> processingCategory)
Sets Builder.processingCategory to an arbitrary JSON value.
You should usually call Builder.processingCategory with a well-typed ProcessingCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
terminalId
final CardAuthorizationCreateParams.Body.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final CardAuthorizationCreateParams.Body.Builder terminalId(JsonField<String> terminalId)
Sets Builder.terminalId to an arbitrary JSON value.
You should usually call Builder.terminalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount()
-
-
-
-