Class CardAuthorizationCreateParams.DeclineReason
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class CardAuthorizationCreateParams.DeclineReason implements EnumForces a card decline with a specific reason. No real time decision will be sent.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumCardAuthorizationCreateParams.DeclineReason.KnownAn enum containing DeclineReason's known values.
public enumCardAuthorizationCreateParams.DeclineReason.ValueAn enum containing DeclineReason's known values, as well as an _UNKNOWN member.
An instance of DeclineReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final CardAuthorizationCreateParams.DeclineReason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final CardAuthorizationCreateParams.DeclineReason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final CardAuthorizationCreateParams.DeclineReasonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationCreateParams.DeclineReasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final CardAuthorizationCreateParams.DeclineReason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final CardAuthorizationCreateParams.DeclineReason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final CardAuthorizationCreateParams.DeclineReason validate()
-
of
final static CardAuthorizationCreateParams.DeclineReason of(String value)
-
-
-
-