Class CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason implements EnumThe reason code for the stand-in processing.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumCardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason.KnownAn enum containing StandInProcessingReason's known values.
public enumCardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason.ValueAn enum containing StandInProcessingReason's known values, as well as an _UNKNOWN member.
An instance of StandInProcessingReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonISSUER_ERRORpublic final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonINVALID_PHYSICAL_CARDpublic final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonINVALID_CARDHOLDER_AUTHENTICATION_VERIFICATION_VALUEpublic final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonINTERNAL_VISA_ERRORpublic final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonMERCHANT_TRANSACTION_ADVISORY_SERVICE_AUTHENTICATION_REQUIREDpublic final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonPAYMENT_FRAUD_DISRUPTION_ACQUIRER_BLOCKpublic final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonOTHER
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReasonof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
of
final static CardAuthorizationCreateParams.NetworkDetails.Visa.StandInProcessingReason of(String value)
-
-
-
-