Class CardAuthorizationCreateResponse
-
- All Implemented Interfaces:
public final class CardAuthorizationCreateResponseThe results of a Card Authorization simulation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationCreateResponse.BuilderA builder for CardAuthorizationCreateResponse.
public final classCardAuthorizationCreateResponse.TypeA constant representing the object's type. For this resource it will always be
inbound_card_authorization_simulation_result.
-
Method Summary
Modifier and Type Method Description final Optional<DeclinedTransaction>declinedTransaction()If the authorization attempt fails, this will contain the resulting #declined-transactions object. final Optional<PendingTransaction>pendingTransaction()If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. final CardAuthorizationCreateResponse.Typetype()A constant representing the object's type. final JsonField<DeclinedTransaction>_declinedTransaction()Returns the raw JSON value of declinedTransaction. final JsonField<PendingTransaction>_pendingTransaction()Returns the raw JSON value of pendingTransaction. final JsonField<CardAuthorizationCreateResponse.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardAuthorizationCreateResponse.BuildertoBuilder()final CardAuthorizationCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthorizationCreateResponse. -
-
Method Detail
-
declinedTransaction
final Optional<DeclinedTransaction> declinedTransaction()
If the authorization attempt fails, this will contain the resulting #declined-transactions object. The Declined Transaction's
sourcewill be ofcategory: card_decline.
-
pendingTransaction
final Optional<PendingTransaction> pendingTransaction()
If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. The Pending Transaction's
sourcewill be ofcategory: card_authorization.
-
type
final CardAuthorizationCreateResponse.Type type()
A constant representing the object's type. For this resource it will always be
inbound_card_authorization_simulation_result.
-
_declinedTransaction
final JsonField<DeclinedTransaction> _declinedTransaction()
Returns the raw JSON value of declinedTransaction.
Unlike declinedTransaction, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransaction
final JsonField<PendingTransaction> _pendingTransaction()
Returns the raw JSON value of pendingTransaction.
Unlike pendingTransaction, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardAuthorizationCreateResponse.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthorizationCreateResponse.Builder toBuilder()
-
validate
final CardAuthorizationCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardAuthorizationCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationCreateResponse.
The following fields are required:
.declinedTransaction() .pendingTransaction() .type()
-
-
-
-