Class CardAuthorizationCreateResponse.Builder
-
- All Implemented Interfaces:
public final class CardAuthorizationCreateResponse.BuilderA builder for CardAuthorizationCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
declinedTransaction
final CardAuthorizationCreateResponse.Builder declinedTransaction(DeclinedTransaction declinedTransaction)
If the authorization attempt fails, this will contain the resulting #declined-transactions object. The Declined Transaction's
sourcewill be ofcategory: card_decline.
-
declinedTransaction
final CardAuthorizationCreateResponse.Builder declinedTransaction(Optional<DeclinedTransaction> declinedTransaction)
Alias for calling Builder.declinedTransaction with
declinedTransaction.orElse(null).
-
declinedTransaction
final CardAuthorizationCreateResponse.Builder declinedTransaction(JsonField<DeclinedTransaction> declinedTransaction)
Sets Builder.declinedTransaction to an arbitrary JSON value.
You should usually call Builder.declinedTransaction with a well-typed DeclinedTransaction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransaction
final CardAuthorizationCreateResponse.Builder pendingTransaction(PendingTransaction pendingTransaction)
If the authorization attempt succeeds, this will contain the resulting Pending Transaction object. The Pending Transaction's
sourcewill be ofcategory: card_authorization.
-
pendingTransaction
final CardAuthorizationCreateResponse.Builder pendingTransaction(Optional<PendingTransaction> pendingTransaction)
Alias for calling Builder.pendingTransaction with
pendingTransaction.orElse(null).
-
pendingTransaction
final CardAuthorizationCreateResponse.Builder pendingTransaction(JsonField<PendingTransaction> pendingTransaction)
Sets Builder.pendingTransaction to an arbitrary JSON value.
You should usually call Builder.pendingTransaction with a well-typed PendingTransaction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardAuthorizationCreateResponse.Builder type(CardAuthorizationCreateResponse.Type type)
A constant representing the object's type. For this resource it will always be
inbound_card_authorization_simulation_result.
-
type
final CardAuthorizationCreateResponse.Builder type(JsonField<CardAuthorizationCreateResponse.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardAuthorizationCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardAuthorizationCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardAuthorizationCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardAuthorizationCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardAuthorizationCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardAuthorizationCreateResponse build()
Returns an immutable instance of CardAuthorizationCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.declinedTransaction() .pendingTransaction() .type()
-
-
-
-