Class CardFuelConfirmationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardFuelConfirmationCreateParams implements Params
Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardFuelConfirmationCreateParams.BuilderA builder for CardFuelConfirmationCreateParams.
public final classCardFuelConfirmationCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the fuel_confirmation in minor units in the card authorization's currency. final StringcardPaymentId()The identifier of the Card Payment to create a fuel_confirmation on. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final CardFuelConfirmationCreateParams.BuildertoBuilder()final CardFuelConfirmationCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardFuelConfirmationCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardFuelConfirmationCreateParams. -
-
Method Detail
-
amount
final Long amount()
The amount of the fuel_confirmation in minor units in the card authorization's currency.
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a fuel_confirmation on.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final CardFuelConfirmationCreateParams.Builder toBuilder()
-
_body
final CardFuelConfirmationCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardFuelConfirmationCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardFuelConfirmationCreateParams.
The following fields are required:
.amount() .cardPaymentId()
-
-
-
-