Class CardIncrementCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardIncrementCreateParams implements Params
Simulates the increment of an authorization by a card acquirer. An authorization can be incremented multiple times.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardIncrementCreateParams.BuilderA builder for CardIncrementCreateParams.
public final classCardIncrementCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the increment in minor units in the card authorization's currency. final StringcardPaymentId()The identifier of the Card Payment to create an increment on. final Optional<String>eventSubscriptionId()The identifier of the Event Subscription to use. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<String>_eventSubscriptionId()Returns the raw JSON value of eventSubscriptionId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardIncrementCreateParams.BuildertoBuilder()final CardIncrementCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardIncrementCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardIncrementCreateParams. -
-
Method Detail
-
amount
final Long amount()
The amount of the increment in minor units in the card authorization's currency.
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create an increment on.
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_eventSubscriptionId
final JsonField<String> _eventSubscriptionId()
Returns the raw JSON value of eventSubscriptionId.
Unlike eventSubscriptionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardIncrementCreateParams.Builder toBuilder()
-
_body
final CardIncrementCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardIncrementCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardIncrementCreateParams.
The following fields are required:
.amount() .cardPaymentId()
-
-
-
-