Class CardIncrementCreateParams.Body
-
- All Implemented Interfaces:
public final class CardIncrementCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardIncrementCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the increment in minor units in the card authorization's currency. final StringcardPaymentId()The identifier of the Card Payment to create an increment on. final Optional<String>eventSubscriptionId()The identifier of the Event Subscription to use. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<String>_eventSubscriptionId()Returns the raw JSON value of eventSubscriptionId. final Map<String, JsonValue>_additionalProperties()final CardIncrementCreateParams.Body.BuildertoBuilder()final CardIncrementCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardIncrementCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
amount
final Long amount()
The amount of the increment in minor units in the card authorization's currency.
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create an increment on.
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_eventSubscriptionId
final JsonField<String> _eventSubscriptionId()
Returns the raw JSON value of eventSubscriptionId.
Unlike eventSubscriptionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardIncrementCreateParams.Body.Builder toBuilder()
-
validate
final CardIncrementCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardIncrementCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .cardPaymentId()
-
-
-
-