Class CardIncrementCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardIncrementCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final CardIncrementCreateParams.Body.Builder amount(Long amount)
The amount of the increment in minor units in the card authorization's currency.
-
amount
final CardIncrementCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final CardIncrementCreateParams.Body.Builder cardPaymentId(String cardPaymentId)
The identifier of the Card Payment to create an increment on.
-
cardPaymentId
final CardIncrementCreateParams.Body.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventSubscriptionId
final CardIncrementCreateParams.Body.Builder eventSubscriptionId(String eventSubscriptionId)
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
eventSubscriptionId
final CardIncrementCreateParams.Body.Builder eventSubscriptionId(JsonField<String> eventSubscriptionId)
Sets Builder.eventSubscriptionId to an arbitrary JSON value.
You should usually call Builder.eventSubscriptionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardIncrementCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardIncrementCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardIncrementCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardIncrementCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardIncrementCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardIncrementCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .cardPaymentId()
-
-
-
-