Class CardRefundCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardRefundCreateParams implements Params
Simulates refunding a card transaction. The full value of the original sandbox transaction is refunded.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRefundCreateParams.BuilderA builder for CardRefundCreateParams.
public final classCardRefundCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()The refund amount in cents. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction for the refund authorization. final Optional<String>transactionId()The identifier for the Transaction to refund. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardRefundCreateParams.BuildertoBuilder()final CardRefundCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRefundCreateParamsnone()final static CardRefundCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardRefundCreateParams. -
-
Method Detail
-
amount
final Optional<Long> amount()
The refund amount in cents. Pulled off the
pending_transactionor thetransactionif not provided.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction for the refund authorization. If this is provided,
transactionmust not be provided as a refund with a refund authorized can not be linked to a regular transaction.
-
transactionId
final Optional<String> transactionId()
The identifier for the Transaction to refund. The Transaction's source must have a category of card_settlement.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardRefundCreateParams.Builder toBuilder()
-
_body
final CardRefundCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardRefundCreateParams none()
-
builder
final static CardRefundCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardRefundCreateParams.
-
-
-
-