Class CardRefundCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CardRefundCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final CardRefundCreateParams.Body.Builder amount(Long amount)
The refund amount in cents. Pulled off the
pending_transactionor thetransactionif not provided.
-
amount
final CardRefundCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final CardRefundCreateParams.Body.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction for the refund authorization. If this is provided,
transactionmust not be provided as a refund with a refund authorized can not be linked to a regular transaction.
-
pendingTransactionId
final CardRefundCreateParams.Body.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final CardRefundCreateParams.Body.Builder transactionId(String transactionId)
The identifier for the Transaction to refund. The Transaction's source must have a category of card_settlement.
-
transactionId
final CardRefundCreateParams.Body.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardRefundCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardRefundCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardRefundCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardRefundCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardRefundCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardRefundCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-