Class CardReversalCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardReversalCreateParams implements Params
Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardReversalCreateParams.BuilderA builder for CardReversalCreateParams.
public final classCardReversalCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringcardPaymentId()The identifier of the Card Payment to create a reversal on. final Optional<Long>amount()The amount of the reversal in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final CardReversalCreateParams.BuildertoBuilder()final CardReversalCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardReversalCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardReversalCreateParams. -
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a reversal on.
-
amount
final Optional<Long> amount()
The amount of the reversal in minor units in the card authorization's currency. This defaults to the authorization amount.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final CardReversalCreateParams.Builder toBuilder()
-
_body
final CardReversalCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardReversalCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardReversalCreateParams.
The following fields are required:
.cardPaymentId()
-
-
-
-