Class CardReversalCreateParams.Body
-
- All Implemented Interfaces:
public final class CardReversalCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardReversalCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardPaymentId()The identifier of the Card Payment to create a reversal on. final Optional<Long>amount()The amount of the reversal in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalProperties()final CardReversalCreateParams.Body.BuildertoBuilder()final CardReversalCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardReversalCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a reversal on.
-
amount
final Optional<Long> amount()
The amount of the reversal in minor units in the card authorization's currency. This defaults to the authorization amount.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardReversalCreateParams.Body.Builder toBuilder()
-
validate
final CardReversalCreateParams.Body validate()
-
builder
final static CardReversalCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.cardPaymentId()
-
-
-
-