Class CardSettlementCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class CardSettlementCreateParams
     implements Params
                        

    Simulates the settlement of an authorization by a card acquirer. After a card authorization is created, the merchant will eventually send a settlement. This simulates that event, which may occur many days after the purchase in production. The amount settled can be different from the amount originally authorized, for example, when adding a tip to a restaurant bill.