Class CardSettlementCreateParams.Body
-
- All Implemented Interfaces:
public final class CardSettlementCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSettlementCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to create a settlement on. final StringpendingTransactionId()The identifier of the Pending Transaction for the Card Authorization you wish to settle. final Optional<Long>amount()The amount to be settled. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalProperties()final CardSettlementCreateParams.Body.BuildertoBuilder()final CardSettlementCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSettlementCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
pendingTransactionId
final String pendingTransactionId()
The identifier of the Pending Transaction for the Card Authorization you wish to settle.
-
amount
final Optional<Long> amount()
The amount to be settled. This defaults to the amount of the Pending Transaction being settled.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardSettlementCreateParams.Body.Builder toBuilder()
-
validate
final CardSettlementCreateParams.Body validate()
-
builder
final static CardSettlementCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.cardId() .pendingTransactionId()
-
-
-
-