Class CardTokenCreateParams.Body
-
- All Implemented Interfaces:
public final class CardTokenCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<CardTokenCreateParams.Capability>>capabilities()The capabilities of the outbound card token. final Optional<LocalDate>expiration()The expiration date of the card. final Optional<String>last4()The last 4 digits of the card number. final Optional<String>prefix()The prefix of the card number, usually the first 8 digits. final Optional<Long>primaryAccountNumberLength()The total length of the card number, including prefix and last4. final JsonField<List<CardTokenCreateParams.Capability>>_capabilities()Returns the raw JSON value of capabilities. final JsonField<LocalDate>_expiration()Returns the raw JSON value of expiration. final JsonField<String>_last4()Returns the raw JSON value of last4. final JsonField<String>_prefix()Returns the raw JSON value of prefix. final JsonField<Long>_primaryAccountNumberLength()Returns the raw JSON value of primaryAccountNumberLength. final Map<String, JsonValue>_additionalProperties()final CardTokenCreateParams.Body.BuildertoBuilder()final CardTokenCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
capabilities
final Optional<List<CardTokenCreateParams.Capability>> capabilities()
The capabilities of the outbound card token.
-
expiration
final Optional<LocalDate> expiration()
The expiration date of the card.
-
primaryAccountNumberLength
final Optional<Long> primaryAccountNumberLength()
The total length of the card number, including prefix and last4.
-
_capabilities
final JsonField<List<CardTokenCreateParams.Capability>> _capabilities()
Returns the raw JSON value of capabilities.
Unlike capabilities, this method doesn't throw if the JSON field has an unexpected type.
-
_expiration
final JsonField<LocalDate> _expiration()
Returns the raw JSON value of expiration.
Unlike expiration, this method doesn't throw if the JSON field has an unexpected type.
-
_last4
final JsonField<String> _last4()
Returns the raw JSON value of last4.
Unlike last4, this method doesn't throw if the JSON field has an unexpected type.
-
_prefix
final JsonField<String> _prefix()
Returns the raw JSON value of prefix.
Unlike prefix, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryAccountNumberLength
final JsonField<Long> _primaryAccountNumberLength()
Returns the raw JSON value of primaryAccountNumberLength.
Unlike primaryAccountNumberLength, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTokenCreateParams.Body.Builder toBuilder()
-
validate
final CardTokenCreateParams.Body validate()
-
builder
final static CardTokenCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-