Class CardTokenCreateParams.Capability
-
- All Implemented Interfaces:
public final class CardTokenCreateParams.Capability
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenCreateParams.Capability.BuilderA builder for Capability.
public final classCardTokenCreateParams.Capability.CrossBorderPushTransfersThe cross-border push transfers capability.
public final classCardTokenCreateParams.Capability.DomesticPushTransfersThe domestic push transfers capability.
public final classCardTokenCreateParams.Capability.RouteThe route of the capability.
-
Method Summary
-
-
Method Detail
-
crossBorderPushTransfers
final CardTokenCreateParams.Capability.CrossBorderPushTransfers crossBorderPushTransfers()
The cross-border push transfers capability.
-
domesticPushTransfers
final CardTokenCreateParams.Capability.DomesticPushTransfers domesticPushTransfers()
The domestic push transfers capability.
-
route
final CardTokenCreateParams.Capability.Route route()
The route of the capability.
-
_crossBorderPushTransfers
final JsonField<CardTokenCreateParams.Capability.CrossBorderPushTransfers> _crossBorderPushTransfers()
Returns the raw JSON value of crossBorderPushTransfers.
Unlike crossBorderPushTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_domesticPushTransfers
final JsonField<CardTokenCreateParams.Capability.DomesticPushTransfers> _domesticPushTransfers()
Returns the raw JSON value of domesticPushTransfers.
Unlike domesticPushTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_route
final JsonField<CardTokenCreateParams.Capability.Route> _route()
Returns the raw JSON value of route.
Unlike route, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTokenCreateParams.Capability.Builder toBuilder()
-
validate
final CardTokenCreateParams.Capability validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardTokenCreateParams.Capability.Builder builder()
Returns a mutable builder for constructing an instance of Capability.
The following fields are required:
.crossBorderPushTransfers() .domesticPushTransfers() .route()
-
-
-
-