Class CheckDepositSubmitParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CheckDepositSubmitParams implements Params
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositSubmitParams.BuilderA builder for CheckDepositSubmitParams.
public final classCheckDepositSubmitParams.Bodypublic final classCheckDepositSubmitParams.ScanIf set, the simulation will use these values for the check's scanned MICR data.
-
Method Summary
Modifier and Type Method Description final Optional<String>checkDepositId()The identifier of the Check Deposit you wish to submit. final Optional<CheckDepositSubmitParams.Scan>scan()If set, the simulation will use these values for the check's scanned MICR data. final JsonField<CheckDepositSubmitParams.Scan>_scan()Returns the raw JSON value of scan. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CheckDepositSubmitParams.BuildertoBuilder()final CheckDepositSubmitParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositSubmitParamsnone()final static CheckDepositSubmitParams.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDepositSubmitParams. -
-
Method Detail
-
checkDepositId
final Optional<String> checkDepositId()
The identifier of the Check Deposit you wish to submit.
-
scan
final Optional<CheckDepositSubmitParams.Scan> scan()
If set, the simulation will use these values for the check's scanned MICR data.
-
_scan
final JsonField<CheckDepositSubmitParams.Scan> _scan()
Returns the raw JSON value of scan.
Unlike scan, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CheckDepositSubmitParams.Builder toBuilder()
-
_body
final CheckDepositSubmitParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CheckDepositSubmitParams none()
-
builder
final static CheckDepositSubmitParams.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositSubmitParams.
-
-
-
-