Class CheckDepositSubmitParams.Scan
-
- All Implemented Interfaces:
public final class CheckDepositSubmitParams.ScanIf set, the simulation will use these values for the check's scanned MICR data. If not set, the simulation will use random values.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositSubmitParams.Scan.BuilderA builder for Scan.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number to be returned in the check deposit's scan data. final StringroutingNumber()The routing number to be returned in the check deposit's scan data. final Optional<String>auxiliaryOnUs()The auxiliary on-us data to be returned in the check deposit's scan data. final Optional<String>serialNumber()The serial number to be returned in the check deposit's scan data. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_auxiliaryOnUs()Returns the raw JSON value of auxiliaryOnUs. final JsonField<String>_serialNumber()Returns the raw JSON value of serialNumber. final Map<String, JsonValue>_additionalProperties()final CheckDepositSubmitParams.Scan.BuildertoBuilder()final CheckDepositSubmitParams.Scanvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositSubmitParams.Scan.Builderbuilder()Returns a mutable builder for constructing an instance of Scan. -
-
Method Detail
-
accountNumber
final String accountNumber()
The account number to be returned in the check deposit's scan data.
-
routingNumber
final String routingNumber()
The routing number to be returned in the check deposit's scan data.
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
The auxiliary on-us data to be returned in the check deposit's scan data. Auxiliary on-us is typically the check number for business checks.
-
serialNumber
final Optional<String> serialNumber()
The serial number to be returned in the check deposit's scan data. Serial number is typically the check number for consumer checks.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
Returns the raw JSON value of auxiliaryOnUs.
Unlike auxiliaryOnUs, this method doesn't throw if the JSON field has an unexpected type.
-
_serialNumber
final JsonField<String> _serialNumber()
Returns the raw JSON value of serialNumber.
Unlike serialNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDepositSubmitParams.Scan.Builder toBuilder()
-
validate
final CheckDepositSubmitParams.Scan validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CheckDepositSubmitParams.Scan.Builder builder()
Returns a mutable builder for constructing an instance of Scan.
The following fields are required:
.accountNumber() .routingNumber()
-
-
-
-