Class DigitalWalletTokenRequestCreateResponse
-
- All Implemented Interfaces:
public final class DigitalWalletTokenRequestCreateResponseThe results of a Digital Wallet Token simulation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenRequestCreateResponse.BuilderA builder for DigitalWalletTokenRequestCreateResponse.
public final classDigitalWalletTokenRequestCreateResponse.DeclineReasonIf the simulated tokenization attempt was declined, this field contains details as to why.
public final classDigitalWalletTokenRequestCreateResponse.TypeA constant representing the object's type. For this resource it will always be
inbound_digital_wallet_token_request_simulation_result.
-
Method Summary
Modifier and Type Method Description final Optional<DigitalWalletTokenRequestCreateResponse.DeclineReason>declineReason()If the simulated tokenization attempt was declined, this field contains details as to why. final Optional<String>digitalWalletTokenId()If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created. final DigitalWalletTokenRequestCreateResponse.Typetype()A constant representing the object's type. final JsonField<DigitalWalletTokenRequestCreateResponse.DeclineReason>_declineReason()Returns the raw JSON value of declineReason. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<DigitalWalletTokenRequestCreateResponse.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final DigitalWalletTokenRequestCreateResponse.BuildertoBuilder()final DigitalWalletTokenRequestCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DigitalWalletTokenRequestCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalWalletTokenRequestCreateResponse. -
-
Method Detail
-
declineReason
final Optional<DigitalWalletTokenRequestCreateResponse.DeclineReason> declineReason()
If the simulated tokenization attempt was declined, this field contains details as to why.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created.
-
type
final DigitalWalletTokenRequestCreateResponse.Type type()
A constant representing the object's type. For this resource it will always be
inbound_digital_wallet_token_request_simulation_result.
-
_declineReason
final JsonField<DigitalWalletTokenRequestCreateResponse.DeclineReason> _declineReason()
Returns the raw JSON value of declineReason.
Unlike declineReason, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<DigitalWalletTokenRequestCreateResponse.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DigitalWalletTokenRequestCreateResponse.Builder toBuilder()
-
validate
final DigitalWalletTokenRequestCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DigitalWalletTokenRequestCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletTokenRequestCreateResponse.
The following fields are required:
.declineReason() .digitalWalletTokenId() .type()
-
-
-
-