Class DigitalWalletTokenRequestCreateResponse.Builder
-
- All Implemented Interfaces:
public final class DigitalWalletTokenRequestCreateResponse.BuilderA builder for DigitalWalletTokenRequestCreateResponse.
-
-
Method Summary
-
-
Method Detail
-
declineReason
final DigitalWalletTokenRequestCreateResponse.Builder declineReason(DigitalWalletTokenRequestCreateResponse.DeclineReason declineReason)
If the simulated tokenization attempt was declined, this field contains details as to why.
-
declineReason
final DigitalWalletTokenRequestCreateResponse.Builder declineReason(Optional<DigitalWalletTokenRequestCreateResponse.DeclineReason> declineReason)
Alias for calling Builder.declineReason with
declineReason.orElse(null).
-
declineReason
final DigitalWalletTokenRequestCreateResponse.Builder declineReason(JsonField<DigitalWalletTokenRequestCreateResponse.DeclineReason> declineReason)
Sets Builder.declineReason to an arbitrary JSON value.
You should usually call Builder.declineReason with a well-typed DeclineReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenId
final DigitalWalletTokenRequestCreateResponse.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the simulated tokenization attempt was accepted, this field contains the id of the Digital Wallet Token that was created.
-
digitalWalletTokenId
final DigitalWalletTokenRequestCreateResponse.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
Alias for calling Builder.digitalWalletTokenId with
digitalWalletTokenId.orElse(null).
-
digitalWalletTokenId
final DigitalWalletTokenRequestCreateResponse.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
Sets Builder.digitalWalletTokenId to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final DigitalWalletTokenRequestCreateResponse.Builder type(DigitalWalletTokenRequestCreateResponse.Type type)
A constant representing the object's type. For this resource it will always be
inbound_digital_wallet_token_request_simulation_result.
-
type
final DigitalWalletTokenRequestCreateResponse.Builder type(JsonField<DigitalWalletTokenRequestCreateResponse.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final DigitalWalletTokenRequestCreateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final DigitalWalletTokenRequestCreateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final DigitalWalletTokenRequestCreateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final DigitalWalletTokenRequestCreateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final DigitalWalletTokenRequestCreateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final DigitalWalletTokenRequestCreateResponse build()
Returns an immutable instance of DigitalWalletTokenRequestCreateResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.declineReason() .digitalWalletTokenId() .type()
-
-
-
-