Class DocumentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class DocumentCreateParams implements Params
Simulates an tax document being created for an account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentCreateParams.BuilderA builder for DocumentCreateParams.
public final classDocumentCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the tax document is for. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final DocumentCreateParams.BuildertoBuilder()final DocumentCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentCreateParams. -
-
Method Detail
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final DocumentCreateParams.Builder toBuilder()
-
_body
final DocumentCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static DocumentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of DocumentCreateParams.
The following fields are required:
.accountId()
-
-
-
-