Class DocumentCreateParams.Body
-
- All Implemented Interfaces:
public final class DocumentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the tax document is for. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final Map<String, JsonValue>_additionalProperties()final DocumentCreateParams.Body.BuildertoBuilder()final DocumentCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DocumentCreateParams.Body.Builder toBuilder()
-
validate
final DocumentCreateParams.Body validate()
-
builder
final static DocumentCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId()
-
-
-
-