Class EntityUpdateValidationParams.Issue
-
- All Implemented Interfaces:
public final class EntityUpdateValidationParams.Issue
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateValidationParams.Issue.BuilderA builder for Issue.
public final classEntityUpdateValidationParams.Issue.CategoryThe type of issue.
-
Method Summary
Modifier and Type Method Description final EntityUpdateValidationParams.Issue.Categorycategory()The type of issue. final JsonField<EntityUpdateValidationParams.Issue.Category>_category()Returns the raw JSON value of category. final Map<String, JsonValue>_additionalProperties()final EntityUpdateValidationParams.Issue.BuildertoBuilder()final EntityUpdateValidationParams.Issuevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateValidationParams.Issue.Builderbuilder()Returns a mutable builder for constructing an instance of Issue. -
-
Method Detail
-
category
final EntityUpdateValidationParams.Issue.Category category()
The type of issue.
-
_category
final JsonField<EntityUpdateValidationParams.Issue.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateValidationParams.Issue.Builder toBuilder()
-
validate
final EntityUpdateValidationParams.Issue validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EntityUpdateValidationParams.Issue.Builder builder()
Returns a mutable builder for constructing an instance of Issue.
The following fields are required:
.category()
-
-
-
-