Class EntityValidationParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityValidationParams implements Params
Simulates setting an #entities's validation under the managed compliance regime. Any existing managed compliance validation on the Entity will be marked as no longer current.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityValidationParams.BuilderA builder for EntityValidationParams.
public final classEntityValidationParams.Bodypublic final classEntityValidationParams.Issuepublic final classEntityValidationParams.StatusThe status to set on the new managed compliance validation.
-
Method Summary
Modifier and Type Method Description final Optional<String>entityId()The identifier of the Entity to set the validation on. final List<EntityValidationParams.Issue>issues()The issues to attach to the new managed compliance validation. final EntityValidationParams.Statusstatus()The status to set on the new managed compliance validation. final JsonField<List<EntityValidationParams.Issue>>_issues()Returns the raw JSON value of issues. final JsonField<EntityValidationParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityValidationParams.BuildertoBuilder()final EntityValidationParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityValidationParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityValidationParams. -
-
Method Detail
-
issues
final List<EntityValidationParams.Issue> issues()
The issues to attach to the new managed compliance validation.
-
status
final EntityValidationParams.Status status()
The status to set on the new managed compliance validation.
-
_issues
final JsonField<List<EntityValidationParams.Issue>> _issues()
Returns the raw JSON value of issues.
Unlike issues, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<EntityValidationParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityValidationParams.Builder toBuilder()
-
_body
final EntityValidationParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityValidationParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityValidationParams.
The following fields are required:
.issues() .status()
-
-
-
-