Class ExportCreateParams

  • All Implemented Interfaces:
    com.increase.api.core.Params

    
    public final class ExportCreateParams
     implements Params
                        

    Many exports are created by you via POST /exports or in the Dashboard. Some exports are created automatically by Increase. For example, tax documents are published once a year. In sandbox, you can trigger the arrival of an export that would normally only be created automatically via this simulation.