Class ExportCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
category
final ExportCreateParams.Body.Builder category(ExportCreateParams.Category category)
The type of Export to create.
-
category
final ExportCreateParams.Body.Builder category(JsonField<ExportCreateParams.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
form1099Int
final ExportCreateParams.Body.Builder form1099Int(ExportCreateParams.Form1099Int form1099Int)
Options for the created export. Required if
categoryis equal toform_1099_int.
-
form1099Int
final ExportCreateParams.Body.Builder form1099Int(JsonField<ExportCreateParams.Form1099Int> form1099Int)
Sets Builder.form1099Int to an arbitrary JSON value.
You should usually call Builder.form1099Int with a well-typed Form1099Int value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category()
-
-
-
-