Class ExportCreateParams.Form1099Int
-
- All Implemented Interfaces:
public final class ExportCreateParams.Form1099IntOptions for the created export. Required if
categoryis equal toform_1099_int.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.Form1099Int.BuilderA builder for Form1099Int.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the tax document is for. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.Form1099Int.BuildertoBuilder()final ExportCreateParams.Form1099Intvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.Form1099Int.Builderbuilder()Returns a mutable builder for constructing an instance of Form1099Int. -
-
Method Detail
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.Form1099Int.Builder toBuilder()
-
validate
final ExportCreateParams.Form1099Int validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExportCreateParams.Form1099Int.Builder builder()
Returns a mutable builder for constructing an instance of Form1099Int.
The following fields are required:
.accountId()
-
-
-
-