Class ExportCreateParams.Form1099Int.Builder
-
- All Implemented Interfaces:
public final class ExportCreateParams.Form1099Int.BuilderA builder for Form1099Int.
-
-
Method Summary
Modifier and Type Method Description final ExportCreateParams.Form1099Int.BuilderaccountId(String accountId)The identifier of the Account the tax document is for. final ExportCreateParams.Form1099Int.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final ExportCreateParams.Form1099Int.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ExportCreateParams.Form1099Int.BuilderputAdditionalProperty(String key, JsonValue value)final ExportCreateParams.Form1099Int.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ExportCreateParams.Form1099Int.BuilderremoveAdditionalProperty(String key)final ExportCreateParams.Form1099Int.BuilderremoveAllAdditionalProperties(Set<String> keys)final ExportCreateParams.Form1099Intbuild()Returns an immutable instance of Form1099Int. -
-
Method Detail
-
accountId
final ExportCreateParams.Form1099Int.Builder accountId(String accountId)
The identifier of the Account the tax document is for.
-
accountId
final ExportCreateParams.Form1099Int.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExportCreateParams.Form1099Int.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExportCreateParams.Form1099Int.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExportCreateParams.Form1099Int.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExportCreateParams.Form1099Int.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExportCreateParams.Form1099Int.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExportCreateParams.Form1099Int build()
Returns an immutable instance of Form1099Int.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId()
-
-
-
-