Class InboundAchTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundAchTransferCreateParams implements Params
Simulates an inbound ACH transfer to your account. This imitates initiating a transfer to an Increase account from a different financial institution. The transfer may be either a credit or a debit depending on if the
amountis positive or negative. The result of calling this API will contain the created transfer. You can pass aresolve_atparameter to allow for a window to action on the Inbound ACH Transfer. Alternatively, if you don't pass theresolve_atparameter the result will contain either a #transactions or a #declined-transactions depending on whether or not the transfer is allowed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferCreateParams.BuilderA builder for InboundAchTransferCreateParams.
public final classInboundAchTransferCreateParams.Bodypublic final classInboundAchTransferCreateParams.AddendaAdditional information to include in the transfer.
public final classInboundAchTransferCreateParams.StandardEntryClassCodeThe standard entry class code for the transfer.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the inbound ACH Transfer is for. final Longamount()The transfer amount in cents. final Optional<InboundAchTransferCreateParams.Addenda>addenda()Additional information to include in the transfer. final Optional<String>companyDescriptiveDate()The description of the date of the transfer. final Optional<String>companyDiscretionaryData()Data associated with the transfer set by the sender. final Optional<String>companyEntryDescription()The description of the transfer set by the sender. final Optional<String>companyId()The sender's company ID. final Optional<String>companyName()The name of the sender. final Optional<String>receiverIdNumber()The ID of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final Optional<OffsetDateTime>resolveAt()The time at which the transfer should be resolved. final Optional<InboundAchTransferCreateParams.StandardEntryClassCode>standardEntryClassCode()The standard entry class code for the transfer. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<InboundAchTransferCreateParams.Addenda>_addenda()Returns the raw JSON value of addenda. final JsonField<String>_companyDescriptiveDate()Returns the raw JSON value of companyDescriptiveDate. final JsonField<String>_companyDiscretionaryData()Returns the raw JSON value of companyDiscretionaryData. final JsonField<String>_companyEntryDescription()Returns the raw JSON value of companyEntryDescription. final JsonField<String>_companyId()Returns the raw JSON value of companyId. final JsonField<String>_companyName()Returns the raw JSON value of companyName. final JsonField<String>_receiverIdNumber()Returns the raw JSON value of receiverIdNumber. final JsonField<String>_receiverName()Returns the raw JSON value of receiverName. final JsonField<OffsetDateTime>_resolveAt()Returns the raw JSON value of resolveAt. final JsonField<InboundAchTransferCreateParams.StandardEntryClassCode>_standardEntryClassCode()Returns the raw JSON value of standardEntryClassCode. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final InboundAchTransferCreateParams.BuildertoBuilder()final InboundAchTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundAchTransferCreateParams. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the inbound ACH Transfer is for.
-
amount
final Long amount()
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
addenda
final Optional<InboundAchTransferCreateParams.Addenda> addenda()
Additional information to include in the transfer.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
Data associated with the transfer set by the sender.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the transfer set by the sender.
-
companyName
final Optional<String> companyName()
The name of the sender.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The ID of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
resolveAt
final Optional<OffsetDateTime> resolveAt()
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
standardEntryClassCode
final Optional<InboundAchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode()
The standard entry class code for the transfer.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<InboundAchTransferCreateParams.Addenda> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
Returns the raw JSON value of companyDescriptiveDate.
Unlike companyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Returns the raw JSON value of companyDiscretionaryData.
Unlike companyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
Returns the raw JSON value of companyEntryDescription.
Unlike companyEntryDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_companyId
final JsonField<String> _companyId()
Returns the raw JSON value of companyId.
Unlike companyId, this method doesn't throw if the JSON field has an unexpected type.
-
_companyName
final JsonField<String> _companyName()
Returns the raw JSON value of companyName.
Unlike companyName, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
Returns the raw JSON value of receiverIdNumber.
Unlike receiverIdNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverName
final JsonField<String> _receiverName()
Returns the raw JSON value of receiverName.
Unlike receiverName, this method doesn't throw if the JSON field has an unexpected type.
-
_resolveAt
final JsonField<OffsetDateTime> _resolveAt()
Returns the raw JSON value of resolveAt.
Unlike resolveAt, this method doesn't throw if the JSON field has an unexpected type.
-
_standardEntryClassCode
final JsonField<InboundAchTransferCreateParams.StandardEntryClassCode> _standardEntryClassCode()
Returns the raw JSON value of standardEntryClassCode.
Unlike standardEntryClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final InboundAchTransferCreateParams.Builder toBuilder()
-
_body
final InboundAchTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundAchTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundAchTransferCreateParams.
The following fields are required:
.accountNumberId() .amount()
-
-
-
-