Class InboundAchTransferCreateParams.Addenda
-
- All Implemented Interfaces:
public final class InboundAchTransferCreateParams.AddendaAdditional information to include in the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferCreateParams.Addenda.BuilderA builder for Addenda.
public final classInboundAchTransferCreateParams.Addenda.CategoryThe type of addenda to simulate being sent with the transfer.
public final classInboundAchTransferCreateParams.Addenda.FreeformUnstructured
payment_related_informationpassed through with the transfer.
-
Method Summary
Modifier and Type Method Description final InboundAchTransferCreateParams.Addenda.Categorycategory()The type of addenda to simulate being sent with the transfer. final Optional<InboundAchTransferCreateParams.Addenda.Freeform>freeform()Unstructured payment_related_informationpassed through with the transfer.final JsonField<InboundAchTransferCreateParams.Addenda.Category>_category()Returns the raw JSON value of category. final JsonField<InboundAchTransferCreateParams.Addenda.Freeform>_freeform()Returns the raw JSON value of freeform. final Map<String, JsonValue>_additionalProperties()final InboundAchTransferCreateParams.Addenda.BuildertoBuilder()final InboundAchTransferCreateParams.Addendavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundAchTransferCreateParams.Addenda.Builderbuilder()Returns a mutable builder for constructing an instance of Addenda. -
-
Method Detail
-
category
final InboundAchTransferCreateParams.Addenda.Category category()
The type of addenda to simulate being sent with the transfer.
-
freeform
final Optional<InboundAchTransferCreateParams.Addenda.Freeform> freeform()
Unstructured
payment_related_informationpassed through with the transfer.
-
_category
final JsonField<InboundAchTransferCreateParams.Addenda.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_freeform
final JsonField<InboundAchTransferCreateParams.Addenda.Freeform> _freeform()
Returns the raw JSON value of freeform.
Unlike freeform, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundAchTransferCreateParams.Addenda.Builder toBuilder()
-
validate
final InboundAchTransferCreateParams.Addenda validate()
-
builder
final static InboundAchTransferCreateParams.Addenda.Builder builder()
Returns a mutable builder for constructing an instance of Addenda.
The following fields are required:
.category()
-
-
-
-