Class InboundCheckDepositCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundCheckDepositCreateParams implements Params
Simulates an Inbound Check Deposit against your account. This imitates someone depositing a check at their bank that was issued from your account. It may or may not be associated with a Check Transfer. Increase will evaluate the Inbound Check Deposit as we would in production and either create a Transaction or a Declined Transaction as a result. You can inspect the resulting Inbound Check Deposit object to see the result.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositCreateParams.BuilderA builder for InboundCheckDepositCreateParams.
public final classInboundCheckDepositCreateParams.Bodypublic final classInboundCheckDepositCreateParams.PayeeNameAnalysisSimulate the outcome of payee name checking. Defaults to
not_evaluated.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the Inbound Check Deposit will be against. final Longamount()The check amount in cents. final StringcheckNumber()The check number on the check to be deposited. final Optional<InboundCheckDepositCreateParams.PayeeNameAnalysis>payeeNameAnalysis()Simulate the outcome of payee name checking. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_checkNumber()Returns the raw JSON value of checkNumber. final JsonField<InboundCheckDepositCreateParams.PayeeNameAnalysis>_payeeNameAnalysis()Returns the raw JSON value of payeeNameAnalysis. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundCheckDepositCreateParams.BuildertoBuilder()final InboundCheckDepositCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDepositCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundCheckDepositCreateParams. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the Inbound Check Deposit will be against.
-
checkNumber
final String checkNumber()
The check number on the check to be deposited.
-
payeeNameAnalysis
final Optional<InboundCheckDepositCreateParams.PayeeNameAnalysis> payeeNameAnalysis()
Simulate the outcome of payee name checking. Defaults to
not_evaluated.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_payeeNameAnalysis
final JsonField<InboundCheckDepositCreateParams.PayeeNameAnalysis> _payeeNameAnalysis()
Returns the raw JSON value of payeeNameAnalysis.
Unlike payeeNameAnalysis, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundCheckDepositCreateParams.Builder toBuilder()
-
_body
final InboundCheckDepositCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundCheckDepositCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundCheckDepositCreateParams.
The following fields are required:
.accountNumberId() .amount() .checkNumber()
-
-
-
-