Class InboundCheckDepositCreateParams.Body
-
- All Implemented Interfaces:
public final class InboundCheckDepositCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositCreateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the Inbound Check Deposit will be against.
-
checkNumber
final String checkNumber()
The check number on the check to be deposited.
-
payeeNameAnalysis
final Optional<InboundCheckDepositCreateParams.PayeeNameAnalysis> payeeNameAnalysis()
Simulate the outcome of payee name checking. Defaults to
not_evaluated.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_payeeNameAnalysis
final JsonField<InboundCheckDepositCreateParams.PayeeNameAnalysis> _payeeNameAnalysis()
Returns the raw JSON value of payeeNameAnalysis.
Unlike payeeNameAnalysis, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundCheckDepositCreateParams.Body.Builder toBuilder()
-
validate
final InboundCheckDepositCreateParams.Body validate()
-
builder
final static InboundCheckDepositCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountNumberId() .amount() .checkNumber()
-
-
-
-