Class InboundMailItemCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboundMailItemCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final InboundMailItemCreateParams.Body.Builder amount(Long amount)
The amount of the check to be simulated, in cents.
-
amount
final InboundMailItemCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lockboxId
final InboundMailItemCreateParams.Body.Builder lockboxId(String lockboxId)
The identifier of the Lockbox to simulate inbound mail to.
-
lockboxId
final InboundMailItemCreateParams.Body.Builder lockboxId(JsonField<String> lockboxId)
Sets Builder.lockboxId to an arbitrary JSON value.
You should usually call Builder.lockboxId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contentsFileId
final InboundMailItemCreateParams.Body.Builder contentsFileId(String contentsFileId)
The file containing the PDF contents. If not present, a default check image file will be used.
-
contentsFileId
final InboundMailItemCreateParams.Body.Builder contentsFileId(JsonField<String> contentsFileId)
Sets Builder.contentsFileId to an arbitrary JSON value.
You should usually call Builder.contentsFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundMailItemCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundMailItemCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundMailItemCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundMailItemCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundMailItemCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundMailItemCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .lockboxId()
-
-
-
-