Class InboundWireDrawdownRequestCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundWireDrawdownRequestCreateParams implements Params
Simulates receiving an #inbound-wire-drawdown-requests.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestCreateParams.BuilderA builder for InboundWireDrawdownRequestCreateParams.
public final classInboundWireDrawdownRequestCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Longamount()The amount being requested in cents. final StringcreditorAccountNumber()The creditor's account number. final StringcreditorRoutingNumber()The creditor's routing number. final Stringcurrency()The ISO 4217 code for the amount being requested. final StringrecipientAccountNumberId()The Account Number to which the recipient of this request is being requested to send funds from. final Optional<String>creditorAddressLine1()A free-form address field set by the sender representing the first line of the creditor's address. final Optional<String>creditorAddressLine2()A free-form address field set by the sender representing the second line of the creditor's address. final Optional<String>creditorAddressLine3()A free-form address field set by the sender representing the third line of the creditor's address. final Optional<String>creditorName()A free-form name field set by the sender representing the creditor's name. final Optional<String>debtorAccountNumber()The debtor's account number. final Optional<String>debtorAddressLine1()A free-form address field set by the sender representing the first line of the debtor's address. final Optional<String>debtorAddressLine2()A free-form address field set by the sender representing the second line of the debtor's address. final Optional<String>debtorAddressLine3()A free-form address field set by the sender. final Optional<String>debtorName()A free-form name field set by the sender representing the debtor's name. final Optional<String>debtorRoutingNumber()The debtor's routing number. final Optional<String>endToEndIdentification()A free-form reference string set by the sender, to help identify the transfer. final Optional<String>instructionIdentification()The sending bank's identifier for the wire transfer. final Optional<String>uniqueEndToEndTransactionReference()The Unique End-to-end Transaction Reference (UETR) of the transfer. final Optional<String>unstructuredRemittanceInformation()A free-form message set by the sender. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorAccountNumber()Returns the raw JSON value of creditorAccountNumber. final JsonField<String>_creditorRoutingNumber()Returns the raw JSON value of creditorRoutingNumber. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_recipientAccountNumberId()Returns the raw JSON value of recipientAccountNumberId. final JsonField<String>_creditorAddressLine1()Returns the raw JSON value of creditorAddressLine1. final JsonField<String>_creditorAddressLine2()Returns the raw JSON value of creditorAddressLine2. final JsonField<String>_creditorAddressLine3()Returns the raw JSON value of creditorAddressLine3. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_debtorAccountNumber()Returns the raw JSON value of debtorAccountNumber. final JsonField<String>_debtorAddressLine1()Returns the raw JSON value of debtorAddressLine1. final JsonField<String>_debtorAddressLine2()Returns the raw JSON value of debtorAddressLine2. final JsonField<String>_debtorAddressLine3()Returns the raw JSON value of debtorAddressLine3. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final JsonField<String>_instructionIdentification()Returns the raw JSON value of instructionIdentification. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundWireDrawdownRequestCreateParams.BuildertoBuilder()final InboundWireDrawdownRequestCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequestCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestCreateParams. -
-
Method Detail
-
creditorAccountNumber
final String creditorAccountNumber()
The creditor's account number.
-
creditorRoutingNumber
final String creditorRoutingNumber()
The creditor's routing number.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
recipientAccountNumberId
final String recipientAccountNumberId()
The Account Number to which the recipient of this request is being requested to send funds from.
-
creditorAddressLine1
final Optional<String> creditorAddressLine1()
A free-form address field set by the sender representing the first line of the creditor's address.
-
creditorAddressLine2
final Optional<String> creditorAddressLine2()
A free-form address field set by the sender representing the second line of the creditor's address.
-
creditorAddressLine3
final Optional<String> creditorAddressLine3()
A free-form address field set by the sender representing the third line of the creditor's address.
-
creditorName
final Optional<String> creditorName()
A free-form name field set by the sender representing the creditor's name.
-
debtorAccountNumber
final Optional<String> debtorAccountNumber()
The debtor's account number.
-
debtorAddressLine1
final Optional<String> debtorAddressLine1()
A free-form address field set by the sender representing the first line of the debtor's address.
-
debtorAddressLine2
final Optional<String> debtorAddressLine2()
A free-form address field set by the sender representing the second line of the debtor's address.
-
debtorAddressLine3
final Optional<String> debtorAddressLine3()
A free-form address field set by the sender.
-
debtorName
final Optional<String> debtorName()
A free-form name field set by the sender representing the debtor's name.
-
debtorRoutingNumber
final Optional<String> debtorRoutingNumber()
The debtor's routing number.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender, to help identify the transfer.
-
instructionIdentification
final Optional<String> instructionIdentification()
The sending bank's identifier for the wire transfer.
-
uniqueEndToEndTransactionReference
final Optional<String> uniqueEndToEndTransactionReference()
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
unstructuredRemittanceInformation
final Optional<String> unstructuredRemittanceInformation()
A free-form message set by the sender.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAccountNumber
final JsonField<String> _creditorAccountNumber()
Returns the raw JSON value of creditorAccountNumber.
Unlike creditorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorRoutingNumber
final JsonField<String> _creditorRoutingNumber()
Returns the raw JSON value of creditorRoutingNumber.
Unlike creditorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAccountNumberId
final JsonField<String> _recipientAccountNumberId()
Returns the raw JSON value of recipientAccountNumberId.
Unlike recipientAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine1
final JsonField<String> _creditorAddressLine1()
Returns the raw JSON value of creditorAddressLine1.
Unlike creditorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine2
final JsonField<String> _creditorAddressLine2()
Returns the raw JSON value of creditorAddressLine2.
Unlike creditorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine3
final JsonField<String> _creditorAddressLine3()
Returns the raw JSON value of creditorAddressLine3.
Unlike creditorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
Returns the raw JSON value of debtorAccountNumber.
Unlike debtorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine1
final JsonField<String> _debtorAddressLine1()
Returns the raw JSON value of debtorAddressLine1.
Unlike debtorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine2
final JsonField<String> _debtorAddressLine2()
Returns the raw JSON value of debtorAddressLine2.
Unlike debtorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine3
final JsonField<String> _debtorAddressLine3()
Returns the raw JSON value of debtorAddressLine3.
Unlike debtorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_instructionIdentification
final JsonField<String> _instructionIdentification()
Returns the raw JSON value of instructionIdentification.
Unlike instructionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundWireDrawdownRequestCreateParams.Builder toBuilder()
-
_body
final InboundWireDrawdownRequestCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundWireDrawdownRequestCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestCreateParams.
The following fields are required:
.amount() .creditorAccountNumber() .creditorRoutingNumber() .currency() .recipientAccountNumberId()
-
-
-
-