Class InboundWireDrawdownRequestCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final InboundWireDrawdownRequestCreateParams.Body.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final InboundWireDrawdownRequestCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAccountNumber(String creditorAccountNumber)
The creditor's account number.
-
creditorAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAccountNumber(JsonField<String> creditorAccountNumber)
Sets Builder.creditorAccountNumber to an arbitrary JSON value.
You should usually call Builder.creditorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorRoutingNumber(String creditorRoutingNumber)
The creditor's routing number.
-
creditorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorRoutingNumber(JsonField<String> creditorRoutingNumber)
Sets Builder.creditorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.creditorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InboundWireDrawdownRequestCreateParams.Body.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final InboundWireDrawdownRequestCreateParams.Body.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumberId
final InboundWireDrawdownRequestCreateParams.Body.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number to which the recipient of this request is being requested to send funds from.
-
recipientAccountNumberId
final InboundWireDrawdownRequestCreateParams.Body.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
Sets Builder.recipientAccountNumberId to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAddressLine1(String creditorAddressLine1)
A free-form address field set by the sender representing the first line of the creditor's address.
-
creditorAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAddressLine1(JsonField<String> creditorAddressLine1)
Sets Builder.creditorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAddressLine2(String creditorAddressLine2)
A free-form address field set by the sender representing the second line of the creditor's address.
-
creditorAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAddressLine2(JsonField<String> creditorAddressLine2)
Sets Builder.creditorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAddressLine3(String creditorAddressLine3)
A free-form address field set by the sender representing the third line of the creditor's address.
-
creditorAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorAddressLine3(JsonField<String> creditorAddressLine3)
Sets Builder.creditorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorName(String creditorName)
A free-form name field set by the sender representing the creditor's name.
-
creditorName
final InboundWireDrawdownRequestCreateParams.Body.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAccountNumber(String debtorAccountNumber)
The debtor's account number.
-
debtorAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAccountNumber(JsonField<String> debtorAccountNumber)
Sets Builder.debtorAccountNumber to an arbitrary JSON value.
You should usually call Builder.debtorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAddressLine1(String debtorAddressLine1)
A free-form address field set by the sender representing the first line of the debtor's address.
-
debtorAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAddressLine1(JsonField<String> debtorAddressLine1)
Sets Builder.debtorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAddressLine2(String debtorAddressLine2)
A free-form address field set by the sender representing the second line of the debtor's address.
-
debtorAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAddressLine2(JsonField<String> debtorAddressLine2)
Sets Builder.debtorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAddressLine3(String debtorAddressLine3)
A free-form address field set by the sender.
-
debtorAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorAddressLine3(JsonField<String> debtorAddressLine3)
Sets Builder.debtorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorName(String debtorName)
A free-form name field set by the sender representing the debtor's name.
-
debtorName
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorRoutingNumber(String debtorRoutingNumber)
The debtor's routing number.
-
debtorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
Sets Builder.debtorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.debtorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final InboundWireDrawdownRequestCreateParams.Body.Builder endToEndIdentification(String endToEndIdentification)
A free-form reference string set by the sender, to help identify the transfer.
-
endToEndIdentification
final InboundWireDrawdownRequestCreateParams.Body.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructionIdentification
final InboundWireDrawdownRequestCreateParams.Body.Builder instructionIdentification(String instructionIdentification)
The sending bank's identifier for the wire transfer.
-
instructionIdentification
final InboundWireDrawdownRequestCreateParams.Body.Builder instructionIdentification(JsonField<String> instructionIdentification)
Sets Builder.instructionIdentification to an arbitrary JSON value.
You should usually call Builder.instructionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueEndToEndTransactionReference
final InboundWireDrawdownRequestCreateParams.Body.Builder uniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
uniqueEndToEndTransactionReference
final InboundWireDrawdownRequestCreateParams.Body.Builder uniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)
Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value.
You should usually call Builder.uniqueEndToEndTransactionReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final InboundWireDrawdownRequestCreateParams.Body.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
A free-form message set by the sender.
-
unstructuredRemittanceInformation
final InboundWireDrawdownRequestCreateParams.Body.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireDrawdownRequestCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireDrawdownRequestCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireDrawdownRequestCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireDrawdownRequestCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireDrawdownRequestCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireDrawdownRequestCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .creditorAccountNumber() .creditorRoutingNumber() .currency() .recipientAccountNumberId()
-
-
-
-