Class InboundWireTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundWireTransferCreateParams implements Params
Simulates an #inbound-wire-transfers to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferCreateParams.BuilderA builder for InboundWireTransferCreateParams.
public final classInboundWireTransferCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the inbound Wire Transfer is for. final Longamount()The transfer amount in cents. final Optional<String>creditorAddressLine1()The sending bank will set creditor_address_line1 in production. final Optional<String>creditorAddressLine2()The sending bank will set creditor_address_line2 in production. final Optional<String>creditorAddressLine3()The sending bank will set creditor_address_line3 in production. final Optional<String>creditorName()The sending bank will set creditor_name in production. final Optional<String>debtorAddressLine1()The sending bank will set debtor_address_line1 in production. final Optional<String>debtorAddressLine2()The sending bank will set debtor_address_line2 in production. final Optional<String>debtorAddressLine3()The sending bank will set debtor_address_line3 in production. final Optional<String>debtorName()The sending bank will set debtor_name in production. final Optional<String>endToEndIdentification()The sending bank will set end_to_end_identification in production. final Optional<String>instructingAgentRoutingNumber()The sending bank will set instructing_agent_routing_number in production. final Optional<String>instructionIdentification()The sending bank will set instruction_identification in production. final Optional<String>purpose()The sending bank will set purpose in production. final Optional<String>uniqueEndToEndTransactionReference()The sending bank will set unique_end_to_end_transaction_reference in production. final Optional<String>unstructuredRemittanceInformation()The sending bank will set unstructured_remittance_information in production. final Optional<String>wireDrawdownRequestId()The identifier of a Wire Drawdown Request the inbound Wire Transfer is fulfilling. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorAddressLine1()Returns the raw JSON value of creditorAddressLine1. final JsonField<String>_creditorAddressLine2()Returns the raw JSON value of creditorAddressLine2. final JsonField<String>_creditorAddressLine3()Returns the raw JSON value of creditorAddressLine3. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_debtorAddressLine1()Returns the raw JSON value of debtorAddressLine1. final JsonField<String>_debtorAddressLine2()Returns the raw JSON value of debtorAddressLine2. final JsonField<String>_debtorAddressLine3()Returns the raw JSON value of debtorAddressLine3. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final JsonField<String>_instructingAgentRoutingNumber()Returns the raw JSON value of instructingAgentRoutingNumber. final JsonField<String>_instructionIdentification()Returns the raw JSON value of instructionIdentification. final JsonField<String>_purpose()Returns the raw JSON value of purpose. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final JsonField<String>_wireDrawdownRequestId()Returns the raw JSON value of wireDrawdownRequestId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundWireTransferCreateParams.BuildertoBuilder()final InboundWireTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransferCreateParams. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the inbound Wire Transfer is for.
-
creditorAddressLine1
final Optional<String> creditorAddressLine1()
The sending bank will set creditor_address_line1 in production. You can simulate any value here.
-
creditorAddressLine2
final Optional<String> creditorAddressLine2()
The sending bank will set creditor_address_line2 in production. You can simulate any value here.
-
creditorAddressLine3
final Optional<String> creditorAddressLine3()
The sending bank will set creditor_address_line3 in production. You can simulate any value here.
-
creditorName
final Optional<String> creditorName()
The sending bank will set creditor_name in production. You can simulate any value here.
-
debtorAddressLine1
final Optional<String> debtorAddressLine1()
The sending bank will set debtor_address_line1 in production. You can simulate any value here.
-
debtorAddressLine2
final Optional<String> debtorAddressLine2()
The sending bank will set debtor_address_line2 in production. You can simulate any value here.
-
debtorAddressLine3
final Optional<String> debtorAddressLine3()
The sending bank will set debtor_address_line3 in production. You can simulate any value here.
-
debtorName
final Optional<String> debtorName()
The sending bank will set debtor_name in production. You can simulate any value here.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
The sending bank will set end_to_end_identification in production. You can simulate any value here.
-
instructingAgentRoutingNumber
final Optional<String> instructingAgentRoutingNumber()
The sending bank will set instructing_agent_routing_number in production. You can simulate any value here.
-
instructionIdentification
final Optional<String> instructionIdentification()
The sending bank will set instruction_identification in production. You can simulate any value here.
-
purpose
final Optional<String> purpose()
The sending bank will set purpose in production. You can simulate any value here.
-
uniqueEndToEndTransactionReference
final Optional<String> uniqueEndToEndTransactionReference()
The sending bank will set unique_end_to_end_transaction_reference in production. You can simulate any value here.
-
unstructuredRemittanceInformation
final Optional<String> unstructuredRemittanceInformation()
The sending bank will set unstructured_remittance_information in production. You can simulate any value here.
-
wireDrawdownRequestId
final Optional<String> wireDrawdownRequestId()
The identifier of a Wire Drawdown Request the inbound Wire Transfer is fulfilling.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine1
final JsonField<String> _creditorAddressLine1()
Returns the raw JSON value of creditorAddressLine1.
Unlike creditorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine2
final JsonField<String> _creditorAddressLine2()
Returns the raw JSON value of creditorAddressLine2.
Unlike creditorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine3
final JsonField<String> _creditorAddressLine3()
Returns the raw JSON value of creditorAddressLine3.
Unlike creditorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine1
final JsonField<String> _debtorAddressLine1()
Returns the raw JSON value of debtorAddressLine1.
Unlike debtorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine2
final JsonField<String> _debtorAddressLine2()
Returns the raw JSON value of debtorAddressLine2.
Unlike debtorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine3
final JsonField<String> _debtorAddressLine3()
Returns the raw JSON value of debtorAddressLine3.
Unlike debtorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_instructingAgentRoutingNumber
final JsonField<String> _instructingAgentRoutingNumber()
Returns the raw JSON value of instructingAgentRoutingNumber.
Unlike instructingAgentRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_instructionIdentification
final JsonField<String> _instructionIdentification()
Returns the raw JSON value of instructionIdentification.
Unlike instructionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_purpose
final JsonField<String> _purpose()
Returns the raw JSON value of purpose.
Unlike purpose, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_wireDrawdownRequestId
final JsonField<String> _wireDrawdownRequestId()
Returns the raw JSON value of wireDrawdownRequestId.
Unlike wireDrawdownRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundWireTransferCreateParams.Builder toBuilder()
-
_body
final InboundWireTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundWireTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransferCreateParams.
The following fields are required:
.accountNumberId() .amount()
-
-
-
-