Class InboundWireTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final InboundWireTransferCreateParams.Body.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number the inbound Wire Transfer is for.
-
accountNumberId
final InboundWireTransferCreateParams.Body.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in cents. Must be positive.
-
amount
final InboundWireTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine1
final InboundWireTransferCreateParams.Body.Builder creditorAddressLine1(String creditorAddressLine1)
The sending bank will set creditor_address_line1 in production. You can simulate any value here.
-
creditorAddressLine1
final InboundWireTransferCreateParams.Body.Builder creditorAddressLine1(JsonField<String> creditorAddressLine1)
Sets Builder.creditorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine2
final InboundWireTransferCreateParams.Body.Builder creditorAddressLine2(String creditorAddressLine2)
The sending bank will set creditor_address_line2 in production. You can simulate any value here.
-
creditorAddressLine2
final InboundWireTransferCreateParams.Body.Builder creditorAddressLine2(JsonField<String> creditorAddressLine2)
Sets Builder.creditorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine3
final InboundWireTransferCreateParams.Body.Builder creditorAddressLine3(String creditorAddressLine3)
The sending bank will set creditor_address_line3 in production. You can simulate any value here.
-
creditorAddressLine3
final InboundWireTransferCreateParams.Body.Builder creditorAddressLine3(JsonField<String> creditorAddressLine3)
Sets Builder.creditorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final InboundWireTransferCreateParams.Body.Builder creditorName(String creditorName)
The sending bank will set creditor_name in production. You can simulate any value here.
-
creditorName
final InboundWireTransferCreateParams.Body.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine1
final InboundWireTransferCreateParams.Body.Builder debtorAddressLine1(String debtorAddressLine1)
The sending bank will set debtor_address_line1 in production. You can simulate any value here.
-
debtorAddressLine1
final InboundWireTransferCreateParams.Body.Builder debtorAddressLine1(JsonField<String> debtorAddressLine1)
Sets Builder.debtorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine2
final InboundWireTransferCreateParams.Body.Builder debtorAddressLine2(String debtorAddressLine2)
The sending bank will set debtor_address_line2 in production. You can simulate any value here.
-
debtorAddressLine2
final InboundWireTransferCreateParams.Body.Builder debtorAddressLine2(JsonField<String> debtorAddressLine2)
Sets Builder.debtorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine3
final InboundWireTransferCreateParams.Body.Builder debtorAddressLine3(String debtorAddressLine3)
The sending bank will set debtor_address_line3 in production. You can simulate any value here.
-
debtorAddressLine3
final InboundWireTransferCreateParams.Body.Builder debtorAddressLine3(JsonField<String> debtorAddressLine3)
Sets Builder.debtorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final InboundWireTransferCreateParams.Body.Builder debtorName(String debtorName)
The sending bank will set debtor_name in production. You can simulate any value here.
-
debtorName
final InboundWireTransferCreateParams.Body.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final InboundWireTransferCreateParams.Body.Builder endToEndIdentification(String endToEndIdentification)
The sending bank will set end_to_end_identification in production. You can simulate any value here.
-
endToEndIdentification
final InboundWireTransferCreateParams.Body.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructingAgentRoutingNumber
final InboundWireTransferCreateParams.Body.Builder instructingAgentRoutingNumber(String instructingAgentRoutingNumber)
The sending bank will set instructing_agent_routing_number in production. You can simulate any value here.
-
instructingAgentRoutingNumber
final InboundWireTransferCreateParams.Body.Builder instructingAgentRoutingNumber(JsonField<String> instructingAgentRoutingNumber)
Sets Builder.instructingAgentRoutingNumber to an arbitrary JSON value.
You should usually call Builder.instructingAgentRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructionIdentification
final InboundWireTransferCreateParams.Body.Builder instructionIdentification(String instructionIdentification)
The sending bank will set instruction_identification in production. You can simulate any value here.
-
instructionIdentification
final InboundWireTransferCreateParams.Body.Builder instructionIdentification(JsonField<String> instructionIdentification)
Sets Builder.instructionIdentification to an arbitrary JSON value.
You should usually call Builder.instructionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueEndToEndTransactionReference
final InboundWireTransferCreateParams.Body.Builder uniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)
The sending bank will set unique_end_to_end_transaction_reference in production. You can simulate any value here.
-
uniqueEndToEndTransactionReference
final InboundWireTransferCreateParams.Body.Builder uniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)
Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value.
You should usually call Builder.uniqueEndToEndTransactionReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final InboundWireTransferCreateParams.Body.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
The sending bank will set unstructured_remittance_information in production. You can simulate any value here.
-
unstructuredRemittanceInformation
final InboundWireTransferCreateParams.Body.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireDrawdownRequestId
final InboundWireTransferCreateParams.Body.Builder wireDrawdownRequestId(String wireDrawdownRequestId)
The identifier of a Wire Drawdown Request the inbound Wire Transfer is fulfilling.
-
wireDrawdownRequestId
final InboundWireTransferCreateParams.Body.Builder wireDrawdownRequestId(JsonField<String> wireDrawdownRequestId)
Sets Builder.wireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.wireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .amount()
-
-
-
-