Class InboundWireTransferCreateParams.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransferCreateParams.BuilderA builder for InboundWireTransferCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final InboundWireTransferCreateParams.Builder body(InboundWireTransferCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
accountNumberId
final InboundWireTransferCreateParams.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number the inbound Wire Transfer is for.
-
accountNumberId
final InboundWireTransferCreateParams.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireTransferCreateParams.Builder amount(Long amount)
The transfer amount in cents. Must be positive.
-
amount
final InboundWireTransferCreateParams.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine1
final InboundWireTransferCreateParams.Builder creditorAddressLine1(String creditorAddressLine1)
The sending bank will set creditor_address_line1 in production. You can simulate any value here.
-
creditorAddressLine1
final InboundWireTransferCreateParams.Builder creditorAddressLine1(JsonField<String> creditorAddressLine1)
Sets Builder.creditorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine2
final InboundWireTransferCreateParams.Builder creditorAddressLine2(String creditorAddressLine2)
The sending bank will set creditor_address_line2 in production. You can simulate any value here.
-
creditorAddressLine2
final InboundWireTransferCreateParams.Builder creditorAddressLine2(JsonField<String> creditorAddressLine2)
Sets Builder.creditorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddressLine3
final InboundWireTransferCreateParams.Builder creditorAddressLine3(String creditorAddressLine3)
The sending bank will set creditor_address_line3 in production. You can simulate any value here.
-
creditorAddressLine3
final InboundWireTransferCreateParams.Builder creditorAddressLine3(JsonField<String> creditorAddressLine3)
Sets Builder.creditorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.creditorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final InboundWireTransferCreateParams.Builder creditorName(String creditorName)
The sending bank will set creditor_name in production. You can simulate any value here.
-
creditorName
final InboundWireTransferCreateParams.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine1
final InboundWireTransferCreateParams.Builder debtorAddressLine1(String debtorAddressLine1)
The sending bank will set debtor_address_line1 in production. You can simulate any value here.
-
debtorAddressLine1
final InboundWireTransferCreateParams.Builder debtorAddressLine1(JsonField<String> debtorAddressLine1)
Sets Builder.debtorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine2
final InboundWireTransferCreateParams.Builder debtorAddressLine2(String debtorAddressLine2)
The sending bank will set debtor_address_line2 in production. You can simulate any value here.
-
debtorAddressLine2
final InboundWireTransferCreateParams.Builder debtorAddressLine2(JsonField<String> debtorAddressLine2)
Sets Builder.debtorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddressLine3
final InboundWireTransferCreateParams.Builder debtorAddressLine3(String debtorAddressLine3)
The sending bank will set debtor_address_line3 in production. You can simulate any value here.
-
debtorAddressLine3
final InboundWireTransferCreateParams.Builder debtorAddressLine3(JsonField<String> debtorAddressLine3)
Sets Builder.debtorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.debtorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final InboundWireTransferCreateParams.Builder debtorName(String debtorName)
The sending bank will set debtor_name in production. You can simulate any value here.
-
debtorName
final InboundWireTransferCreateParams.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final InboundWireTransferCreateParams.Builder endToEndIdentification(String endToEndIdentification)
The sending bank will set end_to_end_identification in production. You can simulate any value here.
-
endToEndIdentification
final InboundWireTransferCreateParams.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructingAgentRoutingNumber
final InboundWireTransferCreateParams.Builder instructingAgentRoutingNumber(String instructingAgentRoutingNumber)
The sending bank will set instructing_agent_routing_number in production. You can simulate any value here.
-
instructingAgentRoutingNumber
final InboundWireTransferCreateParams.Builder instructingAgentRoutingNumber(JsonField<String> instructingAgentRoutingNumber)
Sets Builder.instructingAgentRoutingNumber to an arbitrary JSON value.
You should usually call Builder.instructingAgentRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructionIdentification
final InboundWireTransferCreateParams.Builder instructionIdentification(String instructionIdentification)
The sending bank will set instruction_identification in production. You can simulate any value here.
-
instructionIdentification
final InboundWireTransferCreateParams.Builder instructionIdentification(JsonField<String> instructionIdentification)
Sets Builder.instructionIdentification to an arbitrary JSON value.
You should usually call Builder.instructionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueEndToEndTransactionReference
final InboundWireTransferCreateParams.Builder uniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)
The sending bank will set unique_end_to_end_transaction_reference in production. You can simulate any value here.
-
uniqueEndToEndTransactionReference
final InboundWireTransferCreateParams.Builder uniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)
Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value.
You should usually call Builder.uniqueEndToEndTransactionReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final InboundWireTransferCreateParams.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
The sending bank will set unstructured_remittance_information in production. You can simulate any value here.
-
unstructuredRemittanceInformation
final InboundWireTransferCreateParams.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireDrawdownRequestId
final InboundWireTransferCreateParams.Builder wireDrawdownRequestId(String wireDrawdownRequestId)
The identifier of a Wire Drawdown Request the inbound Wire Transfer is fulfilling.
-
wireDrawdownRequestId
final InboundWireTransferCreateParams.Builder wireDrawdownRequestId(JsonField<String> wireDrawdownRequestId)
Sets Builder.wireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.wireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final InboundWireTransferCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final InboundWireTransferCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final InboundWireTransferCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final InboundWireTransferCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final InboundWireTransferCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final InboundWireTransferCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final InboundWireTransferCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final InboundWireTransferCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final InboundWireTransferCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final InboundWireTransferCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final InboundWireTransferCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final InboundWireTransferCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final InboundWireTransferCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final InboundWireTransferCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final InboundWireTransferCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final InboundWireTransferCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final InboundWireTransferCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final InboundWireTransferCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final InboundWireTransferCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final InboundWireTransferCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final InboundWireTransferCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final InboundWireTransferCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final InboundWireTransferCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final InboundWireTransferCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final InboundWireTransferCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final InboundWireTransferCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final InboundWireTransferCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final InboundWireTransferCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final InboundWireTransferCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final InboundWireTransferCreateParams build()
Returns an immutable instance of InboundWireTransferCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .amount()
-
-
-
-