Class InterestPaymentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InterestPaymentCreateParams implements Params
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInterestPaymentCreateParams.BuilderA builder for InterestPaymentCreateParams.
public final classInterestPaymentCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the Interest Payment should be paid to is for. final Longamount()The interest amount in cents. final Optional<String>accruedOnAccountId()The identifier of the Account the Interest accrued on. final Optional<OffsetDateTime>periodEnd()The end of the interest period. final Optional<OffsetDateTime>periodStart()The start of the interest period. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_accruedOnAccountId()Returns the raw JSON value of accruedOnAccountId. final JsonField<OffsetDateTime>_periodEnd()Returns the raw JSON value of periodEnd. final JsonField<OffsetDateTime>_periodStart()Returns the raw JSON value of periodStart. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InterestPaymentCreateParams.BuildertoBuilder()final InterestPaymentCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InterestPaymentCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InterestPaymentCreateParams. -
-
Method Detail
-
accountId
final String accountId()
The identifier of the Account the Interest Payment should be paid to is for.
-
accruedOnAccountId
final Optional<String> accruedOnAccountId()
The identifier of the Account the Interest accrued on. Defaults to
account_id.
-
periodEnd
final Optional<OffsetDateTime> periodEnd()
The end of the interest period. If not provided, defaults to the current time.
-
periodStart
final Optional<OffsetDateTime> periodStart()
The start of the interest period. If not provided, defaults to the current time.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_accruedOnAccountId
final JsonField<String> _accruedOnAccountId()
Returns the raw JSON value of accruedOnAccountId.
Unlike accruedOnAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
Returns the raw JSON value of periodEnd.
Unlike periodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
Returns the raw JSON value of periodStart.
Unlike periodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InterestPaymentCreateParams.Builder toBuilder()
-
_body
final InterestPaymentCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InterestPaymentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InterestPaymentCreateParams.
The following fields are required:
.accountId() .amount()
-
-
-
-