Class InterestPaymentCreateParams.Body
-
- All Implemented Interfaces:
public final class InterestPaymentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInterestPaymentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the Interest Payment should be paid to is for. final Longamount()The interest amount in cents. final Optional<String>accruedOnAccountId()The identifier of the Account the Interest accrued on. final Optional<OffsetDateTime>periodEnd()The end of the interest period. final Optional<OffsetDateTime>periodStart()The start of the interest period. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_accruedOnAccountId()Returns the raw JSON value of accruedOnAccountId. final JsonField<OffsetDateTime>_periodEnd()Returns the raw JSON value of periodEnd. final JsonField<OffsetDateTime>_periodStart()Returns the raw JSON value of periodStart. final Map<String, JsonValue>_additionalProperties()final InterestPaymentCreateParams.Body.BuildertoBuilder()final InterestPaymentCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InterestPaymentCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountId
final String accountId()
The identifier of the Account the Interest Payment should be paid to is for.
-
accruedOnAccountId
final Optional<String> accruedOnAccountId()
The identifier of the Account the Interest accrued on. Defaults to
account_id.
-
periodEnd
final Optional<OffsetDateTime> periodEnd()
The end of the interest period. If not provided, defaults to the current time.
-
periodStart
final Optional<OffsetDateTime> periodStart()
The start of the interest period. If not provided, defaults to the current time.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_accruedOnAccountId
final JsonField<String> _accruedOnAccountId()
Returns the raw JSON value of accruedOnAccountId.
Unlike accruedOnAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
Returns the raw JSON value of periodEnd.
Unlike periodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
Returns the raw JSON value of periodStart.
Unlike periodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InterestPaymentCreateParams.Body.Builder toBuilder()
-
validate
final InterestPaymentCreateParams.Body validate()
-
builder
final static InterestPaymentCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount()
-
-
-
-