Class PhysicalCardCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardCreateParams implements Params
This endpoint allows you to simulate receiving a tracking update for a Physical Card, to simulate the progress of a shipment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.BuilderA builder for PhysicalCardCreateParams.
public final classPhysicalCardCreateParams.Bodypublic final classPhysicalCardCreateParams.CategoryThe type of tracking event.
-
Method Summary
Modifier and Type Method Description final Optional<String>physicalCardId()The Physical Card you would like to action. final PhysicalCardCreateParams.Categorycategory()The type of tracking event. final Optional<OffsetDateTime>carrierEstimatedDeliveryAt()The ISO 8601 date and time when the carrier expects the card to be delivered. final Optional<String>city()The city where the event took place. final Optional<String>postalCode()The postal code where the event took place. final Optional<String>state()The state where the event took place. final JsonField<PhysicalCardCreateParams.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_carrierEstimatedDeliveryAt()Returns the raw JSON value of carrierEstimatedDeliveryAt. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PhysicalCardCreateParams.BuildertoBuilder()final PhysicalCardCreateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardCreateParams. -
-
Method Detail
-
physicalCardId
final Optional<String> physicalCardId()
The Physical Card you would like to action.
-
category
final PhysicalCardCreateParams.Category category()
The type of tracking event.
-
carrierEstimatedDeliveryAt
final Optional<OffsetDateTime> carrierEstimatedDeliveryAt()
The ISO 8601 date and time when the carrier expects the card to be delivered.
-
postalCode
final Optional<String> postalCode()
The postal code where the event took place.
-
_category
final JsonField<PhysicalCardCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_carrierEstimatedDeliveryAt
final JsonField<OffsetDateTime> _carrierEstimatedDeliveryAt()
Returns the raw JSON value of carrierEstimatedDeliveryAt.
Unlike carrierEstimatedDeliveryAt, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PhysicalCardCreateParams.Builder toBuilder()
-
_body
final PhysicalCardCreateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PhysicalCardCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardCreateParams.
The following fields are required:
.category()
-
-
-
-