Class PhysicalCardTrackingUpdatesParams.Body.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardTrackingUpdatesParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
category
final PhysicalCardTrackingUpdatesParams.Body.Builder category(PhysicalCardTrackingUpdatesParams.Category category)
The type of tracking event.
-
category
final PhysicalCardTrackingUpdatesParams.Body.Builder category(JsonField<PhysicalCardTrackingUpdatesParams.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
carrierEstimatedDeliveryAt
final PhysicalCardTrackingUpdatesParams.Body.Builder carrierEstimatedDeliveryAt(OffsetDateTime carrierEstimatedDeliveryAt)
The ISO 8601 date and time when the carrier expects the card to be delivered.
-
carrierEstimatedDeliveryAt
final PhysicalCardTrackingUpdatesParams.Body.Builder carrierEstimatedDeliveryAt(JsonField<OffsetDateTime> carrierEstimatedDeliveryAt)
Sets Builder.carrierEstimatedDeliveryAt to an arbitrary JSON value.
You should usually call Builder.carrierEstimatedDeliveryAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
city
final PhysicalCardTrackingUpdatesParams.Body.Builder city(String city)
The city where the event took place.
-
city
final PhysicalCardTrackingUpdatesParams.Body.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final PhysicalCardTrackingUpdatesParams.Body.Builder postalCode(String postalCode)
The postal code where the event took place.
-
postalCode
final PhysicalCardTrackingUpdatesParams.Body.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final PhysicalCardTrackingUpdatesParams.Body.Builder state(String state)
The state where the event took place.
-
state
final PhysicalCardTrackingUpdatesParams.Body.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardTrackingUpdatesParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardTrackingUpdatesParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardTrackingUpdatesParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardTrackingUpdatesParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardTrackingUpdatesParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardTrackingUpdatesParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category()
-
-
-
-