Enum ProgramCreateParams.Bank.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum ProgramCreateParams.Bank.Known extends Enum<ProgramCreateParams.Bank.Known>
An enum containing Bank's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<ProgramCreateParams.Bank.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CORE_BANKCore Bank
FIRST_INTERNET_BANKFirst Internet Bank of Indiana
GRASSHOPPER_BANKGrasshopper Bank
TWIN_CITY_BANKTwin City Bank
-
Method Summary
Modifier and Type Method Description final ProgramCreateParams.Bank.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<ProgramCreateParams.Bank.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<ProgramCreateParams.Bank.Known>getEntries()An enum containing Bank's known values. -
-
Method Detail
-
valueOf
final ProgramCreateParams.Bank.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<ProgramCreateParams.Bank.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<ProgramCreateParams.Bank.Known> getEntries()
An enum containing Bank's known values.
-
-
-
-