Class ProgramCreateParams.Body
-
- All Implemented Interfaces:
public final class ProgramCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()The name of the program being added. final Optional<ProgramCreateParams.Bank>bank()The bank for the program's accounts, defaults to First Internet Bank. final Optional<Long>lendingMaximumExtendableCredit()The maximum extendable credit of the program being added. final Optional<String>reserveAccountId()The identifier of the Account the Program should be added to is for. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<ProgramCreateParams.Bank>_bank()Returns the raw JSON value of bank. final JsonField<Long>_lendingMaximumExtendableCredit()Returns the raw JSON value of lendingMaximumExtendableCredit. final JsonField<String>_reserveAccountId()Returns the raw JSON value of reserveAccountId. final Map<String, JsonValue>_additionalProperties()final ProgramCreateParams.Body.BuildertoBuilder()final ProgramCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
bank
final Optional<ProgramCreateParams.Bank> bank()
The bank for the program's accounts, defaults to First Internet Bank.
-
lendingMaximumExtendableCredit
final Optional<Long> lendingMaximumExtendableCredit()
The maximum extendable credit of the program being added.
-
reserveAccountId
final Optional<String> reserveAccountId()
The identifier of the Account the Program should be added to is for.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_bank
final JsonField<ProgramCreateParams.Bank> _bank()
Returns the raw JSON value of bank.
Unlike bank, this method doesn't throw if the JSON field has an unexpected type.
-
_lendingMaximumExtendableCredit
final JsonField<Long> _lendingMaximumExtendableCredit()
Returns the raw JSON value of lendingMaximumExtendableCredit.
Unlike lendingMaximumExtendableCredit, this method doesn't throw if the JSON field has an unexpected type.
-
_reserveAccountId
final JsonField<String> _reserveAccountId()
Returns the raw JSON value of reserveAccountId.
Unlike reserveAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProgramCreateParams.Body.Builder toBuilder()
-
validate
final ProgramCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProgramCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-