Class ProgramCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class ProgramCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
name
final ProgramCreateParams.Body.Builder name(String name)
The name of the program being added.
-
name
final ProgramCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bank
final ProgramCreateParams.Body.Builder bank(ProgramCreateParams.Bank bank)
The bank for the program's accounts, defaults to First Internet Bank.
-
bank
final ProgramCreateParams.Body.Builder bank(JsonField<ProgramCreateParams.Bank> bank)
Sets Builder.bank to an arbitrary JSON value.
You should usually call Builder.bank with a well-typed Bank value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lendingMaximumExtendableCredit
final ProgramCreateParams.Body.Builder lendingMaximumExtendableCredit(Long lendingMaximumExtendableCredit)
The maximum extendable credit of the program being added.
-
lendingMaximumExtendableCredit
final ProgramCreateParams.Body.Builder lendingMaximumExtendableCredit(JsonField<Long> lendingMaximumExtendableCredit)
Sets Builder.lendingMaximumExtendableCredit to an arbitrary JSON value.
You should usually call Builder.lendingMaximumExtendableCredit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reserveAccountId
final ProgramCreateParams.Body.Builder reserveAccountId(String reserveAccountId)
The identifier of the Account the Program should be added to is for.
-
reserveAccountId
final ProgramCreateParams.Body.Builder reserveAccountId(JsonField<String> reserveAccountId)
Sets Builder.reserveAccountId to an arbitrary JSON value.
You should usually call Builder.reserveAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ProgramCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ProgramCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ProgramCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ProgramCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ProgramCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ProgramCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-