Class EntitySupplementalDocument
-
- All Implemented Interfaces:
public final class EntitySupplementalDocumentSupplemental Documents are uploaded files connected to an Entity during onboarding.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntitySupplementalDocument.BuilderA builder for EntitySupplementalDocument.
public final classEntitySupplementalDocument.TypeA constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecreatedAt()The ISO 8601 time at which the Supplemental Document was created. final StringentityId()The Entity the supplemental document is attached to. final StringfileId()The File containing the document. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final EntitySupplementalDocument.Typetype()A constant representing the object's type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<EntitySupplementalDocument.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final EntitySupplementalDocument.BuildertoBuilder()final EntitySupplementalDocumentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntitySupplementalDocument.Builderbuilder()Returns a mutable builder for constructing an instance of EntitySupplementalDocument. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Supplemental Document was created.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
type
final EntitySupplementalDocument.Type type()
A constant representing the object's type. For this resource it will always be
entity_supplemental_document.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<EntitySupplementalDocument.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntitySupplementalDocument.Builder toBuilder()
-
validate
final EntitySupplementalDocument validate()
-
builder
final static EntitySupplementalDocument.Builder builder()
Returns a mutable builder for constructing an instance of EntitySupplementalDocument.
The following fields are required:
.createdAt() .entityId() .fileId() .idempotencyKey() .type()
-
-
-
-