Class SupplementalDocumentCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SupplementalDocumentCreateParams implements Params
Create a supplemental document for an Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentCreateParams.BuilderA builder for SupplementalDocumentCreateParams.
public final classSupplementalDocumentCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to associate with the supplemental document. final StringfileId()The identifier of the File containing the document. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final SupplementalDocumentCreateParams.BuildertoBuilder()final SupplementalDocumentCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of SupplementalDocumentCreateParams. -
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to associate with the supplemental document.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final SupplementalDocumentCreateParams.Builder toBuilder()
-
_body
final SupplementalDocumentCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static SupplementalDocumentCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of SupplementalDocumentCreateParams.
The following fields are required:
.entityId() .fileId()
-
-
-
-