Class SupplementalDocumentCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class SupplementalDocumentCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
entityId
final SupplementalDocumentCreateParams.Body.Builder entityId(String entityId)
The identifier of the Entity to associate with the supplemental document.
-
entityId
final SupplementalDocumentCreateParams.Body.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final SupplementalDocumentCreateParams.Body.Builder fileId(String fileId)
The identifier of the File containing the document.
-
fileId
final SupplementalDocumentCreateParams.Body.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SupplementalDocumentCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SupplementalDocumentCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SupplementalDocumentCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SupplementalDocumentCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SupplementalDocumentCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SupplementalDocumentCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.entityId() .fileId()
-
-
-
-