Class SupplementalDocumentListPage
-
- All Implemented Interfaces:
-
com.increase.api.core.Page
public final class SupplementalDocumentListPage implements Page<EntitySupplementalDocument>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentListPage.BuilderA builder for SupplementalDocumentListPage.
-
Method Summary
Modifier and Type Method Description final List<EntitySupplementalDocument>data()Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data. List<EntitySupplementalDocument>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final SupplementalDocumentListParamsnextPageParams()SupplementalDocumentListPagenextPage()Returns the page after this one by making another request. final AutoPager<EntitySupplementalDocument>autoPager()final SupplementalDocumentListParamsparams()The parameters that were used to request this page. final SupplementalDocumentListPageResponseresponse()The response that this page was parsed from. final SupplementalDocumentListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentListPage.Builderbuilder()Returns a mutable builder for constructing an instance of SupplementalDocumentListPage. -
-
Method Detail
-
data
final List<EntitySupplementalDocument> data()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
items
List<EntitySupplementalDocument> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final SupplementalDocumentListParams nextPageParams()
-
nextPage
SupplementalDocumentListPage nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPager<EntitySupplementalDocument> autoPager()
-
params
final SupplementalDocumentListParams params()
The parameters that were used to request this page.
-
response
final SupplementalDocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final SupplementalDocumentListPage.Builder toBuilder()
-
builder
final static SupplementalDocumentListPage.Builder builder()
Returns a mutable builder for constructing an instance of SupplementalDocumentListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-