Class SupplementalDocumentListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class SupplementalDocumentListPageAsync implements PageAsync<EntitySupplementalDocument>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentListPageAsync.BuilderA builder for SupplementalDocumentListPageAsync.
-
Method Summary
-
-
Method Detail
-
data
final List<EntitySupplementalDocument> data()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
items
List<EntitySupplementalDocument> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final SupplementalDocumentListParams nextPageParams()
-
nextPage
CompletableFuture<SupplementalDocumentListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<EntitySupplementalDocument> autoPager()
-
params
final SupplementalDocumentListParams params()
The parameters that were used to request this page.
-
response
final SupplementalDocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final SupplementalDocumentListPageAsync.Builder toBuilder()
-
builder
final static SupplementalDocumentListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of SupplementalDocumentListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-