Class SupplementalDocumentListPageAsync.Builder
-
- All Implemented Interfaces:
public final class SupplementalDocumentListPageAsync.BuilderA builder for SupplementalDocumentListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final SupplementalDocumentListPageAsync.Builderservice(SupplementalDocumentServiceAsync service)final SupplementalDocumentListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final SupplementalDocumentListPageAsync.Builderparams(SupplementalDocumentListParams params)The parameters that were used to request this page. final SupplementalDocumentListPageAsync.Builderresponse(SupplementalDocumentListPageResponse response)The response that this page was parsed from. final SupplementalDocumentListPageAsyncbuild()Returns an immutable instance of SupplementalDocumentListPageAsync. -
-
Method Detail
-
service
final SupplementalDocumentListPageAsync.Builder service(SupplementalDocumentServiceAsync service)
-
streamHandlerExecutor
final SupplementalDocumentListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final SupplementalDocumentListPageAsync.Builder params(SupplementalDocumentListParams params)
The parameters that were used to request this page.
-
response
final SupplementalDocumentListPageAsync.Builder response(SupplementalDocumentListPageResponse response)
The response that this page was parsed from.
-
build
final SupplementalDocumentListPageAsync build()
Returns an immutable instance of SupplementalDocumentListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-