Class SwiftTransfer
-
- All Implemented Interfaces:
public final class SwiftTransferSwift Transfers send funds internationally.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSwiftTransfer.BuilderA builder for SwiftTransfer.
public final classSwiftTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classSwiftTransfer.CreditorAddressThe creditor's address.
public final classSwiftTransfer.DebtorAddressThe debtor's address.
public final classSwiftTransfer.InstructedCurrencyThe ISO 4217 currency code of the instructed amount.
public final classSwiftTransfer.StatusThe lifecycle status of the transfer.
public final classSwiftTransfer.TypeA constant representing the object's type. For this resource it will always be
swift_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The Swift transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumber()The creditor's account number. final Longamount()The transfer amount in USD cents. final StringbankIdentificationCode()The bank identification code (BIC) of the creditor. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final SwiftTransfer.CreatedBycreatedBy()What object created the transfer, either via the API or the dashboard. final SwiftTransfer.CreditorAddresscreditorAddress()The creditor's address. final StringcreditorName()The creditor's name. final SwiftTransfer.DebtorAddressdebtorAddress()The debtor's address. final StringdebtorName()The debtor's name. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final LonginstructedAmount()The amount that was instructed to be transferred in minor units of the instructed_currency.final SwiftTransfer.InstructedCurrencyinstructedCurrency()The ISO 4217 currency code of the instructed amount. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<String>routingNumber()The creditor's bank account routing or transit number. final StringsourceAccountNumberId()The Account Number included in the transfer as the debtor's account number. final SwiftTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<String>transactionId()The ID for the transaction funding the transfer. final SwiftTransfer.Typetype()A constant representing the object's type. final StringuniqueEndToEndTransactionReference()The Unique End-to-end Transaction Reference (UETR) for the transfer. final StringunstructuredRemittanceInformation()The unstructured remittance information that was included with the transfer. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_bankIdentificationCode()Returns the raw JSON value of bankIdentificationCode. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<SwiftTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<SwiftTransfer.CreditorAddress>_creditorAddress()Returns the raw JSON value of creditorAddress. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<SwiftTransfer.DebtorAddress>_debtorAddress()Returns the raw JSON value of debtorAddress. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<Long>_instructedAmount()Returns the raw JSON value of instructedAmount. final JsonField<SwiftTransfer.InstructedCurrency>_instructedCurrency()Returns the raw JSON value of instructedCurrency. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<SwiftTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<SwiftTransfer.Type>_type()Returns the raw JSON value of type. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final SwiftTransfer.BuildertoBuilder()final SwiftTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SwiftTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of SwiftTransfer. -
-
Method Detail
-
accountNumber
final String accountNumber()
The creditor's account number.
-
bankIdentificationCode
final String bankIdentificationCode()
The bank identification code (BIC) of the creditor.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final SwiftTransfer.CreatedBy createdBy()
What object created the transfer, either via the API or the dashboard.
-
creditorAddress
final SwiftTransfer.CreditorAddress creditorAddress()
The creditor's address.
-
creditorName
final String creditorName()
The creditor's name.
-
debtorAddress
final SwiftTransfer.DebtorAddress debtorAddress()
The debtor's address.
-
debtorName
final String debtorName()
The debtor's name.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
instructedAmount
final Long instructedAmount()
The amount that was instructed to be transferred in minor units of the
instructed_currency.
-
instructedCurrency
final SwiftTransfer.InstructedCurrency instructedCurrency()
The ISO 4217 currency code of the instructed amount.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer.
-
routingNumber
final Optional<String> routingNumber()
The creditor's bank account routing or transit number. Required in certain countries.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number included in the transfer as the debtor's account number.
-
status
final SwiftTransfer.Status status()
The lifecycle status of the transfer.
-
transactionId
final Optional<String> transactionId()
The ID for the transaction funding the transfer. This will be populated after the transfer is initiated.
-
type
final SwiftTransfer.Type type()
A constant representing the object's type. For this resource it will always be
swift_transfer.
-
uniqueEndToEndTransactionReference
final String uniqueEndToEndTransactionReference()
The Unique End-to-end Transaction Reference (UETR) for the transfer.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
The unstructured remittance information that was included with the transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_bankIdentificationCode
final JsonField<String> _bankIdentificationCode()
Returns the raw JSON value of bankIdentificationCode.
Unlike bankIdentificationCode, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<SwiftTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddress
final JsonField<SwiftTransfer.CreditorAddress> _creditorAddress()
Returns the raw JSON value of creditorAddress.
Unlike creditorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddress
final JsonField<SwiftTransfer.DebtorAddress> _debtorAddress()
Returns the raw JSON value of debtorAddress.
Unlike debtorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_instructedAmount
final JsonField<Long> _instructedAmount()
Returns the raw JSON value of instructedAmount.
Unlike instructedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_instructedCurrency
final JsonField<SwiftTransfer.InstructedCurrency> _instructedCurrency()
Returns the raw JSON value of instructedCurrency.
Unlike instructedCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<SwiftTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<SwiftTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SwiftTransfer.Builder toBuilder()
-
validate
final SwiftTransfer validate()
-
builder
final static SwiftTransfer.Builder builder()
Returns a mutable builder for constructing an instance of SwiftTransfer.
The following fields are required:
.id() .accountId() .accountNumber() .amount() .bankIdentificationCode() .createdAt() .createdBy() .creditorAddress() .creditorName() .debtorAddress() .debtorName() .idempotencyKey() .instructedAmount() .instructedCurrency() .pendingTransactionId() .routingNumber() .sourceAccountNumberId() .status() .transactionId() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation()
-
-
-
-