Class SwiftTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class SwiftTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSwiftTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final StringaccountNumber()The creditor's account number. final StringbankIdentificationCode()The bank identification code (BIC) of the creditor. final SwiftTransferCreateParams.CreditorAddresscreditorAddress()The creditor's address. final StringcreditorName()The creditor's name. final SwiftTransferCreateParams.DebtorAddressdebtorAddress()The debtor's address. final StringdebtorName()The debtor's name. final LonginstructedAmount()The amount, in minor units of instructed_currency, to send to the creditor.final SwiftTransferCreateParams.InstructedCurrencyinstructedCurrency()The ISO 4217 currency code of the instructed amount. final StringsourceAccountNumberId()The Account Number to include in the transfer as the debtor's account number. final StringunstructuredRemittanceInformation()Unstructured remittance information to include in the transfer. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The creditor's bank account routing or transit number. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_bankIdentificationCode()Returns the raw JSON value of bankIdentificationCode. final JsonField<SwiftTransferCreateParams.CreditorAddress>_creditorAddress()Returns the raw JSON value of creditorAddress. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<SwiftTransferCreateParams.DebtorAddress>_debtorAddress()Returns the raw JSON value of debtorAddress. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<Long>_instructedAmount()Returns the raw JSON value of instructedAmount. final JsonField<SwiftTransferCreateParams.InstructedCurrency>_instructedCurrency()Returns the raw JSON value of instructedCurrency. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final Map<String, JsonValue>_additionalProperties()final SwiftTransferCreateParams.Body.BuildertoBuilder()final SwiftTransferCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SwiftTransferCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountNumber
final String accountNumber()
The creditor's account number.
-
bankIdentificationCode
final String bankIdentificationCode()
The bank identification code (BIC) of the creditor. If it ends with the three-character branch code, this must be 11 characters long. Otherwise this must be 8 characters and the branch code will be assumed to be
XXX.
-
creditorAddress
final SwiftTransferCreateParams.CreditorAddress creditorAddress()
The creditor's address.
-
creditorName
final String creditorName()
The creditor's name.
-
debtorAddress
final SwiftTransferCreateParams.DebtorAddress debtorAddress()
The debtor's address.
-
debtorName
final String debtorName()
The debtor's name.
-
instructedAmount
final Long instructedAmount()
The amount, in minor units of
instructed_currency, to send to the creditor.
-
instructedCurrency
final SwiftTransferCreateParams.InstructedCurrency instructedCurrency()
The ISO 4217 currency code of the instructed amount.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The Account Number to include in the transfer as the debtor's account number.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Unstructured remittance information to include in the transfer.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The creditor's bank account routing or transit number. Required in certain countries.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_bankIdentificationCode
final JsonField<String> _bankIdentificationCode()
Returns the raw JSON value of bankIdentificationCode.
Unlike bankIdentificationCode, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddress
final JsonField<SwiftTransferCreateParams.CreditorAddress> _creditorAddress()
Returns the raw JSON value of creditorAddress.
Unlike creditorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddress
final JsonField<SwiftTransferCreateParams.DebtorAddress> _debtorAddress()
Returns the raw JSON value of debtorAddress.
Unlike debtorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_instructedAmount
final JsonField<Long> _instructedAmount()
Returns the raw JSON value of instructedAmount.
Unlike instructedAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_instructedCurrency
final JsonField<SwiftTransferCreateParams.InstructedCurrency> _instructedCurrency()
Returns the raw JSON value of instructedCurrency.
Unlike instructedCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SwiftTransferCreateParams.Body.Builder toBuilder()
-
validate
final SwiftTransferCreateParams.Body validate()
-
builder
final static SwiftTransferCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .accountNumber() .bankIdentificationCode() .creditorAddress() .creditorName() .debtorAddress() .debtorName() .instructedAmount() .instructedCurrency() .sourceAccountNumberId() .unstructuredRemittanceInformation()
-
-
-
-