Class Transaction.Builder
-
- All Implemented Interfaces:
public final class Transaction.BuilderA builder for Transaction.
-
-
Method Summary
Modifier and Type Method Description final Transaction.Builderid(String id)The Transaction identifier. final Transaction.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Transaction.BuilderaccountId(String accountId)The identifier for the Account the Transaction belongs to. final Transaction.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final Transaction.Builderamount(Long amount)The Transaction amount in the minor unit of its currency. final Transaction.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final Transaction.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date on which the Transaction occurred. final Transaction.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Transaction.Buildercurrency(Transaction.Currency currency)The ISO 4217 code for the Transaction's currency. final Transaction.Buildercurrency(JsonField<Transaction.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final Transaction.Builderdescription(String description)An informational message describing this transaction. final Transaction.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final Transaction.BuilderrouteId(String routeId)The identifier for the route this Transaction came through. final Transaction.BuilderrouteId(Optional<String> routeId)Alias for calling Builder.routeId with routeId.orElse(null).final Transaction.BuilderrouteId(JsonField<String> routeId)Sets Builder.routeId to an arbitrary JSON value. final Transaction.BuilderrouteType(Transaction.RouteType routeType)The type of the route this Transaction came through. final Transaction.BuilderrouteType(Optional<Transaction.RouteType> routeType)Alias for calling Builder.routeType with routeType.orElse(null).final Transaction.BuilderrouteType(JsonField<Transaction.RouteType> routeType)Sets Builder.routeType to an arbitrary JSON value. final Transaction.Buildersource(Transaction.Source source)This is an object giving more details on the network-level event that caused the Transaction. final Transaction.Buildersource(JsonField<Transaction.Source> source)Sets Builder.source to an arbitrary JSON value. final Transaction.Buildertype(Transaction.Type type)A constant representing the object's type. final Transaction.Buildertype(JsonField<Transaction.Type> type)Sets Builder.type to an arbitrary JSON value. final Transaction.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.BuilderputAdditionalProperty(String key, JsonValue value)final Transaction.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transaction.BuilderremoveAdditionalProperty(String key)final Transaction.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transactionbuild()Returns an immutable instance of Transaction. -
-
Method Detail
-
id
final Transaction.Builder id(String id)
The Transaction identifier.
-
id
final Transaction.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final Transaction.Builder accountId(String accountId)
The identifier for the Account the Transaction belongs to.
-
accountId
final Transaction.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Builder amount(Long amount)
The Transaction amount in the minor unit of its currency. For dollars, for example, this is cents.
-
amount
final Transaction.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Transaction.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date on which the Transaction occurred.
-
createdAt
final Transaction.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Builder currency(Transaction.Currency currency)
The ISO 4217 code for the Transaction's currency. This will match the currency on the Transaction's Account.
-
currency
final Transaction.Builder currency(JsonField<Transaction.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Transaction.Builder description(String description)
An informational message describing this transaction. Use the fields in
sourceto get more detailed information. This field appears as the line-item on the statement.
-
description
final Transaction.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routeId
final Transaction.Builder routeId(String routeId)
The identifier for the route this Transaction came through. Routes are things like cards and ACH details.
-
routeId
final Transaction.Builder routeId(Optional<String> routeId)
Alias for calling Builder.routeId with
routeId.orElse(null).
-
routeId
final Transaction.Builder routeId(JsonField<String> routeId)
Sets Builder.routeId to an arbitrary JSON value.
You should usually call Builder.routeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routeType
final Transaction.Builder routeType(Transaction.RouteType routeType)
The type of the route this Transaction came through.
-
routeType
final Transaction.Builder routeType(Optional<Transaction.RouteType> routeType)
Alias for calling Builder.routeType with
routeType.orElse(null).
-
routeType
final Transaction.Builder routeType(JsonField<Transaction.RouteType> routeType)
Sets Builder.routeType to an arbitrary JSON value.
You should usually call Builder.routeType with a well-typed RouteType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
source
final Transaction.Builder source(Transaction.Source source)
This is an object giving more details on the network-level event that caused the Transaction. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
source
final Transaction.Builder source(JsonField<Transaction.Source> source)
Sets Builder.source to an arbitrary JSON value.
You should usually call Builder.source with a well-typed Source value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Transaction.Builder type(Transaction.Type type)
A constant representing the object's type. For this resource it will always be
transaction.
-
type
final Transaction.Builder type(JsonField<Transaction.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction build()
Returns an immutable instance of Transaction.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .amount() .createdAt() .currency() .description() .routeId() .routeType() .source() .type()
-
-
-
-