Enum Transaction.Currency.Value

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum Transaction.Currency.Value
    extends Enum<Transaction.Currency.Value>
                        

    An enum containing Currency's known values, as well as an _UNKNOWN member.

    An instance of Currency can contain an unknown value in a couple of cases:

    • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

    • It was constructed with an arbitrary value using the of method.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      CAD

      Canadian Dollar (CAD)

      CHF

      Swiss Franc (CHF)

      EUR

      Euro (EUR)

      GBP

      British Pound (GBP)

      JPY

      Japanese Yen (JPY)

      USD

      US Dollar (USD)

      _UNKNOWN

      An enum member indicating that Currency was instantiated with an unknown value.

    • Constructor Detail

    • Method Detail

      • valueOf

         final Transaction.Currency.Value valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • values

         final Array<Transaction.Currency.Value> values()

        Returns an array containing the constants of this enum type, in the order they're declared.

        This method may be used to iterate over the constants.

      • getEntries

         final EnumEntries<Transaction.Currency.Value> getEntries()

        An enum containing Currency's known values, as well as an _UNKNOWN member.

        An instance of Currency can contain an unknown value in a couple of cases:

        • It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

        • It was constructed with an arbitrary value using the of method.