Class Transaction.Source

  • All Implemented Interfaces:

    
    public final class Transaction.Source
    
                        

    This is an object giving more details on the network-level event that caused the Transaction. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.