Class Transaction.Source.AccountRevenuePayment

  • All Implemented Interfaces:

    
    public final class Transaction.Source.AccountRevenuePayment
    
                        

    An Account Revenue Payment object. This field will be present in the JSON response if and only if category is equal to account_revenue_payment. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.