Class Transaction.Source.AccountRevenuePayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.AccountRevenuePayment.BuilderA builder for AccountRevenuePayment.
-
-
Method Summary
-
-
Method Detail
-
accruedOnAccountId
final Transaction.Source.AccountRevenuePayment.Builder accruedOnAccountId(String accruedOnAccountId)
The account on which the account revenue was accrued.
-
accruedOnAccountId
final Transaction.Source.AccountRevenuePayment.Builder accruedOnAccountId(JsonField<String> accruedOnAccountId)
Sets Builder.accruedOnAccountId to an arbitrary JSON value.
You should usually call Builder.accruedOnAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodEnd
final Transaction.Source.AccountRevenuePayment.Builder periodEnd(OffsetDateTime periodEnd)
The end of the period for which this transaction paid account revenue.
-
periodEnd
final Transaction.Source.AccountRevenuePayment.Builder periodEnd(JsonField<OffsetDateTime> periodEnd)
Sets Builder.periodEnd to an arbitrary JSON value.
You should usually call Builder.periodEnd with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodStart
final Transaction.Source.AccountRevenuePayment.Builder periodStart(OffsetDateTime periodStart)
The start of the period for which this transaction paid account revenue.
-
periodStart
final Transaction.Source.AccountRevenuePayment.Builder periodStart(JsonField<OffsetDateTime> periodStart)
Sets Builder.periodStart to an arbitrary JSON value.
You should usually call Builder.periodStart with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.AccountRevenuePayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.AccountRevenuePayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.AccountRevenuePayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.AccountRevenuePayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.AccountRevenuePayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.AccountRevenuePayment build()
Returns an immutable instance of AccountRevenuePayment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accruedOnAccountId() .periodEnd() .periodStart()
-
-
-
-