Class Transaction.Source.AccountTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.AccountTransferIntentionAn Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.AccountTransferIntention.BuilderA builder for AccountTransferIntention.
public final classTransaction.Source.AccountTransferIntention.CurrencyThe ISO 4217 code for the destination account currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The pending amount in the minor unit of the transaction's currency. final Transaction.Source.AccountTransferIntention.Currencycurrency()The ISO 4217 code for the destination account currency. final Stringdescription()The description you chose to give the transfer. final StringdestinationAccountId()The identifier of the Account to where the Account Transfer was sent. final StringsourceAccountId()The identifier of the Account from where the Account Transfer was sent. final StringtransferId()The identifier of the Account Transfer that led to this Pending Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.AccountTransferIntention.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_destinationAccountId()Returns the raw JSON value of destinationAccountId. final JsonField<String>_sourceAccountId()Returns the raw JSON value of sourceAccountId. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.AccountTransferIntention.BuildertoBuilder()final Transaction.Source.AccountTransferIntentionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.AccountTransferIntention.Builderbuilder()Returns a mutable builder for constructing an instance of AccountTransferIntention. -
-
Method Detail
-
amount
final Long amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.AccountTransferIntention.Currency currency()
The ISO 4217 code for the destination account currency.
-
description
final String description()
The description you chose to give the transfer.
-
destinationAccountId
final String destinationAccountId()
The identifier of the Account to where the Account Transfer was sent.
-
sourceAccountId
final String sourceAccountId()
The identifier of the Account from where the Account Transfer was sent.
-
transferId
final String transferId()
The identifier of the Account Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.AccountTransferIntention.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountId
final JsonField<String> _destinationAccountId()
Returns the raw JSON value of destinationAccountId.
Unlike destinationAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountId
final JsonField<String> _sourceAccountId()
Returns the raw JSON value of sourceAccountId.
Unlike sourceAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.AccountTransferIntention.Builder toBuilder()
-
validate
final Transaction.Source.AccountTransferIntention validate()
-
builder
final static Transaction.Source.AccountTransferIntention.Builder builder()
Returns a mutable builder for constructing an instance of AccountTransferIntention.
The following fields are required:
.amount() .currency() .description() .destinationAccountId() .sourceAccountId() .transferId()
-
-
-
-