Class Transaction.Source.AchTransferIntention

  • All Implemented Interfaces:

    
    public final class Transaction.Source.AchTransferIntention
    
                        

    An ACH Transfer Intention object. This field will be present in the JSON response if and only if category is equal to ach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.