Class Transaction.Source.AchTransferIntention.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.AchTransferIntention.BuilderA builder for AchTransferIntention.
-
-
Method Summary
-
-
Method Detail
-
accountNumber
final Transaction.Source.AchTransferIntention.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final Transaction.Source.AchTransferIntention.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.AchTransferIntention.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.AchTransferIntention.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final Transaction.Source.AchTransferIntention.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final Transaction.Source.AchTransferIntention.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementDescriptor
final Transaction.Source.AchTransferIntention.Builder statementDescriptor(String statementDescriptor)
A description set when the ACH Transfer was created.
-
statementDescriptor
final Transaction.Source.AchTransferIntention.Builder statementDescriptor(JsonField<String> statementDescriptor)
Sets Builder.statementDescriptor to an arbitrary JSON value.
You should usually call Builder.statementDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.AchTransferIntention.Builder transferId(String transferId)
The identifier of the ACH Transfer that led to this Transaction.
-
transferId
final Transaction.Source.AchTransferIntention.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.AchTransferIntention.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.AchTransferIntention.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.AchTransferIntention.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.AchTransferIntention.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.AchTransferIntention.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.AchTransferIntention build()
Returns an immutable instance of AchTransferIntention.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumber() .amount() .routingNumber() .statementDescriptor() .transferId()
-
-
-
-