Class Transaction.Source.BlockchainOnrampTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.BlockchainOnrampTransferIntentionA Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_intention.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.BlockchainOnrampTransferIntention.BuilderA builder for BlockchainOnrampTransferIntention.
-
Method Summary
Modifier and Type Method Description final StringdestinationBlockchainAddress()The blockchain address the funds were sent to. final StringtransferId()The identifier of the Blockchain On-Ramp Transfer that led to this Transaction. final JsonField<String>_destinationBlockchainAddress()Returns the raw JSON value of destinationBlockchainAddress. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.BlockchainOnrampTransferIntention.BuildertoBuilder()final Transaction.Source.BlockchainOnrampTransferIntentionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.BlockchainOnrampTransferIntention.Builderbuilder()Returns a mutable builder for constructing an instance of BlockchainOnrampTransferIntention. -
-
Method Detail
-
destinationBlockchainAddress
final String destinationBlockchainAddress()
The blockchain address the funds were sent to.
-
transferId
final String transferId()
The identifier of the Blockchain On-Ramp Transfer that led to this Transaction.
-
_destinationBlockchainAddress
final JsonField<String> _destinationBlockchainAddress()
Returns the raw JSON value of destinationBlockchainAddress.
Unlike destinationBlockchainAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.BlockchainOnrampTransferIntention.Builder toBuilder()
-
validate
final Transaction.Source.BlockchainOnrampTransferIntention validate()
-
builder
final static Transaction.Source.BlockchainOnrampTransferIntention.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOnrampTransferIntention.
The following fields are required:
.destinationBlockchainAddress() .transferId()
-
-
-
-