Class Transaction.Source.BlockchainOnrampTransferIntention.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.BlockchainOnrampTransferIntention.BuilderA builder for BlockchainOnrampTransferIntention.
-
-
Method Summary
-
-
Method Detail
-
destinationBlockchainAddress
final Transaction.Source.BlockchainOnrampTransferIntention.Builder destinationBlockchainAddress(String destinationBlockchainAddress)
The blockchain address the funds were sent to.
-
destinationBlockchainAddress
final Transaction.Source.BlockchainOnrampTransferIntention.Builder destinationBlockchainAddress(JsonField<String> destinationBlockchainAddress)
Sets Builder.destinationBlockchainAddress to an arbitrary JSON value.
You should usually call Builder.destinationBlockchainAddress with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.BlockchainOnrampTransferIntention.Builder transferId(String transferId)
The identifier of the Blockchain On-Ramp Transfer that led to this Transaction.
-
transferId
final Transaction.Source.BlockchainOnrampTransferIntention.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.BlockchainOnrampTransferIntention.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.BlockchainOnrampTransferIntention.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.BlockchainOnrampTransferIntention.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.BlockchainOnrampTransferIntention.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.BlockchainOnrampTransferIntention.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.BlockchainOnrampTransferIntention build()
Returns an immutable instance of BlockchainOnrampTransferIntention.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.destinationBlockchainAddress() .transferId()
-
-
-
-