Class Transaction.Source.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.BuilderA builder for Source.
-
-
Method Summary
-
-
Method Detail
-
category
final Transaction.Source.Builder category(Transaction.Source.Category category)
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
category
final Transaction.Source.Builder category(JsonField<Transaction.Source.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountRevenuePayment
final Transaction.Source.Builder accountRevenuePayment(Transaction.Source.AccountRevenuePayment accountRevenuePayment)
An Account Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal toaccount_revenue_payment. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.
-
accountRevenuePayment
final Transaction.Source.Builder accountRevenuePayment(Optional<Transaction.Source.AccountRevenuePayment> accountRevenuePayment)
Alias for calling Builder.accountRevenuePayment with
accountRevenuePayment.orElse(null).
-
accountRevenuePayment
final Transaction.Source.Builder accountRevenuePayment(JsonField<Transaction.Source.AccountRevenuePayment> accountRevenuePayment)
Sets Builder.accountRevenuePayment to an arbitrary JSON value.
You should usually call Builder.accountRevenuePayment with a well-typed AccountRevenuePayment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountTransferIntention
final Transaction.Source.Builder accountTransferIntention(Transaction.Source.AccountTransferIntention accountTransferIntention)
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
accountTransferIntention
final Transaction.Source.Builder accountTransferIntention(Optional<Transaction.Source.AccountTransferIntention> accountTransferIntention)
Alias for calling Builder.accountTransferIntention with
accountTransferIntention.orElse(null).
-
accountTransferIntention
final Transaction.Source.Builder accountTransferIntention(JsonField<Transaction.Source.AccountTransferIntention> accountTransferIntention)
Sets Builder.accountTransferIntention to an arbitrary JSON value.
You should usually call Builder.accountTransferIntention with a well-typed AccountTransferIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achTransferIntention
final Transaction.Source.Builder achTransferIntention(Transaction.Source.AchTransferIntention achTransferIntention)
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
achTransferIntention
final Transaction.Source.Builder achTransferIntention(Optional<Transaction.Source.AchTransferIntention> achTransferIntention)
Alias for calling Builder.achTransferIntention with
achTransferIntention.orElse(null).
-
achTransferIntention
final Transaction.Source.Builder achTransferIntention(JsonField<Transaction.Source.AchTransferIntention> achTransferIntention)
Sets Builder.achTransferIntention to an arbitrary JSON value.
You should usually call Builder.achTransferIntention with a well-typed AchTransferIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achTransferRejection
final Transaction.Source.Builder achTransferRejection(Transaction.Source.AchTransferRejection achTransferRejection)
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
achTransferRejection
final Transaction.Source.Builder achTransferRejection(Optional<Transaction.Source.AchTransferRejection> achTransferRejection)
Alias for calling Builder.achTransferRejection with
achTransferRejection.orElse(null).
-
achTransferRejection
final Transaction.Source.Builder achTransferRejection(JsonField<Transaction.Source.AchTransferRejection> achTransferRejection)
Sets Builder.achTransferRejection to an arbitrary JSON value.
You should usually call Builder.achTransferRejection with a well-typed AchTransferRejection value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achTransferReturn
final Transaction.Source.Builder achTransferReturn(Transaction.Source.AchTransferReturn achTransferReturn)
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
achTransferReturn
final Transaction.Source.Builder achTransferReturn(Optional<Transaction.Source.AchTransferReturn> achTransferReturn)
Alias for calling Builder.achTransferReturn with
achTransferReturn.orElse(null).
-
achTransferReturn
final Transaction.Source.Builder achTransferReturn(JsonField<Transaction.Source.AchTransferReturn> achTransferReturn)
Sets Builder.achTransferReturn to an arbitrary JSON value.
You should usually call Builder.achTransferReturn with a well-typed AchTransferReturn value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
blockchainOfframpTransferSettlement
final Transaction.Source.Builder blockchainOfframpTransferSettlement(Transaction.Source.BlockchainOfframpTransferSettlement blockchainOfframpTransferSettlement)
A Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_settlement.
-
blockchainOfframpTransferSettlement
final Transaction.Source.Builder blockchainOfframpTransferSettlement(Optional<Transaction.Source.BlockchainOfframpTransferSettlement> blockchainOfframpTransferSettlement)
Alias for calling Builder.blockchainOfframpTransferSettlement with
blockchainOfframpTransferSettlement.orElse(null).
-
blockchainOfframpTransferSettlement
final Transaction.Source.Builder blockchainOfframpTransferSettlement(JsonField<Transaction.Source.BlockchainOfframpTransferSettlement> blockchainOfframpTransferSettlement)
Sets Builder.blockchainOfframpTransferSettlement to an arbitrary JSON value.
You should usually call Builder.blockchainOfframpTransferSettlement with a well-typed BlockchainOfframpTransferSettlement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
blockchainOnrampTransferIntention
final Transaction.Source.Builder blockchainOnrampTransferIntention(Transaction.Source.BlockchainOnrampTransferIntention blockchainOnrampTransferIntention)
A Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_intention.
-
blockchainOnrampTransferIntention
final Transaction.Source.Builder blockchainOnrampTransferIntention(Optional<Transaction.Source.BlockchainOnrampTransferIntention> blockchainOnrampTransferIntention)
Alias for calling Builder.blockchainOnrampTransferIntention with
blockchainOnrampTransferIntention.orElse(null).
-
blockchainOnrampTransferIntention
final Transaction.Source.Builder blockchainOnrampTransferIntention(JsonField<Transaction.Source.BlockchainOnrampTransferIntention> blockchainOnrampTransferIntention)
Sets Builder.blockchainOnrampTransferIntention to an arbitrary JSON value.
You should usually call Builder.blockchainOnrampTransferIntention with a well-typed BlockchainOnrampTransferIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDisputeAcceptance
final Transaction.Source.Builder cardDisputeAcceptance(Transaction.Source.CardDisputeAcceptance cardDisputeAcceptance)
A Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
cardDisputeAcceptance
final Transaction.Source.Builder cardDisputeAcceptance(Optional<Transaction.Source.CardDisputeAcceptance> cardDisputeAcceptance)
Alias for calling Builder.cardDisputeAcceptance with
cardDisputeAcceptance.orElse(null).
-
cardDisputeAcceptance
final Transaction.Source.Builder cardDisputeAcceptance(JsonField<Transaction.Source.CardDisputeAcceptance> cardDisputeAcceptance)
Sets Builder.cardDisputeAcceptance to an arbitrary JSON value.
You should usually call Builder.cardDisputeAcceptance with a well-typed CardDisputeAcceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDisputeFinancial
final Transaction.Source.Builder cardDisputeFinancial(Transaction.Source.CardDisputeFinancial cardDisputeFinancial)
A Card Dispute Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_financial. Financial event related to a Card Dispute.
-
cardDisputeFinancial
final Transaction.Source.Builder cardDisputeFinancial(Optional<Transaction.Source.CardDisputeFinancial> cardDisputeFinancial)
Alias for calling Builder.cardDisputeFinancial with
cardDisputeFinancial.orElse(null).
-
cardDisputeFinancial
final Transaction.Source.Builder cardDisputeFinancial(JsonField<Transaction.Source.CardDisputeFinancial> cardDisputeFinancial)
Sets Builder.cardDisputeFinancial to an arbitrary JSON value.
You should usually call Builder.cardDisputeFinancial with a well-typed CardDisputeFinancial value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDisputeLoss
final Transaction.Source.Builder cardDisputeLoss(Transaction.Source.CardDisputeLoss cardDisputeLoss)
A Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
cardDisputeLoss
final Transaction.Source.Builder cardDisputeLoss(Optional<Transaction.Source.CardDisputeLoss> cardDisputeLoss)
Alias for calling Builder.cardDisputeLoss with
cardDisputeLoss.orElse(null).
-
cardDisputeLoss
final Transaction.Source.Builder cardDisputeLoss(JsonField<Transaction.Source.CardDisputeLoss> cardDisputeLoss)
Sets Builder.cardDisputeLoss to an arbitrary JSON value.
You should usually call Builder.cardDisputeLoss with a well-typed CardDisputeLoss value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardFinancial
final Transaction.Source.Builder cardFinancial(Transaction.Source.CardFinancial cardFinancial)
A Card Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_financial. Card Financials are card transactions that have cleared and settled. Unlike a Card Settlement, which clears a previous authorization, a Card Financial is authorized and cleared in a single message.
-
cardFinancial
final Transaction.Source.Builder cardFinancial(Optional<Transaction.Source.CardFinancial> cardFinancial)
Alias for calling Builder.cardFinancial with
cardFinancial.orElse(null).
-
cardFinancial
final Transaction.Source.Builder cardFinancial(JsonField<Transaction.Source.CardFinancial> cardFinancial)
Sets Builder.cardFinancial to an arbitrary JSON value.
You should usually call Builder.cardFinancial with a well-typed CardFinancial value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPushTransferAcceptance
final Transaction.Source.Builder cardPushTransferAcceptance(Transaction.Source.CardPushTransferAcceptance cardPushTransferAcceptance)
A Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_acceptance. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.
-
cardPushTransferAcceptance
final Transaction.Source.Builder cardPushTransferAcceptance(Optional<Transaction.Source.CardPushTransferAcceptance> cardPushTransferAcceptance)
Alias for calling Builder.cardPushTransferAcceptance with
cardPushTransferAcceptance.orElse(null).
-
cardPushTransferAcceptance
final Transaction.Source.Builder cardPushTransferAcceptance(JsonField<Transaction.Source.CardPushTransferAcceptance> cardPushTransferAcceptance)
Sets Builder.cardPushTransferAcceptance to an arbitrary JSON value.
You should usually call Builder.cardPushTransferAcceptance with a well-typed CardPushTransferAcceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardRefund
final Transaction.Source.Builder cardRefund(Transaction.Source.CardRefund cardRefund)
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRefund
final Transaction.Source.Builder cardRefund(Optional<Transaction.Source.CardRefund> cardRefund)
Alias for calling Builder.cardRefund with
cardRefund.orElse(null).
-
cardRefund
final Transaction.Source.Builder cardRefund(JsonField<Transaction.Source.CardRefund> cardRefund)
Sets Builder.cardRefund to an arbitrary JSON value.
You should usually call Builder.cardRefund with a well-typed CardRefund value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardRevenuePayment
final Transaction.Source.Builder cardRevenuePayment(Transaction.Source.CardRevenuePayment cardRevenuePayment)
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
cardRevenuePayment
final Transaction.Source.Builder cardRevenuePayment(Optional<Transaction.Source.CardRevenuePayment> cardRevenuePayment)
Alias for calling Builder.cardRevenuePayment with
cardRevenuePayment.orElse(null).
-
cardRevenuePayment
final Transaction.Source.Builder cardRevenuePayment(JsonField<Transaction.Source.CardRevenuePayment> cardRevenuePayment)
Sets Builder.cardRevenuePayment to an arbitrary JSON value.
You should usually call Builder.cardRevenuePayment with a well-typed CardRevenuePayment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardSettlement
final Transaction.Source.Builder cardSettlement(Transaction.Source.CardSettlement cardSettlement)
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cardSettlement
final Transaction.Source.Builder cardSettlement(Optional<Transaction.Source.CardSettlement> cardSettlement)
Alias for calling Builder.cardSettlement with
cardSettlement.orElse(null).
-
cardSettlement
final Transaction.Source.Builder cardSettlement(JsonField<Transaction.Source.CardSettlement> cardSettlement)
Sets Builder.cardSettlement to an arbitrary JSON value.
You should usually call Builder.cardSettlement with a well-typed CardSettlement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashbackPayment
final Transaction.Source.Builder cashbackPayment(Transaction.Source.CashbackPayment cashbackPayment)
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
cashbackPayment
final Transaction.Source.Builder cashbackPayment(Optional<Transaction.Source.CashbackPayment> cashbackPayment)
Alias for calling Builder.cashbackPayment with
cashbackPayment.orElse(null).
-
cashbackPayment
final Transaction.Source.Builder cashbackPayment(JsonField<Transaction.Source.CashbackPayment> cashbackPayment)
Sets Builder.cashbackPayment to an arbitrary JSON value.
You should usually call Builder.cashbackPayment with a well-typed CashbackPayment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositAcceptance
final Transaction.Source.Builder checkDepositAcceptance(Transaction.Source.CheckDepositAcceptance checkDepositAcceptance)
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
checkDepositAcceptance
final Transaction.Source.Builder checkDepositAcceptance(Optional<Transaction.Source.CheckDepositAcceptance> checkDepositAcceptance)
Alias for calling Builder.checkDepositAcceptance with
checkDepositAcceptance.orElse(null).
-
checkDepositAcceptance
final Transaction.Source.Builder checkDepositAcceptance(JsonField<Transaction.Source.CheckDepositAcceptance> checkDepositAcceptance)
Sets Builder.checkDepositAcceptance to an arbitrary JSON value.
You should usually call Builder.checkDepositAcceptance with a well-typed CheckDepositAcceptance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkDepositReturn
final Transaction.Source.Builder checkDepositReturn(Transaction.Source.CheckDepositReturn checkDepositReturn)
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
checkDepositReturn
final Transaction.Source.Builder checkDepositReturn(Optional<Transaction.Source.CheckDepositReturn> checkDepositReturn)
Alias for calling Builder.checkDepositReturn with
checkDepositReturn.orElse(null).
-
checkDepositReturn
final Transaction.Source.Builder checkDepositReturn(JsonField<Transaction.Source.CheckDepositReturn> checkDepositReturn)
Sets Builder.checkDepositReturn to an arbitrary JSON value.
You should usually call Builder.checkDepositReturn with a well-typed CheckDepositReturn value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkTransferDeposit
final Transaction.Source.Builder checkTransferDeposit(Transaction.Source.CheckTransferDeposit checkTransferDeposit)
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
checkTransferDeposit
final Transaction.Source.Builder checkTransferDeposit(Optional<Transaction.Source.CheckTransferDeposit> checkTransferDeposit)
Alias for calling Builder.checkTransferDeposit with
checkTransferDeposit.orElse(null).
-
checkTransferDeposit
final Transaction.Source.Builder checkTransferDeposit(JsonField<Transaction.Source.CheckTransferDeposit> checkTransferDeposit)
Sets Builder.checkTransferDeposit to an arbitrary JSON value.
You should usually call Builder.checkTransferDeposit with a well-typed CheckTransferDeposit value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fednowTransferAcknowledgement
final Transaction.Source.Builder fednowTransferAcknowledgement(Transaction.Source.FednowTransferAcknowledgement fednowTransferAcknowledgement)
A FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_acknowledgement. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.
-
fednowTransferAcknowledgement
final Transaction.Source.Builder fednowTransferAcknowledgement(Optional<Transaction.Source.FednowTransferAcknowledgement> fednowTransferAcknowledgement)
Alias for calling Builder.fednowTransferAcknowledgement with
fednowTransferAcknowledgement.orElse(null).
-
fednowTransferAcknowledgement
final Transaction.Source.Builder fednowTransferAcknowledgement(JsonField<Transaction.Source.FednowTransferAcknowledgement> fednowTransferAcknowledgement)
Sets Builder.fednowTransferAcknowledgement to an arbitrary JSON value.
You should usually call Builder.fednowTransferAcknowledgement with a well-typed FednowTransferAcknowledgement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
feePayment
final Transaction.Source.Builder feePayment(Transaction.Source.FeePayment feePayment)
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
feePayment
final Transaction.Source.Builder feePayment(Optional<Transaction.Source.FeePayment> feePayment)
Alias for calling Builder.feePayment with
feePayment.orElse(null).
-
feePayment
final Transaction.Source.Builder feePayment(JsonField<Transaction.Source.FeePayment> feePayment)
Sets Builder.feePayment to an arbitrary JSON value.
You should usually call Builder.feePayment with a well-typed FeePayment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundAchTransfer
final Transaction.Source.Builder inboundAchTransfer(Transaction.Source.InboundAchTransfer inboundAchTransfer)
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
inboundAchTransfer
final Transaction.Source.Builder inboundAchTransfer(Optional<Transaction.Source.InboundAchTransfer> inboundAchTransfer)
Alias for calling Builder.inboundAchTransfer with
inboundAchTransfer.orElse(null).
-
inboundAchTransfer
final Transaction.Source.Builder inboundAchTransfer(JsonField<Transaction.Source.InboundAchTransfer> inboundAchTransfer)
Sets Builder.inboundAchTransfer to an arbitrary JSON value.
You should usually call Builder.inboundAchTransfer with a well-typed InboundAchTransfer value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundAchTransferReturnIntention
final Transaction.Source.Builder inboundAchTransferReturnIntention(Transaction.Source.InboundAchTransferReturnIntention inboundAchTransferReturnIntention)
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
inboundAchTransferReturnIntention
final Transaction.Source.Builder inboundAchTransferReturnIntention(Optional<Transaction.Source.InboundAchTransferReturnIntention> inboundAchTransferReturnIntention)
Alias for calling Builder.inboundAchTransferReturnIntention with
inboundAchTransferReturnIntention.orElse(null).
-
inboundAchTransferReturnIntention
final Transaction.Source.Builder inboundAchTransferReturnIntention(JsonField<Transaction.Source.InboundAchTransferReturnIntention> inboundAchTransferReturnIntention)
Sets Builder.inboundAchTransferReturnIntention to an arbitrary JSON value.
You should usually call Builder.inboundAchTransferReturnIntention with a well-typed InboundAchTransferReturnIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundCheckAdjustment
final Transaction.Source.Builder inboundCheckAdjustment(Transaction.Source.InboundCheckAdjustment inboundCheckAdjustment)
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
inboundCheckAdjustment
final Transaction.Source.Builder inboundCheckAdjustment(Optional<Transaction.Source.InboundCheckAdjustment> inboundCheckAdjustment)
Alias for calling Builder.inboundCheckAdjustment with
inboundCheckAdjustment.orElse(null).
-
inboundCheckAdjustment
final Transaction.Source.Builder inboundCheckAdjustment(JsonField<Transaction.Source.InboundCheckAdjustment> inboundCheckAdjustment)
Sets Builder.inboundCheckAdjustment to an arbitrary JSON value.
You should usually call Builder.inboundCheckAdjustment with a well-typed InboundCheckAdjustment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundCheckDepositReturnIntention
final Transaction.Source.Builder inboundCheckDepositReturnIntention(Transaction.Source.InboundCheckDepositReturnIntention inboundCheckDepositReturnIntention)
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
inboundCheckDepositReturnIntention
final Transaction.Source.Builder inboundCheckDepositReturnIntention(Optional<Transaction.Source.InboundCheckDepositReturnIntention> inboundCheckDepositReturnIntention)
Alias for calling Builder.inboundCheckDepositReturnIntention with
inboundCheckDepositReturnIntention.orElse(null).
-
inboundCheckDepositReturnIntention
final Transaction.Source.Builder inboundCheckDepositReturnIntention(JsonField<Transaction.Source.InboundCheckDepositReturnIntention> inboundCheckDepositReturnIntention)
Sets Builder.inboundCheckDepositReturnIntention to an arbitrary JSON value.
You should usually call Builder.inboundCheckDepositReturnIntention with a well-typed InboundCheckDepositReturnIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundFednowTransferConfirmation
final Transaction.Source.Builder inboundFednowTransferConfirmation(Transaction.Source.InboundFednowTransferConfirmation inboundFednowTransferConfirmation)
An Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_confirmation. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.
-
inboundFednowTransferConfirmation
final Transaction.Source.Builder inboundFednowTransferConfirmation(Optional<Transaction.Source.InboundFednowTransferConfirmation> inboundFednowTransferConfirmation)
Alias for calling Builder.inboundFednowTransferConfirmation with
inboundFednowTransferConfirmation.orElse(null).
-
inboundFednowTransferConfirmation
final Transaction.Source.Builder inboundFednowTransferConfirmation(JsonField<Transaction.Source.InboundFednowTransferConfirmation> inboundFednowTransferConfirmation)
Sets Builder.inboundFednowTransferConfirmation to an arbitrary JSON value.
You should usually call Builder.inboundFednowTransferConfirmation with a well-typed InboundFednowTransferConfirmation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundRealTimePaymentsTransferConfirmation
final Transaction.Source.Builder inboundRealTimePaymentsTransferConfirmation(Transaction.Source.InboundRealTimePaymentsTransferConfirmation inboundRealTimePaymentsTransferConfirmation)
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
inboundRealTimePaymentsTransferConfirmation
final Transaction.Source.Builder inboundRealTimePaymentsTransferConfirmation(Optional<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> inboundRealTimePaymentsTransferConfirmation)
Alias for calling Builder.inboundRealTimePaymentsTransferConfirmation with
inboundRealTimePaymentsTransferConfirmation.orElse(null).
-
inboundRealTimePaymentsTransferConfirmation
final Transaction.Source.Builder inboundRealTimePaymentsTransferConfirmation(JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> inboundRealTimePaymentsTransferConfirmation)
Sets Builder.inboundRealTimePaymentsTransferConfirmation to an arbitrary JSON value.
You should usually call Builder.inboundRealTimePaymentsTransferConfirmation with a well-typed InboundRealTimePaymentsTransferConfirmation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireReversal
final Transaction.Source.Builder inboundWireReversal(Transaction.Source.InboundWireReversal inboundWireReversal)
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
inboundWireReversal
final Transaction.Source.Builder inboundWireReversal(Optional<Transaction.Source.InboundWireReversal> inboundWireReversal)
Alias for calling Builder.inboundWireReversal with
inboundWireReversal.orElse(null).
-
inboundWireReversal
final Transaction.Source.Builder inboundWireReversal(JsonField<Transaction.Source.InboundWireReversal> inboundWireReversal)
Sets Builder.inboundWireReversal to an arbitrary JSON value.
You should usually call Builder.inboundWireReversal with a well-typed InboundWireReversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireTransfer
final Transaction.Source.Builder inboundWireTransfer(Transaction.Source.InboundWireTransfer inboundWireTransfer)
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
inboundWireTransfer
final Transaction.Source.Builder inboundWireTransfer(Optional<Transaction.Source.InboundWireTransfer> inboundWireTransfer)
Alias for calling Builder.inboundWireTransfer with
inboundWireTransfer.orElse(null).
-
inboundWireTransfer
final Transaction.Source.Builder inboundWireTransfer(JsonField<Transaction.Source.InboundWireTransfer> inboundWireTransfer)
Sets Builder.inboundWireTransfer to an arbitrary JSON value.
You should usually call Builder.inboundWireTransfer with a well-typed InboundWireTransfer value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireTransferReversal
final Transaction.Source.Builder inboundWireTransferReversal(Transaction.Source.InboundWireTransferReversal inboundWireTransferReversal)
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
inboundWireTransferReversal
final Transaction.Source.Builder inboundWireTransferReversal(Optional<Transaction.Source.InboundWireTransferReversal> inboundWireTransferReversal)
Alias for calling Builder.inboundWireTransferReversal with
inboundWireTransferReversal.orElse(null).
-
inboundWireTransferReversal
final Transaction.Source.Builder inboundWireTransferReversal(JsonField<Transaction.Source.InboundWireTransferReversal> inboundWireTransferReversal)
Sets Builder.inboundWireTransferReversal to an arbitrary JSON value.
You should usually call Builder.inboundWireTransferReversal with a well-typed InboundWireTransferReversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interestPayment
final Transaction.Source.Builder interestPayment(Transaction.Source.InterestPayment interestPayment)
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
interestPayment
final Transaction.Source.Builder interestPayment(Optional<Transaction.Source.InterestPayment> interestPayment)
Alias for calling Builder.interestPayment with
interestPayment.orElse(null).
-
interestPayment
final Transaction.Source.Builder interestPayment(JsonField<Transaction.Source.InterestPayment> interestPayment)
Sets Builder.interestPayment to an arbitrary JSON value.
You should usually call Builder.interestPayment with a well-typed InterestPayment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
internalSource
final Transaction.Source.Builder internalSource(Transaction.Source.InternalSource internalSource)
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
internalSource
final Transaction.Source.Builder internalSource(Optional<Transaction.Source.InternalSource> internalSource)
Alias for calling Builder.internalSource with
internalSource.orElse(null).
-
internalSource
final Transaction.Source.Builder internalSource(JsonField<Transaction.Source.InternalSource> internalSource)
Sets Builder.internalSource to an arbitrary JSON value.
You should usually call Builder.internalSource with a well-typed InternalSource value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
other
final Transaction.Source.Builder other(Transaction.Source.Other other)
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
other
final Transaction.Source.Builder other(Optional<Transaction.Source.Other> other)
Alias for calling Builder.other with
other.orElse(null).
-
other
final Transaction.Source.Builder other(JsonField<Transaction.Source.Other> other)
Sets Builder.other to an arbitrary JSON value.
You should usually call Builder.other with a well-typed Other value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
realTimePaymentsTransferAcknowledgement
final Transaction.Source.Builder realTimePaymentsTransferAcknowledgement(Transaction.Source.RealTimePaymentsTransferAcknowledgement realTimePaymentsTransferAcknowledgement)
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
realTimePaymentsTransferAcknowledgement
final Transaction.Source.Builder realTimePaymentsTransferAcknowledgement(Optional<Transaction.Source.RealTimePaymentsTransferAcknowledgement> realTimePaymentsTransferAcknowledgement)
Alias for calling Builder.realTimePaymentsTransferAcknowledgement with
realTimePaymentsTransferAcknowledgement.orElse(null).
-
realTimePaymentsTransferAcknowledgement
final Transaction.Source.Builder realTimePaymentsTransferAcknowledgement(JsonField<Transaction.Source.RealTimePaymentsTransferAcknowledgement> realTimePaymentsTransferAcknowledgement)
Sets Builder.realTimePaymentsTransferAcknowledgement to an arbitrary JSON value.
You should usually call Builder.realTimePaymentsTransferAcknowledgement with a well-typed RealTimePaymentsTransferAcknowledgement value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sampleFunds
final Transaction.Source.Builder sampleFunds(Transaction.Source.SampleFunds sampleFunds)
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
sampleFunds
final Transaction.Source.Builder sampleFunds(Optional<Transaction.Source.SampleFunds> sampleFunds)
Alias for calling Builder.sampleFunds with
sampleFunds.orElse(null).
-
sampleFunds
final Transaction.Source.Builder sampleFunds(JsonField<Transaction.Source.SampleFunds> sampleFunds)
Sets Builder.sampleFunds to an arbitrary JSON value.
You should usually call Builder.sampleFunds with a well-typed SampleFunds value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
swiftTransferIntention
final Transaction.Source.Builder swiftTransferIntention(Transaction.Source.SwiftTransferIntention swiftTransferIntention)
A Swift Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_intention. A Swift Transfer initiated via Increase.
-
swiftTransferIntention
final Transaction.Source.Builder swiftTransferIntention(Optional<Transaction.Source.SwiftTransferIntention> swiftTransferIntention)
Alias for calling Builder.swiftTransferIntention with
swiftTransferIntention.orElse(null).
-
swiftTransferIntention
final Transaction.Source.Builder swiftTransferIntention(JsonField<Transaction.Source.SwiftTransferIntention> swiftTransferIntention)
Sets Builder.swiftTransferIntention to an arbitrary JSON value.
You should usually call Builder.swiftTransferIntention with a well-typed SwiftTransferIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
swiftTransferReturn
final Transaction.Source.Builder swiftTransferReturn(Transaction.Source.SwiftTransferReturn swiftTransferReturn)
A Swift Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_return. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.
-
swiftTransferReturn
final Transaction.Source.Builder swiftTransferReturn(Optional<Transaction.Source.SwiftTransferReturn> swiftTransferReturn)
Alias for calling Builder.swiftTransferReturn with
swiftTransferReturn.orElse(null).
-
swiftTransferReturn
final Transaction.Source.Builder swiftTransferReturn(JsonField<Transaction.Source.SwiftTransferReturn> swiftTransferReturn)
Sets Builder.swiftTransferReturn to an arbitrary JSON value.
You should usually call Builder.swiftTransferReturn with a well-typed SwiftTransferReturn value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireTransferIntention
final Transaction.Source.Builder wireTransferIntention(Transaction.Source.WireTransferIntention wireTransferIntention)
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
wireTransferIntention
final Transaction.Source.Builder wireTransferIntention(Optional<Transaction.Source.WireTransferIntention> wireTransferIntention)
Alias for calling Builder.wireTransferIntention with
wireTransferIntention.orElse(null).
-
wireTransferIntention
final Transaction.Source.Builder wireTransferIntention(JsonField<Transaction.Source.WireTransferIntention> wireTransferIntention)
Sets Builder.wireTransferIntention to an arbitrary JSON value.
You should usually call Builder.wireTransferIntention with a well-typed WireTransferIntention value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source build()
Returns an immutable instance of Source.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category()
-
-
-
-