Class Transaction.Source.CardDisputeAcceptance
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeAcceptanceA Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardDisputeAcceptance.BuilderA builder for CardDisputeAcceptance.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimeacceptedAt()The ISO 8601 date and time at which the Card Dispute was accepted. final StringtransactionId()The identifier of the Transaction that was created to return the disputed funds to your account. final JsonField<OffsetDateTime>_acceptedAt()Returns the raw JSON value of acceptedAt. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardDisputeAcceptance.BuildertoBuilder()final Transaction.Source.CardDisputeAcceptancevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardDisputeAcceptance.Builderbuilder()Returns a mutable builder for constructing an instance of CardDisputeAcceptance. -
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the Card Dispute was accepted.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to return the disputed funds to your account.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardDisputeAcceptance.Builder toBuilder()
-
validate
final Transaction.Source.CardDisputeAcceptance validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardDisputeAcceptance.Builder builder()
Returns a mutable builder for constructing an instance of CardDisputeAcceptance.
The following fields are required:
.acceptedAt() .transactionId()
-
-
-
-