Class Transaction.Source.CardDisputeAcceptance.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeAcceptance.BuilderA builder for CardDisputeAcceptance.
-
-
Method Summary
-
-
Method Detail
-
acceptedAt
final Transaction.Source.CardDisputeAcceptance.Builder acceptedAt(OffsetDateTime acceptedAt)
The ISO 8601 date and time at which the Card Dispute was accepted.
-
acceptedAt
final Transaction.Source.CardDisputeAcceptance.Builder acceptedAt(JsonField<OffsetDateTime> acceptedAt)
Sets Builder.acceptedAt to an arbitrary JSON value.
You should usually call Builder.acceptedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardDisputeId
final Transaction.Source.CardDisputeAcceptance.Builder cardDisputeId(String cardDisputeId)
The identifier of the Card Dispute that was accepted.
-
cardDisputeId
final Transaction.Source.CardDisputeAcceptance.Builder cardDisputeId(JsonField<String> cardDisputeId)
Sets Builder.cardDisputeId to an arbitrary JSON value.
You should usually call Builder.cardDisputeId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CardDisputeAcceptance.Builder transactionId(String transactionId)
The identifier of the Transaction that was created to return the disputed funds to your account.
-
transactionId
final Transaction.Source.CardDisputeAcceptance.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardDisputeAcceptance.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardDisputeAcceptance.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardDisputeAcceptance.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardDisputeAcceptance.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardDisputeAcceptance.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardDisputeAcceptance build()
Returns an immutable instance of CardDisputeAcceptance.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.acceptedAt() .cardDisputeId() .transactionId()
-
-
-
-