Class Transaction.Source.CardDisputeFinancial
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeFinancialA Card Dispute Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_financial. Financial event related to a Card Dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardDisputeFinancial.BuilderA builder for CardDisputeFinancial.
public final classTransaction.Source.CardDisputeFinancial.NetworkThe network that the Card Dispute is associated with.
public final classTransaction.Source.CardDisputeFinancial.VisaInformation for events related to card dispute for card payments processed over Visa's network. This field will be present in the JSON response if and only if
networkis equal tovisa.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the financial event. final Transaction.Source.CardDisputeFinancial.Networknetwork()The network that the Card Dispute is associated with. final StringtransactionId()The identifier of the Transaction that was created to credit or debit the disputed funds to or from your account. final Optional<Transaction.Source.CardDisputeFinancial.Visa>visa()Information for events related to card dispute for card payments processed over Visa's network. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.CardDisputeFinancial.Network>_network()Returns the raw JSON value of network. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<Transaction.Source.CardDisputeFinancial.Visa>_visa()Returns the raw JSON value of visa. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardDisputeFinancial.BuildertoBuilder()final Transaction.Source.CardDisputeFinancialvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardDisputeFinancial.Builderbuilder()Returns a mutable builder for constructing an instance of CardDisputeFinancial. -
-
Method Detail
-
network
final Transaction.Source.CardDisputeFinancial.Network network()
The network that the Card Dispute is associated with.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to credit or debit the disputed funds to or from your account.
-
visa
final Optional<Transaction.Source.CardDisputeFinancial.Visa> visa()
Information for events related to card dispute for card payments processed over Visa's network. This field will be present in the JSON response if and only if
networkis equal tovisa.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<Transaction.Source.CardDisputeFinancial.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<Transaction.Source.CardDisputeFinancial.Visa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardDisputeFinancial.Builder toBuilder()
-
validate
final Transaction.Source.CardDisputeFinancial validate()
-
builder
final static Transaction.Source.CardDisputeFinancial.Builder builder()
Returns a mutable builder for constructing an instance of CardDisputeFinancial.
The following fields are required:
.amount() .network() .transactionId() .visa()
-
-
-
-