Class Transaction.Source.CardDisputeFinancial.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeFinancial.BuilderA builder for CardDisputeFinancial.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.CardDisputeFinancial.Builder amount(Long amount)
The amount of the financial event.
-
amount
final Transaction.Source.CardDisputeFinancial.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final Transaction.Source.CardDisputeFinancial.Builder network(Transaction.Source.CardDisputeFinancial.Network network)
The network that the Card Dispute is associated with.
-
network
final Transaction.Source.CardDisputeFinancial.Builder network(JsonField<Transaction.Source.CardDisputeFinancial.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CardDisputeFinancial.Builder transactionId(String transactionId)
The identifier of the Transaction that was created to credit or debit the disputed funds to or from your account.
-
transactionId
final Transaction.Source.CardDisputeFinancial.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
visa
final Transaction.Source.CardDisputeFinancial.Builder visa(Transaction.Source.CardDisputeFinancial.Visa visa)
Information for events related to card dispute for card payments processed over Visa's network. This field will be present in the JSON response if and only if
networkis equal tovisa.
-
visa
final Transaction.Source.CardDisputeFinancial.Builder visa(Optional<Transaction.Source.CardDisputeFinancial.Visa> visa)
Alias for calling Builder.visa with
visa.orElse(null).
-
visa
final Transaction.Source.CardDisputeFinancial.Builder visa(JsonField<Transaction.Source.CardDisputeFinancial.Visa> visa)
Sets Builder.visa to an arbitrary JSON value.
You should usually call Builder.visa with a well-typed Visa value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardDisputeFinancial.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardDisputeFinancial.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardDisputeFinancial.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardDisputeFinancial.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardDisputeFinancial.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardDisputeFinancial build()
Returns an immutable instance of CardDisputeFinancial.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .network() .transactionId() .visa()
-
-
-
-