Class Transaction.Source.CardDisputeLoss
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeLossA Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardDisputeLoss.BuilderA builder for CardDisputeLoss.
-
Method Summary
Modifier and Type Method Description final Stringexplanation()Why the Card Dispute was lost. final OffsetDateTimelostAt()The ISO 8601 date and time at which the Card Dispute was lost. final StringtransactionId()The identifier of the Transaction that was created to debit the disputed funds from your account. final JsonField<String>_explanation()Returns the raw JSON value of explanation. final JsonField<OffsetDateTime>_lostAt()Returns the raw JSON value of lostAt. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardDisputeLoss.BuildertoBuilder()final Transaction.Source.CardDisputeLossvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardDisputeLoss.Builderbuilder()Returns a mutable builder for constructing an instance of CardDisputeLoss. -
-
Method Detail
-
explanation
final String explanation()
Why the Card Dispute was lost.
-
lostAt
final OffsetDateTime lostAt()
The ISO 8601 date and time at which the Card Dispute was lost.
-
transactionId
final String transactionId()
The identifier of the Transaction that was created to debit the disputed funds from your account.
-
_explanation
final JsonField<String> _explanation()
Returns the raw JSON value of explanation.
Unlike explanation, this method doesn't throw if the JSON field has an unexpected type.
-
_lostAt
final JsonField<OffsetDateTime> _lostAt()
Returns the raw JSON value of lostAt.
Unlike lostAt, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardDisputeLoss.Builder toBuilder()
-
validate
final Transaction.Source.CardDisputeLoss validate()
-
builder
final static Transaction.Source.CardDisputeLoss.Builder builder()
Returns a mutable builder for constructing an instance of CardDisputeLoss.
The following fields are required:
.explanation() .lostAt() .transactionId()
-
-
-
-