Class Transaction.Source.CardDisputeLoss.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeLoss.BuilderA builder for CardDisputeLoss.
-
-
Method Summary
-
-
Method Detail
-
explanation
final Transaction.Source.CardDisputeLoss.Builder explanation(String explanation)
Why the Card Dispute was lost.
-
explanation
final Transaction.Source.CardDisputeLoss.Builder explanation(JsonField<String> explanation)
Sets Builder.explanation to an arbitrary JSON value.
You should usually call Builder.explanation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lostAt
final Transaction.Source.CardDisputeLoss.Builder lostAt(OffsetDateTime lostAt)
The ISO 8601 date and time at which the Card Dispute was lost.
-
lostAt
final Transaction.Source.CardDisputeLoss.Builder lostAt(JsonField<OffsetDateTime> lostAt)
Sets Builder.lostAt to an arbitrary JSON value.
You should usually call Builder.lostAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CardDisputeLoss.Builder transactionId(String transactionId)
The identifier of the Transaction that was created to debit the disputed funds from your account.
-
transactionId
final Transaction.Source.CardDisputeLoss.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardDisputeLoss.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardDisputeLoss.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardDisputeLoss.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardDisputeLoss.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardDisputeLoss.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardDisputeLoss build()
Returns an immutable instance of CardDisputeLoss.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.explanation() .lostAt() .transactionId()
-
-
-
-