Class Transaction.Source.CardFinancial
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancialA Card Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_financial. Card Financials are temporary holds placed on a customer's funds with the intent to later clear a transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardFinancial.BuilderA builder for CardFinancial.
public final classTransaction.Source.CardFinancial.ActionerWhether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classTransaction.Source.CardFinancial.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.public final classTransaction.Source.CardFinancial.CurrencyThe ISO 4217 code for the transaction's currency.
public final classTransaction.Source.CardFinancial.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classTransaction.Source.CardFinancial.NetworkDetailsFields specific to the
network.public final classTransaction.Source.CardFinancial.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classTransaction.Source.CardFinancial.ProcessingCategoryThe processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
public final classTransaction.Source.CardFinancial.SchemeFeepublic final classTransaction.Source.CardFinancial.TypeA constant representing the object's type. For this resource it will always be
card_financial.public final classTransaction.Source.CardFinancial.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Financial identifier. final Transaction.Source.CardFinancial.Actioneractioner()Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final Transaction.Source.CardFinancial.AdditionalAmountsadditionalAmounts()Additional amounts associated with the card authorization, such as ATM surcharges fees. final Longamount()The pending amount in the minor unit of the transaction's currency. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final Transaction.Source.CardFinancial.Currencycurrency()The ISO 4217 code for the transaction's currency. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final Transaction.Source.CardFinancial.Directiondirection()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final Transaction.Source.CardFinancial.NetworkDetailsnetworkDetails()Fields specific to the network.final Transaction.Source.CardFinancial.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final LongpresentmentAmount()The pending amount in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final Transaction.Source.CardFinancial.ProcessingCategoryprocessingCategory()The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final List<Transaction.Source.CardFinancial.SchemeFee>schemeFees()The scheme fees associated with this card financial. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final StringtransactionId()The identifier of the Transaction associated with this Transaction. final Transaction.Source.CardFinancial.Typetype()A constant representing the object's type. final Transaction.Source.CardFinancial.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Transaction.Source.CardFinancial.Actioner>_actioner()Returns the raw JSON value of actioner. final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts>_additionalAmounts()Returns the raw JSON value of additionalAmounts. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<Transaction.Source.CardFinancial.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<Transaction.Source.CardFinancial.Direction>_direction()Returns the raw JSON value of direction. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<Transaction.Source.CardFinancial.NetworkDetails>_networkDetails()Returns the raw JSON value of networkDetails. final JsonField<Transaction.Source.CardFinancial.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<Long>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_presentmentCurrency()Returns the raw JSON value of presentmentCurrency. final JsonField<Transaction.Source.CardFinancial.ProcessingCategory>_processingCategory()Returns the raw JSON value of processingCategory. final JsonField<String>_realTimeDecisionId()Returns the raw JSON value of realTimeDecisionId. final JsonField<List<Transaction.Source.CardFinancial.SchemeFee>>_schemeFees()Returns the raw JSON value of schemeFees. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<Transaction.Source.CardFinancial.Type>_type()Returns the raw JSON value of type. final JsonField<Transaction.Source.CardFinancial.Verification>_verification()Returns the raw JSON value of verification. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardFinancial.BuildertoBuilder()final Transaction.Source.CardFinancialvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardFinancial.Builderbuilder()Returns a mutable builder for constructing an instance of CardFinancial. -
-
Method Detail
-
actioner
final Transaction.Source.CardFinancial.Actioner actioner()
Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
additionalAmounts
final Transaction.Source.CardFinancial.AdditionalAmounts additionalAmounts()
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
amount
final Long amount()
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
currency
final Transaction.Source.CardFinancial.Currency currency()
The ISO 4217 code for the transaction's currency.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
direction
final Transaction.Source.CardFinancial.Direction direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final Transaction.Source.CardFinancial.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final Transaction.Source.CardFinancial.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
presentmentAmount
final Long presentmentAmount()
The pending amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
processingCategory
final Transaction.Source.CardFinancial.ProcessingCategory processingCategory()
The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
schemeFees
final List<Transaction.Source.CardFinancial.SchemeFee> schemeFees()
The scheme fees associated with this card financial.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
transactionId
final String transactionId()
The identifier of the Transaction associated with this Transaction.
-
type
final Transaction.Source.CardFinancial.Type type()
A constant representing the object's type. For this resource it will always be
card_financial.
-
verification
final Transaction.Source.CardFinancial.Verification verification()
Fields related to verification of cardholder-provided values.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_actioner
final JsonField<Transaction.Source.CardFinancial.Actioner> _actioner()
Returns the raw JSON value of actioner.
Unlike actioner, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalAmounts
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts> _additionalAmounts()
Returns the raw JSON value of additionalAmounts.
Unlike additionalAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CardFinancial.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<Transaction.Source.CardFinancial.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_networkDetails
final JsonField<Transaction.Source.CardFinancial.NetworkDetails> _networkDetails()
Returns the raw JSON value of networkDetails.
Unlike networkDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<Transaction.Source.CardFinancial.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
Returns the raw JSON value of presentmentCurrency.
Unlike presentmentCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_processingCategory
final JsonField<Transaction.Source.CardFinancial.ProcessingCategory> _processingCategory()
Returns the raw JSON value of processingCategory.
Unlike processingCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_schemeFees
final JsonField<List<Transaction.Source.CardFinancial.SchemeFee>> _schemeFees()
Returns the raw JSON value of schemeFees.
Unlike schemeFees, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Transaction.Source.CardFinancial.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_verification
final JsonField<Transaction.Source.CardFinancial.Verification> _verification()
Returns the raw JSON value of verification.
Unlike verification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardFinancial.Builder toBuilder()
-
validate
final Transaction.Source.CardFinancial validate()
-
builder
final static Transaction.Source.CardFinancial.Builder builder()
Returns a mutable builder for constructing an instance of CardFinancial.
The following fields are required:
.id() .actioner() .additionalAmounts() .amount() .cardPaymentId() .currency() .digitalWalletTokenId() .direction() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .presentmentAmount() .presentmentCurrency() .processingCategory() .realTimeDecisionId() .schemeFees() .terminalId() .transactionId() .type() .verification()
-
-
-
-