Class Transaction.Source.CardFinancial.AdditionalAmounts
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardFinancial.AdditionalAmounts.BuilderA builder for AdditionalAmounts.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.ClinicThe part of this transaction amount that was for clinic-related services.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.DentalThe part of this transaction amount that was for dental-related services.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.OriginalThe original pre-authorized amount.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.PrescriptionThe part of this transaction amount that was for healthcare prescriptions.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.SurchargeThe surcharge amount charged for this transaction by the merchant.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.TotalCumulativeThe total amount of a series of incremental authorizations, optionally provided.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.TotalHealthcareThe total amount of healthcare-related additional amounts.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.TransitThe part of this transaction amount that was for transit-related services.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.UnknownAn unknown additional amount.
public final classTransaction.Source.CardFinancial.AdditionalAmounts.VisionThe part of this transaction amount that was for vision-related services.
-
Method Summary
-
-
Method Detail
-
clinic
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Clinic> clinic()
The part of this transaction amount that was for clinic-related services.
-
dental
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Dental> dental()
The part of this transaction amount that was for dental-related services.
-
original
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Original> original()
The original pre-authorized amount.
-
prescription
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Prescription> prescription()
The part of this transaction amount that was for healthcare prescriptions.
-
surcharge
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Surcharge> surcharge()
The surcharge amount charged for this transaction by the merchant.
-
totalCumulative
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.TotalCumulative> totalCumulative()
The total amount of a series of incremental authorizations, optionally provided.
-
totalHealthcare
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.TotalHealthcare> totalHealthcare()
The total amount of healthcare-related additional amounts.
-
transit
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Transit> transit()
The part of this transaction amount that was for transit-related services.
-
unknown
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Unknown> unknown()
An unknown additional amount.
-
vision
final Optional<Transaction.Source.CardFinancial.AdditionalAmounts.Vision> vision()
The part of this transaction amount that was for vision-related services.
-
_clinic
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Clinic> _clinic()
Returns the raw JSON value of clinic.
Unlike clinic, this method doesn't throw if the JSON field has an unexpected type.
-
_dental
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Dental> _dental()
Returns the raw JSON value of dental.
Unlike dental, this method doesn't throw if the JSON field has an unexpected type.
-
_original
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Original> _original()
Returns the raw JSON value of original.
Unlike original, this method doesn't throw if the JSON field has an unexpected type.
-
_prescription
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Prescription> _prescription()
Returns the raw JSON value of prescription.
Unlike prescription, this method doesn't throw if the JSON field has an unexpected type.
-
_surcharge
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Surcharge> _surcharge()
Returns the raw JSON value of surcharge.
Unlike surcharge, this method doesn't throw if the JSON field has an unexpected type.
-
_totalCumulative
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.TotalCumulative> _totalCumulative()
Returns the raw JSON value of totalCumulative.
Unlike totalCumulative, this method doesn't throw if the JSON field has an unexpected type.
-
_totalHealthcare
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.TotalHealthcare> _totalHealthcare()
Returns the raw JSON value of totalHealthcare.
Unlike totalHealthcare, this method doesn't throw if the JSON field has an unexpected type.
-
_transit
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Transit> _transit()
Returns the raw JSON value of transit.
Unlike transit, this method doesn't throw if the JSON field has an unexpected type.
-
_unknown
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Unknown> _unknown()
Returns the raw JSON value of unknown.
Unlike unknown, this method doesn't throw if the JSON field has an unexpected type.
-
_vision
final JsonField<Transaction.Source.CardFinancial.AdditionalAmounts.Vision> _vision()
Returns the raw JSON value of vision.
Unlike vision, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardFinancial.AdditionalAmounts.Builder toBuilder()
-
validate
final Transaction.Source.CardFinancial.AdditionalAmounts validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardFinancial.AdditionalAmounts.Builder builder()
Returns a mutable builder for constructing an instance of AdditionalAmounts.
The following fields are required:
.clinic() .dental() .original() .prescription() .surcharge() .totalCumulative() .totalHealthcare() .transit() .unknown() .vision()
-
-
-
-