Class Transaction.Source.CardFinancial.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.BuilderA builder for CardFinancial.
-
-
Method Summary
-
-
Method Detail
-
id
final Transaction.Source.CardFinancial.Builder id(String id)
The Card Financial identifier.
-
id
final Transaction.Source.CardFinancial.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
actioner
final Transaction.Source.CardFinancial.Builder actioner(Transaction.Source.CardFinancial.Actioner actioner)
Whether this financial was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
actioner
final Transaction.Source.CardFinancial.Builder actioner(JsonField<Transaction.Source.CardFinancial.Actioner> actioner)
Sets Builder.actioner to an arbitrary JSON value.
You should usually call Builder.actioner with a well-typed Actioner value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalAmounts
final Transaction.Source.CardFinancial.Builder additionalAmounts(Transaction.Source.CardFinancial.AdditionalAmounts additionalAmounts)
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
additionalAmounts
final Transaction.Source.CardFinancial.Builder additionalAmounts(JsonField<Transaction.Source.CardFinancial.AdditionalAmounts> additionalAmounts)
Sets Builder.additionalAmounts to an arbitrary JSON value.
You should usually call Builder.additionalAmounts with a well-typed AdditionalAmounts value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.CardFinancial.Builder amount(Long amount)
The pending amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.CardFinancial.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final Transaction.Source.CardFinancial.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final Transaction.Source.CardFinancial.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CardFinancial.Builder currency(Transaction.Source.CardFinancial.Currency currency)
The ISO 4217 code for the transaction's currency.
-
currency
final Transaction.Source.CardFinancial.Builder currency(JsonField<Transaction.Source.CardFinancial.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
digitalWalletTokenId
final Transaction.Source.CardFinancial.Builder digitalWalletTokenId(String digitalWalletTokenId)
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
digitalWalletTokenId
final Transaction.Source.CardFinancial.Builder digitalWalletTokenId(Optional<String> digitalWalletTokenId)
Alias for calling Builder.digitalWalletTokenId with
digitalWalletTokenId.orElse(null).
-
digitalWalletTokenId
final Transaction.Source.CardFinancial.Builder digitalWalletTokenId(JsonField<String> digitalWalletTokenId)
Sets Builder.digitalWalletTokenId to an arbitrary JSON value.
You should usually call Builder.digitalWalletTokenId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
direction
final Transaction.Source.CardFinancial.Builder direction(Transaction.Source.CardFinancial.Direction direction)
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
direction
final Transaction.Source.CardFinancial.Builder direction(JsonField<Transaction.Source.CardFinancial.Direction> direction)
Sets Builder.direction to an arbitrary JSON value.
You should usually call Builder.direction with a well-typed Direction value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final Transaction.Source.CardFinancial.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final Transaction.Source.CardFinancial.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final Transaction.Source.CardFinancial.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final Transaction.Source.CardFinancial.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCity
final Transaction.Source.CardFinancial.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final Transaction.Source.CardFinancial.Builder merchantCity(Optional<String> merchantCity)
Alias for calling Builder.merchantCity with
merchantCity.orElse(null).
-
merchantCity
final Transaction.Source.CardFinancial.Builder merchantCity(JsonField<String> merchantCity)
Sets Builder.merchantCity to an arbitrary JSON value.
You should usually call Builder.merchantCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final Transaction.Source.CardFinancial.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final Transaction.Source.CardFinancial.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantDescriptor
final Transaction.Source.CardFinancial.Builder merchantDescriptor(String merchantDescriptor)
The merchant descriptor of the merchant the card is transacting with.
-
merchantDescriptor
final Transaction.Source.CardFinancial.Builder merchantDescriptor(JsonField<String> merchantDescriptor)
Sets Builder.merchantDescriptor to an arbitrary JSON value.
You should usually call Builder.merchantDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final Transaction.Source.CardFinancial.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantPostalCode
final Transaction.Source.CardFinancial.Builder merchantPostalCode(Optional<String> merchantPostalCode)
Alias for calling Builder.merchantPostalCode with
merchantPostalCode.orElse(null).
-
merchantPostalCode
final Transaction.Source.CardFinancial.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final Transaction.Source.CardFinancial.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final Transaction.Source.CardFinancial.Builder merchantState(Optional<String> merchantState)
Alias for calling Builder.merchantState with
merchantState.orElse(null).
-
merchantState
final Transaction.Source.CardFinancial.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkDetails
final Transaction.Source.CardFinancial.Builder networkDetails(Transaction.Source.CardFinancial.NetworkDetails networkDetails)
Fields specific to the
network.
-
networkDetails
final Transaction.Source.CardFinancial.Builder networkDetails(JsonField<Transaction.Source.CardFinancial.NetworkDetails> networkDetails)
Sets Builder.networkDetails to an arbitrary JSON value.
You should usually call Builder.networkDetails with a well-typed NetworkDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final Transaction.Source.CardFinancial.Builder networkIdentifiers(Transaction.Source.CardFinancial.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for a specific request or transaction.
-
networkIdentifiers
final Transaction.Source.CardFinancial.Builder networkIdentifiers(JsonField<Transaction.Source.CardFinancial.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkRiskScore
final Transaction.Source.CardFinancial.Builder networkRiskScore(Long networkRiskScore)
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
-
networkRiskScore
final Transaction.Source.CardFinancial.Builder networkRiskScore(Long networkRiskScore)
Alias for Builder.networkRiskScore.
This unboxed primitive overload exists for backwards compatibility.
-
networkRiskScore
final Transaction.Source.CardFinancial.Builder networkRiskScore(Optional<Long> networkRiskScore)
Alias for calling Builder.networkRiskScore with
networkRiskScore.orElse(null).
-
networkRiskScore
final Transaction.Source.CardFinancial.Builder networkRiskScore(JsonField<Long> networkRiskScore)
Sets Builder.networkRiskScore to an arbitrary JSON value.
You should usually call Builder.networkRiskScore with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCardId
final Transaction.Source.CardFinancial.Builder physicalCardId(String physicalCardId)
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
physicalCardId
final Transaction.Source.CardFinancial.Builder physicalCardId(Optional<String> physicalCardId)
Alias for calling Builder.physicalCardId with
physicalCardId.orElse(null).
-
physicalCardId
final Transaction.Source.CardFinancial.Builder physicalCardId(JsonField<String> physicalCardId)
Sets Builder.physicalCardId to an arbitrary JSON value.
You should usually call Builder.physicalCardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentAmount
final Transaction.Source.CardFinancial.Builder presentmentAmount(Long presentmentAmount)
The pending amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final Transaction.Source.CardFinancial.Builder presentmentAmount(JsonField<Long> presentmentAmount)
Sets Builder.presentmentAmount to an arbitrary JSON value.
You should usually call Builder.presentmentAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentCurrency
final Transaction.Source.CardFinancial.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final Transaction.Source.CardFinancial.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
Sets Builder.presentmentCurrency to an arbitrary JSON value.
You should usually call Builder.presentmentCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
processingCategory
final Transaction.Source.CardFinancial.Builder processingCategory(Transaction.Source.CardFinancial.ProcessingCategory processingCategory)
The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.
-
processingCategory
final Transaction.Source.CardFinancial.Builder processingCategory(JsonField<Transaction.Source.CardFinancial.ProcessingCategory> processingCategory)
Sets Builder.processingCategory to an arbitrary JSON value.
You should usually call Builder.processingCategory with a well-typed ProcessingCategory value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
realTimeDecisionId
final Transaction.Source.CardFinancial.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
realTimeDecisionId
final Transaction.Source.CardFinancial.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
Alias for calling Builder.realTimeDecisionId with
realTimeDecisionId.orElse(null).
-
realTimeDecisionId
final Transaction.Source.CardFinancial.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
Sets Builder.realTimeDecisionId to an arbitrary JSON value.
You should usually call Builder.realTimeDecisionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schemeFees
final Transaction.Source.CardFinancial.Builder schemeFees(List<Transaction.Source.CardFinancial.SchemeFee> schemeFees)
The scheme fees associated with this card financial.
-
schemeFees
final Transaction.Source.CardFinancial.Builder schemeFees(JsonField<List<Transaction.Source.CardFinancial.SchemeFee>> schemeFees)
Sets Builder.schemeFees to an arbitrary JSON value.
You should usually call Builder.schemeFees with a well-typed
List<SchemeFee>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSchemeFee
final Transaction.Source.CardFinancial.Builder addSchemeFee(Transaction.Source.CardFinancial.SchemeFee schemeFee)
Adds a single SchemeFee to schemeFees.
-
terminalId
final Transaction.Source.CardFinancial.Builder terminalId(String terminalId)
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
terminalId
final Transaction.Source.CardFinancial.Builder terminalId(Optional<String> terminalId)
Alias for calling Builder.terminalId with
terminalId.orElse(null).
-
terminalId
final Transaction.Source.CardFinancial.Builder terminalId(JsonField<String> terminalId)
Sets Builder.terminalId to an arbitrary JSON value.
You should usually call Builder.terminalId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CardFinancial.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this Transaction.
-
transactionId
final Transaction.Source.CardFinancial.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Transaction.Source.CardFinancial.Builder type(Transaction.Source.CardFinancial.Type type)
A constant representing the object's type. For this resource it will always be
card_financial.
-
type
final Transaction.Source.CardFinancial.Builder type(JsonField<Transaction.Source.CardFinancial.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
verification
final Transaction.Source.CardFinancial.Builder verification(Transaction.Source.CardFinancial.Verification verification)
Fields related to verification of cardholder-provided values.
-
verification
final Transaction.Source.CardFinancial.Builder verification(JsonField<Transaction.Source.CardFinancial.Verification> verification)
Sets Builder.verification to an arbitrary JSON value.
You should usually call Builder.verification with a well-typed Verification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardFinancial.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardFinancial.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardFinancial.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardFinancial.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardFinancial.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardFinancial build()
Returns an immutable instance of CardFinancial.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .actioner() .additionalAmounts() .amount() .cardPaymentId() .currency() .digitalWalletTokenId() .direction() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .presentmentAmount() .presentmentCurrency() .processingCategory() .realTimeDecisionId() .schemeFees() .terminalId() .transactionId() .type() .verification()
-
-
-
-