Class Transaction.Source.CardFinancial.NetworkDetails
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.NetworkDetailsFields specific to the
network.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardFinancial.NetworkDetails.BuilderA builder for NetworkDetails.
public final classTransaction.Source.CardFinancial.NetworkDetails.CategoryThe payment network used to process this card authorization.
public final classTransaction.Source.CardFinancial.NetworkDetails.PulseFields specific to the
pulsenetwork.public final classTransaction.Source.CardFinancial.NetworkDetails.VisaFields specific to the
visanetwork.
-
Method Summary
-
-
Method Detail
-
category
final Transaction.Source.CardFinancial.NetworkDetails.Category category()
The payment network used to process this card authorization.
-
pulse
final Optional<Transaction.Source.CardFinancial.NetworkDetails.Pulse> pulse()
Fields specific to the
pulsenetwork.
-
visa
final Optional<Transaction.Source.CardFinancial.NetworkDetails.Visa> visa()
Fields specific to the
visanetwork.
-
_category
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_pulse
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Pulse> _pulse()
Returns the raw JSON value of pulse.
Unlike pulse, this method doesn't throw if the JSON field has an unexpected type.
-
_visa
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Visa> _visa()
Returns the raw JSON value of visa.
Unlike visa, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardFinancial.NetworkDetails.Builder toBuilder()
-
validate
final Transaction.Source.CardFinancial.NetworkDetails validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardFinancial.NetworkDetails.Builder builder()
Returns a mutable builder for constructing an instance of NetworkDetails.
The following fields are required:
.category() .pulse() .visa()
-
-
-
-