Class Transaction.Source.CardFinancial.NetworkDetails.Visa
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.NetworkDetails.VisaFields specific to the
visanetwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardFinancial.NetworkDetails.Visa.BuilderA builder for Visa.
public final classTransaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicatorFor electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
public final classTransaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryModeThe method used to enter the cardholder's primary account number and card expiration date.
public final classTransaction.Source.CardFinancial.NetworkDetails.Visa.StandInProcessingReasonOnly present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.public final classTransaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityThe capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
-
Method Summary
-
-
Method Detail
-
electronicCommerceIndicator
final Optional<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator> electronicCommerceIndicator()
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
-
pointOfServiceEntryMode
final Optional<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode> pointOfServiceEntryMode()
The method used to enter the cardholder's primary account number and card expiration date.
-
standInProcessingReason
final Optional<Transaction.Source.CardFinancial.NetworkDetails.Visa.StandInProcessingReason> standInProcessingReason()
Only present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.
-
terminalEntryCapability
final Optional<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability> terminalEntryCapability()
The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
-
_electronicCommerceIndicator
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator> _electronicCommerceIndicator()
Returns the raw JSON value of electronicCommerceIndicator.
Unlike electronicCommerceIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_pointOfServiceEntryMode
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode> _pointOfServiceEntryMode()
Returns the raw JSON value of pointOfServiceEntryMode.
Unlike pointOfServiceEntryMode, this method doesn't throw if the JSON field has an unexpected type.
-
_standInProcessingReason
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Visa.StandInProcessingReason> _standInProcessingReason()
Returns the raw JSON value of standInProcessingReason.
Unlike standInProcessingReason, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalEntryCapability
final JsonField<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability> _terminalEntryCapability()
Returns the raw JSON value of terminalEntryCapability.
Unlike terminalEntryCapability, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardFinancial.NetworkDetails.Visa.Builder toBuilder()
-
validate
final Transaction.Source.CardFinancial.NetworkDetails.Visa validate()
-
builder
final static Transaction.Source.CardFinancial.NetworkDetails.Visa.Builder builder()
Returns a mutable builder for constructing an instance of Visa.
The following fields are required:
.electronicCommerceIndicator() .pointOfServiceEntryMode() .standInProcessingReason() .terminalEntryCapability()
-
-
-
-