Enum Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value extends Enum<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value>
An enum containing ElectronicCommerceIndicator's known values, as well as an _UNKNOWN member.
An instance of ElectronicCommerceIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description MAIL_PHONE_ORDERSingle transaction of a mail/phone order: Use to indicate that the transaction is a mail/phone order purchase, not a recurring transaction or installment payment. For domestic transactions in the US region, this value may also indicate one bill payment transaction in the card-present or card-absent environments.
RECURRINGRecurring transaction: Payment indicator used to indicate a recurring transaction that originates from an acquirer in the US region.
INSTALLMENTInstallment payment: Payment indicator used to indicate one purchase of goods or services that is billed to the account in multiple charges over a period of time agreed upon by the cardholder and merchant from transactions that originate from an acquirer in the US region.
UNKNOWN_MAIL_PHONE_ORDERUnknown classification: other mail order: Use to indicate that the type of mail/telephone order is unknown.
SECURE_ELECTRONIC_COMMERCESecure electronic commerce transaction: Use to indicate that the electronic commerce transaction has been authenticated using e.g., 3-D Secure
NON_AUTHENTICATED_SECURITY_TRANSACTION_AT_3DS_CAPABLE_MERCHANTNon-authenticated security transaction at a 3-D Secure-capable merchant, and merchant attempted to authenticate the cardholder using 3-D Secure: Use to identify an electronic commerce transaction where the merchant attempted to authenticate the cardholder using 3-D Secure, but was unable to complete the authentication because the issuer or cardholder does not participate in the 3-D Secure program.
NON_AUTHENTICATED_SECURITY_TRANSACTIONNon-authenticated security transaction: Use to identify an electronic commerce transaction that uses data encryption for security however, cardholder authentication is not performed using 3-D Secure.
NON_SECURE_TRANSACTIONNon-secure transaction: Use to identify an electronic commerce transaction that has no data protection.
_UNKNOWNAn enum member indicating that ElectronicCommerceIndicator was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value>getEntries()An enum containing ElectronicCommerceIndicator's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.ElectronicCommerceIndicator.Value> getEntries()
An enum containing ElectronicCommerceIndicator's known values, as well as an _UNKNOWN member.
An instance of ElectronicCommerceIndicator can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-