Enum Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value extends Enum<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value>
An enum containing PointOfServiceEntryMode's known values, as well as an _UNKNOWN member.
An instance of PointOfServiceEntryMode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description UNKNOWNUnknown
MANUALManual key entry
MAGNETIC_STRIPE_NO_CVVMagnetic stripe read, without card verification value
OPTICAL_CODEOptical code
INTEGRATED_CIRCUIT_CARDContact chip card
CONTACTLESSContactless read of chip card
CREDENTIAL_ON_FILETransaction initiated using a credential that has previously been stored on file
MAGNETIC_STRIPEMagnetic stripe read
CONTACTLESS_MAGNETIC_STRIPEContactless read of magnetic stripe data
INTEGRATED_CIRCUIT_CARD_NO_CVVContact chip card, without card verification value
_UNKNOWNAn enum member indicating that PointOfServiceEntryMode was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value>getEntries()An enum containing PointOfServiceEntryMode's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.PointOfServiceEntryMode.Value> getEntries()
An enum containing PointOfServiceEntryMode's known values, as well as an _UNKNOWN member.
An instance of PointOfServiceEntryMode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-