Class Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability
     implements Enum
                        

    The capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.