Enum Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value extends Enum<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value>
An enum containing TerminalEntryCapability's known values, as well as an _UNKNOWN member.
An instance of TerminalEntryCapability can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description UNKNOWNUnknown
TERMINAL_NOT_USEDNo terminal was used for this transaction.
MAGNETIC_STRIPEThe terminal can only read magnetic stripes and does not have chip or contactless reading capability.
BARCODEThe terminal can only read barcodes.
OPTICAL_CHARACTER_RECOGNITIONThe terminal can only read cards via Optical Character Recognition.
CHIP_OR_CONTACTLESSThe terminal supports contact chip cards and can also read the magnetic stripe. If contact chip is supported, this value is used regardless of whether contactless is also supported.
CONTACTLESS_ONLYThe terminal supports contactless reads but does not support contact chip. Only used when the terminal lacks contact chip capability.
NO_CAPABILITYThe terminal has no card reading capability.
_UNKNOWNAn enum member indicating that TerminalEntryCapability was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value>getEntries()An enum containing TerminalEntryCapability's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value> getEntries()
An enum containing TerminalEntryCapability's known values, as well as an _UNKNOWN member.
An instance of TerminalEntryCapability can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-