Class Transaction.Source.CardFinancial.NetworkIdentifiers.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.NetworkIdentifiers.BuilderA builder for NetworkIdentifiers.
-
-
Method Summary
-
-
Method Detail
-
authorizationIdentificationResponse
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder authorizationIdentificationResponse(String authorizationIdentificationResponse)
The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.
-
authorizationIdentificationResponse
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder authorizationIdentificationResponse(Optional<String> authorizationIdentificationResponse)
Alias for calling Builder.authorizationIdentificationResponse with
authorizationIdentificationResponse.orElse(null).
-
authorizationIdentificationResponse
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder authorizationIdentificationResponse(JsonField<String> authorizationIdentificationResponse)
Sets Builder.authorizationIdentificationResponse to an arbitrary JSON value.
You should usually call Builder.authorizationIdentificationResponse with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
retrievalReferenceNumber
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder retrievalReferenceNumber(String retrievalReferenceNumber)
A life-cycle identifier used across e.g., an authorization and a reversal. Expected to be unique per acquirer within a window of time. For some card networks the retrieval reference number includes the trace counter.
-
retrievalReferenceNumber
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder retrievalReferenceNumber(Optional<String> retrievalReferenceNumber)
Alias for calling Builder.retrievalReferenceNumber with
retrievalReferenceNumber.orElse(null).
-
retrievalReferenceNumber
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder retrievalReferenceNumber(JsonField<String> retrievalReferenceNumber)
Sets Builder.retrievalReferenceNumber to an arbitrary JSON value.
You should usually call Builder.retrievalReferenceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
traceNumber
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder traceNumber(String traceNumber)
A counter used to verify an individual authorization. Expected to be unique per acquirer within a window of time.
-
traceNumber
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder traceNumber(Optional<String> traceNumber)
Alias for calling Builder.traceNumber with
traceNumber.orElse(null).
-
traceNumber
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder traceNumber(JsonField<String> traceNumber)
Sets Builder.traceNumber to an arbitrary JSON value.
You should usually call Builder.traceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder transactionId(String transactionId)
A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.
-
transactionId
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardFinancial.NetworkIdentifiers.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardFinancial.NetworkIdentifiers build()
Returns an immutable instance of NetworkIdentifiers.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.authorizationIdentificationResponse() .retrievalReferenceNumber() .traceNumber() .transactionId()
-
-
-
-