Class Transaction.Source.CardFinancial.ProcessingCategory

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class Transaction.Source.CardFinancial.ProcessingCategory
     implements Enum
                        

    The processing category describes the intent behind the financial, such as whether it was used for bill payments or an automatic fuel dispenser.