Enum Transaction.Source.CardFinancial.ProcessingCategory.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.CardFinancial.ProcessingCategory.Known extends Enum<Transaction.Source.CardFinancial.ProcessingCategory.Known>
An enum containing ProcessingCategory's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.CardFinancial.ProcessingCategory.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_FUNDINGAccount funding transactions are transactions used to e.g., fund an account or transfer funds between accounts.
AUTOMATIC_FUEL_DISPENSERAutomatic fuel dispenser authorizations occur when a card is used at a gas pump, prior to the actual transaction amount being known. They are followed by an advice message that updates the amount of the pending transaction.
BILL_PAYMENTA transaction used to pay a bill.
ORIGINAL_CREDITOriginal credit transactions are used to send money to a cardholder.
PURCHASEA regular purchase.
QUASI_CASHQuasi-cash transactions represent purchases of items which may be convertible to cash.
REFUNDA refund card authorization, sometimes referred to as a credit voucher authorization, where funds are credited to the cardholder.
CASH_DISBURSEMENTCash disbursement transactions are used to withdraw cash from an ATM or a point of sale.
BALANCE_INQUIRYA balance inquiry transaction is used to check the balance of an account associated with a card.
UNKNOWNThe processing category is unknown.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CardFinancial.ProcessingCategory.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.CardFinancial.ProcessingCategory.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.CardFinancial.ProcessingCategory.Known>getEntries()An enum containing ProcessingCategory's known values. -
-
Method Detail
-
valueOf
final Transaction.Source.CardFinancial.ProcessingCategory.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.CardFinancial.ProcessingCategory.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.CardFinancial.ProcessingCategory.Known> getEntries()
An enum containing ProcessingCategory's known values.
-
-
-
-