Class Transaction.Source.CardFinancial.Verification.CardholderAddress
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.Verification.CardholderAddressCardholder address provided in the authorization request and the address on file we verified it against.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardFinancial.Verification.CardholderAddress.BuilderA builder for CardholderAddress.
public final classTransaction.Source.CardFinancial.Verification.CardholderAddress.ResultThe address verification result returned to the card network.
-
Method Summary
Modifier and Type Method Description final Optional<String>actualLine1()Line 1 of the address on file for the cardholder. final Optional<String>actualPostalCode()The postal code of the address on file for the cardholder. final Optional<String>providedLine1()The cardholder address line 1 provided for verification in the authorization request. final Optional<String>providedPostalCode()The postal code provided for verification in the authorization request. final Transaction.Source.CardFinancial.Verification.CardholderAddress.Resultresult()The address verification result returned to the card network. final JsonField<String>_actualLine1()Returns the raw JSON value of actualLine1. final JsonField<String>_actualPostalCode()Returns the raw JSON value of actualPostalCode. final JsonField<String>_providedLine1()Returns the raw JSON value of providedLine1. final JsonField<String>_providedPostalCode()Returns the raw JSON value of providedPostalCode. final JsonField<Transaction.Source.CardFinancial.Verification.CardholderAddress.Result>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardFinancial.Verification.CardholderAddress.BuildertoBuilder()final Transaction.Source.CardFinancial.Verification.CardholderAddressvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardFinancial.Verification.CardholderAddress.Builderbuilder()Returns a mutable builder for constructing an instance of CardholderAddress. -
-
Method Detail
-
actualLine1
final Optional<String> actualLine1()
Line 1 of the address on file for the cardholder.
-
actualPostalCode
final Optional<String> actualPostalCode()
The postal code of the address on file for the cardholder.
-
providedLine1
final Optional<String> providedLine1()
The cardholder address line 1 provided for verification in the authorization request.
-
providedPostalCode
final Optional<String> providedPostalCode()
The postal code provided for verification in the authorization request.
-
result
final Transaction.Source.CardFinancial.Verification.CardholderAddress.Result result()
The address verification result returned to the card network.
-
_actualLine1
final JsonField<String> _actualLine1()
Returns the raw JSON value of actualLine1.
Unlike actualLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_actualPostalCode
final JsonField<String> _actualPostalCode()
Returns the raw JSON value of actualPostalCode.
Unlike actualPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_providedLine1
final JsonField<String> _providedLine1()
Returns the raw JSON value of providedLine1.
Unlike providedLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_providedPostalCode
final JsonField<String> _providedPostalCode()
Returns the raw JSON value of providedPostalCode.
Unlike providedPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<Transaction.Source.CardFinancial.Verification.CardholderAddress.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardFinancial.Verification.CardholderAddress validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardFinancial.Verification.CardholderAddress.Builder builder()
Returns a mutable builder for constructing an instance of CardholderAddress.
The following fields are required:
.actualLine1() .actualPostalCode() .providedLine1() .providedPostalCode() .result()
-
-
-
-