Class Transaction.Source.CardPushTransferAcceptance

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardPushTransferAcceptance
    
                        

    A Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if category is equal to card_push_transfer_acceptance. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.