Class Transaction.Source.CardRefund

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardRefund
    
                        

    A Card Refund object. This field will be present in the JSON response if and only if category is equal to card_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.