Class Transaction.Source.CardRefund.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.BuilderA builder for CardRefund.
-
-
Method Summary
-
-
Method Detail
-
id
final Transaction.Source.CardRefund.Builder id(String id)
The Card Refund identifier.
-
id
final Transaction.Source.CardRefund.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.CardRefund.Builder amount(Long amount)
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.CardRefund.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final Transaction.Source.CardRefund.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final Transaction.Source.CardRefund.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashback
final Transaction.Source.CardRefund.Builder cashback(Transaction.Source.CardRefund.Cashback cashback)
Cashback debited for this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
cashback
final Transaction.Source.CardRefund.Builder cashback(Optional<Transaction.Source.CardRefund.Cashback> cashback)
Alias for calling Builder.cashback with
cashback.orElse(null).
-
cashback
final Transaction.Source.CardRefund.Builder cashback(JsonField<Transaction.Source.CardRefund.Cashback> cashback)
Sets Builder.cashback to an arbitrary JSON value.
You should usually call Builder.cashback with a well-typed Cashback value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CardRefund.Builder currency(Transaction.Source.CardRefund.Currency currency)
The ISO 4217 code for the transaction's settlement currency.
-
currency
final Transaction.Source.CardRefund.Builder currency(JsonField<Transaction.Source.CardRefund.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interchange
final Transaction.Source.CardRefund.Builder interchange(Transaction.Source.CardRefund.Interchange interchange)
Interchange assessed as a part of this transaction.
-
interchange
final Transaction.Source.CardRefund.Builder interchange(Optional<Transaction.Source.CardRefund.Interchange> interchange)
Alias for calling Builder.interchange with
interchange.orElse(null).
-
interchange
final Transaction.Source.CardRefund.Builder interchange(JsonField<Transaction.Source.CardRefund.Interchange> interchange)
Sets Builder.interchange to an arbitrary JSON value.
You should usually call Builder.interchange with a well-typed Interchange value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final Transaction.Source.CardRefund.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final Transaction.Source.CardRefund.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final Transaction.Source.CardRefund.Builder merchantCategoryCode(String merchantCategoryCode)
The 4-digit MCC describing the merchant's business.
-
merchantCategoryCode
final Transaction.Source.CardRefund.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCity
final Transaction.Source.CardRefund.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final Transaction.Source.CardRefund.Builder merchantCity(JsonField<String> merchantCity)
Sets Builder.merchantCity to an arbitrary JSON value.
You should usually call Builder.merchantCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final Transaction.Source.CardRefund.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final Transaction.Source.CardRefund.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final Transaction.Source.CardRefund.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final Transaction.Source.CardRefund.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final Transaction.Source.CardRefund.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantPostalCode
final Transaction.Source.CardRefund.Builder merchantPostalCode(Optional<String> merchantPostalCode)
Alias for calling Builder.merchantPostalCode with
merchantPostalCode.orElse(null).
-
merchantPostalCode
final Transaction.Source.CardRefund.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final Transaction.Source.CardRefund.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final Transaction.Source.CardRefund.Builder merchantState(Optional<String> merchantState)
Alias for calling Builder.merchantState with
merchantState.orElse(null).
-
merchantState
final Transaction.Source.CardRefund.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final Transaction.Source.CardRefund.Builder networkIdentifiers(Transaction.Source.CardRefund.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for this refund.
-
networkIdentifiers
final Transaction.Source.CardRefund.Builder networkIdentifiers(JsonField<Transaction.Source.CardRefund.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentAmount
final Transaction.Source.CardRefund.Builder presentmentAmount(Long presentmentAmount)
The amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final Transaction.Source.CardRefund.Builder presentmentAmount(JsonField<Long> presentmentAmount)
Sets Builder.presentmentAmount to an arbitrary JSON value.
You should usually call Builder.presentmentAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentCurrency
final Transaction.Source.CardRefund.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final Transaction.Source.CardRefund.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
Sets Builder.presentmentCurrency to an arbitrary JSON value.
You should usually call Builder.presentmentCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseDetails
final Transaction.Source.CardRefund.Builder purchaseDetails(Transaction.Source.CardRefund.PurchaseDetails purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
purchaseDetails
final Transaction.Source.CardRefund.Builder purchaseDetails(Optional<Transaction.Source.CardRefund.PurchaseDetails> purchaseDetails)
Alias for calling Builder.purchaseDetails with
purchaseDetails.orElse(null).
-
purchaseDetails
final Transaction.Source.CardRefund.Builder purchaseDetails(JsonField<Transaction.Source.CardRefund.PurchaseDetails> purchaseDetails)
Sets Builder.purchaseDetails to an arbitrary JSON value.
You should usually call Builder.purchaseDetails with a well-typed PurchaseDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schemeFees
final Transaction.Source.CardRefund.Builder schemeFees(List<Transaction.Source.CardRefund.SchemeFee> schemeFees)
The scheme fees associated with this card refund.
-
schemeFees
final Transaction.Source.CardRefund.Builder schemeFees(JsonField<List<Transaction.Source.CardRefund.SchemeFee>> schemeFees)
Sets Builder.schemeFees to an arbitrary JSON value.
You should usually call Builder.schemeFees with a well-typed
List<SchemeFee>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSchemeFee
final Transaction.Source.CardRefund.Builder addSchemeFee(Transaction.Source.CardRefund.SchemeFee schemeFee)
Adds a single SchemeFee to schemeFees.
-
transactionId
final Transaction.Source.CardRefund.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this Transaction.
-
transactionId
final Transaction.Source.CardRefund.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Transaction.Source.CardRefund.Builder type(Transaction.Source.CardRefund.Type type)
A constant representing the object's type. For this resource it will always be
card_refund.
-
type
final Transaction.Source.CardRefund.Builder type(JsonField<Transaction.Source.CardRefund.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardRefund.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRefund.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRefund.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRefund.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRefund.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRefund build()
Returns an immutable instance of CardRefund.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .amount() .cardPaymentId() .cashback() .currency() .interchange() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantName() .merchantPostalCode() .merchantState() .networkIdentifiers() .presentmentAmount() .presentmentCurrency() .purchaseDetails() .schemeFees() .transactionId() .type()
-
-
-
-