Class Transaction.Source.CardRefund.Cashback.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.Cashback.BuilderA builder for Cashback.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.CardRefund.Cashback.Builder amount(String amount)
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
amount
final Transaction.Source.CardRefund.Cashback.Builder amount(JsonField<String> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CardRefund.Cashback.Builder currency(Transaction.Source.CardRefund.Cashback.Currency currency)
The ISO 4217 code for the cashback.
-
currency
final Transaction.Source.CardRefund.Cashback.Builder currency(JsonField<Transaction.Source.CardRefund.Cashback.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardRefund.Cashback.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRefund.Cashback.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRefund.Cashback.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRefund.Cashback.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRefund.Cashback.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRefund.Cashback build()
Returns an immutable instance of Cashback.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency()
-
-
-
-