Class Transaction.Source.CardRefund.Interchange
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.InterchangeInterchange assessed as a part of this transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.Interchange.BuilderA builder for Interchange.
public final classTransaction.Source.CardRefund.Interchange.CurrencyThe ISO 4217 code for the interchange reimbursement.
-
Method Summary
Modifier and Type Method Description final Stringamount()The interchange amount given as a string containing a decimal number in major units (so e.g., "3.14" for $3.14). final Optional<String>code()The card network specific interchange code. final Transaction.Source.CardRefund.Interchange.Currencycurrency()The ISO 4217 code for the interchange reimbursement. final JsonField<String>_amount()Returns the raw JSON value of amount. final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<Transaction.Source.CardRefund.Interchange.Currency>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRefund.Interchange.BuildertoBuilder()final Transaction.Source.CardRefund.Interchangevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRefund.Interchange.Builderbuilder()Returns a mutable builder for constructing an instance of Interchange. -
-
Method Detail
-
amount
final String amount()
The interchange amount given as a string containing a decimal number in major units (so e.g., "3.14" for $3.14). The amount is a positive number if it is credited to Increase (e.g., settlements) and a negative number if it is debited (e.g., refunds).
-
currency
final Transaction.Source.CardRefund.Interchange.Currency currency()
The ISO 4217 code for the interchange reimbursement.
-
_amount
final JsonField<String> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CardRefund.Interchange.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.Interchange.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.Interchange validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardRefund.Interchange.Builder builder()
Returns a mutable builder for constructing an instance of Interchange.
The following fields are required:
.amount() .code() .currency()
-
-
-
-