Class Transaction.Source.CardRefund.NetworkIdentifiers
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.NetworkIdentifiersNetwork-specific identifiers for this refund.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.NetworkIdentifiers.BuilderA builder for NetworkIdentifiers.
-
Method Summary
Modifier and Type Method Description final StringacquirerBusinessId()A network assigned business ID that identifies the acquirer that processed this transaction. final StringacquirerReferenceNumber()A globally unique identifier for this settlement. final Optional<String>authorizationIdentificationResponse()The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response. final Optional<String>transactionId()A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests. final JsonField<String>_acquirerBusinessId()Returns the raw JSON value of acquirerBusinessId. final JsonField<String>_acquirerReferenceNumber()Returns the raw JSON value of acquirerReferenceNumber. final JsonField<String>_authorizationIdentificationResponse()Returns the raw JSON value of authorizationIdentificationResponse. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRefund.NetworkIdentifiers.BuildertoBuilder()final Transaction.Source.CardRefund.NetworkIdentifiersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRefund.NetworkIdentifiers.Builderbuilder()Returns a mutable builder for constructing an instance of NetworkIdentifiers. -
-
Method Detail
-
acquirerBusinessId
final String acquirerBusinessId()
A network assigned business ID that identifies the acquirer that processed this transaction.
-
acquirerReferenceNumber
final String acquirerReferenceNumber()
A globally unique identifier for this settlement.
-
authorizationIdentificationResponse
final Optional<String> authorizationIdentificationResponse()
The randomly generated 6-character Authorization Identification Response code sent back to the acquirer in an approved response.
-
transactionId
final Optional<String> transactionId()
A globally unique transaction identifier provided by the card network, used across multiple life-cycle requests.
-
_acquirerBusinessId
final JsonField<String> _acquirerBusinessId()
Returns the raw JSON value of acquirerBusinessId.
Unlike acquirerBusinessId, this method doesn't throw if the JSON field has an unexpected type.
-
_acquirerReferenceNumber
final JsonField<String> _acquirerReferenceNumber()
Returns the raw JSON value of acquirerReferenceNumber.
Unlike acquirerReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationIdentificationResponse
final JsonField<String> _authorizationIdentificationResponse()
Returns the raw JSON value of authorizationIdentificationResponse.
Unlike authorizationIdentificationResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.NetworkIdentifiers.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.NetworkIdentifiers validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardRefund.NetworkIdentifiers.Builder builder()
Returns a mutable builder for constructing an instance of NetworkIdentifiers.
The following fields are required:
.acquirerBusinessId() .acquirerReferenceNumber() .authorizationIdentificationResponse() .transactionId()
-
-
-
-