Class Transaction.Source.CardRefund.PurchaseDetails.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.BuilderA builder for PurchaseDetails.
-
-
Method Summary
-
-
Method Detail
-
carRental
final Transaction.Source.CardRefund.PurchaseDetails.Builder carRental(Transaction.Source.CardRefund.PurchaseDetails.CarRental carRental)
Fields specific to car rentals.
-
carRental
final Transaction.Source.CardRefund.PurchaseDetails.Builder carRental(Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental> carRental)
Alias for calling Builder.carRental with
carRental.orElse(null).
-
carRental
final Transaction.Source.CardRefund.PurchaseDetails.Builder carRental(JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental> carRental)
Sets Builder.carRental to an arbitrary JSON value.
You should usually call Builder.carRental with a well-typed CarRental value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customerReferenceIdentifier
final Transaction.Source.CardRefund.PurchaseDetails.Builder customerReferenceIdentifier(String customerReferenceIdentifier)
An identifier from the merchant for the customer or consumer.
-
customerReferenceIdentifier
final Transaction.Source.CardRefund.PurchaseDetails.Builder customerReferenceIdentifier(Optional<String> customerReferenceIdentifier)
Alias for calling Builder.customerReferenceIdentifier with
customerReferenceIdentifier.orElse(null).
-
customerReferenceIdentifier
final Transaction.Source.CardRefund.PurchaseDetails.Builder customerReferenceIdentifier(JsonField<String> customerReferenceIdentifier)
Sets Builder.customerReferenceIdentifier to an arbitrary JSON value.
You should usually call Builder.customerReferenceIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
localTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxAmount(Long localTaxAmount)
The state or provincial tax amount in minor units.
-
localTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxAmount(Long localTaxAmount)
Alias for Builder.localTaxAmount.
This unboxed primitive overload exists for backwards compatibility.
-
localTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxAmount(Optional<Long> localTaxAmount)
Alias for calling Builder.localTaxAmount with
localTaxAmount.orElse(null).
-
localTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxAmount(JsonField<Long> localTaxAmount)
Sets Builder.localTaxAmount to an arbitrary JSON value.
You should usually call Builder.localTaxAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
localTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxCurrency(String localTaxCurrency)
The ISO 4217 code for the local tax assessed.
-
localTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxCurrency(Optional<String> localTaxCurrency)
Alias for calling Builder.localTaxCurrency with
localTaxCurrency.orElse(null).
-
localTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Builder localTaxCurrency(JsonField<String> localTaxCurrency)
Sets Builder.localTaxCurrency to an arbitrary JSON value.
You should usually call Builder.localTaxCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lodging
final Transaction.Source.CardRefund.PurchaseDetails.Builder lodging(Transaction.Source.CardRefund.PurchaseDetails.Lodging lodging)
Fields specific to lodging.
-
lodging
final Transaction.Source.CardRefund.PurchaseDetails.Builder lodging(Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging> lodging)
Alias for calling Builder.lodging with
lodging.orElse(null).
-
lodging
final Transaction.Source.CardRefund.PurchaseDetails.Builder lodging(JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging> lodging)
Sets Builder.lodging to an arbitrary JSON value.
You should usually call Builder.lodging with a well-typed Lodging value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nationalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxAmount(Long nationalTaxAmount)
The national tax amount in minor units.
-
nationalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxAmount(Long nationalTaxAmount)
Alias for Builder.nationalTaxAmount.
This unboxed primitive overload exists for backwards compatibility.
-
nationalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxAmount(Optional<Long> nationalTaxAmount)
Alias for calling Builder.nationalTaxAmount with
nationalTaxAmount.orElse(null).
-
nationalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxAmount(JsonField<Long> nationalTaxAmount)
Sets Builder.nationalTaxAmount to an arbitrary JSON value.
You should usually call Builder.nationalTaxAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
nationalTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxCurrency(String nationalTaxCurrency)
The ISO 4217 code for the local tax assessed.
-
nationalTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxCurrency(Optional<String> nationalTaxCurrency)
Alias for calling Builder.nationalTaxCurrency with
nationalTaxCurrency.orElse(null).
-
nationalTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Builder nationalTaxCurrency(JsonField<String> nationalTaxCurrency)
Sets Builder.nationalTaxCurrency to an arbitrary JSON value.
You should usually call Builder.nationalTaxCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseIdentifier
final Transaction.Source.CardRefund.PurchaseDetails.Builder purchaseIdentifier(String purchaseIdentifier)
An identifier from the merchant for the purchase to the issuer and cardholder.
-
purchaseIdentifier
final Transaction.Source.CardRefund.PurchaseDetails.Builder purchaseIdentifier(Optional<String> purchaseIdentifier)
Alias for calling Builder.purchaseIdentifier with
purchaseIdentifier.orElse(null).
-
purchaseIdentifier
final Transaction.Source.CardRefund.PurchaseDetails.Builder purchaseIdentifier(JsonField<String> purchaseIdentifier)
Sets Builder.purchaseIdentifier to an arbitrary JSON value.
You should usually call Builder.purchaseIdentifier with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseIdentifierFormat
final Transaction.Source.CardRefund.PurchaseDetails.Builder purchaseIdentifierFormat(Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat purchaseIdentifierFormat)
The format of the purchase identifier.
-
purchaseIdentifierFormat
final Transaction.Source.CardRefund.PurchaseDetails.Builder purchaseIdentifierFormat(Optional<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat> purchaseIdentifierFormat)
Alias for calling Builder.purchaseIdentifierFormat with
purchaseIdentifierFormat.orElse(null).
-
purchaseIdentifierFormat
final Transaction.Source.CardRefund.PurchaseDetails.Builder purchaseIdentifierFormat(JsonField<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat> purchaseIdentifierFormat)
Sets Builder.purchaseIdentifierFormat to an arbitrary JSON value.
You should usually call Builder.purchaseIdentifierFormat with a well-typed PurchaseIdentifierFormat value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
travel
final Transaction.Source.CardRefund.PurchaseDetails.Builder travel(Transaction.Source.CardRefund.PurchaseDetails.Travel travel)
Fields specific to travel.
-
travel
final Transaction.Source.CardRefund.PurchaseDetails.Builder travel(Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel> travel)
Alias for calling Builder.travel with
travel.orElse(null).
-
travel
final Transaction.Source.CardRefund.PurchaseDetails.Builder travel(JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel> travel)
Sets Builder.travel to an arbitrary JSON value.
You should usually call Builder.travel with a well-typed Travel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardRefund.PurchaseDetails.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRefund.PurchaseDetails.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRefund.PurchaseDetails.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRefund.PurchaseDetails.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRefund.PurchaseDetails.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRefund.PurchaseDetails build()
Returns an immutable instance of PurchaseDetails.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.carRental() .customerReferenceIdentifier() .localTaxAmount() .localTaxCurrency() .lodging() .nationalTaxAmount() .nationalTaxCurrency() .purchaseIdentifier() .purchaseIdentifierFormat() .travel()
-
-
-
-