Class Transaction.Source.CardRefund.PurchaseDetails.CarRental
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.CarRentalFields specific to car rentals.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.CarRental.BuilderA builder for CarRental.
public final classTransaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraChargesAdditional charges (gas, late fee, etc.) being billed.
public final classTransaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicatorAn indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
-
Method Summary
-
-
Method Detail
-
carClassCode
final Optional<String> carClassCode()
Code indicating the vehicle's class.
-
checkoutDate
final Optional<LocalDate> checkoutDate()
Date the customer picked up the car or, in the case of a no-show or pre-pay transaction, the scheduled pick up date.
-
dailyRentalRateAmount
final Optional<Long> dailyRentalRateAmount()
Daily rate being charged for the vehicle.
-
dailyRentalRateCurrency
final Optional<String> dailyRentalRateCurrency()
The ISO 4217 code for the daily rental rate.
-
daysRented
final Optional<Long> daysRented()
Number of days the vehicle was rented.
-
extraCharges
final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraCharges> extraCharges()
Additional charges (gas, late fee, etc.) being billed.
-
fuelChargesAmount
final Optional<Long> fuelChargesAmount()
Fuel charges for the vehicle.
-
fuelChargesCurrency
final Optional<String> fuelChargesCurrency()
The ISO 4217 code for the fuel charges assessed.
-
insuranceChargesAmount
final Optional<Long> insuranceChargesAmount()
Any insurance being charged for the vehicle.
-
insuranceChargesCurrency
final Optional<String> insuranceChargesCurrency()
The ISO 4217 code for the insurance charges assessed.
-
noShowIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicator> noShowIndicator()
An indicator that the cardholder is being billed for a reserved vehicle that was not actually rented (that is, a "no-show" charge).
-
oneWayDropOffChargesAmount
final Optional<Long> oneWayDropOffChargesAmount()
Charges for returning the vehicle at a different location than where it was picked up.
-
oneWayDropOffChargesCurrency
final Optional<String> oneWayDropOffChargesCurrency()
The ISO 4217 code for the one-way drop-off charges assessed.
-
renterName
final Optional<String> renterName()
Name of the person renting the vehicle.
-
weeklyRentalRateAmount
final Optional<Long> weeklyRentalRateAmount()
Weekly rate being charged for the vehicle.
-
weeklyRentalRateCurrency
final Optional<String> weeklyRentalRateCurrency()
The ISO 4217 code for the weekly rental rate.
-
_carClassCode
final JsonField<String> _carClassCode()
Returns the raw JSON value of carClassCode.
Unlike carClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_checkoutDate
final JsonField<LocalDate> _checkoutDate()
Returns the raw JSON value of checkoutDate.
Unlike checkoutDate, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyRentalRateAmount
final JsonField<Long> _dailyRentalRateAmount()
Returns the raw JSON value of dailyRentalRateAmount.
Unlike dailyRentalRateAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyRentalRateCurrency
final JsonField<String> _dailyRentalRateCurrency()
Returns the raw JSON value of dailyRentalRateCurrency.
Unlike dailyRentalRateCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_daysRented
final JsonField<Long> _daysRented()
Returns the raw JSON value of daysRented.
Unlike daysRented, this method doesn't throw if the JSON field has an unexpected type.
-
_extraCharges
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental.ExtraCharges> _extraCharges()
Returns the raw JSON value of extraCharges.
Unlike extraCharges, this method doesn't throw if the JSON field has an unexpected type.
-
_fuelChargesAmount
final JsonField<Long> _fuelChargesAmount()
Returns the raw JSON value of fuelChargesAmount.
Unlike fuelChargesAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_fuelChargesCurrency
final JsonField<String> _fuelChargesCurrency()
Returns the raw JSON value of fuelChargesCurrency.
Unlike fuelChargesCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_insuranceChargesAmount
final JsonField<Long> _insuranceChargesAmount()
Returns the raw JSON value of insuranceChargesAmount.
Unlike insuranceChargesAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_insuranceChargesCurrency
final JsonField<String> _insuranceChargesCurrency()
Returns the raw JSON value of insuranceChargesCurrency.
Unlike insuranceChargesCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_noShowIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental.NoShowIndicator> _noShowIndicator()
Returns the raw JSON value of noShowIndicator.
Unlike noShowIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_oneWayDropOffChargesAmount
final JsonField<Long> _oneWayDropOffChargesAmount()
Returns the raw JSON value of oneWayDropOffChargesAmount.
Unlike oneWayDropOffChargesAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_oneWayDropOffChargesCurrency
final JsonField<String> _oneWayDropOffChargesCurrency()
Returns the raw JSON value of oneWayDropOffChargesCurrency.
Unlike oneWayDropOffChargesCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_renterName
final JsonField<String> _renterName()
Returns the raw JSON value of renterName.
Unlike renterName, this method doesn't throw if the JSON field has an unexpected type.
-
_weeklyRentalRateAmount
final JsonField<Long> _weeklyRentalRateAmount()
Returns the raw JSON value of weeklyRentalRateAmount.
Unlike weeklyRentalRateAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_weeklyRentalRateCurrency
final JsonField<String> _weeklyRentalRateCurrency()
Returns the raw JSON value of weeklyRentalRateCurrency.
Unlike weeklyRentalRateCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.CarRental.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.CarRental validate()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.CarRental.Builder builder()
Returns a mutable builder for constructing an instance of CarRental.
The following fields are required:
.carClassCode() .checkoutDate() .dailyRentalRateAmount() .dailyRentalRateCurrency() .daysRented() .extraCharges() .fuelChargesAmount() .fuelChargesCurrency() .insuranceChargesAmount() .insuranceChargesCurrency() .noShowIndicator() .oneWayDropOffChargesAmount() .oneWayDropOffChargesCurrency() .renterName() .weeklyRentalRateAmount() .weeklyRentalRateCurrency()
-
-
-
-