Class Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.Lodging.BuilderA builder for Lodging.
-
-
Method Summary
-
-
Method Detail
-
checkInDate
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder checkInDate(LocalDate checkInDate)
Date the customer checked in.
-
checkInDate
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder checkInDate(Optional<LocalDate> checkInDate)
Alias for calling Builder.checkInDate with
checkInDate.orElse(null).
-
checkInDate
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder checkInDate(JsonField<LocalDate> checkInDate)
Sets Builder.checkInDate to an arbitrary JSON value.
You should usually call Builder.checkInDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dailyRoomRateAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateAmount(Long dailyRoomRateAmount)
Daily rate being charged for the room.
-
dailyRoomRateAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateAmount(Long dailyRoomRateAmount)
Alias for Builder.dailyRoomRateAmount.
This unboxed primitive overload exists for backwards compatibility.
-
dailyRoomRateAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateAmount(Optional<Long> dailyRoomRateAmount)
Alias for calling Builder.dailyRoomRateAmount with
dailyRoomRateAmount.orElse(null).
-
dailyRoomRateAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateAmount(JsonField<Long> dailyRoomRateAmount)
Sets Builder.dailyRoomRateAmount to an arbitrary JSON value.
You should usually call Builder.dailyRoomRateAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dailyRoomRateCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateCurrency(String dailyRoomRateCurrency)
The ISO 4217 code for the daily room rate.
-
dailyRoomRateCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateCurrency(Optional<String> dailyRoomRateCurrency)
Alias for calling Builder.dailyRoomRateCurrency with
dailyRoomRateCurrency.orElse(null).
-
dailyRoomRateCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder dailyRoomRateCurrency(JsonField<String> dailyRoomRateCurrency)
Sets Builder.dailyRoomRateCurrency to an arbitrary JSON value.
You should usually call Builder.dailyRoomRateCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extraCharges
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder extraCharges(Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges extraCharges)
Additional charges (phone, late check-out, etc.) being billed.
-
extraCharges
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder extraCharges(Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges> extraCharges)
Alias for calling Builder.extraCharges with
extraCharges.orElse(null).
-
extraCharges
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder extraCharges(JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges> extraCharges)
Sets Builder.extraCharges to an arbitrary JSON value.
You should usually call Builder.extraCharges with a well-typed ExtraCharges value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
folioCashAdvancesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesAmount(Long folioCashAdvancesAmount)
Folio cash advances for the room.
-
folioCashAdvancesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesAmount(Long folioCashAdvancesAmount)
Alias for Builder.folioCashAdvancesAmount.
This unboxed primitive overload exists for backwards compatibility.
-
folioCashAdvancesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesAmount(Optional<Long> folioCashAdvancesAmount)
Alias for calling Builder.folioCashAdvancesAmount with
folioCashAdvancesAmount.orElse(null).
-
folioCashAdvancesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesAmount(JsonField<Long> folioCashAdvancesAmount)
Sets Builder.folioCashAdvancesAmount to an arbitrary JSON value.
You should usually call Builder.folioCashAdvancesAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
folioCashAdvancesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesCurrency(String folioCashAdvancesCurrency)
The ISO 4217 code for the folio cash advances.
-
folioCashAdvancesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesCurrency(Optional<String> folioCashAdvancesCurrency)
Alias for calling Builder.folioCashAdvancesCurrency with
folioCashAdvancesCurrency.orElse(null).
-
folioCashAdvancesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder folioCashAdvancesCurrency(JsonField<String> folioCashAdvancesCurrency)
Sets Builder.folioCashAdvancesCurrency to an arbitrary JSON value.
You should usually call Builder.folioCashAdvancesCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
foodBeverageChargesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesAmount(Long foodBeverageChargesAmount)
Food and beverage charges for the room.
-
foodBeverageChargesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesAmount(Long foodBeverageChargesAmount)
Alias for Builder.foodBeverageChargesAmount.
This unboxed primitive overload exists for backwards compatibility.
-
foodBeverageChargesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesAmount(Optional<Long> foodBeverageChargesAmount)
Alias for calling Builder.foodBeverageChargesAmount with
foodBeverageChargesAmount.orElse(null).
-
foodBeverageChargesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesAmount(JsonField<Long> foodBeverageChargesAmount)
Sets Builder.foodBeverageChargesAmount to an arbitrary JSON value.
You should usually call Builder.foodBeverageChargesAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
foodBeverageChargesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesCurrency(String foodBeverageChargesCurrency)
The ISO 4217 code for the food and beverage charges.
-
foodBeverageChargesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesCurrency(Optional<String> foodBeverageChargesCurrency)
Alias for calling Builder.foodBeverageChargesCurrency with
foodBeverageChargesCurrency.orElse(null).
-
foodBeverageChargesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder foodBeverageChargesCurrency(JsonField<String> foodBeverageChargesCurrency)
Sets Builder.foodBeverageChargesCurrency to an arbitrary JSON value.
You should usually call Builder.foodBeverageChargesCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
noShowIndicator
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder noShowIndicator(Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator noShowIndicator)
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
noShowIndicator
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder noShowIndicator(Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator> noShowIndicator)
Alias for calling Builder.noShowIndicator with
noShowIndicator.orElse(null).
-
noShowIndicator
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder noShowIndicator(JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator> noShowIndicator)
Sets Builder.noShowIndicator to an arbitrary JSON value.
You should usually call Builder.noShowIndicator with a well-typed NoShowIndicator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prepaidExpensesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesAmount(Long prepaidExpensesAmount)
Prepaid expenses being charged for the room.
-
prepaidExpensesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesAmount(Long prepaidExpensesAmount)
Alias for Builder.prepaidExpensesAmount.
This unboxed primitive overload exists for backwards compatibility.
-
prepaidExpensesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesAmount(Optional<Long> prepaidExpensesAmount)
Alias for calling Builder.prepaidExpensesAmount with
prepaidExpensesAmount.orElse(null).
-
prepaidExpensesAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesAmount(JsonField<Long> prepaidExpensesAmount)
Sets Builder.prepaidExpensesAmount to an arbitrary JSON value.
You should usually call Builder.prepaidExpensesAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
prepaidExpensesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesCurrency(String prepaidExpensesCurrency)
The ISO 4217 code for the prepaid expenses.
-
prepaidExpensesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesCurrency(Optional<String> prepaidExpensesCurrency)
Alias for calling Builder.prepaidExpensesCurrency with
prepaidExpensesCurrency.orElse(null).
-
prepaidExpensesCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder prepaidExpensesCurrency(JsonField<String> prepaidExpensesCurrency)
Sets Builder.prepaidExpensesCurrency to an arbitrary JSON value.
You should usually call Builder.prepaidExpensesCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
roomNights
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder roomNights(Long roomNights)
Number of nights the room was rented.
-
roomNights
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder roomNights(Long roomNights)
Alias for Builder.roomNights.
This unboxed primitive overload exists for backwards compatibility.
-
roomNights
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder roomNights(Optional<Long> roomNights)
Alias for calling Builder.roomNights with
roomNights.orElse(null).
-
roomNights
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder roomNights(JsonField<Long> roomNights)
Sets Builder.roomNights to an arbitrary JSON value.
You should usually call Builder.roomNights with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalRoomTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxAmount(Long totalRoomTaxAmount)
Total room tax being charged.
-
totalRoomTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxAmount(Long totalRoomTaxAmount)
Alias for Builder.totalRoomTaxAmount.
This unboxed primitive overload exists for backwards compatibility.
-
totalRoomTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxAmount(Optional<Long> totalRoomTaxAmount)
Alias for calling Builder.totalRoomTaxAmount with
totalRoomTaxAmount.orElse(null).
-
totalRoomTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxAmount(JsonField<Long> totalRoomTaxAmount)
Sets Builder.totalRoomTaxAmount to an arbitrary JSON value.
You should usually call Builder.totalRoomTaxAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalRoomTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxCurrency(String totalRoomTaxCurrency)
The ISO 4217 code for the total room tax.
-
totalRoomTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxCurrency(Optional<String> totalRoomTaxCurrency)
Alias for calling Builder.totalRoomTaxCurrency with
totalRoomTaxCurrency.orElse(null).
-
totalRoomTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalRoomTaxCurrency(JsonField<String> totalRoomTaxCurrency)
Sets Builder.totalRoomTaxCurrency to an arbitrary JSON value.
You should usually call Builder.totalRoomTaxCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxAmount(Long totalTaxAmount)
Total tax being charged for the room.
-
totalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxAmount(Long totalTaxAmount)
Alias for Builder.totalTaxAmount.
This unboxed primitive overload exists for backwards compatibility.
-
totalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxAmount(Optional<Long> totalTaxAmount)
Alias for calling Builder.totalTaxAmount with
totalTaxAmount.orElse(null).
-
totalTaxAmount
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxAmount(JsonField<Long> totalTaxAmount)
Sets Builder.totalTaxAmount to an arbitrary JSON value.
You should usually call Builder.totalTaxAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
totalTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxCurrency(String totalTaxCurrency)
The ISO 4217 code for the total tax assessed.
-
totalTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxCurrency(Optional<String> totalTaxCurrency)
Alias for calling Builder.totalTaxCurrency with
totalTaxCurrency.orElse(null).
-
totalTaxCurrency
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder totalTaxCurrency(JsonField<String> totalTaxCurrency)
Sets Builder.totalTaxCurrency to an arbitrary JSON value.
You should usually call Builder.totalTaxCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRefund.PurchaseDetails.Lodging build()
Returns an immutable instance of Lodging.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.checkInDate() .dailyRoomRateAmount() .dailyRoomRateCurrency() .extraCharges() .folioCashAdvancesAmount() .folioCashAdvancesCurrency() .foodBeverageChargesAmount() .foodBeverageChargesCurrency() .noShowIndicator() .prepaidExpensesAmount() .prepaidExpensesCurrency() .roomNights() .totalRoomTaxAmount() .totalRoomTaxCurrency() .totalTaxAmount() .totalTaxCurrency()
-
-
-
-