Enum Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known extends Enum<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known>
An enum containing PurchaseIdentifierFormat's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description FREE_TEXTFree text
ORDER_NUMBEROrder number
RENTAL_AGREEMENT_NUMBERRental agreement number
HOTEL_FOLIO_NUMBERHotel folio number
INVOICE_NUMBERInvoice number
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known>getEntries()An enum containing PurchaseIdentifierFormat's known values. -
-
Method Detail
-
valueOf
final Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat.Known> getEntries()
An enum containing PurchaseIdentifierFormat's known values.
-
-
-
-