Class Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.Travel.AncillaryAncillary purchases in addition to the airfare.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.BuilderA builder for Ancillary.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.CreditReasonIndicatorIndicates the reason for a credit to the cardholder.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service
-
Method Summary
-
-
Method Detail
-
connectedTicketDocumentNumber
final Optional<String> connectedTicketDocumentNumber()
If this purchase has a connection or relationship to another purchase, such as a baggage fee for a passenger transport ticket, this field should contain the ticket document number for the other purchase.
-
creditReasonIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.CreditReasonIndicator> creditReasonIndicator()
Indicates the reason for a credit to the cardholder.
-
passengerNameOrDescription
final Optional<String> passengerNameOrDescription()
Name of the passenger or description of the ancillary purchase.
-
services
final List<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service> services()
Additional travel charges, such as baggage fees.
-
ticketDocumentNumber
final Optional<String> ticketDocumentNumber()
Ticket document number.
-
_connectedTicketDocumentNumber
final JsonField<String> _connectedTicketDocumentNumber()
Returns the raw JSON value of connectedTicketDocumentNumber.
Unlike connectedTicketDocumentNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_creditReasonIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.CreditReasonIndicator> _creditReasonIndicator()
Returns the raw JSON value of creditReasonIndicator.
Unlike creditReasonIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_passengerNameOrDescription
final JsonField<String> _passengerNameOrDescription()
Returns the raw JSON value of passengerNameOrDescription.
Unlike passengerNameOrDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_services
final JsonField<List<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service>> _services()
Returns the raw JSON value of services.
Unlike services, this method doesn't throw if the JSON field has an unexpected type.
-
_ticketDocumentNumber
final JsonField<String> _ticketDocumentNumber()
Returns the raw JSON value of ticketDocumentNumber.
Unlike ticketDocumentNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary validate()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Builder builder()
Returns a mutable builder for constructing an instance of Ancillary.
The following fields are required:
.connectedTicketDocumentNumber() .creditReasonIndicator() .passengerNameOrDescription() .services() .ticketDocumentNumber()
-
-
-
-