Class Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service.BuilderA builder for Service.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service.CategoryCategory of the ancillary service.
-
Method Summary
-
-
Method Detail
-
category
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service.Category> category()
Category of the ancillary service.
-
subCategory
final Optional<String> subCategory()
Sub-category of the ancillary service, free-form.
-
_category
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_subCategory
final JsonField<String> _subCategory()
Returns the raw JSON value of subCategory.
Unlike subCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary.Service.Builder builder()
Returns a mutable builder for constructing an instance of Service.
The following fields are required:
.category() .subCategory()
-
-
-
-