Class Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg.BuilderA builder for TripLeg.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg.StopOverCodeIndicates whether a stopover is allowed on this ticket.
-
Method Summary
-
-
Method Detail
-
carrierCode
final Optional<String> carrierCode()
Carrier code (e.g., United Airlines, Jet Blue, etc.).
-
destinationCityAirportCode
final Optional<String> destinationCityAirportCode()
Code for the destination city or airport.
-
fareBasisCode
final Optional<String> fareBasisCode()
Fare basis code.
-
flightNumber
final Optional<String> flightNumber()
Flight number.
-
serviceClass
final Optional<String> serviceClass()
Service class (e.g., first class, business class, etc.).
-
stopOverCode
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg.StopOverCode> stopOverCode()
Indicates whether a stopover is allowed on this ticket.
-
_carrierCode
final JsonField<String> _carrierCode()
Returns the raw JSON value of carrierCode.
Unlike carrierCode, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationCityAirportCode
final JsonField<String> _destinationCityAirportCode()
Returns the raw JSON value of destinationCityAirportCode.
Unlike destinationCityAirportCode, this method doesn't throw if the JSON field has an unexpected type.
-
_fareBasisCode
final JsonField<String> _fareBasisCode()
Returns the raw JSON value of fareBasisCode.
Unlike fareBasisCode, this method doesn't throw if the JSON field has an unexpected type.
-
_flightNumber
final JsonField<String> _flightNumber()
Returns the raw JSON value of flightNumber.
Unlike flightNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_serviceClass
final JsonField<String> _serviceClass()
Returns the raw JSON value of serviceClass.
Unlike serviceClass, this method doesn't throw if the JSON field has an unexpected type.
-
_stopOverCode
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg.StopOverCode> _stopOverCode()
Returns the raw JSON value of stopOverCode.
Unlike stopOverCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg validate()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg.Builder builder()
Returns a mutable builder for constructing an instance of TripLeg.
The following fields are required:
.carrierCode() .destinationCityAirportCode() .fareBasisCode() .flightNumber() .serviceClass() .stopOverCode()
-
-
-
-