Class Transaction.Source.CardRefund.SchemeFee
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.SchemeFee
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.SchemeFee.BuilderA builder for SchemeFee.
public final classTransaction.Source.CardRefund.SchemeFee.CurrencyThe ISO 4217 code for the fee reimbursement.
public final classTransaction.Source.CardRefund.SchemeFee.FeeTypeThe type of fee being assessed.
-
Method Summary
Modifier and Type Method Description final Stringamount()The fee amount given as a string containing a decimal number. final OffsetDateTimecreatedAt()The ISO 8601 time at which the fee was created. final Transaction.Source.CardRefund.SchemeFee.Currencycurrency()The ISO 4217 code for the fee reimbursement. final Transaction.Source.CardRefund.SchemeFee.FeeTypefeeType()The type of fee being assessed. final Optional<String>fixedComponent()The fixed component of the fee, if applicable, given in major units of the fee amount. final Optional<String>variableRate()The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%). final JsonField<String>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Transaction.Source.CardRefund.SchemeFee.Currency>_currency()Returns the raw JSON value of currency. final JsonField<Transaction.Source.CardRefund.SchemeFee.FeeType>_feeType()Returns the raw JSON value of feeType. final JsonField<String>_fixedComponent()Returns the raw JSON value of fixedComponent. final JsonField<String>_variableRate()Returns the raw JSON value of variableRate. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRefund.SchemeFee.BuildertoBuilder()final Transaction.Source.CardRefund.SchemeFeevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRefund.SchemeFee.Builderbuilder()Returns a mutable builder for constructing an instance of SchemeFee. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the fee was created.
-
currency
final Transaction.Source.CardRefund.SchemeFee.Currency currency()
The ISO 4217 code for the fee reimbursement.
-
feeType
final Transaction.Source.CardRefund.SchemeFee.FeeType feeType()
The type of fee being assessed.
-
fixedComponent
final Optional<String> fixedComponent()
The fixed component of the fee, if applicable, given in major units of the fee amount.
-
variableRate
final Optional<String> variableRate()
The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).
-
_amount
final JsonField<String> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CardRefund.SchemeFee.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_feeType
final JsonField<Transaction.Source.CardRefund.SchemeFee.FeeType> _feeType()
Returns the raw JSON value of feeType.
Unlike feeType, this method doesn't throw if the JSON field has an unexpected type.
-
_fixedComponent
final JsonField<String> _fixedComponent()
Returns the raw JSON value of fixedComponent.
Unlike fixedComponent, this method doesn't throw if the JSON field has an unexpected type.
-
_variableRate
final JsonField<String> _variableRate()
Returns the raw JSON value of variableRate.
Unlike variableRate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.SchemeFee.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.SchemeFee validate()
-
builder
final static Transaction.Source.CardRefund.SchemeFee.Builder builder()
Returns a mutable builder for constructing an instance of SchemeFee.
The following fields are required:
.amount() .createdAt() .currency() .feeType() .fixedComponent() .variableRate()
-
-
-
-