Class Transaction.Source.CardRefund.SchemeFee.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.SchemeFee.BuilderA builder for SchemeFee.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.CardRefund.SchemeFee.Builder amount(String amount)
The fee amount given as a string containing a decimal number.
-
amount
final Transaction.Source.CardRefund.SchemeFee.Builder amount(JsonField<String> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Transaction.Source.CardRefund.SchemeFee.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the fee was created.
-
createdAt
final Transaction.Source.CardRefund.SchemeFee.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CardRefund.SchemeFee.Builder currency(Transaction.Source.CardRefund.SchemeFee.Currency currency)
The ISO 4217 code for the fee reimbursement.
-
currency
final Transaction.Source.CardRefund.SchemeFee.Builder currency(JsonField<Transaction.Source.CardRefund.SchemeFee.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
feeType
final Transaction.Source.CardRefund.SchemeFee.Builder feeType(Transaction.Source.CardRefund.SchemeFee.FeeType feeType)
The type of fee being assessed.
-
feeType
final Transaction.Source.CardRefund.SchemeFee.Builder feeType(JsonField<Transaction.Source.CardRefund.SchemeFee.FeeType> feeType)
Sets Builder.feeType to an arbitrary JSON value.
You should usually call Builder.feeType with a well-typed FeeType value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fixedComponent
final Transaction.Source.CardRefund.SchemeFee.Builder fixedComponent(String fixedComponent)
The fixed component of the fee, if applicable, given in major units of the fee amount.
-
fixedComponent
final Transaction.Source.CardRefund.SchemeFee.Builder fixedComponent(Optional<String> fixedComponent)
Alias for calling Builder.fixedComponent with
fixedComponent.orElse(null).
-
fixedComponent
final Transaction.Source.CardRefund.SchemeFee.Builder fixedComponent(JsonField<String> fixedComponent)
Sets Builder.fixedComponent to an arbitrary JSON value.
You should usually call Builder.fixedComponent with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
variableRate
final Transaction.Source.CardRefund.SchemeFee.Builder variableRate(String variableRate)
The variable rate component of the fee, if applicable, given as a decimal (e.g., 0.015 for 1.5%).
-
variableRate
final Transaction.Source.CardRefund.SchemeFee.Builder variableRate(Optional<String> variableRate)
Alias for calling Builder.variableRate with
variableRate.orElse(null).
-
variableRate
final Transaction.Source.CardRefund.SchemeFee.Builder variableRate(JsonField<String> variableRate)
Sets Builder.variableRate to an arbitrary JSON value.
You should usually call Builder.variableRate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardRefund.SchemeFee.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRefund.SchemeFee.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRefund.SchemeFee.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRefund.SchemeFee.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRefund.SchemeFee.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRefund.SchemeFee build()
Returns an immutable instance of SchemeFee.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .createdAt() .currency() .feeType() .fixedComponent() .variableRate()
-
-
-
-