Class Transaction.Source.CardRevenuePayment

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardRevenuePayment
    
                        

    A Card Revenue Payment object. This field will be present in the JSON response if and only if category is equal to card_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.