Class Transaction.Source.CardRevenuePayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRevenuePayment.BuilderA builder for CardRevenuePayment.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.CardRevenuePayment.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.CardRevenuePayment.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CardRevenuePayment.Builder currency(Transaction.Source.CardRevenuePayment.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.CardRevenuePayment.Builder currency(JsonField<Transaction.Source.CardRevenuePayment.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodEnd
final Transaction.Source.CardRevenuePayment.Builder periodEnd(OffsetDateTime periodEnd)
The end of the period for which this transaction paid interest.
-
periodEnd
final Transaction.Source.CardRevenuePayment.Builder periodEnd(JsonField<OffsetDateTime> periodEnd)
Sets Builder.periodEnd to an arbitrary JSON value.
You should usually call Builder.periodEnd with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodStart
final Transaction.Source.CardRevenuePayment.Builder periodStart(OffsetDateTime periodStart)
The start of the period for which this transaction paid interest.
-
periodStart
final Transaction.Source.CardRevenuePayment.Builder periodStart(JsonField<OffsetDateTime> periodStart)
Sets Builder.periodStart to an arbitrary JSON value.
You should usually call Builder.periodStart with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactedOnAccountId
final Transaction.Source.CardRevenuePayment.Builder transactedOnAccountId(String transactedOnAccountId)
The account the card belonged to.
-
transactedOnAccountId
final Transaction.Source.CardRevenuePayment.Builder transactedOnAccountId(Optional<String> transactedOnAccountId)
Alias for calling Builder.transactedOnAccountId with
transactedOnAccountId.orElse(null).
-
transactedOnAccountId
final Transaction.Source.CardRevenuePayment.Builder transactedOnAccountId(JsonField<String> transactedOnAccountId)
Sets Builder.transactedOnAccountId to an arbitrary JSON value.
You should usually call Builder.transactedOnAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardRevenuePayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardRevenuePayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardRevenuePayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardRevenuePayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardRevenuePayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardRevenuePayment build()
Returns an immutable instance of CardRevenuePayment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency() .periodEnd() .periodStart() .transactedOnAccountId()
-
-
-
-