Class Transaction.Source.CardSettlement
-
- All Implemented Interfaces:
public final class Transaction.Source.CardSettlementA Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardSettlement.BuilderA builder for CardSettlement.
public final classTransaction.Source.CardSettlement.CashbackCashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
public final classTransaction.Source.CardSettlement.CurrencyThe ISO 4217 code for the transaction's settlement currency.
public final classTransaction.Source.CardSettlement.InterchangeInterchange assessed as a part of this transaction.
public final classTransaction.Source.CardSettlement.NetworkThe card network on which this transaction was processed.
public final classTransaction.Source.CardSettlement.NetworkIdentifiersNetwork-specific identifiers for this refund.
public final classTransaction.Source.CardSettlement.PurchaseDetailsAdditional details about the card purchase, such as tax and industry-specific fields.
public final classTransaction.Source.CardSettlement.SchemeFeepublic final classTransaction.Source.CardSettlement.SurchargeSurcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
public final classTransaction.Source.CardSettlement.TypeA constant representing the object's type. For this resource it will always be
card_settlement.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Settlement identifier. final Longamount()The amount in the minor unit of the transaction's settlement currency. final Optional<String>cardAuthorization()The Card Authorization that was created prior to this Card Settlement, if one exists. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final Optional<Transaction.Source.CardSettlement.Cashback>cashback()Cashback earned on this transaction, if eligible. final Transaction.Source.CardSettlement.Currencycurrency()The ISO 4217 code for the transaction's settlement currency. final Optional<Transaction.Source.CardSettlement.Interchange>interchange()Interchange assessed as a part of this transaction. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The 4-digit MCC describing the merchant's business. final StringmerchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantName()The name of the merchant. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final Transaction.Source.CardSettlement.Networknetwork()The card network on which this transaction was processed. final Transaction.Source.CardSettlement.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for this refund. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Transaction. final LongpresentmentAmount()The amount in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final Optional<Transaction.Source.CardSettlement.PurchaseDetails>purchaseDetails()Additional details about the card purchase, such as tax and industry-specific fields. final List<Transaction.Source.CardSettlement.SchemeFee>schemeFees()The scheme fees associated with this card settlement. final Optional<Transaction.Source.CardSettlement.Surcharge>surcharge()Surcharge amount details, if applicable. final StringtransactionId()The identifier of the Transaction associated with this Transaction. final Transaction.Source.CardSettlement.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardAuthorization()Returns the raw JSON value of cardAuthorization. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<Transaction.Source.CardSettlement.Cashback>_cashback()Returns the raw JSON value of cashback. final JsonField<Transaction.Source.CardSettlement.Currency>_currency()Returns the raw JSON value of currency. final JsonField<Transaction.Source.CardSettlement.Interchange>_interchange()Returns the raw JSON value of interchange. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<Transaction.Source.CardSettlement.Network>_network()Returns the raw JSON value of network. final JsonField<Transaction.Source.CardSettlement.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<Long>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_presentmentCurrency()Returns the raw JSON value of presentmentCurrency. final JsonField<Transaction.Source.CardSettlement.PurchaseDetails>_purchaseDetails()Returns the raw JSON value of purchaseDetails. final JsonField<List<Transaction.Source.CardSettlement.SchemeFee>>_schemeFees()Returns the raw JSON value of schemeFees. final JsonField<Transaction.Source.CardSettlement.Surcharge>_surcharge()Returns the raw JSON value of surcharge. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<Transaction.Source.CardSettlement.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardSettlement.BuildertoBuilder()final Transaction.Source.CardSettlementvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardSettlement.Builderbuilder()Returns a mutable builder for constructing an instance of CardSettlement. -
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
cardAuthorization
final Optional<String> cardAuthorization()
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
cashback
final Optional<Transaction.Source.CardSettlement.Cashback> cashback()
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
currency
final Transaction.Source.CardSettlement.Currency currency()
The ISO 4217 code for the transaction's settlement currency.
-
interchange
final Optional<Transaction.Source.CardSettlement.Interchange> interchange()
Interchange assessed as a part of this transaction.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The 4-digit MCC describing the merchant's business.
-
merchantCity
final String merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantName
final String merchantName()
The name of the merchant.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
network
final Transaction.Source.CardSettlement.Network network()
The card network on which this transaction was processed.
-
networkIdentifiers
final Transaction.Source.CardSettlement.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for this refund.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Transaction.
-
presentmentAmount
final Long presentmentAmount()
The amount in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
purchaseDetails
final Optional<Transaction.Source.CardSettlement.PurchaseDetails> purchaseDetails()
Additional details about the card purchase, such as tax and industry-specific fields.
-
schemeFees
final List<Transaction.Source.CardSettlement.SchemeFee> schemeFees()
The scheme fees associated with this card settlement.
-
surcharge
final Optional<Transaction.Source.CardSettlement.Surcharge> surcharge()
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
-
transactionId
final String transactionId()
The identifier of the Transaction associated with this Transaction.
-
type
final Transaction.Source.CardSettlement.Type type()
A constant representing the object's type. For this resource it will always be
card_settlement.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorization
final JsonField<String> _cardAuthorization()
Returns the raw JSON value of cardAuthorization.
Unlike cardAuthorization, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_cashback
final JsonField<Transaction.Source.CardSettlement.Cashback> _cashback()
Returns the raw JSON value of cashback.
Unlike cashback, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CardSettlement.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_interchange
final JsonField<Transaction.Source.CardSettlement.Interchange> _interchange()
Returns the raw JSON value of interchange.
Unlike interchange, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<Transaction.Source.CardSettlement.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<Transaction.Source.CardSettlement.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
Returns the raw JSON value of presentmentCurrency.
Unlike presentmentCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseDetails
final JsonField<Transaction.Source.CardSettlement.PurchaseDetails> _purchaseDetails()
Returns the raw JSON value of purchaseDetails.
Unlike purchaseDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_schemeFees
final JsonField<List<Transaction.Source.CardSettlement.SchemeFee>> _schemeFees()
Returns the raw JSON value of schemeFees.
Unlike schemeFees, this method doesn't throw if the JSON field has an unexpected type.
-
_surcharge
final JsonField<Transaction.Source.CardSettlement.Surcharge> _surcharge()
Returns the raw JSON value of surcharge.
Unlike surcharge, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Transaction.Source.CardSettlement.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardSettlement.Builder toBuilder()
-
validate
final Transaction.Source.CardSettlement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardSettlement.Builder builder()
Returns a mutable builder for constructing an instance of CardSettlement.
The following fields are required:
.id() .amount() .cardAuthorization() .cardPaymentId() .cashback() .currency() .interchange() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantName() .merchantPostalCode() .merchantState() .network() .networkIdentifiers() .pendingTransactionId() .presentmentAmount() .presentmentCurrency() .purchaseDetails() .schemeFees() .surcharge() .transactionId() .type()
-
-
-
-