Class Transaction.Source.CardSettlement.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CardSettlement.BuilderA builder for CardSettlement.
-
-
Method Summary
-
-
Method Detail
-
id
final Transaction.Source.CardSettlement.Builder id(String id)
The Card Settlement identifier.
-
id
final Transaction.Source.CardSettlement.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.CardSettlement.Builder amount(Long amount)
The amount in the minor unit of the transaction's settlement currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.CardSettlement.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardAuthorization
final Transaction.Source.CardSettlement.Builder cardAuthorization(String cardAuthorization)
The Card Authorization that was created prior to this Card Settlement, if one exists.
-
cardAuthorization
final Transaction.Source.CardSettlement.Builder cardAuthorization(Optional<String> cardAuthorization)
Alias for calling Builder.cardAuthorization with
cardAuthorization.orElse(null).
-
cardAuthorization
final Transaction.Source.CardSettlement.Builder cardAuthorization(JsonField<String> cardAuthorization)
Sets Builder.cardAuthorization to an arbitrary JSON value.
You should usually call Builder.cardAuthorization with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final Transaction.Source.CardSettlement.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final Transaction.Source.CardSettlement.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cashback
final Transaction.Source.CardSettlement.Builder cashback(Transaction.Source.CardSettlement.Cashback cashback)
Cashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
cashback
final Transaction.Source.CardSettlement.Builder cashback(Optional<Transaction.Source.CardSettlement.Cashback> cashback)
Alias for calling Builder.cashback with
cashback.orElse(null).
-
cashback
final Transaction.Source.CardSettlement.Builder cashback(JsonField<Transaction.Source.CardSettlement.Cashback> cashback)
Sets Builder.cashback to an arbitrary JSON value.
You should usually call Builder.cashback with a well-typed Cashback value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CardSettlement.Builder currency(Transaction.Source.CardSettlement.Currency currency)
The ISO 4217 code for the transaction's settlement currency.
-
currency
final Transaction.Source.CardSettlement.Builder currency(JsonField<Transaction.Source.CardSettlement.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
interchange
final Transaction.Source.CardSettlement.Builder interchange(Transaction.Source.CardSettlement.Interchange interchange)
Interchange assessed as a part of this transaction.
-
interchange
final Transaction.Source.CardSettlement.Builder interchange(Optional<Transaction.Source.CardSettlement.Interchange> interchange)
Alias for calling Builder.interchange with
interchange.orElse(null).
-
interchange
final Transaction.Source.CardSettlement.Builder interchange(JsonField<Transaction.Source.CardSettlement.Interchange> interchange)
Sets Builder.interchange to an arbitrary JSON value.
You should usually call Builder.interchange with a well-typed Interchange value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final Transaction.Source.CardSettlement.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final Transaction.Source.CardSettlement.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final Transaction.Source.CardSettlement.Builder merchantCategoryCode(String merchantCategoryCode)
The 4-digit MCC describing the merchant's business.
-
merchantCategoryCode
final Transaction.Source.CardSettlement.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCity
final Transaction.Source.CardSettlement.Builder merchantCity(String merchantCity)
The city the merchant resides in.
-
merchantCity
final Transaction.Source.CardSettlement.Builder merchantCity(JsonField<String> merchantCity)
Sets Builder.merchantCity to an arbitrary JSON value.
You should usually call Builder.merchantCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final Transaction.Source.CardSettlement.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final Transaction.Source.CardSettlement.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final Transaction.Source.CardSettlement.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final Transaction.Source.CardSettlement.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantPostalCode
final Transaction.Source.CardSettlement.Builder merchantPostalCode(String merchantPostalCode)
The merchant's postal code. For US merchants this is always a 5-digit ZIP code.
-
merchantPostalCode
final Transaction.Source.CardSettlement.Builder merchantPostalCode(Optional<String> merchantPostalCode)
Alias for calling Builder.merchantPostalCode with
merchantPostalCode.orElse(null).
-
merchantPostalCode
final Transaction.Source.CardSettlement.Builder merchantPostalCode(JsonField<String> merchantPostalCode)
Sets Builder.merchantPostalCode to an arbitrary JSON value.
You should usually call Builder.merchantPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantState
final Transaction.Source.CardSettlement.Builder merchantState(String merchantState)
The state the merchant resides in.
-
merchantState
final Transaction.Source.CardSettlement.Builder merchantState(Optional<String> merchantState)
Alias for calling Builder.merchantState with
merchantState.orElse(null).
-
merchantState
final Transaction.Source.CardSettlement.Builder merchantState(JsonField<String> merchantState)
Sets Builder.merchantState to an arbitrary JSON value.
You should usually call Builder.merchantState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final Transaction.Source.CardSettlement.Builder network(Transaction.Source.CardSettlement.Network network)
The card network on which this transaction was processed.
-
network
final Transaction.Source.CardSettlement.Builder network(JsonField<Transaction.Source.CardSettlement.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
networkIdentifiers
final Transaction.Source.CardSettlement.Builder networkIdentifiers(Transaction.Source.CardSettlement.NetworkIdentifiers networkIdentifiers)
Network-specific identifiers for this refund.
-
networkIdentifiers
final Transaction.Source.CardSettlement.Builder networkIdentifiers(JsonField<Transaction.Source.CardSettlement.NetworkIdentifiers> networkIdentifiers)
Sets Builder.networkIdentifiers to an arbitrary JSON value.
You should usually call Builder.networkIdentifiers with a well-typed NetworkIdentifiers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final Transaction.Source.CardSettlement.Builder pendingTransactionId(String pendingTransactionId)
The identifier of the Pending Transaction associated with this Transaction.
-
pendingTransactionId
final Transaction.Source.CardSettlement.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final Transaction.Source.CardSettlement.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentAmount
final Transaction.Source.CardSettlement.Builder presentmentAmount(Long presentmentAmount)
The amount in the minor unit of the transaction's presentment currency.
-
presentmentAmount
final Transaction.Source.CardSettlement.Builder presentmentAmount(JsonField<Long> presentmentAmount)
Sets Builder.presentmentAmount to an arbitrary JSON value.
You should usually call Builder.presentmentAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
presentmentCurrency
final Transaction.Source.CardSettlement.Builder presentmentCurrency(String presentmentCurrency)
The ISO 4217 code for the transaction's presentment currency.
-
presentmentCurrency
final Transaction.Source.CardSettlement.Builder presentmentCurrency(JsonField<String> presentmentCurrency)
Sets Builder.presentmentCurrency to an arbitrary JSON value.
You should usually call Builder.presentmentCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseDetails
final Transaction.Source.CardSettlement.Builder purchaseDetails(Transaction.Source.CardSettlement.PurchaseDetails purchaseDetails)
Additional details about the card purchase, such as tax and industry-specific fields.
-
purchaseDetails
final Transaction.Source.CardSettlement.Builder purchaseDetails(Optional<Transaction.Source.CardSettlement.PurchaseDetails> purchaseDetails)
Alias for calling Builder.purchaseDetails with
purchaseDetails.orElse(null).
-
purchaseDetails
final Transaction.Source.CardSettlement.Builder purchaseDetails(JsonField<Transaction.Source.CardSettlement.PurchaseDetails> purchaseDetails)
Sets Builder.purchaseDetails to an arbitrary JSON value.
You should usually call Builder.purchaseDetails with a well-typed PurchaseDetails value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schemeFees
final Transaction.Source.CardSettlement.Builder schemeFees(List<Transaction.Source.CardSettlement.SchemeFee> schemeFees)
The scheme fees associated with this card settlement.
-
schemeFees
final Transaction.Source.CardSettlement.Builder schemeFees(JsonField<List<Transaction.Source.CardSettlement.SchemeFee>> schemeFees)
Sets Builder.schemeFees to an arbitrary JSON value.
You should usually call Builder.schemeFees with a well-typed
List<SchemeFee>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSchemeFee
final Transaction.Source.CardSettlement.Builder addSchemeFee(Transaction.Source.CardSettlement.SchemeFee schemeFee)
Adds a single SchemeFee to schemeFees.
-
surcharge
final Transaction.Source.CardSettlement.Builder surcharge(Transaction.Source.CardSettlement.Surcharge surcharge)
Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
-
surcharge
final Transaction.Source.CardSettlement.Builder surcharge(Optional<Transaction.Source.CardSettlement.Surcharge> surcharge)
Alias for calling Builder.surcharge with
surcharge.orElse(null).
-
surcharge
final Transaction.Source.CardSettlement.Builder surcharge(JsonField<Transaction.Source.CardSettlement.Surcharge> surcharge)
Sets Builder.surcharge to an arbitrary JSON value.
You should usually call Builder.surcharge with a well-typed Surcharge value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CardSettlement.Builder transactionId(String transactionId)
The identifier of the Transaction associated with this Transaction.
-
transactionId
final Transaction.Source.CardSettlement.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Transaction.Source.CardSettlement.Builder type(Transaction.Source.CardSettlement.Type type)
A constant representing the object's type. For this resource it will always be
card_settlement.
-
type
final Transaction.Source.CardSettlement.Builder type(JsonField<Transaction.Source.CardSettlement.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CardSettlement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CardSettlement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CardSettlement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CardSettlement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CardSettlement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CardSettlement build()
Returns an immutable instance of CardSettlement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .amount() .cardAuthorization() .cardPaymentId() .cashback() .currency() .interchange() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantName() .merchantPostalCode() .merchantState() .network() .networkIdentifiers() .pendingTransactionId() .presentmentAmount() .presentmentCurrency() .purchaseDetails() .schemeFees() .surcharge() .transactionId() .type()
-
-
-
-