Class Transaction.Source.CardSettlement.Cashback
-
- All Implemented Interfaces:
public final class Transaction.Source.CardSettlement.CashbackCashback earned on this transaction, if eligible. Cashback is paid out in aggregate, monthly.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardSettlement.Cashback.BuilderA builder for Cashback.
public final classTransaction.Source.CardSettlement.Cashback.CurrencyThe ISO 4217 code for the cashback.
-
Method Summary
Modifier and Type Method Description final Stringamount()The cashback amount given as a string containing a decimal number. final Transaction.Source.CardSettlement.Cashback.Currencycurrency()The ISO 4217 code for the cashback. final JsonField<String>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.CardSettlement.Cashback.Currency>_currency()Returns the raw JSON value of currency. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardSettlement.Cashback.BuildertoBuilder()final Transaction.Source.CardSettlement.Cashbackvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardSettlement.Cashback.Builderbuilder()Returns a mutable builder for constructing an instance of Cashback. -
-
Method Detail
-
amount
final String amount()
The cashback amount given as a string containing a decimal number. The amount is a positive number if it will be credited to you (e.g., settlements) and a negative number if it will be debited (e.g., refunds).
-
currency
final Transaction.Source.CardSettlement.Cashback.Currency currency()
The ISO 4217 code for the cashback.
-
_amount
final JsonField<String> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CardSettlement.Cashback.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardSettlement.Cashback.Builder toBuilder()
-
validate
final Transaction.Source.CardSettlement.Cashback validate()
-
builder
final static Transaction.Source.CardSettlement.Cashback.Builder builder()
Returns a mutable builder for constructing an instance of Cashback.
The following fields are required:
.amount() .currency()
-
-
-
-