Class Transaction.Source.CardSettlement.Surcharge

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardSettlement.Surcharge
    
                        

    Surcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).