Class Transaction.Source.CashbackPayment
-
- All Implemented Interfaces:
public final class Transaction.Source.CashbackPaymentA Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CashbackPayment.BuilderA builder for CashbackPayment.
public final classTransaction.Source.CashbackPayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final Optional<String>accruedOnCardId()The card on which the cashback was accrued. final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.CashbackPayment.Currencycurrency()The ISO 4217 code for the transaction currency. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid cashback. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid cashback. final JsonField<String>_accruedOnCardId()Returns the raw JSON value of accruedOnCardId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.CashbackPayment.Currency>_currency()Returns the raw JSON value of currency. final JsonField<OffsetDateTime>_periodEnd()Returns the raw JSON value of periodEnd. final JsonField<OffsetDateTime>_periodStart()Returns the raw JSON value of periodStart. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CashbackPayment.BuildertoBuilder()final Transaction.Source.CashbackPaymentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CashbackPayment.Builderbuilder()Returns a mutable builder for constructing an instance of CashbackPayment. -
-
Method Detail
-
accruedOnCardId
final Optional<String> accruedOnCardId()
The card on which the cashback was accrued.
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.CashbackPayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid cashback.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid cashback.
-
_accruedOnCardId
final JsonField<String> _accruedOnCardId()
Returns the raw JSON value of accruedOnCardId.
Unlike accruedOnCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CashbackPayment.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
Returns the raw JSON value of periodEnd.
Unlike periodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
Returns the raw JSON value of periodStart.
Unlike periodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CashbackPayment.Builder toBuilder()
-
validate
final Transaction.Source.CashbackPayment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CashbackPayment.Builder builder()
Returns a mutable builder for constructing an instance of CashbackPayment.
The following fields are required:
.accruedOnCardId() .amount() .currency() .periodEnd() .periodStart()
-
-
-
-