Class Transaction.Source.CashbackPayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CashbackPayment.BuilderA builder for CashbackPayment.
-
-
Method Summary
-
-
Method Detail
-
accruedOnCardId
final Transaction.Source.CashbackPayment.Builder accruedOnCardId(String accruedOnCardId)
The card on which the cashback was accrued.
-
accruedOnCardId
final Transaction.Source.CashbackPayment.Builder accruedOnCardId(Optional<String> accruedOnCardId)
Alias for calling Builder.accruedOnCardId with
accruedOnCardId.orElse(null).
-
accruedOnCardId
final Transaction.Source.CashbackPayment.Builder accruedOnCardId(JsonField<String> accruedOnCardId)
Sets Builder.accruedOnCardId to an arbitrary JSON value.
You should usually call Builder.accruedOnCardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.CashbackPayment.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.CashbackPayment.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.CashbackPayment.Builder currency(Transaction.Source.CashbackPayment.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.CashbackPayment.Builder currency(JsonField<Transaction.Source.CashbackPayment.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodEnd
final Transaction.Source.CashbackPayment.Builder periodEnd(OffsetDateTime periodEnd)
The end of the period for which this transaction paid cashback.
-
periodEnd
final Transaction.Source.CashbackPayment.Builder periodEnd(JsonField<OffsetDateTime> periodEnd)
Sets Builder.periodEnd to an arbitrary JSON value.
You should usually call Builder.periodEnd with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodStart
final Transaction.Source.CashbackPayment.Builder periodStart(OffsetDateTime periodStart)
The start of the period for which this transaction paid cashback.
-
periodStart
final Transaction.Source.CashbackPayment.Builder periodStart(JsonField<OffsetDateTime> periodStart)
Sets Builder.periodStart to an arbitrary JSON value.
You should usually call Builder.periodStart with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CashbackPayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CashbackPayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CashbackPayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CashbackPayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CashbackPayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CashbackPayment build()
Returns an immutable instance of CashbackPayment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accruedOnCardId() .amount() .currency() .periodEnd() .periodStart()
-
-
-
-