Class Transaction.Source.Category

  • All Implemented Interfaces:
    com.increase.api.core.Enum

    
    public final class Transaction.Source.Category
     implements Enum
                        

    The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.