Enum Transaction.Source.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.Category.Known extends Enum<Transaction.Source.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_TRANSFER_INTENTIONAccount Transfer Intention: details will be under the
account_transfer_intentionobject.ACH_TRANSFER_INTENTIONACH Transfer Intention: details will be under the
ach_transfer_intentionobject.ACH_TRANSFER_REJECTIONACH Transfer Rejection: details will be under the
ach_transfer_rejectionobject.ACH_TRANSFER_RETURNACH Transfer Return: details will be under the
ach_transfer_returnobject.CASHBACK_PAYMENTCashback Payment: details will be under the
cashback_paymentobject.CARD_DISPUTE_ACCEPTANCELegacy Card Dispute Acceptance: details will be under the
card_dispute_acceptanceobject.CARD_DISPUTE_FINANCIALCard Dispute Financial: details will be under the
card_dispute_financialobject.CARD_DISPUTE_LOSSLegacy Card Dispute Loss: details will be under the
card_dispute_lossobject.CARD_REFUNDCard Refund: details will be under the
card_refundobject.CARD_SETTLEMENTCard Settlement: details will be under the
card_settlementobject.CARD_FINANCIALCard Financial: details will be under the
card_financialobject.CARD_REVENUE_PAYMENTCard Revenue Payment: details will be under the
card_revenue_paymentobject.CHECK_DEPOSIT_ACCEPTANCECheck Deposit Acceptance: details will be under the
check_deposit_acceptanceobject.CHECK_DEPOSIT_RETURNCheck Deposit Return: details will be under the
check_deposit_returnobject.FEDNOW_TRANSFER_ACKNOWLEDGEMENTFedNow Transfer Acknowledgement: details will be under the
fednow_transfer_acknowledgementobject.CHECK_TRANSFER_DEPOSITCheck Transfer Deposit: details will be under the
check_transfer_depositobject.FEE_PAYMENTFee Payment: details will be under the
fee_paymentobject.INBOUND_ACH_TRANSFERInbound ACH Transfer Intention: details will be under the
inbound_ach_transferobject.INBOUND_ACH_TRANSFER_RETURN_INTENTIONInbound ACH Transfer Return Intention: details will be under the
inbound_ach_transfer_return_intentionobject.INBOUND_CHECK_DEPOSIT_RETURN_INTENTIONInbound Check Deposit Return Intention: details will be under the
inbound_check_deposit_return_intentionobject.INBOUND_CHECK_ADJUSTMENTInbound Check Adjustment: details will be under the
inbound_check_adjustmentobject.INBOUND_FEDNOW_TRANSFER_CONFIRMATIONInbound FedNow Transfer Confirmation: details will be under the
inbound_fednow_transfer_confirmationobject.INBOUND_REAL_TIME_PAYMENTS_TRANSFER_CONFIRMATIONInbound Real-Time Payments Transfer Confirmation: details will be under the
inbound_real_time_payments_transfer_confirmationobject.INBOUND_WIRE_REVERSALInbound Wire Reversal: details will be under the
inbound_wire_reversalobject.INBOUND_WIRE_TRANSFERInbound Wire Transfer Intention: details will be under the
inbound_wire_transferobject.INBOUND_WIRE_TRANSFER_REVERSALInbound Wire Transfer Reversal Intention: details will be under the
inbound_wire_transfer_reversalobject.INTEREST_PAYMENTInterest Payment: details will be under the
interest_paymentobject.INTERNAL_SOURCEInternal Source: details will be under the
internal_sourceobject.REAL_TIME_PAYMENTS_TRANSFER_ACKNOWLEDGEMENTReal-Time Payments Transfer Acknowledgement: details will be under the
real_time_payments_transfer_acknowledgementobject.SAMPLE_FUNDSSample Funds: details will be under the
sample_fundsobject.WIRE_TRANSFER_INTENTIONWire Transfer Intention: details will be under the
wire_transfer_intentionobject.SWIFT_TRANSFER_INTENTIONSwift Transfer Intention: details will be under the
swift_transfer_intentionobject.SWIFT_TRANSFER_RETURNSwift Transfer Return: details will be under the
swift_transfer_returnobject.CARD_PUSH_TRANSFER_ACCEPTANCECard Push Transfer Acceptance: details will be under the
card_push_transfer_acceptanceobject.ACCOUNT_REVENUE_PAYMENTAccount Revenue Payment: details will be under the
account_revenue_paymentobject.BLOCKCHAIN_ONRAMP_TRANSFER_INTENTIONBlockchain On-Ramp Transfer Intention: details will be under the
blockchain_onramp_transfer_intentionobject.BLOCKCHAIN_OFFRAMP_TRANSFER_SETTLEMENTBlockchain Off-Ramp Transfer Settlement: details will be under the
blockchain_offramp_transfer_settlementobject.OTHERThe Transaction was made for an undocumented or deprecated reason.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final Transaction.Source.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-