Class Transaction.Source.CheckTransferDeposit

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CheckTransferDeposit
    
                        

    A Check Transfer Deposit object. This field will be present in the JSON response if and only if category is equal to check_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.