Class Transaction.Source.CheckTransferDeposit.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.CheckTransferDeposit.BuilderA builder for CheckTransferDeposit.
-
-
Method Summary
-
-
Method Detail
-
backImageFileId
final Transaction.Source.CheckTransferDeposit.Builder backImageFileId(String backImageFileId)
The identifier of the API File object containing an image of the back of the deposited check.
-
backImageFileId
final Transaction.Source.CheckTransferDeposit.Builder backImageFileId(Optional<String> backImageFileId)
Alias for calling Builder.backImageFileId with
backImageFileId.orElse(null).
-
backImageFileId
final Transaction.Source.CheckTransferDeposit.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bankOfFirstDepositRoutingNumber
final Transaction.Source.CheckTransferDeposit.Builder bankOfFirstDepositRoutingNumber(String bankOfFirstDepositRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
bankOfFirstDepositRoutingNumber
final Transaction.Source.CheckTransferDeposit.Builder bankOfFirstDepositRoutingNumber(Optional<String> bankOfFirstDepositRoutingNumber)
Alias for calling Builder.bankOfFirstDepositRoutingNumber with
bankOfFirstDepositRoutingNumber.orElse(null).
-
bankOfFirstDepositRoutingNumber
final Transaction.Source.CheckTransferDeposit.Builder bankOfFirstDepositRoutingNumber(JsonField<String> bankOfFirstDepositRoutingNumber)
Sets Builder.bankOfFirstDepositRoutingNumber to an arbitrary JSON value.
You should usually call Builder.bankOfFirstDepositRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
depositedAt
final Transaction.Source.CheckTransferDeposit.Builder depositedAt(OffsetDateTime depositedAt)
When the check was deposited.
-
depositedAt
final Transaction.Source.CheckTransferDeposit.Builder depositedAt(JsonField<OffsetDateTime> depositedAt)
Sets Builder.depositedAt to an arbitrary JSON value.
You should usually call Builder.depositedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final Transaction.Source.CheckTransferDeposit.Builder frontImageFileId(String frontImageFileId)
The identifier of the API File object containing an image of the front of the deposited check.
-
frontImageFileId
final Transaction.Source.CheckTransferDeposit.Builder frontImageFileId(Optional<String> frontImageFileId)
Alias for calling Builder.frontImageFileId with
frontImageFileId.orElse(null).
-
frontImageFileId
final Transaction.Source.CheckTransferDeposit.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundCheckDepositId
final Transaction.Source.CheckTransferDeposit.Builder inboundCheckDepositId(String inboundCheckDepositId)
The identifier of the Inbound Check Deposit object associated with this transaction.
-
inboundCheckDepositId
final Transaction.Source.CheckTransferDeposit.Builder inboundCheckDepositId(Optional<String> inboundCheckDepositId)
Alias for calling Builder.inboundCheckDepositId with
inboundCheckDepositId.orElse(null).
-
inboundCheckDepositId
final Transaction.Source.CheckTransferDeposit.Builder inboundCheckDepositId(JsonField<String> inboundCheckDepositId)
Sets Builder.inboundCheckDepositId to an arbitrary JSON value.
You should usually call Builder.inboundCheckDepositId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.CheckTransferDeposit.Builder transactionId(String transactionId)
The identifier of the Transaction object created when the check was deposited.
-
transactionId
final Transaction.Source.CheckTransferDeposit.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final Transaction.Source.CheckTransferDeposit.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.CheckTransferDeposit.Builder transferId(String transferId)
The identifier of the Check Transfer object that was deposited.
-
transferId
final Transaction.Source.CheckTransferDeposit.Builder transferId(Optional<String> transferId)
Alias for calling Builder.transferId with
transferId.orElse(null).
-
transferId
final Transaction.Source.CheckTransferDeposit.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Transaction.Source.CheckTransferDeposit.Builder type(Transaction.Source.CheckTransferDeposit.Type type)
A constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
type
final Transaction.Source.CheckTransferDeposit.Builder type(JsonField<Transaction.Source.CheckTransferDeposit.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.CheckTransferDeposit.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.CheckTransferDeposit.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.CheckTransferDeposit.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.CheckTransferDeposit.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.CheckTransferDeposit.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.CheckTransferDeposit build()
Returns an immutable instance of CheckTransferDeposit.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.backImageFileId() .bankOfFirstDepositRoutingNumber() .depositedAt() .frontImageFileId() .inboundCheckDepositId() .transactionId() .transferId() .type()
-
-
-
-