Class Transaction.Source.FednowTransferAcknowledgement
-
- All Implemented Interfaces:
public final class Transaction.Source.FednowTransferAcknowledgementA FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_acknowledgement. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.FednowTransferAcknowledgement.BuilderA builder for FednowTransferAcknowledgement.
-
Method Summary
Modifier and Type Method Description final StringtransferId()The identifier of the FedNow Transfer that led to this Transaction. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.FednowTransferAcknowledgement.BuildertoBuilder()final Transaction.Source.FednowTransferAcknowledgementvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.FednowTransferAcknowledgement.Builderbuilder()Returns a mutable builder for constructing an instance of FednowTransferAcknowledgement. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the FedNow Transfer that led to this Transaction.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.FednowTransferAcknowledgement.Builder toBuilder()
-
validate
final Transaction.Source.FednowTransferAcknowledgement validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.FednowTransferAcknowledgement.Builder builder()
Returns a mutable builder for constructing an instance of FednowTransferAcknowledgement.
The following fields are required:
.transferId()
-
-
-
-