Class Transaction.Source.FeePayment
-
- All Implemented Interfaces:
public final class Transaction.Source.FeePaymentA Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.FeePayment.BuilderA builder for FeePayment.
public final classTransaction.Source.FeePayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.FeePayment.Currencycurrency()The ISO 4217 code for the transaction currency. final LocalDatefeePeriodStart()The start of this payment's fee period, usually the first day of a month. final Optional<String>programId()The Program for which this fee was incurred. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.FeePayment.Currency>_currency()Returns the raw JSON value of currency. final JsonField<LocalDate>_feePeriodStart()Returns the raw JSON value of feePeriodStart. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.FeePayment.BuildertoBuilder()final Transaction.Source.FeePaymentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.FeePayment.Builderbuilder()Returns a mutable builder for constructing an instance of FeePayment. -
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.FeePayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
feePeriodStart
final LocalDate feePeriodStart()
The start of this payment's fee period, usually the first day of a month.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.FeePayment.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_feePeriodStart
final JsonField<LocalDate> _feePeriodStart()
Returns the raw JSON value of feePeriodStart.
Unlike feePeriodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.FeePayment.Builder toBuilder()
-
validate
final Transaction.Source.FeePayment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.FeePayment.Builder builder()
Returns a mutable builder for constructing an instance of FeePayment.
The following fields are required:
.amount() .currency() .feePeriodStart() .programId()
-
-
-
-