Class Transaction.Source.FeePayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.FeePayment.BuilderA builder for FeePayment.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.FeePayment.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.FeePayment.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.FeePayment.Builder currency(Transaction.Source.FeePayment.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.FeePayment.Builder currency(JsonField<Transaction.Source.FeePayment.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
feePeriodStart
final Transaction.Source.FeePayment.Builder feePeriodStart(LocalDate feePeriodStart)
The start of this payment's fee period, usually the first day of a month.
-
feePeriodStart
final Transaction.Source.FeePayment.Builder feePeriodStart(JsonField<LocalDate> feePeriodStart)
Sets Builder.feePeriodStart to an arbitrary JSON value.
You should usually call Builder.feePeriodStart with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
programId
final Transaction.Source.FeePayment.Builder programId(String programId)
The Program for which this fee was incurred.
-
programId
final Transaction.Source.FeePayment.Builder programId(Optional<String> programId)
Alias for calling Builder.programId with
programId.orElse(null).
-
programId
final Transaction.Source.FeePayment.Builder programId(JsonField<String> programId)
Sets Builder.programId to an arbitrary JSON value.
You should usually call Builder.programId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.FeePayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.FeePayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.FeePayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.FeePayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.FeePayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.FeePayment build()
Returns an immutable instance of FeePayment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency() .feePeriodStart() .programId()
-
-
-
-