Class Transaction.Source.InboundAchTransfer.Addenda
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.AddendaAdditional information sent from the originator.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundAchTransfer.Addenda.BuilderA builder for Addenda.
public final classTransaction.Source.InboundAchTransfer.Addenda.CategoryThe type of addendum.
public final classTransaction.Source.InboundAchTransfer.Addenda.FreeformUnstructured
payment_related_informationpassed through by the originator.
-
Method Summary
-
-
Method Detail
-
category
final Transaction.Source.InboundAchTransfer.Addenda.Category category()
The type of addendum.
-
freeform
final Optional<Transaction.Source.InboundAchTransfer.Addenda.Freeform> freeform()
Unstructured
payment_related_informationpassed through by the originator.
-
_category
final JsonField<Transaction.Source.InboundAchTransfer.Addenda.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_freeform
final JsonField<Transaction.Source.InboundAchTransfer.Addenda.Freeform> _freeform()
Returns the raw JSON value of freeform.
Unlike freeform, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundAchTransfer.Addenda.Builder toBuilder()
-
validate
final Transaction.Source.InboundAchTransfer.Addenda validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.InboundAchTransfer.Addenda.Builder builder()
Returns a mutable builder for constructing an instance of Addenda.
The following fields are required:
.category() .freeform()
-
-
-
-