Class Transaction.Source.InboundAchTransfer.Addenda.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.Addenda.BuilderA builder for Addenda.
-
-
Method Summary
-
-
Method Detail
-
category
final Transaction.Source.InboundAchTransfer.Addenda.Builder category(Transaction.Source.InboundAchTransfer.Addenda.Category category)
The type of addendum.
-
category
final Transaction.Source.InboundAchTransfer.Addenda.Builder category(JsonField<Transaction.Source.InboundAchTransfer.Addenda.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
freeform
final Transaction.Source.InboundAchTransfer.Addenda.Builder freeform(Transaction.Source.InboundAchTransfer.Addenda.Freeform freeform)
Unstructured
payment_related_informationpassed through by the originator.
-
freeform
final Transaction.Source.InboundAchTransfer.Addenda.Builder freeform(Optional<Transaction.Source.InboundAchTransfer.Addenda.Freeform> freeform)
Alias for calling Builder.freeform with
freeform.orElse(null).
-
freeform
final Transaction.Source.InboundAchTransfer.Addenda.Builder freeform(JsonField<Transaction.Source.InboundAchTransfer.Addenda.Freeform> freeform)
Sets Builder.freeform to an arbitrary JSON value.
You should usually call Builder.freeform with a well-typed Freeform value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundAchTransfer.Addenda.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundAchTransfer.Addenda.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Addenda.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundAchTransfer.Addenda.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Addenda.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundAchTransfer.Addenda build()
Returns an immutable instance of Addenda.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.category() .freeform()
-
-
-
-