Class Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.BuilderA builder for Entry.
-
Method Summary
Modifier and Type Method Description final StringpaymentRelatedInformation()The payment related information passed in the addendum. final JsonField<String>_paymentRelatedInformation()Returns the raw JSON value of paymentRelatedInformation. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.BuildertoBuilder()final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builderbuilder()Returns a mutable builder for constructing an instance of Entry. -
-
Method Detail
-
paymentRelatedInformation
final String paymentRelatedInformation()
The payment related information passed in the addendum.
-
_paymentRelatedInformation
final JsonField<String> _paymentRelatedInformation()
Returns the raw JSON value of paymentRelatedInformation.
Unlike paymentRelatedInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder builder()
Returns a mutable builder for constructing an instance of Entry.
The following fields are required:
.paymentRelatedInformation()
-
-
-
-