Class Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.BuilderA builder for Entry.
-
-
Method Summary
-
-
Method Detail
-
paymentRelatedInformation
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder paymentRelatedInformation(String paymentRelatedInformation)
The payment related information passed in the addendum.
-
paymentRelatedInformation
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder paymentRelatedInformation(JsonField<String> paymentRelatedInformation)
Sets Builder.paymentRelatedInformation to an arbitrary JSON value.
You should usually call Builder.paymentRelatedInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry build()
Returns an immutable instance of Entry.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.paymentRelatedInformation()
-
-
-
-