Class Transaction.Source.InboundAchTransfer.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.BuilderA builder for InboundAchTransfer.
-
-
Method Summary
-
-
Method Detail
-
addenda
final Transaction.Source.InboundAchTransfer.Builder addenda(Transaction.Source.InboundAchTransfer.Addenda addenda)
Additional information sent from the originator.
-
addenda
final Transaction.Source.InboundAchTransfer.Builder addenda(Optional<Transaction.Source.InboundAchTransfer.Addenda> addenda)
Alias for calling Builder.addenda with
addenda.orElse(null).
-
addenda
final Transaction.Source.InboundAchTransfer.Builder addenda(JsonField<Transaction.Source.InboundAchTransfer.Addenda> addenda)
Sets Builder.addenda to an arbitrary JSON value.
You should usually call Builder.addenda with a well-typed Addenda value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.InboundAchTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final Transaction.Source.InboundAchTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyDescriptiveDate
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDescriptiveDate(String originatorCompanyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD.
-
originatorCompanyDescriptiveDate
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDescriptiveDate(Optional<String> originatorCompanyDescriptiveDate)
Alias for calling Builder.originatorCompanyDescriptiveDate with
originatorCompanyDescriptiveDate.orElse(null).
-
originatorCompanyDescriptiveDate
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDescriptiveDate(JsonField<String> originatorCompanyDescriptiveDate)
Sets Builder.originatorCompanyDescriptiveDate to an arbitrary JSON value.
You should usually call Builder.originatorCompanyDescriptiveDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyDiscretionaryData
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDiscretionaryData(String originatorCompanyDiscretionaryData)
Data set by the originator.
-
originatorCompanyDiscretionaryData
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDiscretionaryData(Optional<String> originatorCompanyDiscretionaryData)
Alias for calling Builder.originatorCompanyDiscretionaryData with
originatorCompanyDiscretionaryData.orElse(null).
-
originatorCompanyDiscretionaryData
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyDiscretionaryData(JsonField<String> originatorCompanyDiscretionaryData)
Sets Builder.originatorCompanyDiscretionaryData to an arbitrary JSON value.
You should usually call Builder.originatorCompanyDiscretionaryData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyEntryDescription
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyEntryDescription(String originatorCompanyEntryDescription)
An informational description of the transfer.
-
originatorCompanyEntryDescription
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyEntryDescription(JsonField<String> originatorCompanyEntryDescription)
Sets Builder.originatorCompanyEntryDescription to an arbitrary JSON value.
You should usually call Builder.originatorCompanyEntryDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyId
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyId(String originatorCompanyId)
An identifier for the originating company. This is generally, but not always, a stable identifier across multiple transfers.
-
originatorCompanyId
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyId(JsonField<String> originatorCompanyId)
Sets Builder.originatorCompanyId to an arbitrary JSON value.
You should usually call Builder.originatorCompanyId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorCompanyName
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyName(String originatorCompanyName)
A name set by the originator to identify themselves.
-
originatorCompanyName
final Transaction.Source.InboundAchTransfer.Builder originatorCompanyName(JsonField<String> originatorCompanyName)
Sets Builder.originatorCompanyName to an arbitrary JSON value.
You should usually call Builder.originatorCompanyName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverIdNumber
final Transaction.Source.InboundAchTransfer.Builder receiverIdNumber(String receiverIdNumber)
The originator's identifier for the transfer recipient.
-
receiverIdNumber
final Transaction.Source.InboundAchTransfer.Builder receiverIdNumber(Optional<String> receiverIdNumber)
Alias for calling Builder.receiverIdNumber with
receiverIdNumber.orElse(null).
-
receiverIdNumber
final Transaction.Source.InboundAchTransfer.Builder receiverIdNumber(JsonField<String> receiverIdNumber)
Sets Builder.receiverIdNumber to an arbitrary JSON value.
You should usually call Builder.receiverIdNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverName
final Transaction.Source.InboundAchTransfer.Builder receiverName(String receiverName)
The name of the transfer recipient. This value is informational and not verified by Increase.
-
receiverName
final Transaction.Source.InboundAchTransfer.Builder receiverName(Optional<String> receiverName)
Alias for calling Builder.receiverName with
receiverName.orElse(null).
-
receiverName
final Transaction.Source.InboundAchTransfer.Builder receiverName(JsonField<String> receiverName)
Sets Builder.receiverName to an arbitrary JSON value.
You should usually call Builder.receiverName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
traceNumber
final Transaction.Source.InboundAchTransfer.Builder traceNumber(String traceNumber)
A 15 digit number recorded in the Nacha file and available to both the originating and receiving bank. Along with the amount, date, and originating routing number, this can be used to identify the ACH transfer at either bank. ACH trace numbers are not unique, but are used to correlate returns.
-
traceNumber
final Transaction.Source.InboundAchTransfer.Builder traceNumber(JsonField<String> traceNumber)
Sets Builder.traceNumber to an arbitrary JSON value.
You should usually call Builder.traceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.InboundAchTransfer.Builder transferId(String transferId)
The Inbound ACH Transfer's identifier.
-
transferId
final Transaction.Source.InboundAchTransfer.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundAchTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundAchTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundAchTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundAchTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundAchTransfer build()
Returns an immutable instance of InboundAchTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.addenda() .amount() .originatorCompanyDescriptiveDate() .originatorCompanyDiscretionaryData() .originatorCompanyEntryDescription() .originatorCompanyId() .originatorCompanyName() .receiverIdNumber() .receiverName() .traceNumber() .transferId()
-
-
-
-