Class Transaction.Source.InboundCheckAdjustment
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundCheckAdjustmentAn Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundCheckAdjustment.BuilderA builder for InboundCheckAdjustment.
public final classTransaction.Source.InboundCheckAdjustment.ReasonThe reason for the adjustment.
-
Method Summary
Modifier and Type Method Description final StringadjustedTransactionId()The ID of the transaction that was adjusted. final Longamount()The amount of the check adjustment. final Transaction.Source.InboundCheckAdjustment.Reasonreason()The reason for the adjustment. final JsonField<String>_adjustedTransactionId()Returns the raw JSON value of adjustedTransactionId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.InboundCheckAdjustment.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundCheckAdjustment.BuildertoBuilder()final Transaction.Source.InboundCheckAdjustmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundCheckAdjustment.Builderbuilder()Returns a mutable builder for constructing an instance of InboundCheckAdjustment. -
-
Method Detail
-
adjustedTransactionId
final String adjustedTransactionId()
The ID of the transaction that was adjusted.
-
reason
final Transaction.Source.InboundCheckAdjustment.Reason reason()
The reason for the adjustment.
-
_adjustedTransactionId
final JsonField<String> _adjustedTransactionId()
Returns the raw JSON value of adjustedTransactionId.
Unlike adjustedTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<Transaction.Source.InboundCheckAdjustment.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundCheckAdjustment.Builder toBuilder()
-
validate
final Transaction.Source.InboundCheckAdjustment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.InboundCheckAdjustment.Builder builder()
Returns a mutable builder for constructing an instance of InboundCheckAdjustment.
The following fields are required:
.adjustedTransactionId() .amount() .reason()
-
-
-
-