Enum Transaction.Source.InboundCheckAdjustment.Reason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.InboundCheckAdjustment.Reason.Value extends Enum<Transaction.Source.InboundCheckAdjustment.Reason.Value>
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.InboundCheckAdjustment.Reason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description LATE_RETURNThe return was initiated too late and the receiving institution has responded with a Late Return Claim.
WRONG_PAYEE_CREDITThe check was deposited to the wrong payee and the depositing institution has reimbursed the funds with a Wrong Payee Credit.
ADJUSTED_AMOUNTThe check was deposited with a different amount than what was written on the check.
NON_CONFORMING_ITEMThe recipient was not able to process the check. This usually happens for e.g., low quality images.
PAIDThe check has already been deposited elsewhere and so this is a duplicate.
_UNKNOWNAn enum member indicating that Reason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.InboundCheckAdjustment.Reason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.InboundCheckAdjustment.Reason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.InboundCheckAdjustment.Reason.Value>getEntries()An enum containing Reason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final Transaction.Source.InboundCheckAdjustment.Reason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.InboundCheckAdjustment.Reason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.InboundCheckAdjustment.Reason.Value> getEntries()
An enum containing Reason's known values, as well as an _UNKNOWN member.
An instance of Reason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-