Class Transaction.Source.InboundFednowTransferConfirmation

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InboundFednowTransferConfirmation
    
                        

    An Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if category is equal to inbound_fednow_transfer_confirmation. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.