Class Transaction.Source.InboundRealTimePaymentsTransferConfirmation
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundRealTimePaymentsTransferConfirmationAn Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundRealTimePaymentsTransferConfirmation.BuilderA builder for InboundRealTimePaymentsTransferConfirmation.
public final classTransaction.Source.InboundRealTimePaymentsTransferConfirmation.CurrencyThe ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in the minor unit of the transfer's currency. final StringcreditorName()The name the sender of the transfer specified as the recipient of the transfer. final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currencycurrency()The ISO 4217 code of the transfer's currency. final StringdebtorAccountNumber()The account number of the account that sent the transfer. final StringdebtorName()The name provided by the sender of the transfer. final StringdebtorRoutingNumber()The routing number of the account that sent the transfer. final StringtransactionIdentification()The Real-Time Payments network identification of the transfer. final StringtransferId()The identifier of the Real-Time Payments Transfer that led to this Transaction. final Optional<String>unstructuredRemittanceInformation()Additional information included with the transfer. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_debtorAccountNumber()Returns the raw JSON value of debtorAccountNumber. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<String>_transactionIdentification()Returns the raw JSON value of transactionIdentification. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.BuildertoBuilder()final Transaction.Source.InboundRealTimePaymentsTransferConfirmationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builderbuilder()Returns a mutable builder for constructing an instance of InboundRealTimePaymentsTransferConfirmation. -
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transfer's currency. For dollars, for example, this is cents.
-
creditorName
final String creditorName()
The name the sender of the transfer specified as the recipient of the transfer.
-
currency
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency currency()
The ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
debtorAccountNumber
final String debtorAccountNumber()
The account number of the account that sent the transfer.
-
debtorName
final String debtorName()
The name provided by the sender of the transfer.
-
debtorRoutingNumber
final String debtorRoutingNumber()
The routing number of the account that sent the transfer.
-
transactionIdentification
final String transactionIdentification()
The Real-Time Payments network identification of the transfer.
-
transferId
final String transferId()
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
unstructuredRemittanceInformation
final Optional<String> unstructuredRemittanceInformation()
Additional information included with the transfer.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
Returns the raw JSON value of debtorAccountNumber.
Unlike debtorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionIdentification
final JsonField<String> _transactionIdentification()
Returns the raw JSON value of transactionIdentification.
Unlike transactionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation validate()
-
builder
final static Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder builder()
Returns a mutable builder for constructing an instance of InboundRealTimePaymentsTransferConfirmation.
The following fields are required:
.amount() .creditorName() .currency() .debtorAccountNumber() .debtorName() .debtorRoutingNumber() .transactionIdentification() .transferId() .unstructuredRemittanceInformation()
-
-
-
-