Class Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundRealTimePaymentsTransferConfirmation.BuilderA builder for InboundRealTimePaymentsTransferConfirmation.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder amount(Long amount)
The amount in the minor unit of the transfer's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder creditorName(String creditorName)
The name the sender of the transfer specified as the recipient of the transfer.
-
creditorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder currency(Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency currency)
The ISO 4217 code of the transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
currency
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder currency(JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAccountNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorAccountNumber(String debtorAccountNumber)
The account number of the account that sent the transfer.
-
debtorAccountNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorAccountNumber(JsonField<String> debtorAccountNumber)
Sets Builder.debtorAccountNumber to an arbitrary JSON value.
You should usually call Builder.debtorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorName(String debtorName)
The name provided by the sender of the transfer.
-
debtorName
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorRoutingNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorRoutingNumber(String debtorRoutingNumber)
The routing number of the account that sent the transfer.
-
debtorRoutingNumber
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
Sets Builder.debtorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.debtorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionIdentification
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transactionIdentification(String transactionIdentification)
The Real-Time Payments network identification of the transfer.
-
transactionIdentification
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transactionIdentification(JsonField<String> transactionIdentification)
Sets Builder.transactionIdentification to an arbitrary JSON value.
You should usually call Builder.transactionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transferId(String transferId)
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
transferId
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
Additional information included with the transfer.
-
unstructuredRemittanceInformation
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder unstructuredRemittanceInformation(Optional<String> unstructuredRemittanceInformation)
Alias for calling Builder.unstructuredRemittanceInformation with
unstructuredRemittanceInformation.orElse(null).
-
unstructuredRemittanceInformation
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundRealTimePaymentsTransferConfirmation build()
Returns an immutable instance of InboundRealTimePaymentsTransferConfirmation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .creditorName() .currency() .debtorAccountNumber() .debtorName() .debtorRoutingNumber() .transactionIdentification() .transferId() .unstructuredRemittanceInformation()
-
-
-
-