Class Transaction.Source.InboundRealTimePaymentsTransferDecline
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundRealTimePaymentsTransferDeclineAn Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundRealTimePaymentsTransferDecline.BuilderA builder for InboundRealTimePaymentsTransferDecline.
public final classTransaction.Source.InboundRealTimePaymentsTransferDecline.CurrencyThe ISO 4217 code of the declined transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
public final classTransaction.Source.InboundRealTimePaymentsTransferDecline.ReasonWhy the transfer was declined.
-
Method Summary
Modifier and Type Method Description final Longamount()The declined amount in the minor unit of the destination account currency. final StringcreditorName()The name the sender of the transfer specified as the recipient of the transfer. final Transaction.Source.InboundRealTimePaymentsTransferDecline.Currencycurrency()The ISO 4217 code of the declined transfer's currency. final StringdebtorAccountNumber()The account number of the account that sent the transfer. final StringdebtorName()The name provided by the sender of the transfer. final StringdebtorRoutingNumber()The routing number of the account that sent the transfer. final Transaction.Source.InboundRealTimePaymentsTransferDecline.Reasonreason()Why the transfer was declined. final Optional<String>remittanceInformation()Additional information included with the transfer. final StringtransactionIdentification()The Real-Time Payments network identification of the declined transfer. final StringtransferId()The identifier of the Real-Time Payments Transfer that led to this Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<Transaction.Source.InboundRealTimePaymentsTransferDecline.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_debtorAccountNumber()Returns the raw JSON value of debtorAccountNumber. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason>_reason()Returns the raw JSON value of reason. final JsonField<String>_remittanceInformation()Returns the raw JSON value of remittanceInformation. final JsonField<String>_transactionIdentification()Returns the raw JSON value of transactionIdentification. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundRealTimePaymentsTransferDecline.BuildertoBuilder()final Transaction.Source.InboundRealTimePaymentsTransferDeclinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundRealTimePaymentsTransferDecline.Builderbuilder()Returns a mutable builder for constructing an instance of InboundRealTimePaymentsTransferDecline. -
-
Method Detail
-
amount
final Long amount()
The declined amount in the minor unit of the destination account currency. For dollars, for example, this is cents.
-
creditorName
final String creditorName()
The name the sender of the transfer specified as the recipient of the transfer.
-
currency
final Transaction.Source.InboundRealTimePaymentsTransferDecline.Currency currency()
The ISO 4217 code of the declined transfer's currency. This will always be "USD" for a Real-Time Payments transfer.
-
debtorAccountNumber
final String debtorAccountNumber()
The account number of the account that sent the transfer.
-
debtorName
final String debtorName()
The name provided by the sender of the transfer.
-
debtorRoutingNumber
final String debtorRoutingNumber()
The routing number of the account that sent the transfer.
-
reason
final Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason reason()
Why the transfer was declined.
-
remittanceInformation
final Optional<String> remittanceInformation()
Additional information included with the transfer.
-
transactionIdentification
final String transactionIdentification()
The Real-Time Payments network identification of the declined transfer.
-
transferId
final String transferId()
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.InboundRealTimePaymentsTransferDecline.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
Returns the raw JSON value of debtorAccountNumber.
Unlike debtorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Returns the raw JSON value of remittanceInformation.
Unlike remittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionIdentification
final JsonField<String> _transactionIdentification()
Returns the raw JSON value of transactionIdentification.
Unlike transactionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundRealTimePaymentsTransferDecline.Builder toBuilder()
-
validate
final Transaction.Source.InboundRealTimePaymentsTransferDecline validate()
-
builder
final static Transaction.Source.InboundRealTimePaymentsTransferDecline.Builder builder()
Returns a mutable builder for constructing an instance of InboundRealTimePaymentsTransferDecline.
The following fields are required:
.amount() .creditorName() .currency() .debtorAccountNumber() .debtorName() .debtorRoutingNumber() .reason() .remittanceInformation() .transactionIdentification() .transferId()
-
-
-
-