Enum Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known extends Enum<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_NUMBER_CANCELEDThe account number is canceled.
ACCOUNT_NUMBER_DISABLEDThe account number is disabled.
ACCOUNT_RESTRICTEDYour account is restricted.
GROUP_LOCKEDYour account is inactive.
ENTITY_NOT_ACTIVEThe account's entity is not active.
REAL_TIME_PAYMENTS_NOT_ENABLEDYour account is not enabled to receive Real-Time Payments transfers.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.InboundRealTimePaymentsTransferDecline.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-