Class Transaction.Source.InboundWireReversal
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireReversalAn Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundWireReversal.BuilderA builder for InboundWireReversal.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount that was reversed in USD cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the reversal was created. final Optional<String>debtorRoutingNumber()The debtor's routing number. final Stringdescription()The description on the reversal message from Fedwire, set by the reversing bank. final LocalDateinputCycleDate()The Fedwire cycle date for the wire reversal. final StringinputMessageAccountabilityData()The Fedwire transaction identifier. final StringinputSequenceNumber()The Fedwire sequence number. final StringinputSource()The Fedwire input source identifier. final Optional<String>instructionIdentification()The sending bank's identifier for the reversal. final Optional<String>returnReasonAdditionalInformation()Additional information about the reason for the reversal. final Optional<String>returnReasonCode()A code provided by the sending bank giving a reason for the reversal. final Optional<String>returnReasonCodeDescription()An Increase-generated description of the return_reason_code.final StringtransactionId()The ID for the Transaction associated with the transfer reversal. final StringwireTransferId()The ID for the Wire Transfer that is being reversed. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<LocalDate>_inputCycleDate()Returns the raw JSON value of inputCycleDate. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_inputSequenceNumber()Returns the raw JSON value of inputSequenceNumber. final JsonField<String>_inputSource()Returns the raw JSON value of inputSource. final JsonField<String>_instructionIdentification()Returns the raw JSON value of instructionIdentification. final JsonField<String>_returnReasonAdditionalInformation()Returns the raw JSON value of returnReasonAdditionalInformation. final JsonField<String>_returnReasonCode()Returns the raw JSON value of returnReasonCode. final JsonField<String>_returnReasonCodeDescription()Returns the raw JSON value of returnReasonCodeDescription. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<String>_wireTransferId()Returns the raw JSON value of wireTransferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundWireReversal.BuildertoBuilder()final Transaction.Source.InboundWireReversalvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundWireReversal.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireReversal. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the reversal was created.
-
debtorRoutingNumber
final Optional<String> debtorRoutingNumber()
The debtor's routing number.
-
description
final String description()
The description on the reversal message from Fedwire, set by the reversing bank.
-
inputCycleDate
final LocalDate inputCycleDate()
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00 PM Eastern Time on the evening before the
cycle date.
-
inputMessageAccountabilityData
final String inputMessageAccountabilityData()
The Fedwire transaction identifier.
-
inputSequenceNumber
final String inputSequenceNumber()
The Fedwire sequence number.
-
inputSource
final String inputSource()
The Fedwire input source identifier.
-
instructionIdentification
final Optional<String> instructionIdentification()
The sending bank's identifier for the reversal.
-
returnReasonAdditionalInformation
final Optional<String> returnReasonAdditionalInformation()
Additional information about the reason for the reversal.
-
returnReasonCode
final Optional<String> returnReasonCode()
A code provided by the sending bank giving a reason for the reversal. The common return reason codes are /documentation/wire-reversals#reversal-reason-codes.
-
returnReasonCodeDescription
final Optional<String> returnReasonCodeDescription()
An Increase-generated description of the
return_reason_code.
-
transactionId
final String transactionId()
The ID for the Transaction associated with the transfer reversal.
-
wireTransferId
final String wireTransferId()
The ID for the Wire Transfer that is being reversed.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_inputCycleDate
final JsonField<LocalDate> _inputCycleDate()
Returns the raw JSON value of inputCycleDate.
Unlike inputCycleDate, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_inputSequenceNumber
final JsonField<String> _inputSequenceNumber()
Returns the raw JSON value of inputSequenceNumber.
Unlike inputSequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_inputSource
final JsonField<String> _inputSource()
Returns the raw JSON value of inputSource.
Unlike inputSource, this method doesn't throw if the JSON field has an unexpected type.
-
_instructionIdentification
final JsonField<String> _instructionIdentification()
Returns the raw JSON value of instructionIdentification.
Unlike instructionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonAdditionalInformation
final JsonField<String> _returnReasonAdditionalInformation()
Returns the raw JSON value of returnReasonAdditionalInformation.
Unlike returnReasonAdditionalInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonCode
final JsonField<String> _returnReasonCode()
Returns the raw JSON value of returnReasonCode.
Unlike returnReasonCode, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReasonCodeDescription
final JsonField<String> _returnReasonCodeDescription()
Returns the raw JSON value of returnReasonCodeDescription.
Unlike returnReasonCodeDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_wireTransferId
final JsonField<String> _wireTransferId()
Returns the raw JSON value of wireTransferId.
Unlike wireTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundWireReversal.Builder toBuilder()
-
validate
final Transaction.Source.InboundWireReversal validate()
-
builder
final static Transaction.Source.InboundWireReversal.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireReversal.
The following fields are required:
.amount() .createdAt() .debtorRoutingNumber() .description() .inputCycleDate() .inputMessageAccountabilityData() .inputSequenceNumber() .inputSource() .instructionIdentification() .returnReasonAdditionalInformation() .returnReasonCode() .returnReasonCodeDescription() .transactionId() .wireTransferId()
-
-
-
-