Class Transaction.Source.InboundWireReversal.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireReversal.BuilderA builder for InboundWireReversal.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.InboundWireReversal.Builder amount(Long amount)
The amount that was reversed in USD cents.
-
amount
final Transaction.Source.InboundWireReversal.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Transaction.Source.InboundWireReversal.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the reversal was created.
-
createdAt
final Transaction.Source.InboundWireReversal.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorRoutingNumber
final Transaction.Source.InboundWireReversal.Builder debtorRoutingNumber(String debtorRoutingNumber)
The debtor's routing number.
-
debtorRoutingNumber
final Transaction.Source.InboundWireReversal.Builder debtorRoutingNumber(Optional<String> debtorRoutingNumber)
Alias for calling Builder.debtorRoutingNumber with
debtorRoutingNumber.orElse(null).
-
debtorRoutingNumber
final Transaction.Source.InboundWireReversal.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
Sets Builder.debtorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.debtorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Transaction.Source.InboundWireReversal.Builder description(String description)
The description on the reversal message from Fedwire, set by the reversing bank.
-
description
final Transaction.Source.InboundWireReversal.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputCycleDate
final Transaction.Source.InboundWireReversal.Builder inputCycleDate(LocalDate inputCycleDate)
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00 PM Eastern Time on the evening before the
cycle date.
-
inputCycleDate
final Transaction.Source.InboundWireReversal.Builder inputCycleDate(JsonField<LocalDate> inputCycleDate)
Sets Builder.inputCycleDate to an arbitrary JSON value.
You should usually call Builder.inputCycleDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireReversal.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
The Fedwire transaction identifier.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireReversal.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.inputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputSequenceNumber
final Transaction.Source.InboundWireReversal.Builder inputSequenceNumber(String inputSequenceNumber)
The Fedwire sequence number.
-
inputSequenceNumber
final Transaction.Source.InboundWireReversal.Builder inputSequenceNumber(JsonField<String> inputSequenceNumber)
Sets Builder.inputSequenceNumber to an arbitrary JSON value.
You should usually call Builder.inputSequenceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputSource
final Transaction.Source.InboundWireReversal.Builder inputSource(String inputSource)
The Fedwire input source identifier.
-
inputSource
final Transaction.Source.InboundWireReversal.Builder inputSource(JsonField<String> inputSource)
Sets Builder.inputSource to an arbitrary JSON value.
You should usually call Builder.inputSource with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instructionIdentification
final Transaction.Source.InboundWireReversal.Builder instructionIdentification(String instructionIdentification)
The sending bank's identifier for the reversal.
-
instructionIdentification
final Transaction.Source.InboundWireReversal.Builder instructionIdentification(Optional<String> instructionIdentification)
Alias for calling Builder.instructionIdentification with
instructionIdentification.orElse(null).
-
instructionIdentification
final Transaction.Source.InboundWireReversal.Builder instructionIdentification(JsonField<String> instructionIdentification)
Sets Builder.instructionIdentification to an arbitrary JSON value.
You should usually call Builder.instructionIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
returnReasonAdditionalInformation
final Transaction.Source.InboundWireReversal.Builder returnReasonAdditionalInformation(String returnReasonAdditionalInformation)
Additional information about the reason for the reversal.
-
returnReasonAdditionalInformation
final Transaction.Source.InboundWireReversal.Builder returnReasonAdditionalInformation(Optional<String> returnReasonAdditionalInformation)
Alias for calling Builder.returnReasonAdditionalInformation with
returnReasonAdditionalInformation.orElse(null).
-
returnReasonAdditionalInformation
final Transaction.Source.InboundWireReversal.Builder returnReasonAdditionalInformation(JsonField<String> returnReasonAdditionalInformation)
Sets Builder.returnReasonAdditionalInformation to an arbitrary JSON value.
You should usually call Builder.returnReasonAdditionalInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
returnReasonCode
final Transaction.Source.InboundWireReversal.Builder returnReasonCode(String returnReasonCode)
A code provided by the sending bank giving a reason for the reversal. The common return reason codes are /documentation/wire-reversals#reversal-reason-codes.
-
returnReasonCode
final Transaction.Source.InboundWireReversal.Builder returnReasonCode(Optional<String> returnReasonCode)
Alias for calling Builder.returnReasonCode with
returnReasonCode.orElse(null).
-
returnReasonCode
final Transaction.Source.InboundWireReversal.Builder returnReasonCode(JsonField<String> returnReasonCode)
Sets Builder.returnReasonCode to an arbitrary JSON value.
You should usually call Builder.returnReasonCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
returnReasonCodeDescription
final Transaction.Source.InboundWireReversal.Builder returnReasonCodeDescription(String returnReasonCodeDescription)
An Increase-generated description of the
return_reason_code.
-
returnReasonCodeDescription
final Transaction.Source.InboundWireReversal.Builder returnReasonCodeDescription(Optional<String> returnReasonCodeDescription)
Alias for calling Builder.returnReasonCodeDescription with
returnReasonCodeDescription.orElse(null).
-
returnReasonCodeDescription
final Transaction.Source.InboundWireReversal.Builder returnReasonCodeDescription(JsonField<String> returnReasonCodeDescription)
Sets Builder.returnReasonCodeDescription to an arbitrary JSON value.
You should usually call Builder.returnReasonCodeDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.InboundWireReversal.Builder transactionId(String transactionId)
The ID for the Transaction associated with the transfer reversal.
-
transactionId
final Transaction.Source.InboundWireReversal.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireTransferId
final Transaction.Source.InboundWireReversal.Builder wireTransferId(String wireTransferId)
The ID for the Wire Transfer that is being reversed.
-
wireTransferId
final Transaction.Source.InboundWireReversal.Builder wireTransferId(JsonField<String> wireTransferId)
Sets Builder.wireTransferId to an arbitrary JSON value.
You should usually call Builder.wireTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundWireReversal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundWireReversal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundWireReversal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundWireReversal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundWireReversal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundWireReversal build()
Returns an immutable instance of InboundWireReversal.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .createdAt() .debtorRoutingNumber() .description() .inputCycleDate() .inputMessageAccountabilityData() .inputSequenceNumber() .inputSource() .instructionIdentification() .returnReasonAdditionalInformation() .returnReasonCode() .returnReasonCodeDescription() .transactionId() .wireTransferId()
-
-
-
-