Class Transaction.Source.InboundWireTransfer

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InboundWireTransfer
    
                        

    An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if category is equal to inbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.