Class Transaction.Source.InboundWireTransferReversal.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireTransferReversal.BuilderA builder for InboundWireTransferReversal.
-
-
Method Summary
-
-
Method Detail
-
inboundWireTransferId
final Transaction.Source.InboundWireTransferReversal.Builder inboundWireTransferId(String inboundWireTransferId)
The ID of the Inbound Wire Transfer that is being reversed.
-
inboundWireTransferId
final Transaction.Source.InboundWireTransferReversal.Builder inboundWireTransferId(JsonField<String> inboundWireTransferId)
Sets Builder.inboundWireTransferId to an arbitrary JSON value.
You should usually call Builder.inboundWireTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundWireTransferReversal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundWireTransferReversal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundWireTransferReversal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundWireTransferReversal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundWireTransferReversal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundWireTransferReversal build()
Returns an immutable instance of InboundWireTransferReversal.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.inboundWireTransferId()
-
-
-
-