Class Transaction.Source.InterestPayment
-
- All Implemented Interfaces:
public final class Transaction.Source.InterestPaymentAn Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InterestPayment.BuilderA builder for InterestPayment.
public final classTransaction.Source.InterestPayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final StringaccruedOnAccountId()The account on which the interest was accrued. final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.InterestPayment.Currencycurrency()The ISO 4217 code for the transaction currency. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid interest. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid interest. final JsonField<String>_accruedOnAccountId()Returns the raw JSON value of accruedOnAccountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.InterestPayment.Currency>_currency()Returns the raw JSON value of currency. final JsonField<OffsetDateTime>_periodEnd()Returns the raw JSON value of periodEnd. final JsonField<OffsetDateTime>_periodStart()Returns the raw JSON value of periodStart. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InterestPayment.BuildertoBuilder()final Transaction.Source.InterestPaymentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InterestPayment.Builderbuilder()Returns a mutable builder for constructing an instance of InterestPayment. -
-
Method Detail
-
accruedOnAccountId
final String accruedOnAccountId()
The account on which the interest was accrued.
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.InterestPayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid interest.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid interest.
-
_accruedOnAccountId
final JsonField<String> _accruedOnAccountId()
Returns the raw JSON value of accruedOnAccountId.
Unlike accruedOnAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.InterestPayment.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
Returns the raw JSON value of periodEnd.
Unlike periodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
Returns the raw JSON value of periodStart.
Unlike periodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InterestPayment.Builder toBuilder()
-
validate
final Transaction.Source.InterestPayment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.InterestPayment.Builder builder()
Returns a mutable builder for constructing an instance of InterestPayment.
The following fields are required:
.accruedOnAccountId() .amount() .currency() .periodEnd() .periodStart()
-
-
-
-