Class Transaction.Source.InterestPayment.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InterestPayment.BuilderA builder for InterestPayment.
-
-
Method Summary
-
-
Method Detail
-
accruedOnAccountId
final Transaction.Source.InterestPayment.Builder accruedOnAccountId(String accruedOnAccountId)
The account on which the interest was accrued.
-
accruedOnAccountId
final Transaction.Source.InterestPayment.Builder accruedOnAccountId(JsonField<String> accruedOnAccountId)
Sets Builder.accruedOnAccountId to an arbitrary JSON value.
You should usually call Builder.accruedOnAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.InterestPayment.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.InterestPayment.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.InterestPayment.Builder currency(Transaction.Source.InterestPayment.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.InterestPayment.Builder currency(JsonField<Transaction.Source.InterestPayment.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodEnd
final Transaction.Source.InterestPayment.Builder periodEnd(OffsetDateTime periodEnd)
The end of the period for which this transaction paid interest.
-
periodEnd
final Transaction.Source.InterestPayment.Builder periodEnd(JsonField<OffsetDateTime> periodEnd)
Sets Builder.periodEnd to an arbitrary JSON value.
You should usually call Builder.periodEnd with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
periodStart
final Transaction.Source.InterestPayment.Builder periodStart(OffsetDateTime periodStart)
The start of the period for which this transaction paid interest.
-
periodStart
final Transaction.Source.InterestPayment.Builder periodStart(JsonField<OffsetDateTime> periodStart)
Sets Builder.periodStart to an arbitrary JSON value.
You should usually call Builder.periodStart with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InterestPayment.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InterestPayment.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InterestPayment.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InterestPayment.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InterestPayment.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InterestPayment build()
Returns an immutable instance of InterestPayment.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accruedOnAccountId() .amount() .currency() .periodEnd() .periodStart()
-
-
-
-