Class Transaction.Source.InternalSource.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InternalSource.BuilderA builder for InternalSource.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.InternalSource.Builder amount(Long amount)
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
amount
final Transaction.Source.InternalSource.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final Transaction.Source.InternalSource.Builder currency(Transaction.Source.InternalSource.Currency currency)
The ISO 4217 code for the transaction currency.
-
currency
final Transaction.Source.InternalSource.Builder currency(JsonField<Transaction.Source.InternalSource.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reason
final Transaction.Source.InternalSource.Builder reason(Transaction.Source.InternalSource.Reason reason)
An Internal Source is a transaction between you and Increase. This describes the reason for the transaction.
-
reason
final Transaction.Source.InternalSource.Builder reason(JsonField<Transaction.Source.InternalSource.Reason> reason)
Sets Builder.reason to an arbitrary JSON value.
You should usually call Builder.reason with a well-typed Reason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InternalSource.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InternalSource.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InternalSource.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InternalSource.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InternalSource.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InternalSource build()
Returns an immutable instance of InternalSource.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .currency() .reason()
-
-
-
-