Enum Transaction.Source.InternalSource.Reason.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum Transaction.Source.InternalSource.Reason.Known extends Enum<Transaction.Source.InternalSource.Reason.Known>
An enum containing Reason's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<Transaction.Source.InternalSource.Reason.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description ACCOUNT_CLOSUREAccount closure
ACCOUNT_REVENUE_PAYMENT_DISTRIBUTIONAccount revenue payment distribution
BANK_DRAWN_CHECKBank-drawn check
BANK_DRAWN_CHECK_CREDITBank-drawn check credit
BANK_MIGRATIONBank migration
CHECK_ADJUSTMENTCheck adjustment
COLLECTION_PAYMENTCollection payment
COLLECTION_RECEIVABLECollection receivable
DISHONORED_ACH_RETURNDishonored ACH return
EMPYREAL_ADJUSTMENTEmpyreal adjustment
ERRORError
ERROR_CORRECTIONError correction
FEESFees
GENERAL_LEDGER_TRANSFERGeneral ledger transfer
INTERESTInterest
NEGATIVE_BALANCE_FORGIVENESSNegative balance forgiveness
SAMPLE_FUNDSSample funds
SAMPLE_FUNDS_RETURNSample funds return
-
Method Summary
Modifier and Type Method Description final Transaction.Source.InternalSource.Reason.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<Transaction.Source.InternalSource.Reason.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<Transaction.Source.InternalSource.Reason.Known>getEntries()An enum containing Reason's known values. -
-
Method Detail
-
valueOf
final Transaction.Source.InternalSource.Reason.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<Transaction.Source.InternalSource.Reason.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<Transaction.Source.InternalSource.Reason.Known> getEntries()
An enum containing Reason's known values.
-
-
-
-