Class Transaction.Source.Other
-
- All Implemented Interfaces:
public final class Transaction.Source.OtherIf the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.Other.BuilderA builder for Other.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final Transaction.Source.Other.BuildertoBuilder()final Transaction.Source.Othervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.Other.Builderbuilder()Returns a mutable builder for constructing an instance of Other. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.Other.Builder toBuilder()
-
validate
final Transaction.Source.Other validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.Other.Builder builder()
Returns a mutable builder for constructing an instance of Other.
-
-
-
-