Class Transaction.Source.OutboundCardPushTransferAcceptance

  • All Implemented Interfaces:

    
    public final class Transaction.Source.OutboundCardPushTransferAcceptance
    
                        

    An Outbound Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if category is equal to outbound_card_push_transfer_acceptance. An Outbound Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.