Class Transaction.Source.RealTimePaymentsTransferAcknowledgement
-
- All Implemented Interfaces:
public final class Transaction.Source.RealTimePaymentsTransferAcknowledgementA Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.RealTimePaymentsTransferAcknowledgement.BuilderA builder for RealTimePaymentsTransferAcknowledgement.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The destination account number. final Longamount()The transfer amount in USD cents. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final StringtransferId()The identifier of the Real-Time Payments Transfer that led to this Transaction. final StringunstructuredRemittanceInformation()Unstructured information that will show on the recipient's bank statement. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.RealTimePaymentsTransferAcknowledgement.BuildertoBuilder()final Transaction.Source.RealTimePaymentsTransferAcknowledgementvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builderbuilder()Returns a mutable builder for constructing an instance of RealTimePaymentsTransferAcknowledgement. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
transferId
final String transferId()
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder toBuilder()
-
validate
final Transaction.Source.RealTimePaymentsTransferAcknowledgement validate()
-
builder
final static Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder builder()
Returns a mutable builder for constructing an instance of RealTimePaymentsTransferAcknowledgement.
The following fields are required:
.accountNumber() .amount() .routingNumber() .transferId() .unstructuredRemittanceInformation()
-
-
-
-