Class Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.RealTimePaymentsTransferAcknowledgement.BuilderA builder for RealTimePaymentsTransferAcknowledgement.
-
-
Method Summary
-
-
Method Detail
-
accountNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder transferId(String transferId)
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
transferId
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
Unstructured information that will show on the recipient's bank statement.
-
unstructuredRemittanceInformation
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.RealTimePaymentsTransferAcknowledgement build()
Returns an immutable instance of RealTimePaymentsTransferAcknowledgement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumber() .amount() .routingNumber() .transferId() .unstructuredRemittanceInformation()
-
-
-
-