Class Transaction.Source.SwiftTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.SwiftTransferIntentionA Swift Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_intention. A Swift Transfer initiated via Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.SwiftTransferIntention.BuilderA builder for SwiftTransferIntention.
-
Method Summary
Modifier and Type Method Description final StringtransferId()The identifier of the Swift Transfer that led to this Transaction. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.SwiftTransferIntention.BuildertoBuilder()final Transaction.Source.SwiftTransferIntentionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.SwiftTransferIntention.Builderbuilder()Returns a mutable builder for constructing an instance of SwiftTransferIntention. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the Swift Transfer that led to this Transaction.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.SwiftTransferIntention.Builder toBuilder()
-
validate
final Transaction.Source.SwiftTransferIntention validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.SwiftTransferIntention.Builder builder()
Returns a mutable builder for constructing an instance of SwiftTransferIntention.
The following fields are required:
.transferId()
-
-
-
-