Class Transaction.Source.WireTransferIntention

  • All Implemented Interfaces:

    
    public final class Transaction.Source.WireTransferIntention
    
                        

    A Wire Transfer Intention object. This field will be present in the JSON response if and only if category is equal to wire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.