Class TransactionListPageResponse.Builder
-
- All Implemented Interfaces:
public final class TransactionListPageResponse.BuilderA builder for TransactionListPageResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final TransactionListPageResponse.Builder data(List<Transaction> data)
The contents of the list.
-
data
final TransactionListPageResponse.Builder data(JsonField<List<Transaction>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<Transaction>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final TransactionListPageResponse.Builder addData(Transaction data)
Adds a single Transaction to Builder.data.
-
nextCursor
final TransactionListPageResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
nextCursor
final TransactionListPageResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final TransactionListPageResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final TransactionListPageResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TransactionListPageResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TransactionListPageResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TransactionListPageResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TransactionListPageResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TransactionListPageResponse build()
Returns an immutable instance of TransactionListPageResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-