Class TransactionListParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class TransactionListParams implements Params
List Transactions
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionListParams.BuilderA builder for TransactionListParams.
public final classTransactionListParams.Categorypublic final classTransactionListParams.CreatedAt
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter Transactions for those belonging to the specified Account. final Optional<TransactionListParams.Category>category()final Optional<TransactionListParams.CreatedAt>createdAt()final Optional<String>cursor()Return the page of entries after this one. final Optional<Long>limit()Limit the size of the list that is returned. final Optional<String>routeId()Filter Transactions for those belonging to the specified route. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final TransactionListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static TransactionListParamsnone()final static TransactionListParams.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionListParams. -
-
Method Detail
-
accountId
final Optional<String> accountId()
Filter Transactions for those belonging to the specified Account.
-
category
final Optional<TransactionListParams.Category> category()
-
createdAt
final Optional<TransactionListParams.CreatedAt> createdAt()
-
limit
final Optional<Long> limit()
Limit the size of the list that is returned. The default (and maximum) is 100 objects.
-
routeId
final Optional<String> routeId()
Filter Transactions for those belonging to the specified route. This could be a Card ID or an Account Number ID.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final TransactionListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static TransactionListParams none()
-
builder
final static TransactionListParams.Builder builder()
Returns a mutable builder for constructing an instance of TransactionListParams.
-
-
-
-