Class WireDrawdownRequest
-
- All Implemented Interfaces:
public final class WireDrawdownRequestWire drawdown requests enable you to request that someone else send you a wire. Because there is nuance to making sure your counterparty's bank processes these correctly, we ask that you reach out to [email protected] to enable this feature so we can help you plan your integration. For more information, see our /documentation/wire-drawdown-requests.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequest.BuilderA builder for WireDrawdownRequest.
public final classWireDrawdownRequest.CreditorAddressThe creditor's address.
public final classWireDrawdownRequest.DebtorAddressThe debtor's address.
public final classWireDrawdownRequest.StatusThe lifecycle status of the drawdown request.
public final classWireDrawdownRequest.SubmissionAfter the drawdown request is submitted to Fedwire, this will contain supplemental details.
public final classWireDrawdownRequest.TypeA constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Wire drawdown request identifier. final StringaccountNumberId()The Account Number to which the debtor—the recipient of this request—is being requested to send funds. final Longamount()The amount being requested in cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the wire drawdown request was created. final WireDrawdownRequest.CreditorAddresscreditorAddress()The creditor's address. final StringcreditorName()The creditor's name. final Stringcurrency()The ISO 4217 code for the amount being requested. final StringdebtorAccountNumber()The debtor's account number. final WireDrawdownRequest.DebtorAddressdebtorAddress()The debtor's address. final Optional<String>debtorExternalAccountId()The debtor's external account identifier. final StringdebtorName()The debtor's name. final StringdebtorRoutingNumber()The debtor's routing number. final Optional<String>endToEndIdentification()A free-form reference string set by the sender, to be mirrored back in the subsequent wire transfer. final Optional<String>fulfillmentInboundWireTransferId()If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final WireDrawdownRequest.Statusstatus()The lifecycle status of the drawdown request. final Optional<WireDrawdownRequest.Submission>submission()After the drawdown request is submitted to Fedwire, this will contain supplemental details. final WireDrawdownRequest.Typetype()A constant representing the object's type. final Optional<String>uniqueEndToEndTransactionReference()The unique end-to-end transaction reference (UETR) of the drawdown request. final StringunstructuredRemittanceInformation()Remittance information the debtor will see as part of the drawdown request. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<WireDrawdownRequest.CreditorAddress>_creditorAddress()Returns the raw JSON value of creditorAddress. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_debtorAccountNumber()Returns the raw JSON value of debtorAccountNumber. final JsonField<WireDrawdownRequest.DebtorAddress>_debtorAddress()Returns the raw JSON value of debtorAddress. final JsonField<String>_debtorExternalAccountId()Returns the raw JSON value of debtorExternalAccountId. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final JsonField<String>_fulfillmentInboundWireTransferId()Returns the raw JSON value of fulfillmentInboundWireTransferId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<WireDrawdownRequest.Status>_status()Returns the raw JSON value of status. final JsonField<WireDrawdownRequest.Submission>_submission()Returns the raw JSON value of submission. final JsonField<WireDrawdownRequest.Type>_type()Returns the raw JSON value of type. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final WireDrawdownRequest.BuildertoBuilder()final WireDrawdownRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequest.Builderbuilder()Returns a mutable builder for constructing an instance of WireDrawdownRequest. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to which the debtor—the recipient of this request—is being requested to send funds.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the wire drawdown request was created.
-
creditorAddress
final WireDrawdownRequest.CreditorAddress creditorAddress()
The creditor's address.
-
creditorName
final String creditorName()
The creditor's name.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
debtorAccountNumber
final String debtorAccountNumber()
The debtor's account number.
-
debtorAddress
final WireDrawdownRequest.DebtorAddress debtorAddress()
The debtor's address.
-
debtorExternalAccountId
final Optional<String> debtorExternalAccountId()
The debtor's external account identifier.
-
debtorName
final String debtorName()
The debtor's name.
-
debtorRoutingNumber
final String debtorRoutingNumber()
The debtor's routing number.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender, to be mirrored back in the subsequent wire transfer.
-
fulfillmentInboundWireTransferId
final Optional<String> fulfillmentInboundWireTransferId()
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final WireDrawdownRequest.Status status()
The lifecycle status of the drawdown request.
-
submission
final Optional<WireDrawdownRequest.Submission> submission()
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
type
final WireDrawdownRequest.Type type()
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
uniqueEndToEndTransactionReference
final Optional<String> uniqueEndToEndTransactionReference()
The unique end-to-end transaction reference (UETR) of the drawdown request.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Remittance information the debtor will see as part of the drawdown request.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddress
final JsonField<WireDrawdownRequest.CreditorAddress> _creditorAddress()
Returns the raw JSON value of creditorAddress.
Unlike creditorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
Returns the raw JSON value of debtorAccountNumber.
Unlike debtorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddress
final JsonField<WireDrawdownRequest.DebtorAddress> _debtorAddress()
Returns the raw JSON value of debtorAddress.
Unlike debtorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorExternalAccountId
final JsonField<String> _debtorExternalAccountId()
Returns the raw JSON value of debtorExternalAccountId.
Unlike debtorExternalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_fulfillmentInboundWireTransferId
final JsonField<String> _fulfillmentInboundWireTransferId()
Returns the raw JSON value of fulfillmentInboundWireTransferId.
Unlike fulfillmentInboundWireTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<WireDrawdownRequest.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<WireDrawdownRequest.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WireDrawdownRequest.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireDrawdownRequest.Builder toBuilder()
-
validate
final WireDrawdownRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WireDrawdownRequest.Builder builder()
Returns a mutable builder for constructing an instance of WireDrawdownRequest.
The following fields are required:
.id() .accountNumberId() .amount() .createdAt() .creditorAddress() .creditorName() .currency() .debtorAccountNumber() .debtorAddress() .debtorExternalAccountId() .debtorName() .debtorRoutingNumber() .endToEndIdentification() .fulfillmentInboundWireTransferId() .idempotencyKey() .status() .submission() .type() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation()
-
-
-
-