Class WireDrawdownRequest.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequest.BuilderA builder for WireDrawdownRequest.
-
-
Method Summary
-
-
Method Detail
-
id
final WireDrawdownRequest.Builder id(String id)
The Wire drawdown request identifier.
-
id
final WireDrawdownRequest.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumberId
final WireDrawdownRequest.Builder accountNumberId(String accountNumberId)
The Account Number to which the debtor—the recipient of this request—is being requested to send funds.
-
accountNumberId
final WireDrawdownRequest.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireDrawdownRequest.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final WireDrawdownRequest.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final WireDrawdownRequest.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the wire drawdown request was created.
-
createdAt
final WireDrawdownRequest.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddress
final WireDrawdownRequest.Builder creditorAddress(WireDrawdownRequest.CreditorAddress creditorAddress)
The creditor's address.
-
creditorAddress
final WireDrawdownRequest.Builder creditorAddress(JsonField<WireDrawdownRequest.CreditorAddress> creditorAddress)
Sets Builder.creditorAddress to an arbitrary JSON value.
You should usually call Builder.creditorAddress with a well-typed CreditorAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final WireDrawdownRequest.Builder creditorName(String creditorName)
The creditor's name.
-
creditorName
final WireDrawdownRequest.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final WireDrawdownRequest.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final WireDrawdownRequest.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAccountNumber
final WireDrawdownRequest.Builder debtorAccountNumber(String debtorAccountNumber)
The debtor's account number.
-
debtorAccountNumber
final WireDrawdownRequest.Builder debtorAccountNumber(JsonField<String> debtorAccountNumber)
Sets Builder.debtorAccountNumber to an arbitrary JSON value.
You should usually call Builder.debtorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddress
final WireDrawdownRequest.Builder debtorAddress(WireDrawdownRequest.DebtorAddress debtorAddress)
The debtor's address.
-
debtorAddress
final WireDrawdownRequest.Builder debtorAddress(JsonField<WireDrawdownRequest.DebtorAddress> debtorAddress)
Sets Builder.debtorAddress to an arbitrary JSON value.
You should usually call Builder.debtorAddress with a well-typed DebtorAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorExternalAccountId
final WireDrawdownRequest.Builder debtorExternalAccountId(String debtorExternalAccountId)
The debtor's external account identifier.
-
debtorExternalAccountId
final WireDrawdownRequest.Builder debtorExternalAccountId(Optional<String> debtorExternalAccountId)
Alias for calling Builder.debtorExternalAccountId with
debtorExternalAccountId.orElse(null).
-
debtorExternalAccountId
final WireDrawdownRequest.Builder debtorExternalAccountId(JsonField<String> debtorExternalAccountId)
Sets Builder.debtorExternalAccountId to an arbitrary JSON value.
You should usually call Builder.debtorExternalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final WireDrawdownRequest.Builder debtorName(String debtorName)
The debtor's name.
-
debtorName
final WireDrawdownRequest.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorRoutingNumber
final WireDrawdownRequest.Builder debtorRoutingNumber(String debtorRoutingNumber)
The debtor's routing number.
-
debtorRoutingNumber
final WireDrawdownRequest.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
Sets Builder.debtorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.debtorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fulfillmentInboundWireTransferId
final WireDrawdownRequest.Builder fulfillmentInboundWireTransferId(String fulfillmentInboundWireTransferId)
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
fulfillmentInboundWireTransferId
final WireDrawdownRequest.Builder fulfillmentInboundWireTransferId(Optional<String> fulfillmentInboundWireTransferId)
Alias for calling Builder.fulfillmentInboundWireTransferId with
fulfillmentInboundWireTransferId.orElse(null).
-
fulfillmentInboundWireTransferId
final WireDrawdownRequest.Builder fulfillmentInboundWireTransferId(JsonField<String> fulfillmentInboundWireTransferId)
Sets Builder.fulfillmentInboundWireTransferId to an arbitrary JSON value.
You should usually call Builder.fulfillmentInboundWireTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final WireDrawdownRequest.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final WireDrawdownRequest.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final WireDrawdownRequest.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final WireDrawdownRequest.Builder status(WireDrawdownRequest.Status status)
The lifecycle status of the drawdown request.
-
status
final WireDrawdownRequest.Builder status(JsonField<WireDrawdownRequest.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submission
final WireDrawdownRequest.Builder submission(WireDrawdownRequest.Submission submission)
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
submission
final WireDrawdownRequest.Builder submission(Optional<WireDrawdownRequest.Submission> submission)
Alias for calling Builder.submission with
submission.orElse(null).
-
submission
final WireDrawdownRequest.Builder submission(JsonField<WireDrawdownRequest.Submission> submission)
Sets Builder.submission to an arbitrary JSON value.
You should usually call Builder.submission with a well-typed Submission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final WireDrawdownRequest.Builder type(WireDrawdownRequest.Type type)
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
type
final WireDrawdownRequest.Builder type(JsonField<WireDrawdownRequest.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final WireDrawdownRequest.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
Remittance information the debtor will see as part of the drawdown request.
-
unstructuredRemittanceInformation
final WireDrawdownRequest.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequest build()
Returns an immutable instance of WireDrawdownRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountNumberId() .amount() .createdAt() .creditorAddress() .creditorName() .currency() .debtorAccountNumber() .debtorAddress() .debtorExternalAccountId() .debtorName() .debtorRoutingNumber() .fulfillmentInboundWireTransferId() .idempotencyKey() .status() .submission() .type() .unstructuredRemittanceInformation()
-
-
-
-