Class WireDrawdownRequest.DebtorAddress.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequest.DebtorAddress.BuilderA builder for DebtorAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final WireDrawdownRequest.DebtorAddress.Builder city(String city)
The city, district, town, or village of the address.
-
city
final WireDrawdownRequest.DebtorAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final WireDrawdownRequest.DebtorAddress.Builder country(String country)
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
country
final WireDrawdownRequest.DebtorAddress.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final WireDrawdownRequest.DebtorAddress.Builder line1(String line1)
The first line of the address.
-
line1
final WireDrawdownRequest.DebtorAddress.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final WireDrawdownRequest.DebtorAddress.Builder line2(String line2)
The second line of the address.
-
line2
final WireDrawdownRequest.DebtorAddress.Builder line2(Optional<String> line2)
Alias for calling Builder.line2 with
line2.orElse(null).
-
line2
final WireDrawdownRequest.DebtorAddress.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final WireDrawdownRequest.DebtorAddress.Builder postalCode(String postalCode)
The ZIP code of the address.
-
postalCode
final WireDrawdownRequest.DebtorAddress.Builder postalCode(Optional<String> postalCode)
Alias for calling Builder.postalCode with
postalCode.orElse(null).
-
postalCode
final WireDrawdownRequest.DebtorAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final WireDrawdownRequest.DebtorAddress.Builder state(String state)
The address state.
-
state
final WireDrawdownRequest.DebtorAddress.Builder state(Optional<String> state)
Alias for calling Builder.state with
state.orElse(null).
-
state
final WireDrawdownRequest.DebtorAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequest.DebtorAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequest.DebtorAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequest.DebtorAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequest.DebtorAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequest.DebtorAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequest.DebtorAddress build()
Returns an immutable instance of DebtorAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .country() .line1() .line2() .postalCode() .state()
-
-
-
-