Enum WireDrawdownRequest.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum WireDrawdownRequest.Status.Known extends Enum<WireDrawdownRequest.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<WireDrawdownRequest.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_SUBMISSIONThe drawdown request is queued to be submitted to Fedwire.
FULFILLEDThe drawdown request has been fulfilled by the recipient.
PENDING_RESPONSEThe drawdown request has been sent and the recipient should respond in some way.
REFUSEDThe drawdown request has been refused by the recipient.
-
Method Summary
Modifier and Type Method Description final WireDrawdownRequest.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<WireDrawdownRequest.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<WireDrawdownRequest.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final WireDrawdownRequest.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<WireDrawdownRequest.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<WireDrawdownRequest.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-