Class WireDrawdownRequestCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class WireDrawdownRequestCreateParams implements Params
Create a Wire Drawdown Request
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestCreateParams.BuilderA builder for WireDrawdownRequestCreateParams.
public final classWireDrawdownRequestCreateParams.Bodypublic final classWireDrawdownRequestCreateParams.CreditorAddressThe creditor's address.
public final classWireDrawdownRequestCreateParams.DebtorAddressThe debtor's address.
public final classWireDrawdownRequestCreateParams.ChargeBearerDetermines who bears the cost of the drawdown request. Defaults to
sharedif not specified.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number to which the debtor should send funds. final Longamount()The amount requested from the debtor, in USD cents. final WireDrawdownRequestCreateParams.CreditorAddresscreditorAddress()The creditor's address. final StringcreditorName()The creditor's name. final WireDrawdownRequestCreateParams.DebtorAddressdebtorAddress()The debtor's address. final StringdebtorName()The debtor's name. final StringunstructuredRemittanceInformation()Remittance information the debtor will see as part of the request. final Optional<WireDrawdownRequestCreateParams.ChargeBearer>chargeBearer()Determines who bears the cost of the drawdown request. final Optional<String>debtorAccountNumber()The debtor's account number. final Optional<String>debtorExternalAccountId()The ID of an External Account to initiate a transfer to. final Optional<String>debtorRoutingNumber()The debtor's routing number. final Optional<String>endToEndIdentification()A free-form reference string set by the sender mirrored back in the subsequent wire transfer. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<WireDrawdownRequestCreateParams.CreditorAddress>_creditorAddress()Returns the raw JSON value of creditorAddress. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<WireDrawdownRequestCreateParams.DebtorAddress>_debtorAddress()Returns the raw JSON value of debtorAddress. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final JsonField<WireDrawdownRequestCreateParams.ChargeBearer>_chargeBearer()Returns the raw JSON value of chargeBearer. final JsonField<String>_debtorAccountNumber()Returns the raw JSON value of debtorAccountNumber. final JsonField<String>_debtorExternalAccountId()Returns the raw JSON value of debtorExternalAccountId. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final WireDrawdownRequestCreateParams.BuildertoBuilder()final WireDrawdownRequestCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of WireDrawdownRequestCreateParams. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to which the debtor should send funds.
-
creditorAddress
final WireDrawdownRequestCreateParams.CreditorAddress creditorAddress()
The creditor's address.
-
creditorName
final String creditorName()
The creditor's name.
-
debtorAddress
final WireDrawdownRequestCreateParams.DebtorAddress debtorAddress()
The debtor's address.
-
debtorName
final String debtorName()
The debtor's name.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Remittance information the debtor will see as part of the request.
-
chargeBearer
final Optional<WireDrawdownRequestCreateParams.ChargeBearer> chargeBearer()
Determines who bears the cost of the drawdown request. Defaults to
sharedif not specified.
-
debtorAccountNumber
final Optional<String> debtorAccountNumber()
The debtor's account number.
-
debtorExternalAccountId
final Optional<String> debtorExternalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
debtor_account_numberanddebtor_routing_numbermust be absent.
-
debtorRoutingNumber
final Optional<String> debtorRoutingNumber()
The debtor's routing number.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender mirrored back in the subsequent wire transfer.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddress
final JsonField<WireDrawdownRequestCreateParams.CreditorAddress> _creditorAddress()
Returns the raw JSON value of creditorAddress.
Unlike creditorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddress
final JsonField<WireDrawdownRequestCreateParams.DebtorAddress> _debtorAddress()
Returns the raw JSON value of debtorAddress.
Unlike debtorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_chargeBearer
final JsonField<WireDrawdownRequestCreateParams.ChargeBearer> _chargeBearer()
Returns the raw JSON value of chargeBearer.
Unlike chargeBearer, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
Returns the raw JSON value of debtorAccountNumber.
Unlike debtorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorExternalAccountId
final JsonField<String> _debtorExternalAccountId()
Returns the raw JSON value of debtorExternalAccountId.
Unlike debtorExternalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final WireDrawdownRequestCreateParams.Builder toBuilder()
-
_body
final WireDrawdownRequestCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static WireDrawdownRequestCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of WireDrawdownRequestCreateParams.
The following fields are required:
.accountNumberId() .amount() .creditorAddress() .creditorName() .debtorAddress() .debtorName() .unstructuredRemittanceInformation()
-
-
-
-