Class WireDrawdownRequestCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final WireDrawdownRequestCreateParams.Body.Builder accountNumberId(String accountNumberId)
The Account Number to which the debtor should send funds.
-
accountNumberId
final WireDrawdownRequestCreateParams.Body.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireDrawdownRequestCreateParams.Body.Builder amount(Long amount)
The amount requested from the debtor, in USD cents.
-
amount
final WireDrawdownRequestCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddress
final WireDrawdownRequestCreateParams.Body.Builder creditorAddress(WireDrawdownRequestCreateParams.CreditorAddress creditorAddress)
The creditor's address.
-
creditorAddress
final WireDrawdownRequestCreateParams.Body.Builder creditorAddress(JsonField<WireDrawdownRequestCreateParams.CreditorAddress> creditorAddress)
Sets Builder.creditorAddress to an arbitrary JSON value.
You should usually call Builder.creditorAddress with a well-typed CreditorAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final WireDrawdownRequestCreateParams.Body.Builder creditorName(String creditorName)
The creditor's name.
-
creditorName
final WireDrawdownRequestCreateParams.Body.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddress
final WireDrawdownRequestCreateParams.Body.Builder debtorAddress(WireDrawdownRequestCreateParams.DebtorAddress debtorAddress)
The debtor's address.
-
debtorAddress
final WireDrawdownRequestCreateParams.Body.Builder debtorAddress(JsonField<WireDrawdownRequestCreateParams.DebtorAddress> debtorAddress)
Sets Builder.debtorAddress to an arbitrary JSON value.
You should usually call Builder.debtorAddress with a well-typed DebtorAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final WireDrawdownRequestCreateParams.Body.Builder debtorName(String debtorName)
The debtor's name.
-
debtorName
final WireDrawdownRequestCreateParams.Body.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final WireDrawdownRequestCreateParams.Body.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
Remittance information the debtor will see as part of the request.
-
unstructuredRemittanceInformation
final WireDrawdownRequestCreateParams.Body.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chargeBearer
final WireDrawdownRequestCreateParams.Body.Builder chargeBearer(WireDrawdownRequestCreateParams.ChargeBearer chargeBearer)
Determines who bears the cost of the drawdown request. Defaults to
sharedif not specified.
-
chargeBearer
final WireDrawdownRequestCreateParams.Body.Builder chargeBearer(JsonField<WireDrawdownRequestCreateParams.ChargeBearer> chargeBearer)
Sets Builder.chargeBearer to an arbitrary JSON value.
You should usually call Builder.chargeBearer with a well-typed ChargeBearer value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAccountNumber
final WireDrawdownRequestCreateParams.Body.Builder debtorAccountNumber(String debtorAccountNumber)
The debtor's account number.
-
debtorAccountNumber
final WireDrawdownRequestCreateParams.Body.Builder debtorAccountNumber(JsonField<String> debtorAccountNumber)
Sets Builder.debtorAccountNumber to an arbitrary JSON value.
You should usually call Builder.debtorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorExternalAccountId
final WireDrawdownRequestCreateParams.Body.Builder debtorExternalAccountId(String debtorExternalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
debtor_account_numberanddebtor_routing_numbermust be absent.
-
debtorExternalAccountId
final WireDrawdownRequestCreateParams.Body.Builder debtorExternalAccountId(JsonField<String> debtorExternalAccountId)
Sets Builder.debtorExternalAccountId to an arbitrary JSON value.
You should usually call Builder.debtorExternalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorRoutingNumber
final WireDrawdownRequestCreateParams.Body.Builder debtorRoutingNumber(String debtorRoutingNumber)
The debtor's routing number.
-
debtorRoutingNumber
final WireDrawdownRequestCreateParams.Body.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
Sets Builder.debtorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.debtorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final WireDrawdownRequestCreateParams.Body.Builder endToEndIdentification(String endToEndIdentification)
A free-form reference string set by the sender mirrored back in the subsequent wire transfer.
-
endToEndIdentification
final WireDrawdownRequestCreateParams.Body.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequestCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequestCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequestCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequestCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequestCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequestCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .amount() .creditorAddress() .creditorName() .debtorAddress() .debtorName() .unstructuredRemittanceInformation()
-
-
-
-