Class WireDrawdownRequestCreateParams.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.BuilderA builder for WireDrawdownRequestCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final WireDrawdownRequestCreateParams.Builder body(WireDrawdownRequestCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
accountNumberId
final WireDrawdownRequestCreateParams.Builder accountNumberId(String accountNumberId)
The Account Number to which the debtor should send funds.
-
accountNumberId
final WireDrawdownRequestCreateParams.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireDrawdownRequestCreateParams.Builder amount(Long amount)
The amount requested from the debtor, in USD cents.
-
amount
final WireDrawdownRequestCreateParams.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorAddress
final WireDrawdownRequestCreateParams.Builder creditorAddress(WireDrawdownRequestCreateParams.CreditorAddress creditorAddress)
The creditor's address.
-
creditorAddress
final WireDrawdownRequestCreateParams.Builder creditorAddress(JsonField<WireDrawdownRequestCreateParams.CreditorAddress> creditorAddress)
Sets Builder.creditorAddress to an arbitrary JSON value.
You should usually call Builder.creditorAddress with a well-typed CreditorAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditorName
final WireDrawdownRequestCreateParams.Builder creditorName(String creditorName)
The creditor's name.
-
creditorName
final WireDrawdownRequestCreateParams.Builder creditorName(JsonField<String> creditorName)
Sets Builder.creditorName to an arbitrary JSON value.
You should usually call Builder.creditorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAddress
final WireDrawdownRequestCreateParams.Builder debtorAddress(WireDrawdownRequestCreateParams.DebtorAddress debtorAddress)
The debtor's address.
-
debtorAddress
final WireDrawdownRequestCreateParams.Builder debtorAddress(JsonField<WireDrawdownRequestCreateParams.DebtorAddress> debtorAddress)
Sets Builder.debtorAddress to an arbitrary JSON value.
You should usually call Builder.debtorAddress with a well-typed DebtorAddress value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorName
final WireDrawdownRequestCreateParams.Builder debtorName(String debtorName)
The debtor's name.
-
debtorName
final WireDrawdownRequestCreateParams.Builder debtorName(JsonField<String> debtorName)
Sets Builder.debtorName to an arbitrary JSON value.
You should usually call Builder.debtorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unstructuredRemittanceInformation
final WireDrawdownRequestCreateParams.Builder unstructuredRemittanceInformation(String unstructuredRemittanceInformation)
Remittance information the debtor will see as part of the request.
-
unstructuredRemittanceInformation
final WireDrawdownRequestCreateParams.Builder unstructuredRemittanceInformation(JsonField<String> unstructuredRemittanceInformation)
Sets Builder.unstructuredRemittanceInformation to an arbitrary JSON value.
You should usually call Builder.unstructuredRemittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
chargeBearer
final WireDrawdownRequestCreateParams.Builder chargeBearer(WireDrawdownRequestCreateParams.ChargeBearer chargeBearer)
Determines who bears the cost of the drawdown request. Defaults to
sharedif not specified.
-
chargeBearer
final WireDrawdownRequestCreateParams.Builder chargeBearer(JsonField<WireDrawdownRequestCreateParams.ChargeBearer> chargeBearer)
Sets Builder.chargeBearer to an arbitrary JSON value.
You should usually call Builder.chargeBearer with a well-typed ChargeBearer value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorAccountNumber
final WireDrawdownRequestCreateParams.Builder debtorAccountNumber(String debtorAccountNumber)
The debtor's account number.
-
debtorAccountNumber
final WireDrawdownRequestCreateParams.Builder debtorAccountNumber(JsonField<String> debtorAccountNumber)
Sets Builder.debtorAccountNumber to an arbitrary JSON value.
You should usually call Builder.debtorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorExternalAccountId
final WireDrawdownRequestCreateParams.Builder debtorExternalAccountId(String debtorExternalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
debtor_account_numberanddebtor_routing_numbermust be absent.
-
debtorExternalAccountId
final WireDrawdownRequestCreateParams.Builder debtorExternalAccountId(JsonField<String> debtorExternalAccountId)
Sets Builder.debtorExternalAccountId to an arbitrary JSON value.
You should usually call Builder.debtorExternalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtorRoutingNumber
final WireDrawdownRequestCreateParams.Builder debtorRoutingNumber(String debtorRoutingNumber)
The debtor's routing number.
-
debtorRoutingNumber
final WireDrawdownRequestCreateParams.Builder debtorRoutingNumber(JsonField<String> debtorRoutingNumber)
Sets Builder.debtorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.debtorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endToEndIdentification
final WireDrawdownRequestCreateParams.Builder endToEndIdentification(String endToEndIdentification)
A free-form reference string set by the sender mirrored back in the subsequent wire transfer.
-
endToEndIdentification
final WireDrawdownRequestCreateParams.Builder endToEndIdentification(JsonField<String> endToEndIdentification)
Sets Builder.endToEndIdentification to an arbitrary JSON value.
You should usually call Builder.endToEndIdentification with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final WireDrawdownRequestCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final WireDrawdownRequestCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final WireDrawdownRequestCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final WireDrawdownRequestCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final WireDrawdownRequestCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final WireDrawdownRequestCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final WireDrawdownRequestCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final WireDrawdownRequestCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final WireDrawdownRequestCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final WireDrawdownRequestCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final WireDrawdownRequestCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final WireDrawdownRequestCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final WireDrawdownRequestCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final WireDrawdownRequestCreateParams build()
Returns an immutable instance of WireDrawdownRequestCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .amount() .creditorAddress() .creditorName() .debtorAddress() .debtorName() .unstructuredRemittanceInformation()
-
-
-
-