Enum WireDrawdownRequestCreateParams.ChargeBearer.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum WireDrawdownRequestCreateParams.ChargeBearer.Value extends Enum<WireDrawdownRequestCreateParams.ChargeBearer.Value>
An enum containing ChargeBearer's known values, as well as an _UNKNOWN member.
An instance of ChargeBearer can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<WireDrawdownRequestCreateParams.ChargeBearer.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description SHAREDCharges are shared between the debtor and creditor.
DEBTORCharges are borne by the debtor.
CREDITORCharges are borne by the creditor.
SERVICE_LEVELCharges are determined by the service level.
_UNKNOWNAn enum member indicating that ChargeBearer was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final WireDrawdownRequestCreateParams.ChargeBearer.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<WireDrawdownRequestCreateParams.ChargeBearer.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<WireDrawdownRequestCreateParams.ChargeBearer.Value>getEntries()An enum containing ChargeBearer's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final WireDrawdownRequestCreateParams.ChargeBearer.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<WireDrawdownRequestCreateParams.ChargeBearer.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<WireDrawdownRequestCreateParams.ChargeBearer.Value> getEntries()
An enum containing ChargeBearer's known values, as well as an _UNKNOWN member.
An instance of ChargeBearer can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-