Class WireDrawdownRequestCreateParams.CreditorAddress.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.CreditorAddress.BuilderA builder for CreditorAddress.
-
-
Method Summary
-
-
Method Detail
-
city
final WireDrawdownRequestCreateParams.CreditorAddress.Builder city(String city)
The city, district, town, or village of the address.
-
city
final WireDrawdownRequestCreateParams.CreditorAddress.Builder city(JsonField<String> city)
Sets Builder.city to an arbitrary JSON value.
You should usually call Builder.city with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final WireDrawdownRequestCreateParams.CreditorAddress.Builder country(String country)
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
country
final WireDrawdownRequestCreateParams.CreditorAddress.Builder country(JsonField<String> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line1
final WireDrawdownRequestCreateParams.CreditorAddress.Builder line1(String line1)
The first line of the address. This is usually the street number and street.
-
line1
final WireDrawdownRequestCreateParams.CreditorAddress.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final WireDrawdownRequestCreateParams.CreditorAddress.Builder line2(String line2)
The second line of the address. This might be the floor or room number.
-
line2
final WireDrawdownRequestCreateParams.CreditorAddress.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
postalCode
final WireDrawdownRequestCreateParams.CreditorAddress.Builder postalCode(String postalCode)
The ZIP code of the address.
-
postalCode
final WireDrawdownRequestCreateParams.CreditorAddress.Builder postalCode(JsonField<String> postalCode)
Sets Builder.postalCode to an arbitrary JSON value.
You should usually call Builder.postalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
state
final WireDrawdownRequestCreateParams.CreditorAddress.Builder state(String state)
The address state.
-
state
final WireDrawdownRequestCreateParams.CreditorAddress.Builder state(JsonField<String> state)
Sets Builder.state to an arbitrary JSON value.
You should usually call Builder.state with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequestCreateParams.CreditorAddress.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequestCreateParams.CreditorAddress.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequestCreateParams.CreditorAddress.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequestCreateParams.CreditorAddress.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequestCreateParams.CreditorAddress.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequestCreateParams.CreditorAddress build()
Returns an immutable instance of CreditorAddress.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.city() .country() .line1()
-
-
-
-