Class WireDrawdownRequestListPage
-
- All Implemented Interfaces:
public final class WireDrawdownRequestListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestListPage.BuilderA builder for WireDrawdownRequestListPage.
public final classWireDrawdownRequestListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<WireDrawdownRequest>data()Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<WireDrawdownRequestListParams>getNextPageParams()final Optional<WireDrawdownRequestListPage>getNextPage()final WireDrawdownRequestListPage.AutoPagerautoPager()final WireDrawdownRequestListParamsparams()The parameters that were used to request this page. final WireDrawdownRequestListPageResponseresponse()The response that this page was parsed from. final WireDrawdownRequestListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestListPage.Builderbuilder()Returns a mutable builder for constructing an instance of WireDrawdownRequestListPage. -
-
Method Detail
-
data
final List<WireDrawdownRequest> data()
Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<WireDrawdownRequestListParams> getNextPageParams()
-
getNextPage
final Optional<WireDrawdownRequestListPage> getNextPage()
-
autoPager
final WireDrawdownRequestListPage.AutoPager autoPager()
-
params
final WireDrawdownRequestListParams params()
The parameters that were used to request this page.
-
response
final WireDrawdownRequestListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final WireDrawdownRequestListPage.Builder toBuilder()
-
builder
final static WireDrawdownRequestListPage.Builder builder()
Returns a mutable builder for constructing an instance of WireDrawdownRequestListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-