Class WireDrawdownRequestListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class WireDrawdownRequestListPageAsync implements PageAsync<WireDrawdownRequest>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestListPageAsync.BuilderA builder for WireDrawdownRequestListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<WireDrawdownRequest>data()Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data. List<WireDrawdownRequest>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final WireDrawdownRequestListParamsnextPageParams()CompletableFuture<WireDrawdownRequestListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<WireDrawdownRequest>autoPager()final WireDrawdownRequestListParamsparams()The parameters that were used to request this page. final WireDrawdownRequestListPageResponseresponse()The response that this page was parsed from. final WireDrawdownRequestListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of WireDrawdownRequestListPageAsync. -
-
Method Detail
-
data
final List<WireDrawdownRequest> data()
Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
items
List<WireDrawdownRequest> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final WireDrawdownRequestListParams nextPageParams()
-
nextPage
CompletableFuture<WireDrawdownRequestListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<WireDrawdownRequest> autoPager()
-
params
final WireDrawdownRequestListParams params()
The parameters that were used to request this page.
-
response
final WireDrawdownRequestListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final WireDrawdownRequestListPageAsync.Builder toBuilder()
-
builder
final static WireDrawdownRequestListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of WireDrawdownRequestListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-