Class WireDrawdownRequestListPageAsync.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequestListPageAsync.BuilderA builder for WireDrawdownRequestListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final WireDrawdownRequestListPageAsync.Builderservice(WireDrawdownRequestServiceAsync service)final WireDrawdownRequestListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final WireDrawdownRequestListPageAsync.Builderparams(WireDrawdownRequestListParams params)The parameters that were used to request this page. final WireDrawdownRequestListPageAsync.Builderresponse(WireDrawdownRequestListPageResponse response)The response that this page was parsed from. final WireDrawdownRequestListPageAsyncbuild()Returns an immutable instance of WireDrawdownRequestListPageAsync. -
-
Method Detail
-
service
final WireDrawdownRequestListPageAsync.Builder service(WireDrawdownRequestServiceAsync service)
-
streamHandlerExecutor
final WireDrawdownRequestListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final WireDrawdownRequestListPageAsync.Builder params(WireDrawdownRequestListParams params)
The parameters that were used to request this page.
-
response
final WireDrawdownRequestListPageAsync.Builder response(WireDrawdownRequestListPageResponse response)
The response that this page was parsed from.
-
build
final WireDrawdownRequestListPageAsync build()
Returns an immutable instance of WireDrawdownRequestListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-