Class WireDrawdownRequestListParams.Status.In
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class WireDrawdownRequestListParams.Status.In implements Enum
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumWireDrawdownRequestListParams.Status.In.KnownAn enum containing In's known values.
public enumWireDrawdownRequestListParams.Status.In.ValueAn enum containing In's known values, as well as an _UNKNOWN member.
An instance of In can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static WireDrawdownRequestListParams.Status.InPENDING_SUBMISSIONpublic final static WireDrawdownRequestListParams.Status.InPENDING_RESPONSEpublic final static WireDrawdownRequestListParams.Status.InFULFILLEDpublic final static WireDrawdownRequestListParams.Status.InREFUSED
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final WireDrawdownRequestListParams.Status.In.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final WireDrawdownRequestListParams.Status.In.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final WireDrawdownRequestListParams.Status.Invalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestListParams.Status.Inof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final WireDrawdownRequestListParams.Status.In.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final WireDrawdownRequestListParams.Status.In.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final WireDrawdownRequestListParams.Status.In validate()
-
of
final static WireDrawdownRequestListParams.Status.In of(String value)
-
-
-
-