Enum WireDrawdownRequestListParams.Status.In.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum WireDrawdownRequestListParams.Status.In.Known extends Enum<WireDrawdownRequestListParams.Status.In.Known>
An enum containing In's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<WireDrawdownRequestListParams.Status.In.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_SUBMISSIONThe drawdown request is queued to be submitted to Fedwire.
FULFILLEDThe drawdown request has been fulfilled by the recipient.
PENDING_RESPONSEThe drawdown request has been sent and the recipient should respond in some way.
REFUSEDThe drawdown request has been refused by the recipient.
-
Method Summary
Modifier and Type Method Description final WireDrawdownRequestListParams.Status.In.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<WireDrawdownRequestListParams.Status.In.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<WireDrawdownRequestListParams.Status.In.Known>getEntries()An enum containing In's known values. -
-
Method Detail
-
valueOf
final WireDrawdownRequestListParams.Status.In.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<WireDrawdownRequestListParams.Status.In.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<WireDrawdownRequestListParams.Status.In.Known> getEntries()
An enum containing In's known values.
-
-
-
-