Class WireDrawdownRequestListResponse.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequestListResponse.BuilderA builder for WireDrawdownRequestListResponse.
-
-
Method Summary
-
-
Method Detail
-
data
final WireDrawdownRequestListResponse.Builder data(List<WireDrawdownRequest> data)
The contents of the list.
-
data
final WireDrawdownRequestListResponse.Builder data(JsonField<List<WireDrawdownRequest>> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed
List<WireDrawdownRequest>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addData
final WireDrawdownRequestListResponse.Builder addData(WireDrawdownRequest data)
Adds a single WireDrawdownRequest to Builder.data.
-
nextCursor
final WireDrawdownRequestListResponse.Builder nextCursor(String nextCursor)
A pointer to a place in the list.
-
nextCursor
final WireDrawdownRequestListResponse.Builder nextCursor(Optional<String> nextCursor)
Alias for calling Builder.nextCursor with
nextCursor.orElse(null).
-
nextCursor
final WireDrawdownRequestListResponse.Builder nextCursor(JsonField<String> nextCursor)
Sets Builder.nextCursor to an arbitrary JSON value.
You should usually call Builder.nextCursor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequestListResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequestListResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequestListResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequestListResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequestListResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequestListResponse build()
Returns an immutable instance of WireDrawdownRequestListResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.data() .nextCursor()
-
-
-
-