Class WireTransfer.Builder
-
- All Implemented Interfaces:
public final class WireTransfer.BuilderA builder for WireTransfer.
-
-
Method Summary
Modifier and Type Method Description final WireTransfer.Builderid(String id)The wire transfer's identifier. final WireTransfer.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final WireTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final WireTransfer.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final WireTransfer.BuilderaccountNumber(String accountNumber)The destination account number. final WireTransfer.BuilderaccountNumber(JsonField<String> accountNumber)Sets Builder.accountNumber to an arbitrary JSON value. final WireTransfer.Builderamount(Long amount)The transfer amount in USD cents. final WireTransfer.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final WireTransfer.Builderapproval(WireTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final WireTransfer.Builderapproval(Optional<WireTransfer.Approval> approval)Alias for calling Builder.approval with approval.orElse(null).final WireTransfer.Builderapproval(JsonField<WireTransfer.Approval> approval)Sets Builder.approval to an arbitrary JSON value. final WireTransfer.Buildercancellation(WireTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final WireTransfer.Buildercancellation(Optional<WireTransfer.Cancellation> cancellation)Alias for calling Builder.cancellation with cancellation.orElse(null).final WireTransfer.Buildercancellation(JsonField<WireTransfer.Cancellation> cancellation)Sets Builder.cancellation to an arbitrary JSON value. final WireTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final WireTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final WireTransfer.BuildercreatedBy(WireTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final WireTransfer.BuildercreatedBy(Optional<WireTransfer.CreatedBy> createdBy)Alias for calling Builder.createdBy with createdBy.orElse(null).final WireTransfer.BuildercreatedBy(JsonField<WireTransfer.CreatedBy> createdBy)Sets Builder.createdBy to an arbitrary JSON value. final WireTransfer.Buildercreditor(WireTransfer.Creditor creditor)The person or business that is receiving the funds from the transfer. final WireTransfer.Buildercreditor(Optional<WireTransfer.Creditor> creditor)Alias for calling Builder.creditor with creditor.orElse(null).final WireTransfer.Buildercreditor(JsonField<WireTransfer.Creditor> creditor)Sets Builder.creditor to an arbitrary JSON value. final WireTransfer.Buildercurrency(WireTransfer.Currency currency)The ISO 4217 code for the transfer's currency. final WireTransfer.Buildercurrency(JsonField<WireTransfer.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final WireTransfer.Builderdebtor(WireTransfer.Debtor debtor)The person or business whose funds are being transferred. final WireTransfer.Builderdebtor(Optional<WireTransfer.Debtor> debtor)Alias for calling Builder.debtor with debtor.orElse(null).final WireTransfer.Builderdebtor(JsonField<WireTransfer.Debtor> debtor)Sets Builder.debtor to an arbitrary JSON value. final WireTransfer.BuilderexternalAccountId(String externalAccountId)The identifier of the External Account the transfer was made to, if any. final WireTransfer.BuilderexternalAccountId(Optional<String> externalAccountId)Alias for calling Builder.externalAccountId with externalAccountId.orElse(null).final WireTransfer.BuilderexternalAccountId(JsonField<String> externalAccountId)Sets Builder.externalAccountId to an arbitrary JSON value. final WireTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final WireTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final WireTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final WireTransfer.BuilderinboundWireDrawdownRequestId(String inboundWireDrawdownRequestId)The ID of an Inbound Wire Drawdown Request in response to which this transfer was sent. final WireTransfer.BuilderinboundWireDrawdownRequestId(Optional<String> inboundWireDrawdownRequestId)Alias for calling Builder.inboundWireDrawdownRequestId with inboundWireDrawdownRequestId.orElse(null).final WireTransfer.BuilderinboundWireDrawdownRequestId(JsonField<String> inboundWireDrawdownRequestId)Sets Builder.inboundWireDrawdownRequestId to an arbitrary JSON value. final WireTransfer.Buildernetwork(WireTransfer.Network network)The transfer's network. final WireTransfer.Buildernetwork(JsonField<WireTransfer.Network> network)Sets Builder.network to an arbitrary JSON value. final WireTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final WireTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)Alias for calling Builder.pendingTransactionId with pendingTransactionId.orElse(null).final WireTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)Sets Builder.pendingTransactionId to an arbitrary JSON value. final WireTransfer.Builderremittance(WireTransfer.Remittance remittance)Remittance information sent with the wire transfer. final WireTransfer.Builderremittance(Optional<WireTransfer.Remittance> remittance)Alias for calling Builder.remittance with remittance.orElse(null).final WireTransfer.Builderremittance(JsonField<WireTransfer.Remittance> remittance)Sets Builder.remittance to an arbitrary JSON value. final WireTransfer.Builderreversal(WireTransfer.Reversal reversal)If your transfer is reversed, this will contain details of the reversal. final WireTransfer.Builderreversal(Optional<WireTransfer.Reversal> reversal)Alias for calling Builder.reversal with reversal.orElse(null).final WireTransfer.Builderreversal(JsonField<WireTransfer.Reversal> reversal)Sets Builder.reversal to an arbitrary JSON value. final WireTransfer.BuilderroutingNumber(String routingNumber)The American Bankers' Association (ABA) Routing Transit Number (RTN). final WireTransfer.BuilderroutingNumber(JsonField<String> routingNumber)Sets Builder.routingNumber to an arbitrary JSON value. final WireTransfer.BuildersourceAccountNumberId(String sourceAccountNumberId)The Account Number that was passed to the wire's recipient. final WireTransfer.BuildersourceAccountNumberId(Optional<String> sourceAccountNumberId)Alias for calling Builder.sourceAccountNumberId with sourceAccountNumberId.orElse(null).final WireTransfer.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)Sets Builder.sourceAccountNumberId to an arbitrary JSON value. final WireTransfer.Builderstatus(WireTransfer.Status status)The lifecycle status of the transfer. final WireTransfer.Builderstatus(JsonField<WireTransfer.Status> status)Sets Builder.status to an arbitrary JSON value. final WireTransfer.Buildersubmission(WireTransfer.Submission submission)After the transfer is submitted to Fedwire, this will contain supplemental details. final WireTransfer.Buildersubmission(Optional<WireTransfer.Submission> submission)Alias for calling Builder.submission with submission.orElse(null).final WireTransfer.Buildersubmission(JsonField<WireTransfer.Submission> submission)Sets Builder.submission to an arbitrary JSON value. final WireTransfer.BuildertransactionId(String transactionId)The ID for the transaction funding the transfer. final WireTransfer.BuildertransactionId(Optional<String> transactionId)Alias for calling Builder.transactionId with transactionId.orElse(null).final WireTransfer.BuildertransactionId(JsonField<String> transactionId)Sets Builder.transactionId to an arbitrary JSON value. final WireTransfer.Buildertype(WireTransfer.Type type)A constant representing the object's type. final WireTransfer.Buildertype(JsonField<WireTransfer.Type> type)Sets Builder.type to an arbitrary JSON value. final WireTransfer.BuilderuniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)The unique end-to-end transaction reference (UETR) of the transfer. final WireTransfer.BuilderuniqueEndToEndTransactionReference(Optional<String> uniqueEndToEndTransactionReference)Alias for calling Builder.uniqueEndToEndTransactionReference with uniqueEndToEndTransactionReference.orElse(null).final WireTransfer.BuilderuniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value. final WireTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final WireTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final WireTransfer.BuilderremoveAdditionalProperty(String key)final WireTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final WireTransferbuild()Returns an immutable instance of WireTransfer. -
-
Method Detail
-
id
final WireTransfer.Builder id(String id)
The wire transfer's identifier.
-
id
final WireTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final WireTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final WireTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final WireTransfer.Builder accountNumber(String accountNumber)
The destination account number.
-
accountNumber
final WireTransfer.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final WireTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approval
final WireTransfer.Builder approval(WireTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final WireTransfer.Builder approval(Optional<WireTransfer.Approval> approval)
Alias for calling Builder.approval with
approval.orElse(null).
-
approval
final WireTransfer.Builder approval(JsonField<WireTransfer.Approval> approval)
Sets Builder.approval to an arbitrary JSON value.
You should usually call Builder.approval with a well-typed Approval value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cancellation
final WireTransfer.Builder cancellation(WireTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final WireTransfer.Builder cancellation(Optional<WireTransfer.Cancellation> cancellation)
Alias for calling Builder.cancellation with
cancellation.orElse(null).
-
cancellation
final WireTransfer.Builder cancellation(JsonField<WireTransfer.Cancellation> cancellation)
Sets Builder.cancellation to an arbitrary JSON value.
You should usually call Builder.cancellation with a well-typed Cancellation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final WireTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final WireTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdBy
final WireTransfer.Builder createdBy(WireTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final WireTransfer.Builder createdBy(Optional<WireTransfer.CreatedBy> createdBy)
Alias for calling Builder.createdBy with
createdBy.orElse(null).
-
createdBy
final WireTransfer.Builder createdBy(JsonField<WireTransfer.CreatedBy> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed CreatedBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditor
final WireTransfer.Builder creditor(WireTransfer.Creditor creditor)
The person or business that is receiving the funds from the transfer.
-
creditor
final WireTransfer.Builder creditor(Optional<WireTransfer.Creditor> creditor)
Alias for calling Builder.creditor with
creditor.orElse(null).
-
creditor
final WireTransfer.Builder creditor(JsonField<WireTransfer.Creditor> creditor)
Sets Builder.creditor to an arbitrary JSON value.
You should usually call Builder.creditor with a well-typed Creditor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final WireTransfer.Builder currency(WireTransfer.Currency currency)
The ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.
-
currency
final WireTransfer.Builder currency(JsonField<WireTransfer.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtor
final WireTransfer.Builder debtor(WireTransfer.Debtor debtor)
The person or business whose funds are being transferred.
-
debtor
final WireTransfer.Builder debtor(Optional<WireTransfer.Debtor> debtor)
Alias for calling Builder.debtor with
debtor.orElse(null).
-
debtor
final WireTransfer.Builder debtor(JsonField<WireTransfer.Debtor> debtor)
Sets Builder.debtor to an arbitrary JSON value.
You should usually call Builder.debtor with a well-typed Debtor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalAccountId
final WireTransfer.Builder externalAccountId(String externalAccountId)
The identifier of the External Account the transfer was made to, if any.
-
externalAccountId
final WireTransfer.Builder externalAccountId(Optional<String> externalAccountId)
Alias for calling Builder.externalAccountId with
externalAccountId.orElse(null).
-
externalAccountId
final WireTransfer.Builder externalAccountId(JsonField<String> externalAccountId)
Sets Builder.externalAccountId to an arbitrary JSON value.
You should usually call Builder.externalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final WireTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final WireTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final WireTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireDrawdownRequestId
final WireTransfer.Builder inboundWireDrawdownRequestId(String inboundWireDrawdownRequestId)
The ID of an Inbound Wire Drawdown Request in response to which this transfer was sent.
-
inboundWireDrawdownRequestId
final WireTransfer.Builder inboundWireDrawdownRequestId(Optional<String> inboundWireDrawdownRequestId)
Alias for calling Builder.inboundWireDrawdownRequestId with
inboundWireDrawdownRequestId.orElse(null).
-
inboundWireDrawdownRequestId
final WireTransfer.Builder inboundWireDrawdownRequestId(JsonField<String> inboundWireDrawdownRequestId)
Sets Builder.inboundWireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.inboundWireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
network
final WireTransfer.Builder network(WireTransfer.Network network)
The transfer's network.
-
network
final WireTransfer.Builder network(JsonField<WireTransfer.Network> network)
Sets Builder.network to an arbitrary JSON value.
You should usually call Builder.network with a well-typed Network value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final WireTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final WireTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final WireTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remittance
final WireTransfer.Builder remittance(WireTransfer.Remittance remittance)
Remittance information sent with the wire transfer.
-
remittance
final WireTransfer.Builder remittance(Optional<WireTransfer.Remittance> remittance)
Alias for calling Builder.remittance with
remittance.orElse(null).
-
remittance
final WireTransfer.Builder remittance(JsonField<WireTransfer.Remittance> remittance)
Sets Builder.remittance to an arbitrary JSON value.
You should usually call Builder.remittance with a well-typed Remittance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversal
final WireTransfer.Builder reversal(WireTransfer.Reversal reversal)
If your transfer is reversed, this will contain details of the reversal.
-
reversal
final WireTransfer.Builder reversal(Optional<WireTransfer.Reversal> reversal)
Alias for calling Builder.reversal with
reversal.orElse(null).
-
reversal
final WireTransfer.Builder reversal(JsonField<WireTransfer.Reversal> reversal)
Sets Builder.reversal to an arbitrary JSON value.
You should usually call Builder.reversal with a well-typed Reversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final WireTransfer.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
routingNumber
final WireTransfer.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final WireTransfer.Builder sourceAccountNumberId(String sourceAccountNumberId)
The Account Number that was passed to the wire's recipient.
-
sourceAccountNumberId
final WireTransfer.Builder sourceAccountNumberId(Optional<String> sourceAccountNumberId)
Alias for calling Builder.sourceAccountNumberId with
sourceAccountNumberId.orElse(null).
-
sourceAccountNumberId
final WireTransfer.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final WireTransfer.Builder status(WireTransfer.Status status)
The lifecycle status of the transfer.
-
status
final WireTransfer.Builder status(JsonField<WireTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submission
final WireTransfer.Builder submission(WireTransfer.Submission submission)
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
submission
final WireTransfer.Builder submission(Optional<WireTransfer.Submission> submission)
Alias for calling Builder.submission with
submission.orElse(null).
-
submission
final WireTransfer.Builder submission(JsonField<WireTransfer.Submission> submission)
Sets Builder.submission to an arbitrary JSON value.
You should usually call Builder.submission with a well-typed Submission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final WireTransfer.Builder transactionId(String transactionId)
The ID for the transaction funding the transfer.
-
transactionId
final WireTransfer.Builder transactionId(Optional<String> transactionId)
Alias for calling Builder.transactionId with
transactionId.orElse(null).
-
transactionId
final WireTransfer.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final WireTransfer.Builder type(WireTransfer.Type type)
A constant representing the object's type. For this resource it will always be
wire_transfer.
-
type
final WireTransfer.Builder type(JsonField<WireTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
uniqueEndToEndTransactionReference
final WireTransfer.Builder uniqueEndToEndTransactionReference(String uniqueEndToEndTransactionReference)
The unique end-to-end transaction reference (UETR) of the transfer.
-
uniqueEndToEndTransactionReference
final WireTransfer.Builder uniqueEndToEndTransactionReference(Optional<String> uniqueEndToEndTransactionReference)
Alias for calling Builder.uniqueEndToEndTransactionReference with
uniqueEndToEndTransactionReference.orElse(null).
-
uniqueEndToEndTransactionReference
final WireTransfer.Builder uniqueEndToEndTransactionReference(JsonField<String> uniqueEndToEndTransactionReference)
Sets Builder.uniqueEndToEndTransactionReference to an arbitrary JSON value.
You should usually call Builder.uniqueEndToEndTransactionReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransfer build()
Returns an immutable instance of WireTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .accountNumber() .amount() .approval() .cancellation() .createdAt() .createdBy() .creditor() .currency() .debtor() .externalAccountId() .idempotencyKey() .inboundWireDrawdownRequestId() .network() .pendingTransactionId() .remittance() .reversal() .routingNumber() .sourceAccountNumberId() .status() .submission() .transactionId() .type() .uniqueEndToEndTransactionReference()
-
-
-
-