Class WireTransfer.CreatedBy
-
- All Implemented Interfaces:
public final class WireTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.CreatedBy.BuilderA builder for CreatedBy.
public final classWireTransfer.CreatedBy.CategoryThe type of object that created this transfer.
public final classWireTransfer.CreatedBy.ApiKeyIf present, details about the API key that created the transfer.
public final classWireTransfer.CreatedBy.OAuthApplicationIf present, details about the OAuth Application that created the transfer.
public final classWireTransfer.CreatedBy.UserIf present, details about the User that created the transfer.
-
Method Summary
Modifier and Type Method Description final WireTransfer.CreatedBy.Categorycategory()The type of object that created this transfer. final Optional<WireTransfer.CreatedBy.ApiKey>apiKey()If present, details about the API key that created the transfer. final Optional<WireTransfer.CreatedBy.OAuthApplication>oauthApplication()If present, details about the OAuth Application that created the transfer. final Optional<WireTransfer.CreatedBy.User>user()If present, details about the User that created the transfer. final JsonField<WireTransfer.CreatedBy.Category>_category()Returns the raw JSON value of category. final JsonField<WireTransfer.CreatedBy.ApiKey>_apiKey()Returns the raw JSON value of apiKey. final JsonField<WireTransfer.CreatedBy.OAuthApplication>_oauthApplication()Returns the raw JSON value of oauthApplication. final JsonField<WireTransfer.CreatedBy.User>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final WireTransfer.CreatedBy.BuildertoBuilder()final WireTransfer.CreatedByvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.CreatedBy.Builderbuilder()Returns a mutable builder for constructing an instance of CreatedBy. -
-
Method Detail
-
category
final WireTransfer.CreatedBy.Category category()
The type of object that created this transfer.
-
apiKey
final Optional<WireTransfer.CreatedBy.ApiKey> apiKey()
If present, details about the API key that created the transfer.
-
oauthApplication
final Optional<WireTransfer.CreatedBy.OAuthApplication> oauthApplication()
If present, details about the OAuth Application that created the transfer.
-
user
final Optional<WireTransfer.CreatedBy.User> user()
If present, details about the User that created the transfer.
-
_category
final JsonField<WireTransfer.CreatedBy.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_apiKey
final JsonField<WireTransfer.CreatedBy.ApiKey> _apiKey()
Returns the raw JSON value of apiKey.
Unlike apiKey, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthApplication
final JsonField<WireTransfer.CreatedBy.OAuthApplication> _oauthApplication()
Returns the raw JSON value of oauthApplication.
Unlike oauthApplication, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<WireTransfer.CreatedBy.User> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.CreatedBy.Builder toBuilder()
-
validate
final WireTransfer.CreatedBy validate()
-
builder
final static WireTransfer.CreatedBy.Builder builder()
Returns a mutable builder for constructing an instance of CreatedBy.
The following fields are required:
.category()
-
-
-
-