Class WireTransfer.Creditor
-
- All Implemented Interfaces:
public final class WireTransfer.CreditorThe person or business that is receiving the funds from the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Creditor.BuilderA builder for Creditor.
public final classWireTransfer.Creditor.AddressThe person or business's address.
-
Method Summary
Modifier and Type Method Description final Optional<WireTransfer.Creditor.Address>address()The person or business's address. final Optional<String>name()The person or business's name. final JsonField<WireTransfer.Creditor.Address>_address()Returns the raw JSON value of address. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Creditor.BuildertoBuilder()final WireTransfer.Creditorvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Creditor.Builderbuilder()Returns a mutable builder for constructing an instance of Creditor. -
-
Method Detail
-
address
final Optional<WireTransfer.Creditor.Address> address()
The person or business's address.
-
_address
final JsonField<WireTransfer.Creditor.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Creditor.Builder toBuilder()
-
validate
final WireTransfer.Creditor validate()
-
builder
final static WireTransfer.Creditor.Builder builder()
Returns a mutable builder for constructing an instance of Creditor.
The following fields are required:
.address() .name()
-
-
-
-