Class WireTransfer.Creditor.Address
-
- All Implemented Interfaces:
public final class WireTransfer.Creditor.AddressThe person or business's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Creditor.Address.BuilderA builder for Address.
public final classWireTransfer.Creditor.Address.UnstructuredUnstructured address lines.
-
Method Summary
Modifier and Type Method Description final Optional<WireTransfer.Creditor.Address.Unstructured>unstructured()Unstructured address lines. final JsonField<WireTransfer.Creditor.Address.Unstructured>_unstructured()Returns the raw JSON value of unstructured. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Creditor.Address.BuildertoBuilder()final WireTransfer.Creditor.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Creditor.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
unstructured
final Optional<WireTransfer.Creditor.Address.Unstructured> unstructured()
Unstructured address lines.
-
_unstructured
final JsonField<WireTransfer.Creditor.Address.Unstructured> _unstructured()
Returns the raw JSON value of unstructured.
Unlike unstructured, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Creditor.Address.Builder toBuilder()
-
validate
final WireTransfer.Creditor.Address validate()
-
builder
final static WireTransfer.Creditor.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.unstructured()
-
-
-
-