Class WireTransfer.Debtor.Address.Builder
-
- All Implemented Interfaces:
public final class WireTransfer.Debtor.Address.BuilderA builder for Address.
-
-
Method Summary
-
-
Method Detail
-
unstructured
final WireTransfer.Debtor.Address.Builder unstructured(WireTransfer.Debtor.Address.Unstructured unstructured)
Unstructured address lines.
-
unstructured
final WireTransfer.Debtor.Address.Builder unstructured(Optional<WireTransfer.Debtor.Address.Unstructured> unstructured)
Alias for calling Builder.unstructured with
unstructured.orElse(null).
-
unstructured
final WireTransfer.Debtor.Address.Builder unstructured(JsonField<WireTransfer.Debtor.Address.Unstructured> unstructured)
Sets Builder.unstructured to an arbitrary JSON value.
You should usually call Builder.unstructured with a well-typed Unstructured value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireTransfer.Debtor.Address.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransfer.Debtor.Address.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransfer.Debtor.Address.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransfer.Debtor.Address.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransfer.Debtor.Address.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransfer.Debtor.Address build()
Returns an immutable instance of Address.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.unstructured()
-
-
-
-