Class WireTransfer.Remittance.Unstructured
-
- All Implemented Interfaces:
public final class WireTransfer.Remittance.UnstructuredUnstructured remittance information. Required if
categoryis equal tounstructured.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Remittance.Unstructured.BuilderA builder for Unstructured.
-
Method Summary
Modifier and Type Method Description final Stringmessage()The message to the beneficiary. final JsonField<String>_message()Returns the raw JSON value of message. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Remittance.Unstructured.BuildertoBuilder()final WireTransfer.Remittance.Unstructuredvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Remittance.Unstructured.Builderbuilder()Returns a mutable builder for constructing an instance of Unstructured. -
-
Method Detail
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Remittance.Unstructured.Builder toBuilder()
-
validate
final WireTransfer.Remittance.Unstructured validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WireTransfer.Remittance.Unstructured.Builder builder()
Returns a mutable builder for constructing an instance of Unstructured.
The following fields are required:
.message()
-
-
-
-