Class WireTransfer.Reversal
-
- All Implemented Interfaces:
public final class WireTransfer.ReversalIf your transfer is reversed, this will contain details of the reversal.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Reversal.BuilderA builder for Reversal.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount that was reversed in USD cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the reversal was created. final Stringdescription()The description on the reversal message from Fedwire, set by the reversing bank. final Optional<String>financialInstitutionToFinancialInstitutionInformation()Additional financial institution information included in the wire reversal. final LocalDateinputCycleDate()The Fedwire cycle date for the wire reversal. final StringinputMessageAccountabilityData()The Fedwire transaction identifier. final StringinputSequenceNumber()The Fedwire sequence number. final StringinputSource()The Fedwire input source identifier. final Optional<String>originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>originatorToBeneficiaryInformation()Additional information included in the wire reversal by the reversal originator. final LocalDatepreviousMessageInputCycleDate()The Fedwire cycle date for the wire transfer that is being reversed by this message. final StringpreviousMessageInputMessageAccountabilityData()The Fedwire transaction identifier for the wire transfer that was reversed. final StringpreviousMessageInputSequenceNumber()The Fedwire sequence number for the wire transfer that was reversed. final StringpreviousMessageInputSource()The Fedwire input source identifier for the wire transfer that was reversed. final Optional<String>receiverFinancialInstitutionInformation()Information included in the wire reversal for the receiving financial institution. final Optional<String>senderReference()The sending bank's reference number for the wire reversal. final StringtransactionId()The ID for the Transaction associated with the transfer reversal. final StringwireTransferId()The ID for the Wire Transfer that is being reversed. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_financialInstitutionToFinancialInstitutionInformation()Returns the raw JSON value of financialInstitutionToFinancialInstitutionInformation. final JsonField<LocalDate>_inputCycleDate()Returns the raw JSON value of inputCycleDate. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_inputSequenceNumber()Returns the raw JSON value of inputSequenceNumber. final JsonField<String>_inputSource()Returns the raw JSON value of inputSource. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_originatorToBeneficiaryInformation()Returns the raw JSON value of originatorToBeneficiaryInformation. final JsonField<LocalDate>_previousMessageInputCycleDate()Returns the raw JSON value of previousMessageInputCycleDate. final JsonField<String>_previousMessageInputMessageAccountabilityData()Returns the raw JSON value of previousMessageInputMessageAccountabilityData. final JsonField<String>_previousMessageInputSequenceNumber()Returns the raw JSON value of previousMessageInputSequenceNumber. final JsonField<String>_previousMessageInputSource()Returns the raw JSON value of previousMessageInputSource. final JsonField<String>_receiverFinancialInstitutionInformation()Returns the raw JSON value of receiverFinancialInstitutionInformation. final JsonField<String>_senderReference()Returns the raw JSON value of senderReference. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<String>_wireTransferId()Returns the raw JSON value of wireTransferId. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Reversal.BuildertoBuilder()final WireTransfer.Reversalvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Reversal.Builderbuilder()Returns a mutable builder for constructing an instance of Reversal. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the reversal was created.
-
description
final String description()
The description on the reversal message from Fedwire, set by the reversing bank.
-
financialInstitutionToFinancialInstitutionInformation
final Optional<String> financialInstitutionToFinancialInstitutionInformation()
Additional financial institution information included in the wire reversal.
-
inputCycleDate
final LocalDate inputCycleDate()
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00 PM Eastern Time on the evening before the
cycle date.
-
inputMessageAccountabilityData
final String inputMessageAccountabilityData()
The Fedwire transaction identifier.
-
inputSequenceNumber
final String inputSequenceNumber()
The Fedwire sequence number.
-
inputSource
final String inputSource()
The Fedwire input source identifier.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final Optional<String> originatorToBeneficiaryInformation()
Additional information included in the wire reversal by the reversal originator.
-
previousMessageInputCycleDate
final LocalDate previousMessageInputCycleDate()
The Fedwire cycle date for the wire transfer that is being reversed by this message.
-
previousMessageInputMessageAccountabilityData
final String previousMessageInputMessageAccountabilityData()
The Fedwire transaction identifier for the wire transfer that was reversed.
-
previousMessageInputSequenceNumber
final String previousMessageInputSequenceNumber()
The Fedwire sequence number for the wire transfer that was reversed.
-
previousMessageInputSource
final String previousMessageInputSource()
The Fedwire input source identifier for the wire transfer that was reversed.
-
receiverFinancialInstitutionInformation
final Optional<String> receiverFinancialInstitutionInformation()
Information included in the wire reversal for the receiving financial institution.
-
senderReference
final Optional<String> senderReference()
The sending bank's reference number for the wire reversal.
-
transactionId
final String transactionId()
The ID for the Transaction associated with the transfer reversal.
-
wireTransferId
final String wireTransferId()
The ID for the Wire Transfer that is being reversed.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_financialInstitutionToFinancialInstitutionInformation
final JsonField<String> _financialInstitutionToFinancialInstitutionInformation()
Returns the raw JSON value of financialInstitutionToFinancialInstitutionInformation.
Unlike financialInstitutionToFinancialInstitutionInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_inputCycleDate
final JsonField<LocalDate> _inputCycleDate()
Returns the raw JSON value of inputCycleDate.
Unlike inputCycleDate, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_inputSequenceNumber
final JsonField<String> _inputSequenceNumber()
Returns the raw JSON value of inputSequenceNumber.
Unlike inputSequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_inputSource
final JsonField<String> _inputSource()
Returns the raw JSON value of inputSource.
Unlike inputSource, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformation
final JsonField<String> _originatorToBeneficiaryInformation()
Returns the raw JSON value of originatorToBeneficiaryInformation.
Unlike originatorToBeneficiaryInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_previousMessageInputCycleDate
final JsonField<LocalDate> _previousMessageInputCycleDate()
Returns the raw JSON value of previousMessageInputCycleDate.
Unlike previousMessageInputCycleDate, this method doesn't throw if the JSON field has an unexpected type.
-
_previousMessageInputMessageAccountabilityData
final JsonField<String> _previousMessageInputMessageAccountabilityData()
Returns the raw JSON value of previousMessageInputMessageAccountabilityData.
Unlike previousMessageInputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_previousMessageInputSequenceNumber
final JsonField<String> _previousMessageInputSequenceNumber()
Returns the raw JSON value of previousMessageInputSequenceNumber.
Unlike previousMessageInputSequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_previousMessageInputSource
final JsonField<String> _previousMessageInputSource()
Returns the raw JSON value of previousMessageInputSource.
Unlike previousMessageInputSource, this method doesn't throw if the JSON field has an unexpected type.
-
_receiverFinancialInstitutionInformation
final JsonField<String> _receiverFinancialInstitutionInformation()
Returns the raw JSON value of receiverFinancialInstitutionInformation.
Unlike receiverFinancialInstitutionInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_senderReference
final JsonField<String> _senderReference()
Returns the raw JSON value of senderReference.
Unlike senderReference, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_wireTransferId
final JsonField<String> _wireTransferId()
Returns the raw JSON value of wireTransferId.
Unlike wireTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Reversal.Builder toBuilder()
-
validate
final WireTransfer.Reversal validate()
-
builder
final static WireTransfer.Reversal.Builder builder()
Returns a mutable builder for constructing an instance of Reversal.
The following fields are required:
.amount() .createdAt() .description() .financialInstitutionToFinancialInstitutionInformation() .inputCycleDate() .inputMessageAccountabilityData() .inputSequenceNumber() .inputSource() .originatorRoutingNumber() .originatorToBeneficiaryInformation() .previousMessageInputCycleDate() .previousMessageInputMessageAccountabilityData() .previousMessageInputSequenceNumber() .previousMessageInputSource() .receiverFinancialInstitutionInformation() .senderReference() .transactionId() .wireTransferId()
-
-
-
-