Enum WireTransfer.Status.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum WireTransfer.Status.Known extends Enum<WireTransfer.Status.Known>
An enum containing Status's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<WireTransfer.Status.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_APPROVALThe transfer is pending approval.
CANCELEDThe transfer has been canceled.
PENDING_REVIEWINGThe transfer is pending review by Increase.
REJECTEDThe transfer has been rejected by Increase.
REQUIRES_ATTENTIONThe transfer requires attention from an Increase operator.
PENDING_CREATINGThe transfer is pending creation.
REVERSEDThe transfer has been reversed.
SUBMITTEDThe transfer has been submitted to Fedwire.
COMPLETEThe transfer has been acknowledged by Fedwire and can be considered complete.
-
Method Summary
Modifier and Type Method Description final WireTransfer.Status.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<WireTransfer.Status.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<WireTransfer.Status.Known>getEntries()An enum containing Status's known values. -
-
Method Detail
-
valueOf
final WireTransfer.Status.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<WireTransfer.Status.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<WireTransfer.Status.Known> getEntries()
An enum containing Status's known values.
-
-
-
-