Class WireTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final WireTransferCreateParams.Creditorcreditor()The person or business that is receiving the funds from the transfer. final WireTransferCreateParams.Remittanceremittance()Additional remittance information related to the wire transfer. final Optional<String>accountNumber()The account number for the destination account. final Optional<WireTransferCreateParams.Debtor>debtor()The person or business whose funds are being transferred. final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<String>inboundWireDrawdownRequestId()The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<String>sourceAccountNumberId()The ID of an Account Number that will be passed to the wire's recipient final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<WireTransferCreateParams.Creditor>_creditor()Returns the raw JSON value of creditor. final JsonField<WireTransferCreateParams.Remittance>_remittance()Returns the raw JSON value of remittance. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<WireTransferCreateParams.Debtor>_debtor()Returns the raw JSON value of debtor. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<String>_inboundWireDrawdownRequestId()Returns the raw JSON value of inboundWireDrawdownRequestId. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Body.BuildertoBuilder()final WireTransferCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
creditor
final WireTransferCreateParams.Creditor creditor()
The person or business that is receiving the funds from the transfer.
-
remittance
final WireTransferCreateParams.Remittance remittance()
Additional remittance information related to the wire transfer.
-
accountNumber
final Optional<String> accountNumber()
The account number for the destination account.
-
debtor
final Optional<WireTransferCreateParams.Debtor> debtor()
The person or business whose funds are being transferred. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
inboundWireDrawdownRequestId
final Optional<String> inboundWireDrawdownRequestId()
The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The ID of an Account Number that will be passed to the wire's recipient
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditor
final JsonField<WireTransferCreateParams.Creditor> _creditor()
Returns the raw JSON value of creditor.
Unlike creditor, this method doesn't throw if the JSON field has an unexpected type.
-
_remittance
final JsonField<WireTransferCreateParams.Remittance> _remittance()
Returns the raw JSON value of remittance.
Unlike remittance, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtor
final JsonField<WireTransferCreateParams.Debtor> _debtor()
Returns the raw JSON value of debtor.
Unlike debtor, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireDrawdownRequestId
final JsonField<String> _inboundWireDrawdownRequestId()
Returns the raw JSON value of inboundWireDrawdownRequestId.
Unlike inboundWireDrawdownRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Body.Builder toBuilder()
-
validate
final WireTransferCreateParams.Body validate()
-
builder
final static WireTransferCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount() .creditor() .remittance()
-
-
-
-