Class WireTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final WireTransferCreateParams.Body.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final WireTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final WireTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creditor
final WireTransferCreateParams.Body.Builder creditor(WireTransferCreateParams.Creditor creditor)
The person or business that is receiving the funds from the transfer.
-
creditor
final WireTransferCreateParams.Body.Builder creditor(JsonField<WireTransferCreateParams.Creditor> creditor)
Sets Builder.creditor to an arbitrary JSON value.
You should usually call Builder.creditor with a well-typed Creditor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remittance
final WireTransferCreateParams.Body.Builder remittance(WireTransferCreateParams.Remittance remittance)
Additional remittance information related to the wire transfer.
-
remittance
final WireTransferCreateParams.Body.Builder remittance(JsonField<WireTransferCreateParams.Remittance> remittance)
Sets Builder.remittance to an arbitrary JSON value.
You should usually call Builder.remittance with a well-typed Remittance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final WireTransferCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final WireTransferCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
debtor
final WireTransferCreateParams.Body.Builder debtor(WireTransferCreateParams.Debtor debtor)
The person or business whose funds are being transferred. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
debtor
final WireTransferCreateParams.Body.Builder debtor(JsonField<WireTransferCreateParams.Debtor> debtor)
Sets Builder.debtor to an arbitrary JSON value.
You should usually call Builder.debtor with a well-typed Debtor value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalAccountId
final WireTransferCreateParams.Body.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
externalAccountId
final WireTransferCreateParams.Body.Builder externalAccountId(JsonField<String> externalAccountId)
Sets Builder.externalAccountId to an arbitrary JSON value.
You should usually call Builder.externalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireDrawdownRequestId
final WireTransferCreateParams.Body.Builder inboundWireDrawdownRequestId(String inboundWireDrawdownRequestId)
The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent.
-
inboundWireDrawdownRequestId
final WireTransferCreateParams.Body.Builder inboundWireDrawdownRequestId(JsonField<String> inboundWireDrawdownRequestId)
Sets Builder.inboundWireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.inboundWireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final WireTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final WireTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final WireTransferCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final WireTransferCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final WireTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The ID of an Account Number that will be passed to the wire's recipient
-
sourceAccountNumberId
final WireTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .creditor() .remittance()
-
-
-
-