Class WireTransferCreateParams.Builder
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.BuilderA builder for WireTransferCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final WireTransferCreateParams.Builder body(WireTransferCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
accountId
final WireTransferCreateParams.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final WireTransferCreateParams.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireTransferCreateParams.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final WireTransferCreateParams.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final WireTransferCreateParams.Builder beneficiaryName(String beneficiaryName)
The beneficiary's name.
-
beneficiaryName
final WireTransferCreateParams.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final WireTransferCreateParams.Builder messageToRecipient(String messageToRecipient)
The message that will show on the recipient's bank statement.
-
messageToRecipient
final WireTransferCreateParams.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final WireTransferCreateParams.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final WireTransferCreateParams.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final WireTransferCreateParams.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine1
final WireTransferCreateParams.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final WireTransferCreateParams.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine2
final WireTransferCreateParams.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final WireTransferCreateParams.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
The beneficiary's address line 3.
-
beneficiaryAddressLine3
final WireTransferCreateParams.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalAccountId
final WireTransferCreateParams.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
externalAccountId
final WireTransferCreateParams.Builder externalAccountId(JsonField<String> externalAccountId)
Sets Builder.externalAccountId to an arbitrary JSON value.
You should usually call Builder.externalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireDrawdownRequestId
final WireTransferCreateParams.Builder inboundWireDrawdownRequestId(String inboundWireDrawdownRequestId)
The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent.
-
inboundWireDrawdownRequestId
final WireTransferCreateParams.Builder inboundWireDrawdownRequestId(JsonField<String> inboundWireDrawdownRequestId)
Sets Builder.inboundWireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.inboundWireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final WireTransferCreateParams.Builder originatorAddressLine1(String originatorAddressLine1)
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine1
final WireTransferCreateParams.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final WireTransferCreateParams.Builder originatorAddressLine2(String originatorAddressLine2)
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final WireTransferCreateParams.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final WireTransferCreateParams.Builder originatorAddressLine3(String originatorAddressLine3)
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final WireTransferCreateParams.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final WireTransferCreateParams.Builder originatorName(String originatorName)
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final WireTransferCreateParams.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final WireTransferCreateParams.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final WireTransferCreateParams.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final WireTransferCreateParams.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final WireTransferCreateParams.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final WireTransferCreateParams.Builder sourceAccountNumberId(String sourceAccountNumberId)
The ID of an Account Number that will be passed to the wire's recipient
-
sourceAccountNumberId
final WireTransferCreateParams.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final WireTransferCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final WireTransferCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final WireTransferCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final WireTransferCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final WireTransferCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final WireTransferCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final WireTransferCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final WireTransferCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final WireTransferCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final WireTransferCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final WireTransferCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final WireTransferCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final WireTransferCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final WireTransferCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final WireTransferCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final WireTransferCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final WireTransferCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final WireTransferCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final WireTransferCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final WireTransferCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final WireTransferCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final WireTransferCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final WireTransferCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final WireTransferCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final WireTransferCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final WireTransferCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final WireTransferCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final WireTransferCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final WireTransferCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final WireTransferCreateParams build()
Returns an immutable instance of WireTransferCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .beneficiaryName() .messageToRecipient()
-
-
-
-