Class WireTransferCreateParams.Creditor
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.CreditorThe person or business that is receiving the funds from the transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Creditor.BuilderA builder for Creditor.
public final classWireTransferCreateParams.Creditor.AddressThe person or business's address.
-
Method Summary
Modifier and Type Method Description final Stringname()The person or business's name. final Optional<WireTransferCreateParams.Creditor.Address>address()The person or business's address. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<WireTransferCreateParams.Creditor.Address>_address()Returns the raw JSON value of address. final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Creditor.BuildertoBuilder()final WireTransferCreateParams.Creditorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Creditor.Builderbuilder()Returns a mutable builder for constructing an instance of Creditor. -
-
Method Detail
-
address
final Optional<WireTransferCreateParams.Creditor.Address> address()
The person or business's address.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<WireTransferCreateParams.Creditor.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Creditor.Builder toBuilder()
-
validate
final WireTransferCreateParams.Creditor validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WireTransferCreateParams.Creditor.Builder builder()
Returns a mutable builder for constructing an instance of Creditor.
The following fields are required:
.name()
-
-
-
-