Class WireTransferCreateParams.Creditor.Builder
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Creditor.BuilderA builder for Creditor.
-
-
Method Summary
-
-
Method Detail
-
name
final WireTransferCreateParams.Creditor.Builder name(String name)
The person or business's name.
-
name
final WireTransferCreateParams.Creditor.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
address
final WireTransferCreateParams.Creditor.Builder address(WireTransferCreateParams.Creditor.Address address)
The person or business's address.
-
address
final WireTransferCreateParams.Creditor.Builder address(JsonField<WireTransferCreateParams.Creditor.Address> address)
Sets Builder.address to an arbitrary JSON value.
You should usually call Builder.address with a well-typed Address value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireTransferCreateParams.Creditor.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransferCreateParams.Creditor.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransferCreateParams.Creditor.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransferCreateParams.Creditor.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransferCreateParams.Creditor.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransferCreateParams.Creditor build()
Returns an immutable instance of Creditor.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name()
-
-
-
-