Class WireTransferCreateParams.Debtor
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.DebtorThe person or business whose funds are being transferred. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Debtor.BuilderA builder for Debtor.
public final classWireTransferCreateParams.Debtor.AddressThe person or business's address.
-
Method Summary
Modifier and Type Method Description final Stringname()The person or business's name. final Optional<WireTransferCreateParams.Debtor.Address>address()The person or business's address. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<WireTransferCreateParams.Debtor.Address>_address()Returns the raw JSON value of address. final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Debtor.BuildertoBuilder()final WireTransferCreateParams.Debtorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Debtor.Builderbuilder()Returns a mutable builder for constructing an instance of Debtor. -
-
Method Detail
-
address
final Optional<WireTransferCreateParams.Debtor.Address> address()
The person or business's address.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_address
final JsonField<WireTransferCreateParams.Debtor.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Debtor.Builder toBuilder()
-
validate
final WireTransferCreateParams.Debtor validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WireTransferCreateParams.Debtor.Builder builder()
Returns a mutable builder for constructing an instance of Debtor.
The following fields are required:
.name()
-
-
-
-