Class WireTransferCreateParams.Debtor.Address.Unstructured
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Debtor.Address.UnstructuredUnstructured address lines.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Debtor.Address.Unstructured.BuilderA builder for Unstructured.
-
Method Summary
Modifier and Type Method Description final Stringline1()The address line 1. final Optional<String>line2()The address line 2. final Optional<String>line3()The address line 3. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_line3()Returns the raw JSON value of line3. final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Debtor.Address.Unstructured.BuildertoBuilder()final WireTransferCreateParams.Debtor.Address.Unstructuredvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Debtor.Address.Unstructured.Builderbuilder()Returns a mutable builder for constructing an instance of Unstructured. -
-
Method Detail
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_line3
final JsonField<String> _line3()
Returns the raw JSON value of line3.
Unlike line3, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder toBuilder()
-
validate
final WireTransferCreateParams.Debtor.Address.Unstructured validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WireTransferCreateParams.Debtor.Address.Unstructured.Builder builder()
Returns a mutable builder for constructing an instance of Unstructured.
The following fields are required:
.line1()
-
-
-
-