Class WireTransferCreateParams.Debtor.Address.Unstructured.Builder
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Debtor.Address.Unstructured.BuilderA builder for Unstructured.
-
-
Method Summary
-
-
Method Detail
-
line1
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder line1(String line1)
The address line 1.
-
line1
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder line1(JsonField<String> line1)
Sets Builder.line1 to an arbitrary JSON value.
You should usually call Builder.line1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line2
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder line2(String line2)
The address line 2.
-
line2
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder line2(JsonField<String> line2)
Sets Builder.line2 to an arbitrary JSON value.
You should usually call Builder.line2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
line3
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder line3(String line3)
The address line 3.
-
line3
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder line3(JsonField<String> line3)
Sets Builder.line3 to an arbitrary JSON value.
You should usually call Builder.line3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransferCreateParams.Debtor.Address.Unstructured.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransferCreateParams.Debtor.Address.Unstructured build()
Returns an immutable instance of Unstructured.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.line1()
-
-
-
-