Enum WireTransferCreateParams.Remittance.Category.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum WireTransferCreateParams.Remittance.Category.Known extends Enum<WireTransferCreateParams.Remittance.Category.Known>
An enum containing Category's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<WireTransferCreateParams.Remittance.Category.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description UNSTRUCTUREDThe wire transfer contains unstructured remittance information.
TAXThe wire transfer is for tax payment purposes to the Internal Revenue Service (IRS).
-
Method Summary
Modifier and Type Method Description final WireTransferCreateParams.Remittance.Category.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<WireTransferCreateParams.Remittance.Category.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<WireTransferCreateParams.Remittance.Category.Known>getEntries()An enum containing Category's known values. -
-
Method Detail
-
valueOf
final WireTransferCreateParams.Remittance.Category.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<WireTransferCreateParams.Remittance.Category.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<WireTransferCreateParams.Remittance.Category.Known> getEntries()
An enum containing Category's known values.
-
-
-
-