Class WireTransferListPage.Builder
-
- All Implemented Interfaces:
public final class WireTransferListPage.BuilderA builder for WireTransferListPage.
-
-
Method Summary
Modifier and Type Method Description final WireTransferListPage.Builderservice(WireTransferService service)final WireTransferListPage.Builderparams(WireTransferListParams params)The parameters that were used to request this page. final WireTransferListPage.Builderresponse(WireTransferListPageResponse response)The response that this page was parsed from. final WireTransferListPagebuild()Returns an immutable instance of WireTransferListPage. -
-
Method Detail
-
service
final WireTransferListPage.Builder service(WireTransferService service)
-
params
final WireTransferListPage.Builder params(WireTransferListParams params)
The parameters that were used to request this page.
-
response
final WireTransferListPage.Builder response(WireTransferListPageResponse response)
The response that this page was parsed from.
-
build
final WireTransferListPage build()
Returns an immutable instance of WireTransferListPage.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .params() .response()
-
-
-
-