Class WireTransferListPageAsync
-
- All Implemented Interfaces:
-
com.increase.api.core.PageAsync
public final class WireTransferListPageAsync implements PageAsync<WireTransfer>
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferListPageAsync.BuilderA builder for WireTransferListPageAsync.
-
Method Summary
Modifier and Type Method Description final List<WireTransfer>data()Delegates to WireTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to WireTransferListPageResponse, but gracefully handles missing data. List<WireTransfer>items()Returns the items in this page. BooleanhasNextPage()Returns whether there's another page after this one. final WireTransferListParamsnextPageParams()CompletableFuture<WireTransferListPageAsync>nextPage()Returns the page after this one by making another request. final AutoPagerAsync<WireTransfer>autoPager()final WireTransferListParamsparams()The parameters that were used to request this page. final WireTransferListPageResponseresponse()The response that this page was parsed from. final WireTransferListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of WireTransferListPageAsync. -
-
Method Detail
-
data
final List<WireTransfer> data()
Delegates to WireTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to WireTransferListPageResponse, but gracefully handles missing data.
-
items
List<WireTransfer> items()
Returns the items in this page.
-
hasNextPage
Boolean hasNextPage()
Returns whether there's another page after this one.
The method generally doesn't make requests so the result depends entirely on the data in this page. If a significant amount of time has passed between requesting this page and calling this method, then the result could be stale.
-
nextPageParams
final WireTransferListParams nextPageParams()
-
nextPage
CompletableFuture<WireTransferListPageAsync> nextPage()
Returns the page after this one by making another request.
-
autoPager
final AutoPagerAsync<WireTransfer> autoPager()
-
params
final WireTransferListParams params()
The parameters that were used to request this page.
-
response
final WireTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final WireTransferListPageAsync.Builder toBuilder()
-
builder
final static WireTransferListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of WireTransferListPageAsync.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-