Class WireTransferListPageAsync.Builder
-
- All Implemented Interfaces:
public final class WireTransferListPageAsync.BuilderA builder for WireTransferListPageAsync.
-
-
Method Summary
Modifier and Type Method Description final WireTransferListPageAsync.Builderservice(WireTransferServiceAsync service)final WireTransferListPageAsync.BuilderstreamHandlerExecutor(Executor streamHandlerExecutor)final WireTransferListPageAsync.Builderparams(WireTransferListParams params)The parameters that were used to request this page. final WireTransferListPageAsync.Builderresponse(WireTransferListPageResponse response)The response that this page was parsed from. final WireTransferListPageAsyncbuild()Returns an immutable instance of WireTransferListPageAsync. -
-
Method Detail
-
service
final WireTransferListPageAsync.Builder service(WireTransferServiceAsync service)
-
streamHandlerExecutor
final WireTransferListPageAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
params
final WireTransferListPageAsync.Builder params(WireTransferListParams params)
The parameters that were used to request this page.
-
response
final WireTransferListPageAsync.Builder response(WireTransferListPageResponse response)
The response that this page was parsed from.
-
build
final WireTransferListPageAsync build()
Returns an immutable instance of WireTransferListPageAsync.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.service() .streamHandlerExecutor() .params() .response()
-
-
-
-