Package com.increase.api.services.async
Interface AccountServiceAsync
-
- All Implemented Interfaces:
public interface AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountServiceAsync.WithRawResponseA view of AccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<Account>create(AccountCreateParams params, RequestOptions requestOptions)Create an Account abstract CompletableFuture<Account>create(AccountCreateParams params)Create an Account abstract CompletableFuture<Account>retrieve(AccountRetrieveParams params, RequestOptions requestOptions)Retrieve an Account abstract CompletableFuture<Account>retrieve(AccountRetrieveParams params)Retrieve an Account abstract CompletableFuture<Account>update(AccountUpdateParams params, RequestOptions requestOptions)Update an Account abstract CompletableFuture<Account>update(AccountUpdateParams params)Update an Account abstract CompletableFuture<AccountListPageAsync>list(AccountListParams params, RequestOptions requestOptions)List Accounts abstract CompletableFuture<AccountListPageAsync>list(AccountListParams params)List Accounts abstract CompletableFuture<AccountListPageAsync>list()List Accounts CompletableFuture<AccountListPageAsync>list(RequestOptions requestOptions)List Accounts abstract CompletableFuture<BalanceLookup>balance(AccountBalanceParams params, RequestOptions requestOptions)Retrieve the current and available balances for an account in minor units of the account's currency. abstract CompletableFuture<BalanceLookup>balance(AccountBalanceParams params)Retrieve the current and available balances for an account in minor units of the account's currency. abstract CompletableFuture<Account>close(AccountCloseParams params, RequestOptions requestOptions)Close an Account abstract CompletableFuture<Account>close(AccountCloseParams params)Close an Account -
-
Method Detail
-
withRawResponse
abstract AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract CompletableFuture<Account> create(AccountCreateParams params, RequestOptions requestOptions)
Create an Account
-
create
abstract CompletableFuture<Account> create(AccountCreateParams params)
Create an Account
-
retrieve
abstract CompletableFuture<Account> retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
Retrieve an Account
-
retrieve
abstract CompletableFuture<Account> retrieve(AccountRetrieveParams params)
Retrieve an Account
-
update
abstract CompletableFuture<Account> update(AccountUpdateParams params, RequestOptions requestOptions)
Update an Account
-
update
abstract CompletableFuture<Account> update(AccountUpdateParams params)
Update an Account
-
list
abstract CompletableFuture<AccountListPageAsync> list(AccountListParams params, RequestOptions requestOptions)
List Accounts
-
list
abstract CompletableFuture<AccountListPageAsync> list(AccountListParams params)
List Accounts
-
list
abstract CompletableFuture<AccountListPageAsync> list()
List Accounts
-
list
CompletableFuture<AccountListPageAsync> list(RequestOptions requestOptions)
List Accounts
-
balance
abstract CompletableFuture<BalanceLookup> balance(AccountBalanceParams params, RequestOptions requestOptions)
Retrieve the current and available balances for an account in minor units of the account's currency. Learn more about /documentation/balance.
-
balance
abstract CompletableFuture<BalanceLookup> balance(AccountBalanceParams params)
Retrieve the current and available balances for an account in minor units of the account's currency. Learn more about /documentation/balance.
-
close
abstract CompletableFuture<Account> close(AccountCloseParams params, RequestOptions requestOptions)
Close an Account
-
close
abstract CompletableFuture<Account> close(AccountCloseParams params)
Close an Account
-
-
-
-