Package com.increase.api.services.async
Class AccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AccountServiceAsync
public final class AccountServiceAsyncImpl implements AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Account>create(AccountCreateParams params, RequestOptions requestOptions)CompletableFuture<Account>retrieve(AccountRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Account>update(AccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<AccountListPageAsync>list(AccountListParams params, RequestOptions requestOptions)CompletableFuture<BalanceLookup>balance(AccountBalanceParams params, RequestOptions requestOptions)CompletableFuture<Account>close(AccountCloseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Account> create(AccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Account> retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Account> update(AccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountListPageAsync> list(AccountListParams params, RequestOptions requestOptions)
-
balance
CompletableFuture<BalanceLookup> balance(AccountBalanceParams params, RequestOptions requestOptions)
-
close
CompletableFuture<Account> close(AccountCloseParams params, RequestOptions requestOptions)
-
-
-
-