Package com.increase.api.services.async
Interface AccountStatementServiceAsync
-
- All Implemented Interfaces:
public interface AccountStatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountStatementServiceAsync.WithRawResponseA view of AccountStatementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AccountStatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountStatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<AccountStatement> retrieve(String accountStatementId)
Retrieve an Account Statement
-
retrieve
CompletableFuture<AccountStatement> retrieve(String accountStatementId, AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AccountStatement> retrieve(String accountStatementId, AccountStatementRetrieveParams params)
-
retrieve
abstract CompletableFuture<AccountStatement> retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AccountStatement> retrieve(AccountStatementRetrieveParams params)
-
retrieve
CompletableFuture<AccountStatement> retrieve(String accountStatementId, RequestOptions requestOptions)
-
list
CompletableFuture<AccountStatementListPageAsync> list()
List Account Statements
-
list
abstract CompletableFuture<AccountStatementListPageAsync> list(AccountStatementListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountStatementListPageAsync> list(RequestOptions requestOptions)
-
-
-
-