Package com.increase.api.services.async
Class AccountTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AccountTransferServiceAsync
public final class AccountTransferServiceAsyncImpl implements AccountTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AccountTransfer>create(AccountTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<AccountTransfer>retrieve(AccountTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<AccountTransferListPageAsync>list(AccountTransferListParams params, RequestOptions requestOptions)CompletableFuture<AccountTransfer>approve(AccountTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<AccountTransfer>cancel(AccountTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.AccountTransferServiceAsync
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AccountTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AccountTransfer> create(AccountTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AccountTransfer> retrieve(AccountTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountTransferListPageAsync> list(AccountTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<AccountTransfer> approve(AccountTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<AccountTransfer> cancel(AccountTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-