Package com.increase.api.services.async
Class AccountTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AccountTransferServiceAsync.WithRawResponse
public final class AccountTransferServiceAsyncImpl.WithRawResponseImpl implements AccountTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<AccountTransfer>>create(AccountTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AccountTransfer>>retrieve(AccountTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AccountTransferListPageAsync>>list(AccountTransferListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AccountTransfer>>approve(AccountTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AccountTransfer>>cancel(AccountTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.AccountTransferServiceAsync.WithRawResponse
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<AccountTransfer>> create(AccountTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<AccountTransfer>> retrieve(AccountTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<AccountTransferListPageAsync>> list(AccountTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<HttpResponseFor<AccountTransfer>> approve(AccountTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<HttpResponseFor<AccountTransfer>> cancel(AccountTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-