Package com.increase.api.services.async
Interface AchPrenotificationServiceAsync
-
- All Implemented Interfaces:
public interface AchPrenotificationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchPrenotificationServiceAsync.WithRawResponseA view of AchPrenotificationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AchPrenotificationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AchPrenotificationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AchPrenotification> create(AchPrenotificationCreateParams params)
Create an ACH Prenotification
-
create
abstract CompletableFuture<AchPrenotification> create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AchPrenotification> retrieve(String achPrenotificationId)
Retrieve an ACH Prenotification
-
retrieve
CompletableFuture<AchPrenotification> retrieve(String achPrenotificationId, AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AchPrenotification> retrieve(String achPrenotificationId, AchPrenotificationRetrieveParams params)
-
retrieve
abstract CompletableFuture<AchPrenotification> retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AchPrenotification> retrieve(AchPrenotificationRetrieveParams params)
-
retrieve
CompletableFuture<AchPrenotification> retrieve(String achPrenotificationId, RequestOptions requestOptions)
-
list
CompletableFuture<AchPrenotificationListPageAsync> list()
List ACH Prenotifications
-
list
abstract CompletableFuture<AchPrenotificationListPageAsync> list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AchPrenotificationListPageAsync> list(RequestOptions requestOptions)
-
-
-
-