Package com.increase.api.services.async
Class AchPrenotificationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AchPrenotificationServiceAsync
public final class AchPrenotificationServiceAsyncImpl implements AchPrenotificationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotificationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchPrenotificationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AchPrenotificationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AchPrenotification>create(AchPrenotificationCreateParams params, RequestOptions requestOptions)CompletableFuture<AchPrenotification>retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<AchPrenotificationListPageAsync>list(AchPrenotificationListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.AchPrenotificationServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AchPrenotificationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AchPrenotificationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AchPrenotification> create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AchPrenotification> retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AchPrenotificationListPageAsync> list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
-
-
-