Package com.increase.api.services.async
Class AchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AchTransferServiceAsync
public final class AchTransferServiceAsyncImpl implements AchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AchTransfer>create(AchTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>retrieve(AchTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<AchTransferListPageAsync>list(AchTransferListParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>approve(AchTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>cancel(AchTransferCancelParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<AchTransfer> create(AchTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AchTransfer> retrieve(AchTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AchTransferListPageAsync> list(AchTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<AchTransfer> approve(AchTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<AchTransfer> cancel(AchTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-