Package com.increase.api.services.async
Class BeneficialOwnerServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BeneficialOwnerServiceAsync
public final class BeneficialOwnerServiceAsyncImpl implements BeneficialOwnerServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBeneficialOwnerServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BeneficialOwnerServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BeneficialOwnerServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EntityBeneficialOwner>create(BeneficialOwnerCreateParams params, RequestOptions requestOptions)CompletableFuture<EntityBeneficialOwner>retrieve(BeneficialOwnerRetrieveParams params, RequestOptions requestOptions)CompletableFuture<EntityBeneficialOwner>update(BeneficialOwnerUpdateParams params, RequestOptions requestOptions)CompletableFuture<BeneficialOwnerListPageAsync>list(BeneficialOwnerListParams params, RequestOptions requestOptions)CompletableFuture<EntityBeneficialOwner>archive(BeneficialOwnerArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.BeneficialOwnerServiceAsync
archive, archive, archive, archive, archive, create, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
BeneficialOwnerServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BeneficialOwnerServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<EntityBeneficialOwner> create(BeneficialOwnerCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<EntityBeneficialOwner> retrieve(BeneficialOwnerRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EntityBeneficialOwner> update(BeneficialOwnerUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BeneficialOwnerListPageAsync> list(BeneficialOwnerListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<EntityBeneficialOwner> archive(BeneficialOwnerArchiveParams params, RequestOptions requestOptions)
-
-
-
-