Package com.increase.api.services.async
Class BeneficialOwnerServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BeneficialOwnerServiceAsync.WithRawResponse
public final class BeneficialOwnerServiceAsyncImpl.WithRawResponseImpl implements BeneficialOwnerServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BeneficialOwnerServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<EntityBeneficialOwner>>retrieve(BeneficialOwnerRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BeneficialOwnerListPageAsync>>list(BeneficialOwnerListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
BeneficialOwnerServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<EntityBeneficialOwner>> retrieve(BeneficialOwnerRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<BeneficialOwnerListPageAsync>> list(BeneficialOwnerListParams params, RequestOptions requestOptions)
-
-
-
-