Package com.increase.api.services.async
Interface BookkeepingAccountServiceAsync
-
- All Implemented Interfaces:
public interface BookkeepingAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingAccountServiceAsync.WithRawResponseA view of BookkeepingAccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract BookkeepingAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BookkeepingAccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<BookkeepingAccount> create(BookkeepingAccountCreateParams params)
Create a Bookkeeping Account
-
create
abstract CompletableFuture<BookkeepingAccount> create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<BookkeepingAccount> update(String bookkeepingAccountId, BookkeepingAccountUpdateParams params)
Update a Bookkeeping Account
-
update
CompletableFuture<BookkeepingAccount> update(String bookkeepingAccountId, BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<BookkeepingAccount> update(BookkeepingAccountUpdateParams params)
-
update
abstract CompletableFuture<BookkeepingAccount> update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingAccountListPageAsync> list()
List Bookkeeping Accounts
-
list
abstract CompletableFuture<BookkeepingAccountListPageAsync> list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingAccountListPageAsync> list(RequestOptions requestOptions)
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(String bookkeepingAccountId)
Retrieve a Bookkeeping Account Balance
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(String bookkeepingAccountId, BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(String bookkeepingAccountId, BookkeepingAccountBalanceParams params)
-
balance
abstract CompletableFuture<BookkeepingBalanceLookup> balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(BookkeepingAccountBalanceParams params)
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(String bookkeepingAccountId, RequestOptions requestOptions)
-
-
-
-