Package com.increase.api.services.async
Class BookkeepingAccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingAccountServiceAsync
public final class BookkeepingAccountServiceAsyncImpl implements BookkeepingAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingAccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingAccountServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<BookkeepingAccount>create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingAccount>update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingAccountListPageAsync>list(BookkeepingAccountListParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingBalanceLookup>balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.BookkeepingAccountServiceAsync
balance, balance, balance, balance, balance, create, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
BookkeepingAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BookkeepingAccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<BookkeepingAccount> create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<BookkeepingAccount> update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingAccountListPageAsync> list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
-
-
-