Package com.increase.api.services.async
Class BookkeepingAccountServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingAccountServiceAsync.WithRawResponse
public final class BookkeepingAccountServiceAsyncImpl.WithRawResponseImpl implements BookkeepingAccountServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BookkeepingAccountServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<BookkeepingAccount>>create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BookkeepingAccount>>update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BookkeepingAccountListPageAsync>>list(BookkeepingAccountListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BookkeepingBalanceLookup>>balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.BookkeepingAccountServiceAsync.WithRawResponse
balance, balance, balance, balance, balance, create, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
BookkeepingAccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<BookkeepingAccount>> create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<BookkeepingAccount>> update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<BookkeepingAccountListPageAsync>> list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
balance
CompletableFuture<HttpResponseFor<BookkeepingBalanceLookup>> balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
-
-
-