Package com.increase.api.services.async
Interface BookkeepingEntryServiceAsync
-
- All Implemented Interfaces:
public interface BookkeepingEntryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingEntryServiceAsync.WithRawResponseA view of BookkeepingEntryServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract BookkeepingEntryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BookkeepingEntryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<BookkeepingEntry> retrieve(String bookkeepingEntryId)
Retrieve a Bookkeeping Entry
-
retrieve
CompletableFuture<BookkeepingEntry> retrieve(String bookkeepingEntryId, BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BookkeepingEntry> retrieve(String bookkeepingEntryId, BookkeepingEntryRetrieveParams params)
-
retrieve
abstract CompletableFuture<BookkeepingEntry> retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BookkeepingEntry> retrieve(BookkeepingEntryRetrieveParams params)
-
retrieve
CompletableFuture<BookkeepingEntry> retrieve(String bookkeepingEntryId, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntryListPageAsync> list()
List Bookkeeping Entries
-
list
abstract CompletableFuture<BookkeepingEntryListPageAsync> list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntryListPageAsync> list(RequestOptions requestOptions)
-
-
-
-