Package com.increase.api.services.async
Class BookkeepingEntryServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingEntryServiceAsync.WithRawResponse
public final class BookkeepingEntryServiceAsyncImpl.WithRawResponseImpl implements BookkeepingEntryServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BookkeepingEntryServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<BookkeepingEntry>>retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BookkeepingEntryListPageAsync>>list(BookkeepingEntryListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.BookkeepingEntryServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
BookkeepingEntryServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<BookkeepingEntry>> retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<BookkeepingEntryListPageAsync>> list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
-
-
-