Package com.increase.api.services.async
Interface BookkeepingEntrySetServiceAsync
-
- All Implemented Interfaces:
public interface BookkeepingEntrySetServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingEntrySetServiceAsync.WithRawResponseA view of BookkeepingEntrySetServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract BookkeepingEntrySetServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BookkeepingEntrySetServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<BookkeepingEntrySet> create(BookkeepingEntrySetCreateParams params)
Create a Bookkeeping Entry Set
-
create
abstract CompletableFuture<BookkeepingEntrySet> create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(String bookkeepingEntrySetId)
Retrieve a Bookkeeping Entry Set
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(String bookkeepingEntrySetId, BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(String bookkeepingEntrySetId, BookkeepingEntrySetRetrieveParams params)
-
retrieve
abstract CompletableFuture<BookkeepingEntrySet> retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(BookkeepingEntrySetRetrieveParams params)
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(String bookkeepingEntrySetId, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntrySetListPageAsync> list()
List Bookkeeping Entry Sets
-
list
abstract CompletableFuture<BookkeepingEntrySetListPageAsync> list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntrySetListPageAsync> list(RequestOptions requestOptions)
-
-
-
-