Package com.increase.api.services.async
Class BookkeepingEntrySetServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingEntrySetServiceAsync
public final class BookkeepingEntrySetServiceAsyncImpl implements BookkeepingEntrySetServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingEntrySetServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<BookkeepingEntrySet>create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingEntrySet>retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingEntrySetListPageAsync>list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BookkeepingEntrySetServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<BookkeepingEntrySet> create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntrySetListPageAsync> list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
-
-
-
-