Package com.increase.api.services.async
Class BookkeepingEntrySetServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingEntrySetServiceAsync.WithRawResponse
public final class BookkeepingEntrySetServiceAsyncImpl.WithRawResponseImpl implements BookkeepingEntrySetServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BookkeepingEntrySetServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<BookkeepingEntrySet>>create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BookkeepingEntrySet>>retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<BookkeepingEntrySetListPageAsync>>list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.BookkeepingEntrySetServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
BookkeepingEntrySetServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<BookkeepingEntrySet>> create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<BookkeepingEntrySet>> retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<BookkeepingEntrySetListPageAsync>> list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
-
-
-
-