Package com.increase.api.services.async
Interface CardDetailServiceAsync
-
- All Implemented Interfaces:
public interface CardDetailServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardDetailServiceAsync.WithRawResponseA view of CardDetailServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CardDetailServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardDetailServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<CardDetails> update(String cardId, CardDetailUpdateParams params)
Update a Card's PIN
-
update
CompletableFuture<CardDetails> update(String cardId, CardDetailUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CardDetails> update(CardDetailUpdateParams params)
-
update
abstract CompletableFuture<CardDetails> update(CardDetailUpdateParams params, RequestOptions requestOptions)
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(String cardId)
Create an iframe URL for a Card to display the card details. More details about styling and usage can be found in the /documentation/embedded-card-component.
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(String cardId, CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(String cardId, CardDetailCreateDetailsIframeParams params)
-
createDetailsIframe
abstract CompletableFuture<CardIframeUrl> createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(CardDetailCreateDetailsIframeParams params)
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(String cardId, RequestOptions requestOptions)
-
details
CompletableFuture<CardDetails> details(String cardId)
Sensitive details for a Card include the primary account number, expiry, card verification code, and PIN.
-
details
CompletableFuture<CardDetails> details(String cardId, CardDetailDetailsParams params, RequestOptions requestOptions)
-
details
CompletableFuture<CardDetails> details(String cardId, CardDetailDetailsParams params)
-
details
abstract CompletableFuture<CardDetails> details(CardDetailDetailsParams params, RequestOptions requestOptions)
-
details
CompletableFuture<CardDetails> details(CardDetailDetailsParams params)
-
details
CompletableFuture<CardDetails> details(String cardId, RequestOptions requestOptions)
-
-
-
-