Package com.increase.api.services.async
Class CardDetailServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardDetailServiceAsync
public final class CardDetailServiceAsyncImpl implements CardDetailServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDetailServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardDetailServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardDetailServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardDetails>update(CardDetailUpdateParams params, RequestOptions requestOptions)CompletableFuture<CardIframeUrl>createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)CompletableFuture<CardDetails>details(CardDetailDetailsParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardDetailServiceAsync
createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, details, details, details, details, details, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardDetailServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardDetailServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<CardDetails> update(CardDetailUpdateParams params, RequestOptions requestOptions)
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)
-
details
CompletableFuture<CardDetails> details(CardDetailDetailsParams params, RequestOptions requestOptions)
-
-
-
-