Package com.increase.api.services.async
Class CardDetailServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardDetailServiceAsync.WithRawResponse
public final class CardDetailServiceAsyncImpl.WithRawResponseImpl implements CardDetailServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardDetailServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardDetails>>update(CardDetailUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardIframeUrl>>createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardDetails>>details(CardDetailDetailsParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardDetailServiceAsync.WithRawResponse
createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, details, details, details, details, details, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardDetailServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<HttpResponseFor<CardDetails>> update(CardDetailUpdateParams params, RequestOptions requestOptions)
-
createDetailsIframe
CompletableFuture<HttpResponseFor<CardIframeUrl>> createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)
-
details
CompletableFuture<HttpResponseFor<CardDetails>> details(CardDetailDetailsParams params, RequestOptions requestOptions)
-
-
-
-