Package com.increase.api.services.async
Class CardDisputeServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardDisputeServiceAsync
public final class CardDisputeServiceAsyncImpl implements CardDisputeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardDisputeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardDisputeServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardDispute>create(CardDisputeCreateParams params, RequestOptions requestOptions)CompletableFuture<CardDispute>retrieve(CardDisputeRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardDisputeListPageAsync>list(CardDisputeListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardDisputeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardDisputeServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardDispute> create(CardDisputeCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardDispute> retrieve(CardDisputeRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardDisputeListPageAsync> list(CardDisputeListParams params, RequestOptions requestOptions)
-
-
-
-