Package com.increase.api.services.async
Interface CardPaymentServiceAsync
-
- All Implemented Interfaces:
public interface CardPaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPaymentServiceAsync.WithRawResponseA view of CardPaymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CardPaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardPaymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CardPayment> retrieve(String cardPaymentId)
Retrieve a Card Payment
-
retrieve
CompletableFuture<CardPayment> retrieve(String cardPaymentId, CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardPayment> retrieve(String cardPaymentId, CardPaymentRetrieveParams params)
-
retrieve
abstract CompletableFuture<CardPayment> retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardPayment> retrieve(CardPaymentRetrieveParams params)
-
retrieve
CompletableFuture<CardPayment> retrieve(String cardPaymentId, RequestOptions requestOptions)
-
list
CompletableFuture<CardPaymentListPageAsync> list()
List Card Payments
-
list
abstract CompletableFuture<CardPaymentListPageAsync> list(CardPaymentListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPaymentListPageAsync> list(CardPaymentListParams params)
-
list
CompletableFuture<CardPaymentListPageAsync> list(RequestOptions requestOptions)
-
-
-
-