Package com.increase.api.services.async
Class CardPaymentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPaymentServiceAsync
public final class CardPaymentServiceAsyncImpl implements CardPaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPaymentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPaymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPaymentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardPaymentListPageAsync>list(CardPaymentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardPaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardPaymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CardPayment> retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPaymentListPageAsync> list(CardPaymentListParams params, RequestOptions requestOptions)
-
-
-
-