Package com.increase.api.services.async
Class CardPaymentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPaymentServiceAsync.WithRawResponse
public final class CardPaymentServiceAsyncImpl.WithRawResponseImpl implements CardPaymentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardPaymentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPayment>>retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPaymentListPageAsync>>list(CardPaymentListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardPaymentServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardPaymentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<CardPayment>> retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<CardPaymentListPageAsync>> list(CardPaymentListParams params, RequestOptions requestOptions)
-
-
-
-