Package com.increase.api.services.async
Interface CardPurchaseSupplementServiceAsync
-
- All Implemented Interfaces:
public interface CardPurchaseSupplementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPurchaseSupplementServiceAsync.WithRawResponseA view of CardPurchaseSupplementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CardPurchaseSupplementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardPurchaseSupplementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CardPurchaseSupplement> retrieve(String cardPurchaseSupplementId)
Retrieve a Card Purchase Supplement
-
retrieve
CompletableFuture<CardPurchaseSupplement> retrieve(String cardPurchaseSupplementId, CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardPurchaseSupplement> retrieve(String cardPurchaseSupplementId, CardPurchaseSupplementRetrieveParams params)
-
retrieve
abstract CompletableFuture<CardPurchaseSupplement> retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardPurchaseSupplement> retrieve(CardPurchaseSupplementRetrieveParams params)
-
retrieve
CompletableFuture<CardPurchaseSupplement> retrieve(String cardPurchaseSupplementId, RequestOptions requestOptions)
-
list
CompletableFuture<CardPurchaseSupplementListPageAsync> list()
List Card Purchase Supplements
-
list
abstract CompletableFuture<CardPurchaseSupplementListPageAsync> list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPurchaseSupplementListPageAsync> list(CardPurchaseSupplementListParams params)
-
list
CompletableFuture<CardPurchaseSupplementListPageAsync> list(RequestOptions requestOptions)
-
-
-
-