Package com.increase.api.services.async
Class CardPurchaseSupplementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPurchaseSupplementServiceAsync
public final class CardPurchaseSupplementServiceAsyncImpl implements CardPurchaseSupplementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPurchaseSupplementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CardPurchaseSupplement>retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardPurchaseSupplementListPageAsync>list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardPurchaseSupplementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<CardPurchaseSupplement> retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPurchaseSupplementListPageAsync> list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)
-
-
-
-