Package com.increase.api.services.async
Class CardPurchaseSupplementServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPurchaseSupplementServiceAsync.WithRawResponse
public final class CardPurchaseSupplementServiceAsyncImpl.WithRawResponseImpl implements CardPurchaseSupplementServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardPurchaseSupplementServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPurchaseSupplement>>retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPurchaseSupplementListPageAsync>>list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardPurchaseSupplementServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardPurchaseSupplementServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<CardPurchaseSupplement>> retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<CardPurchaseSupplementListPageAsync>> list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)
-
-
-
-