Package com.increase.api.services.async
Class CardPushTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPushTransferServiceAsync
public final class CardPushTransferServiceAsyncImpl implements CardPushTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPushTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPushTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPushTransfer>create(CardPushTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<CardPushTransfer>retrieve(CardPushTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardPushTransferListPageAsync>list(CardPushTransferListParams params, RequestOptions requestOptions)CompletableFuture<CardPushTransfer>approve(CardPushTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<CardPushTransfer>cancel(CardPushTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardPushTransferServiceAsync
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardPushTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardPushTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPushTransfer> create(CardPushTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CardPushTransfer> retrieve(CardPushTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPushTransferListPageAsync> list(CardPushTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<CardPushTransfer> approve(CardPushTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<CardPushTransfer> cancel(CardPushTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-