Package com.increase.api.services.async
Class CardPushTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPushTransferServiceAsync.WithRawResponse
public final class CardPushTransferServiceAsyncImpl.WithRawResponseImpl implements CardPushTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardPushTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPushTransfer>>create(CardPushTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPushTransfer>>retrieve(CardPushTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPushTransferListPageAsync>>list(CardPushTransferListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPushTransfer>>approve(CardPushTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPushTransfer>>cancel(CardPushTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardPushTransferServiceAsync.WithRawResponse
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardPushTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPushTransfer>> create(CardPushTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<CardPushTransfer>> retrieve(CardPushTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<CardPushTransferListPageAsync>> list(CardPushTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<HttpResponseFor<CardPushTransfer>> approve(CardPushTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<HttpResponseFor<CardPushTransfer>> cancel(CardPushTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-