Package com.increase.api.services.async
Class CardTokenServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardTokenServiceAsync
public final class CardTokenServiceAsyncImpl implements CardTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardTokenServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardToken>retrieve(CardTokenRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardTokenListPageAsync>list(CardTokenListParams params, RequestOptions requestOptions)CompletableFuture<CardTokenCapabilities>capabilities(CardTokenCapabilitiesParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardTokenServiceAsync
capabilities, capabilities, capabilities, capabilities, capabilities, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<CardToken> retrieve(CardTokenRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardTokenListPageAsync> list(CardTokenListParams params, RequestOptions requestOptions)
-
capabilities
CompletableFuture<CardTokenCapabilities> capabilities(CardTokenCapabilitiesParams params, RequestOptions requestOptions)
-
-
-
-