Package com.increase.api.services.async
Class CheckTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CheckTransferServiceAsync
public final class CheckTransferServiceAsyncImpl implements CheckTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CheckTransfer>create(CheckTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CheckTransferListPageAsync>list(CheckTransferListParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>approve(CheckTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>cancel(CheckTransferCancelParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CheckTransferServiceAsync
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, stopPayment, stopPayment, stopPayment, stopPayment, stopPayment -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CheckTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CheckTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CheckTransfer> create(CheckTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CheckTransfer> retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CheckTransferListPageAsync> list(CheckTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<CheckTransfer> approve(CheckTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<CheckTransfer> cancel(CheckTransferCancelParams params, RequestOptions requestOptions)
-
stopPayment
CompletableFuture<CheckTransfer> stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)
-
-
-
-