Package com.increase.api.services.async
Class CheckTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CheckTransferServiceAsync.WithRawResponse
public final class CheckTransferServiceAsyncImpl.WithRawResponseImpl implements CheckTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CheckTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CheckTransfer>>create(CheckTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CheckTransfer>>retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CheckTransferListPageAsync>>list(CheckTransferListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CheckTransfer>>approve(CheckTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CheckTransfer>>cancel(CheckTransferCancelParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CheckTransfer>>stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CheckTransferServiceAsync.WithRawResponse
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, stopPayment, stopPayment, stopPayment, stopPayment, stopPayment -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CheckTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CheckTransfer>> create(CheckTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<CheckTransfer>> retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<CheckTransferListPageAsync>> list(CheckTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<HttpResponseFor<CheckTransfer>> approve(CheckTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<HttpResponseFor<CheckTransfer>> cancel(CheckTransferCancelParams params, RequestOptions requestOptions)
-
stopPayment
CompletableFuture<HttpResponseFor<CheckTransfer>> stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)
-
-
-
-