Package com.increase.api.services.async
Class DigitalCardProfileServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.DigitalCardProfileServiceAsync
public final class DigitalCardProfileServiceAsyncImpl implements DigitalCardProfileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalCardProfileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalCardProfileServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DigitalCardProfile>create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)CompletableFuture<DigitalCardProfile>retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)CompletableFuture<DigitalCardProfileListPageAsync>list(DigitalCardProfileListParams params, RequestOptions requestOptions)CompletableFuture<DigitalCardProfile>archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)CompletableFuture<DigitalCardProfile>clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.DigitalCardProfileServiceAsync
archive, archive, archive, archive, archive, clone, clone, clone, clone, clone, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DigitalCardProfileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigitalCardProfileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<DigitalCardProfile> create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<DigitalCardProfile> retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalCardProfileListPageAsync> list(DigitalCardProfileListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<DigitalCardProfile> archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)
-
clone
CompletableFuture<DigitalCardProfile> clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)
-
-
-
-