Package com.increase.api.services.async
Interface DigitalWalletTokenServiceAsync
-
- All Implemented Interfaces:
public interface DigitalWalletTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalWalletTokenServiceAsync.WithRawResponseA view of DigitalWalletTokenServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DigitalWalletTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DigitalWalletTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(String digitalWalletTokenId)
Retrieve a Digital Wallet Token
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(String digitalWalletTokenId, DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(String digitalWalletTokenId, DigitalWalletTokenRetrieveParams params)
-
retrieve
abstract CompletableFuture<DigitalWalletToken> retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(DigitalWalletTokenRetrieveParams params)
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(String digitalWalletTokenId, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalWalletTokenListPageAsync> list()
List Digital Wallet Tokens
-
list
abstract CompletableFuture<DigitalWalletTokenListPageAsync> list(DigitalWalletTokenListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalWalletTokenListPageAsync> list(RequestOptions requestOptions)
-
-
-
-