Package com.increase.api.services.async
Class DigitalWalletTokenServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.DigitalWalletTokenServiceAsync
public final class DigitalWalletTokenServiceAsyncImpl implements DigitalWalletTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalWalletTokenServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DigitalWalletToken>retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)CompletableFuture<DigitalWalletTokenListPageAsync>list(DigitalWalletTokenListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DigitalWalletTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigitalWalletTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalWalletTokenListPageAsync> list(DigitalWalletTokenListParams params, RequestOptions requestOptions)
-
-
-
-