Interface EntityServiceAsync
-
- All Implemented Interfaces:
public interface EntityServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityServiceAsync.WithRawResponseA view of EntityServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EntityServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<Entity>create(EntityCreateParams params, RequestOptions requestOptions)Create an Entity abstract CompletableFuture<Entity>create(EntityCreateParams params)Create an Entity abstract CompletableFuture<Entity>retrieve(EntityRetrieveParams params, RequestOptions requestOptions)Retrieve an Entity abstract CompletableFuture<Entity>retrieve(EntityRetrieveParams params)Retrieve an Entity abstract CompletableFuture<EntityListPageAsync>list(EntityListParams params, RequestOptions requestOptions)List Entities abstract CompletableFuture<EntityListPageAsync>list(EntityListParams params)List Entities abstract CompletableFuture<EntityListPageAsync>list()List Entities CompletableFuture<EntityListPageAsync>list(RequestOptions requestOptions)List Entities abstract CompletableFuture<Entity>archive(EntityArchiveParams params, RequestOptions requestOptions)Archive an Entity abstract CompletableFuture<Entity>archive(EntityArchiveParams params)Archive an Entity abstract CompletableFuture<Entity>archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)Archive a beneficial owner for a corporate Entity abstract CompletableFuture<Entity>archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params)Archive a beneficial owner for a corporate Entity abstract CompletableFuture<Entity>confirm(EntityConfirmParams params, RequestOptions requestOptions)Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. abstract CompletableFuture<Entity>confirm(EntityConfirmParams params)Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. abstract CompletableFuture<Entity>createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)Create a beneficial owner for a corporate Entity abstract CompletableFuture<Entity>createBeneficialOwner(EntityCreateBeneficialOwnerParams params)Create a beneficial owner for a corporate Entity abstract CompletableFuture<Entity>updateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)Update a Natural Person or Corporation's address abstract CompletableFuture<Entity>updateAddress(EntityUpdateAddressParams params)Update a Natural Person or Corporation's address abstract CompletableFuture<Entity>updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)Update the address for a beneficial owner belonging to a corporate Entity abstract CompletableFuture<Entity>updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params)Update the address for a beneficial owner belonging to a corporate Entity abstract CompletableFuture<Entity>updateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)Update the industry code for a corporate Entity abstract CompletableFuture<Entity>updateIndustryCode(EntityUpdateIndustryCodeParams params)Update the industry code for a corporate Entity -
-
Method Detail
-
withRawResponse
abstract EntityServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract CompletableFuture<Entity> create(EntityCreateParams params, RequestOptions requestOptions)
Create an Entity
-
create
abstract CompletableFuture<Entity> create(EntityCreateParams params)
Create an Entity
-
retrieve
abstract CompletableFuture<Entity> retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
Retrieve an Entity
-
retrieve
abstract CompletableFuture<Entity> retrieve(EntityRetrieveParams params)
Retrieve an Entity
-
list
abstract CompletableFuture<EntityListPageAsync> list(EntityListParams params, RequestOptions requestOptions)
List Entities
-
list
abstract CompletableFuture<EntityListPageAsync> list(EntityListParams params)
List Entities
-
list
abstract CompletableFuture<EntityListPageAsync> list()
List Entities
-
list
CompletableFuture<EntityListPageAsync> list(RequestOptions requestOptions)
List Entities
-
archive
abstract CompletableFuture<Entity> archive(EntityArchiveParams params, RequestOptions requestOptions)
Archive an Entity
-
archive
abstract CompletableFuture<Entity> archive(EntityArchiveParams params)
Archive an Entity
-
archiveBeneficialOwner
abstract CompletableFuture<Entity> archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)
Archive a beneficial owner for a corporate Entity
-
archiveBeneficialOwner
abstract CompletableFuture<Entity> archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params)
Archive a beneficial owner for a corporate Entity
-
confirm
abstract CompletableFuture<Entity> confirm(EntityConfirmParams params, RequestOptions requestOptions)
Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. After making any required updates, call this endpoint to record that your user confirmed their details.
-
confirm
abstract CompletableFuture<Entity> confirm(EntityConfirmParams params)
Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. After making any required updates, call this endpoint to record that your user confirmed their details.
-
createBeneficialOwner
abstract CompletableFuture<Entity> createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)
Create a beneficial owner for a corporate Entity
-
createBeneficialOwner
abstract CompletableFuture<Entity> createBeneficialOwner(EntityCreateBeneficialOwnerParams params)
Create a beneficial owner for a corporate Entity
-
updateAddress
abstract CompletableFuture<Entity> updateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)
Update a Natural Person or Corporation's address
-
updateAddress
abstract CompletableFuture<Entity> updateAddress(EntityUpdateAddressParams params)
Update a Natural Person or Corporation's address
-
updateBeneficialOwnerAddress
abstract CompletableFuture<Entity> updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)
Update the address for a beneficial owner belonging to a corporate Entity
-
updateBeneficialOwnerAddress
abstract CompletableFuture<Entity> updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params)
Update the address for a beneficial owner belonging to a corporate Entity
-
updateIndustryCode
abstract CompletableFuture<Entity> updateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)
Update the industry code for a corporate Entity
-
updateIndustryCode
abstract CompletableFuture<Entity> updateIndustryCode(EntityUpdateIndustryCodeParams params)
Update the industry code for a corporate Entity
-
-
-
-