Package com.increase.api.services.async
Class EntityServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EntityServiceAsync
public final class EntityServiceAsyncImpl implements EntityServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EntityServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EntityServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Entity>create(EntityCreateParams params, RequestOptions requestOptions)CompletableFuture<Entity>retrieve(EntityRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Entity>update(EntityUpdateParams params, RequestOptions requestOptions)CompletableFuture<EntityListPageAsync>list(EntityListParams params, RequestOptions requestOptions)CompletableFuture<Entity>archive(EntityArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.EntityServiceAsync
archive, archive, archive, archive, archive, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EntityServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EntityServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Entity> create(EntityCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Entity> retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Entity> update(EntityUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EntityListPageAsync> list(EntityListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<Entity> archive(EntityArchiveParams params, RequestOptions requestOptions)
-
-
-
-