Package com.increase.api.services.async
Class EntityServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EntityServiceAsync.WithRawResponse
public final class EntityServiceAsyncImpl.WithRawResponseImpl implements EntityServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EntityServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Entity>>create(EntityCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Entity>>retrieve(EntityRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Entity>>update(EntityUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EntityListPageAsync>>list(EntityListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Entity>>archive(EntityArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.EntityServiceAsync.WithRawResponse
archive, archive, archive, archive, archive, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
EntityServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Entity>> create(EntityCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<Entity>> retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<Entity>> update(EntityUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<EntityListPageAsync>> list(EntityListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<HttpResponseFor<Entity>> archive(EntityArchiveParams params, RequestOptions requestOptions)
-
-
-
-