Package com.increase.api.services.async
Interface EventServiceAsync
-
- All Implemented Interfaces:
public interface EventServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventServiceAsync.WithRawResponseA view of EventServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract EventServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EventServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Event> retrieve(String eventId)
Retrieve an Event
-
retrieve
CompletableFuture<Event> retrieve(String eventId, EventRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Event> retrieve(String eventId, EventRetrieveParams params)
-
retrieve
abstract CompletableFuture<Event> retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Event> retrieve(EventRetrieveParams params)
-
retrieve
CompletableFuture<Event> retrieve(String eventId, RequestOptions requestOptions)
-
list
CompletableFuture<EventListPageAsync> list()
List Events
-
list
abstract CompletableFuture<EventListPageAsync> list(EventListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventListPageAsync> list(EventListParams params)
-
list
CompletableFuture<EventListPageAsync> list(RequestOptions requestOptions)
-
unwrap
abstract UnwrapWebhookEvent unwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
abstract UnwrapWebhookEvent unwrap(UnwrapWebhookParams unwrapParams)
Unwraps a webhook event from its JSON representation.
-
-
-
-