Package com.increase.api.services.async
Class EventServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EventServiceAsync
public final class EventServiceAsyncImpl implements EventServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Event>retrieve(EventRetrieveParams params, RequestOptions requestOptions)CompletableFuture<EventListPageAsync>list(EventListParams params, RequestOptions requestOptions)UnwrapWebhookEventunwrap(String body)Unwraps a webhook event from its JSON representation. UnwrapWebhookEventunwrap(UnwrapWebhookParams unwrapParams)Unwraps a webhook event from its JSON representation. -
-
Method Detail
-
withRawResponse
EventServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Event> retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventListPageAsync> list(EventListParams params, RequestOptions requestOptions)
-
unwrap
UnwrapWebhookEvent unwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
UnwrapWebhookEvent unwrap(UnwrapWebhookParams unwrapParams)
Unwraps a webhook event from its JSON representation.
-
-
-
-