Package com.increase.api.services.async
Class EventServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EventServiceAsync.WithRawResponse
public final class EventServiceAsyncImpl.WithRawResponseImpl implements EventServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Event>>retrieve(EventRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EventListPageAsync>>list(EventListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EventServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<Event>> retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<EventListPageAsync>> list(EventListParams params, RequestOptions requestOptions)
-
-
-
-