Package com.increase.api.services.async
Interface EventSubscriptionServiceAsync
-
- All Implemented Interfaces:
public interface EventSubscriptionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventSubscriptionServiceAsync.WithRawResponseA view of EventSubscriptionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract EventSubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<EventSubscription> create(EventSubscriptionCreateParams params)
Create an Event Subscription
-
create
abstract CompletableFuture<EventSubscription> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<EventSubscription> retrieve(EventSubscriptionRetrieveParams params)
Retrieve an Event Subscription
-
retrieve
abstract CompletableFuture<EventSubscription> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EventSubscription> update(EventSubscriptionUpdateParams params)
Update an Event Subscription
-
update
abstract CompletableFuture<EventSubscription> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventSubscriptionListPageAsync> list()
List Event Subscriptions
-
list
abstract CompletableFuture<EventSubscriptionListPageAsync> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventSubscriptionListPageAsync> list(RequestOptions requestOptions)
-
-
-
-