Package com.increase.api.services.async
Class EventSubscriptionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EventSubscriptionServiceAsync
public final class EventSubscriptionServiceAsyncImpl implements EventSubscriptionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventSubscriptionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventSubscriptionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EventSubscription>create(EventSubscriptionCreateParams params, RequestOptions requestOptions)CompletableFuture<EventSubscription>retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<EventSubscription>update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)CompletableFuture<EventSubscriptionListPageAsync>list(EventSubscriptionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.EventSubscriptionServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EventSubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventSubscriptionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<EventSubscription> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<EventSubscription> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EventSubscription> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventSubscriptionListPageAsync> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
-
-
-