Package com.increase.api.services.async
Class EventSubscriptionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EventSubscriptionServiceAsync.WithRawResponse
public final class EventSubscriptionServiceAsyncImpl.WithRawResponseImpl implements EventSubscriptionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventSubscriptionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<EventSubscription>>create(EventSubscriptionCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EventSubscription>>retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EventSubscription>>update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<EventSubscriptionListPageAsync>>list(EventSubscriptionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.EventSubscriptionServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
EventSubscriptionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<EventSubscription>> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<EventSubscription>> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<EventSubscription>> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<EventSubscriptionListPageAsync>> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
-
-
-