Package com.increase.api.services.async
Interface ExportServiceAsync
-
- All Implemented Interfaces:
public interface ExportServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportServiceAsync.WithRawResponseA view of ExportServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ExportServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExportServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Export> create(ExportCreateParams params)
Create an Export
-
create
abstract CompletableFuture<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Export> retrieve(String exportId)
Retrieve an Export
-
retrieve
CompletableFuture<Export> retrieve(String exportId, ExportRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Export> retrieve(String exportId, ExportRetrieveParams params)
-
retrieve
abstract CompletableFuture<Export> retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Export> retrieve(ExportRetrieveParams params)
-
retrieve
CompletableFuture<Export> retrieve(String exportId, RequestOptions requestOptions)
-
list
CompletableFuture<ExportListPageAsync> list()
List Exports
-
list
abstract CompletableFuture<ExportListPageAsync> list(ExportListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExportListPageAsync> list(ExportListParams params)
-
list
CompletableFuture<ExportListPageAsync> list(RequestOptions requestOptions)
-
-
-
-