Package com.increase.api.services.async
Class ExportServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ExportServiceAsync
public final class ExportServiceAsyncImpl implements ExportServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ExportServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ExportServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Export>create(ExportCreateParams params, RequestOptions requestOptions)CompletableFuture<Export>retrieve(ExportRetrieveParams params, RequestOptions requestOptions)CompletableFuture<ExportListPageAsync>list(ExportListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ExportServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExportServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Export> retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExportListPageAsync> list(ExportListParams params, RequestOptions requestOptions)
-
-
-
-