Package com.increase.api.services.async
Interface ExternalAccountServiceAsync
-
- All Implemented Interfaces:
public interface ExternalAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExternalAccountServiceAsync.WithRawResponseA view of ExternalAccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ExternalAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExternalAccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ExternalAccount> create(ExternalAccountCreateParams params)
Create an External Account
-
create
abstract CompletableFuture<ExternalAccount> create(ExternalAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ExternalAccount> retrieve(String externalAccountId)
Retrieve an External Account
-
retrieve
CompletableFuture<ExternalAccount> retrieve(String externalAccountId, ExternalAccountRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ExternalAccount> retrieve(String externalAccountId, ExternalAccountRetrieveParams params)
-
retrieve
abstract CompletableFuture<ExternalAccount> retrieve(ExternalAccountRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ExternalAccount> retrieve(ExternalAccountRetrieveParams params)
-
retrieve
CompletableFuture<ExternalAccount> retrieve(String externalAccountId, RequestOptions requestOptions)
-
update
CompletableFuture<ExternalAccount> update(String externalAccountId)
Update an External Account
-
update
CompletableFuture<ExternalAccount> update(String externalAccountId, ExternalAccountUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ExternalAccount> update(String externalAccountId, ExternalAccountUpdateParams params)
-
update
abstract CompletableFuture<ExternalAccount> update(ExternalAccountUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ExternalAccount> update(ExternalAccountUpdateParams params)
-
update
CompletableFuture<ExternalAccount> update(String externalAccountId, RequestOptions requestOptions)
-
list
CompletableFuture<ExternalAccountListPageAsync> list()
List External Accounts
-
list
abstract CompletableFuture<ExternalAccountListPageAsync> list(ExternalAccountListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExternalAccountListPageAsync> list(RequestOptions requestOptions)
-
-
-
-