Package com.increase.api.services.async
Class ExternalAccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ExternalAccountServiceAsync
public final class ExternalAccountServiceAsyncImpl implements ExternalAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ExternalAccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ExternalAccountServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<ExternalAccount>create(ExternalAccountCreateParams params, RequestOptions requestOptions)CompletableFuture<ExternalAccount>retrieve(ExternalAccountRetrieveParams params, RequestOptions requestOptions)CompletableFuture<ExternalAccount>update(ExternalAccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<ExternalAccountListPageAsync>list(ExternalAccountListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.ExternalAccountServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ExternalAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ExternalAccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<ExternalAccount> create(ExternalAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<ExternalAccount> retrieve(ExternalAccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<ExternalAccount> update(ExternalAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExternalAccountListPageAsync> list(ExternalAccountListParams params, RequestOptions requestOptions)
-
-
-
-