Package com.increase.api.services.async
Class ExternalAccountServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ExternalAccountServiceAsync.WithRawResponse
public final class ExternalAccountServiceAsyncImpl.WithRawResponseImpl implements ExternalAccountServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ExternalAccountServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<ExternalAccount>>create(ExternalAccountCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<ExternalAccount>>retrieve(ExternalAccountRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<ExternalAccount>>update(ExternalAccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<ExternalAccountListPageAsync>>list(ExternalAccountListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.ExternalAccountServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ExternalAccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<ExternalAccount>> create(ExternalAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<ExternalAccount>> retrieve(ExternalAccountRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<ExternalAccount>> update(ExternalAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<ExternalAccountListPageAsync>> list(ExternalAccountListParams params, RequestOptions requestOptions)
-
-
-
-