Package com.increase.api.services.async
Interface FileLinkServiceAsync
-
- All Implemented Interfaces:
public interface FileLinkServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileLinkServiceAsync.WithRawResponseA view of FileLinkServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FileLinkServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FileLinkServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<FileLink>create(FileLinkCreateParams params)Create a File Link abstract CompletableFuture<FileLink>create(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FileLinkServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FileLinkServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<FileLink> create(FileLinkCreateParams params)
Create a File Link
-
create
abstract CompletableFuture<FileLink> create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-