Package com.increase.api.services.async
Interface FileLinkServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface FileLinkServiceAsync.WithRawResponseA view of FileLinkServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract FileLinkServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<FileLink>>create(FileLinkCreateParams params)Returns a raw HTTP response for post /file_links, but is otherwise the same as FileLinkServiceAsync.create.abstract CompletableFuture<HttpResponseFor<FileLink>>create(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract FileLinkServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<FileLink>> create(FileLinkCreateParams params)
Returns a raw HTTP response for
post /file_links, but is otherwise the same as FileLinkServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<FileLink>> create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-