Package com.increase.api.services.async
Class FileLinkServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.FileLinkServiceAsync
public final class FileLinkServiceAsyncImpl implements FileLinkServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileLinkServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileLinkServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileLinkServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<FileLink>create(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileLinkServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileLinkServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<FileLink> create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-