Package com.increase.api.services.async
Class FileLinkServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.FileLinkServiceAsync.WithRawResponse
public final class FileLinkServiceAsyncImpl.WithRawResponseImpl implements FileLinkServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FileLinkServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<FileLink>>create(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
FileLinkServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<FileLink>> create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-