Interface FileServiceAsync
-
- All Implemented Interfaces:
public interface FileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileServiceAsync.WithRawResponseA view of FileServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<File> create(FileCreateParams params)
To upload a file to Increase, you'll need to send a request of Content-Type
multipart/form-data. The request should contain the file you would like to upload, as well as the parameters for creating a file.
-
create
abstract CompletableFuture<File> create(FileCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<File> retrieve(String fileId)
Retrieve a File
-
retrieve
CompletableFuture<File> retrieve(String fileId, FileRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<File> retrieve(String fileId, FileRetrieveParams params)
-
retrieve
abstract CompletableFuture<File> retrieve(FileRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<File> retrieve(FileRetrieveParams params)
-
retrieve
CompletableFuture<File> retrieve(String fileId, RequestOptions requestOptions)
-
list
CompletableFuture<FileListPageAsync> list()
List Files
-
list
abstract CompletableFuture<FileListPageAsync> list(FileListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FileListPageAsync> list(FileListParams params)
-
list
CompletableFuture<FileListPageAsync> list(RequestOptions requestOptions)
-
contents
CompletableFuture<HttpResponse> contents(String fileId)
Download the contents of a File. Responds with a 307 redirect whose
Locationheader points at a short-lived, pre-signed URL. Our /documentation/software-development-kits follow the redirect and return the File's contents; if you call the API directly, follow the redirect to download it. The pre-signed URL serves the File with aContent-Typematching itsmimeand aContent-Dispositionheader set to itsfilename. It expires in 10 minutes. To share a File with someone who doesn't have access to your API key, create a File Link.
-
contents
CompletableFuture<HttpResponse> contents(String fileId, FileContentsParams params, RequestOptions requestOptions)
-
contents
CompletableFuture<HttpResponse> contents(String fileId, FileContentsParams params)
-
contents
abstract CompletableFuture<HttpResponse> contents(FileContentsParams params, RequestOptions requestOptions)
-
contents
CompletableFuture<HttpResponse> contents(FileContentsParams params)
-
contents
CompletableFuture<HttpResponse> contents(String fileId, RequestOptions requestOptions)
-
-
-
-