Package com.increase.api.services.async
Interface GroupServiceAsync
-
- All Implemented Interfaces:
public interface GroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupServiceAsync.WithRawResponseA view of GroupServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract GroupServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Group>retrieve()Returns details for the currently authenticated Group. abstract CompletableFuture<Group>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Group>retrieve(GroupRetrieveParams params)CompletableFuture<Group>retrieve(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract GroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract GroupServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Group> retrieve()
Returns details for the currently authenticated Group.
-
retrieve
abstract CompletableFuture<Group> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Group> retrieve(GroupRetrieveParams params)
-
retrieve
CompletableFuture<Group> retrieve(RequestOptions requestOptions)
-
-
-
-