Package com.increase.api.services.async
Class GroupServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.GroupServiceAsync
public final class GroupServiceAsyncImpl implements GroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Group>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
GroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Group> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
-
-
-