Package com.increase.api.services.async
Class GroupServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.GroupServiceAsync.WithRawResponse
public final class GroupServiceAsyncImpl.WithRawResponseImpl implements GroupServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description GroupServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Group>>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
GroupServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<Group>> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
-
-
-