Package com.increase.api.services.async
Interface InboundAchTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundAchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundAchTransferServiceAsync.WithRawResponseA view of InboundAchTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundAchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundAchTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(String inboundAchTransferId)
Retrieve an Inbound ACH Transfer
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(String inboundAchTransferId, InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(String inboundAchTransferId, InboundAchTransferRetrieveParams params)
-
retrieve
abstract CompletableFuture<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params)
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(String inboundAchTransferId, RequestOptions requestOptions)
-
list
CompletableFuture<InboundAchTransferListPageAsync> list()
List Inbound ACH Transfers
-
list
abstract CompletableFuture<InboundAchTransferListPageAsync> list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundAchTransferListPageAsync> list(RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(String inboundAchTransferId)
Create a notification of change for an Inbound ACH Transfer
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(String inboundAchTransferId, InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(String inboundAchTransferId, InboundAchTransferCreateNotificationOfChangeParams params)
-
createNotificationOfChange
abstract CompletableFuture<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params)
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(String inboundAchTransferId, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundAchTransfer> decline(String inboundAchTransferId)
Decline an Inbound ACH Transfer
-
decline
CompletableFuture<InboundAchTransfer> decline(String inboundAchTransferId, InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundAchTransfer> decline(String inboundAchTransferId, InboundAchTransferDeclineParams params)
-
decline
abstract CompletableFuture<InboundAchTransfer> decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundAchTransfer> decline(InboundAchTransferDeclineParams params)
-
decline
CompletableFuture<InboundAchTransfer> decline(String inboundAchTransferId, RequestOptions requestOptions)
-
transferReturn
CompletableFuture<InboundAchTransfer> transferReturn(String inboundAchTransferId, InboundAchTransferTransferReturnParams params)
Return an Inbound ACH Transfer
-
transferReturn
CompletableFuture<InboundAchTransfer> transferReturn(String inboundAchTransferId, InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
transferReturn
CompletableFuture<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params)
-
transferReturn
abstract CompletableFuture<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-