Package com.increase.api.services.async
Class InboundAchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundAchTransferServiceAsync
public final class InboundAchTransferServiceAsyncImpl implements InboundAchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundAchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundAchTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundAchTransfer>retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundAchTransferListPageAsync>list(InboundAchTransferListParams params, RequestOptions requestOptions)CompletableFuture<InboundAchTransfer>createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)CompletableFuture<InboundAchTransfer>decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)CompletableFuture<InboundAchTransfer>transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundAchTransferServiceAsync
createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, transferReturn, transferReturn, transferReturn -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundAchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundAchTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundAchTransferListPageAsync> list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundAchTransfer> decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
transferReturn
CompletableFuture<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-