Package com.increase.api.services.async
Class InboundAchTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundAchTransferServiceAsync.WithRawResponse
public final class InboundAchTransferServiceAsyncImpl.WithRawResponseImpl implements InboundAchTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundAchTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundAchTransfer>>retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundAchTransferListPageAsync>>list(InboundAchTransferListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundAchTransfer>>createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundAchTransfer>>decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundAchTransfer>>transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundAchTransferServiceAsync.WithRawResponse
createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, transferReturn, transferReturn, transferReturn -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundAchTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundAchTransfer>> retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundAchTransferListPageAsync>> list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<HttpResponseFor<InboundAchTransfer>> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<HttpResponseFor<InboundAchTransfer>> decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
transferReturn
CompletableFuture<HttpResponseFor<InboundAchTransfer>> transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-