Package com.increase.api.services.async
Interface InboundCheckDepositServiceAsync
-
- All Implemented Interfaces:
public interface InboundCheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundCheckDepositServiceAsync.WithRawResponseA view of InboundCheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundCheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundCheckDepositServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(String inboundCheckDepositId)
Retrieve an Inbound Check Deposit
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(String inboundCheckDepositId, InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(String inboundCheckDepositId, InboundCheckDepositRetrieveParams params)
-
retrieve
abstract CompletableFuture<InboundCheckDeposit> retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(InboundCheckDepositRetrieveParams params)
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(String inboundCheckDepositId, RequestOptions requestOptions)
-
list
CompletableFuture<InboundCheckDepositListPageAsync> list()
List Inbound Check Deposits
-
list
abstract CompletableFuture<InboundCheckDepositListPageAsync> list(InboundCheckDepositListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundCheckDepositListPageAsync> list(RequestOptions requestOptions)
-
decline
CompletableFuture<InboundCheckDeposit> decline(String inboundCheckDepositId)
Decline an Inbound Check Deposit
-
decline
CompletableFuture<InboundCheckDeposit> decline(String inboundCheckDepositId, InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundCheckDeposit> decline(String inboundCheckDepositId, InboundCheckDepositDeclineParams params)
-
decline
abstract CompletableFuture<InboundCheckDeposit> decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundCheckDeposit> decline(InboundCheckDepositDeclineParams params)
-
decline
CompletableFuture<InboundCheckDeposit> decline(String inboundCheckDepositId, RequestOptions requestOptions)
-
return_
CompletableFuture<InboundCheckDeposit> return_(String inboundCheckDepositId, InboundCheckDepositReturnParams params)
Return an Inbound Check Deposit
-
return_
CompletableFuture<InboundCheckDeposit> return_(String inboundCheckDepositId, InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<InboundCheckDeposit> return_(InboundCheckDepositReturnParams params)
-
return_
abstract CompletableFuture<InboundCheckDeposit> return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
-
-
-