Package com.increase.api.services.async
Class InboundCheckDepositServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundCheckDepositServiceAsync
public final class InboundCheckDepositServiceAsyncImpl implements InboundCheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundCheckDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundCheckDepositServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundCheckDeposit>retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundCheckDepositListPageAsync>list(InboundCheckDepositListParams params, RequestOptions requestOptions)CompletableFuture<InboundCheckDeposit>decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)CompletableFuture<InboundCheckDeposit>return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundCheckDepositServiceAsync
decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, return_, return_, return_ -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundCheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundCheckDepositServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundCheckDepositListPageAsync> list(InboundCheckDepositListParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundCheckDeposit> decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<InboundCheckDeposit> return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
-
-
-