Package com.increase.api.services.async
Class InboundCheckDepositServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundCheckDepositServiceAsync.WithRawResponse
public final class InboundCheckDepositServiceAsyncImpl.WithRawResponseImpl implements InboundCheckDepositServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundCheckDepositServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundCheckDeposit>>retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundCheckDepositListPageAsync>>list(InboundCheckDepositListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundCheckDeposit>>decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundCheckDeposit>>return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundCheckDepositServiceAsync.WithRawResponse
decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, return_, return_, return_ -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundCheckDepositServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundCheckDeposit>> retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundCheckDepositListPageAsync>> list(InboundCheckDepositListParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<HttpResponseFor<InboundCheckDeposit>> decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<HttpResponseFor<InboundCheckDeposit>> return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
-
-
-