Package com.increase.api.services.async
Class InboundFednowTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundFednowTransferServiceAsync.WithRawResponse
public final class InboundFednowTransferServiceAsyncImpl.WithRawResponseImpl implements InboundFednowTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundFednowTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundFednowTransfer>>retrieve(InboundFednowTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundFednowTransferListPageAsync>>list(InboundFednowTransferListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundFednowTransferServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundFednowTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundFednowTransfer>> retrieve(InboundFednowTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundFednowTransferListPageAsync>> list(InboundFednowTransferListParams params, RequestOptions requestOptions)
-
-
-
-