Package com.increase.api.services.async
Interface InboundMailItemServiceAsync
-
- All Implemented Interfaces:
public interface InboundMailItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundMailItemServiceAsync.WithRawResponseA view of InboundMailItemServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundMailItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundMailItem>retrieve(InboundMailItemRetrieveParams params)Retrieve an Inbound Mail Item abstract CompletableFuture<InboundMailItem>retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundMailItemListPageAsync>list()List Inbound Mail Items abstract CompletableFuture<InboundMailItemListPageAsync>list(InboundMailItemListParams params, RequestOptions requestOptions)CompletableFuture<InboundMailItemListPageAsync>list(InboundMailItemListParams params)CompletableFuture<InboundMailItemListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundMailItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundMailItem> retrieve(InboundMailItemRetrieveParams params)
Retrieve an Inbound Mail Item
-
retrieve
abstract CompletableFuture<InboundMailItem> retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundMailItemListPageAsync> list()
List Inbound Mail Items
-
list
abstract CompletableFuture<InboundMailItemListPageAsync> list(InboundMailItemListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundMailItemListPageAsync> list(RequestOptions requestOptions)
-
-
-
-