Package com.increase.api.services.async
Class InboundMailItemServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundMailItemServiceAsync
public final class InboundMailItemServiceAsyncImpl implements InboundMailItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundMailItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundMailItemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundMailItem>retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundMailItemListPageAsync>list(InboundMailItemListParams params, RequestOptions requestOptions)CompletableFuture<InboundMailItem>action(InboundMailItemActionParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundMailItemServiceAsync
action, action, action, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundMailItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundMailItemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundMailItem> retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundMailItemListPageAsync> list(InboundMailItemListParams params, RequestOptions requestOptions)
-
action
CompletableFuture<InboundMailItem> action(InboundMailItemActionParams params, RequestOptions requestOptions)
-
-
-
-