Package com.increase.api.services.async
Class InboundMailItemServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundMailItemServiceAsync.WithRawResponse
public final class InboundMailItemServiceAsyncImpl.WithRawResponseImpl implements InboundMailItemServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundMailItemServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundMailItem>>retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundMailItemListPageAsync>>list(InboundMailItemListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundMailItem>>action(InboundMailItemActionParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundMailItemServiceAsync.WithRawResponse
action, action, action, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundMailItemServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundMailItem>> retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundMailItemListPageAsync>> list(InboundMailItemListParams params, RequestOptions requestOptions)
-
action
CompletableFuture<HttpResponseFor<InboundMailItem>> action(InboundMailItemActionParams params, RequestOptions requestOptions)
-
-
-
-