Package com.increase.api.services.async
Interface InboundRealTimePaymentsTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundRealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundRealTimePaymentsTransferServiceAsync.WithRawResponseA view of InboundRealTimePaymentsTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundRealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundRealTimePaymentsTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(String inboundRealTimePaymentsTransferId)
Retrieve an Inbound Real-Time Payments Transfer
-
retrieve
CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(String inboundRealTimePaymentsTransferId, InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(String inboundRealTimePaymentsTransferId, InboundRealTimePaymentsTransferRetrieveParams params)
-
retrieve
abstract CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(InboundRealTimePaymentsTransferRetrieveParams params)
-
retrieve
CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(String inboundRealTimePaymentsTransferId, RequestOptions requestOptions)
-
list
CompletableFuture<InboundRealTimePaymentsTransferListPageAsync> list()
List Inbound Real-Time Payments Transfers
-
list
abstract CompletableFuture<InboundRealTimePaymentsTransferListPageAsync> list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundRealTimePaymentsTransferListPageAsync> list(InboundRealTimePaymentsTransferListParams params)
-
list
CompletableFuture<InboundRealTimePaymentsTransferListPageAsync> list(RequestOptions requestOptions)
-
-
-
-