Package com.increase.api.services.async
Class InboundRealTimePaymentsTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundRealTimePaymentsTransferServiceAsync
public final class InboundRealTimePaymentsTransferServiceAsyncImpl implements InboundRealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundRealTimePaymentsTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundRealTimePaymentsTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundRealTimePaymentsTransfer>retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundRealTimePaymentsTransferListPageAsync>list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundRealTimePaymentsTransferServiceAsync
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundRealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundRealTimePaymentsTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundRealTimePaymentsTransfer> retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundRealTimePaymentsTransferListPageAsync> list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
-
-
-