Package com.increase.api.services.async
Class InboundRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundRealTimePaymentsTransferServiceAsync.WithRawResponse
public final class InboundRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl implements InboundRealTimePaymentsTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundRealTimePaymentsTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>>retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransferListPageAsync>>list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundRealTimePaymentsTransferServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundRealTimePaymentsTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>> retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransferListPageAsync>> list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
-
-
-