Package com.increase.api.services.async
Interface InboundWireDrawdownRequestServiceAsync
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireDrawdownRequestServiceAsync.WithRawResponseA view of InboundWireDrawdownRequestServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundWireDrawdownRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundWireDrawdownRequestServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(String inboundWireDrawdownRequestId)
Retrieve an Inbound Wire Drawdown Request
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(String inboundWireDrawdownRequestId, InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(String inboundWireDrawdownRequestId, InboundWireDrawdownRequestRetrieveParams params)
-
retrieve
abstract CompletableFuture<InboundWireDrawdownRequest> retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(InboundWireDrawdownRequestRetrieveParams params)
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(String inboundWireDrawdownRequestId, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list()
List Inbound Wire Drawdown Requests
-
list
abstract CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(InboundWireDrawdownRequestListParams params)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(RequestOptions requestOptions)
-
-
-
-