Package com.increase.api.services.async
Class InboundWireDrawdownRequestServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundWireDrawdownRequestServiceAsync
public final class InboundWireDrawdownRequestServiceAsyncImpl implements InboundWireDrawdownRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundWireDrawdownRequest>retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundWireDrawdownRequestListPageAsync>list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundWireDrawdownRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
-
-
-