Package com.increase.api.services.async
Class InboundWireDrawdownRequestServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundWireDrawdownRequestServiceAsync.WithRawResponse
public final class InboundWireDrawdownRequestServiceAsyncImpl.WithRawResponseImpl implements InboundWireDrawdownRequestServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>>retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundWireDrawdownRequestListPageAsync>>list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundWireDrawdownRequestServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundWireDrawdownRequestServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>> retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundWireDrawdownRequestListPageAsync>> list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
-
-
-