Package com.increase.api.services.async
Class InboundWireTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundWireTransferServiceAsync
public final class InboundWireTransferServiceAsyncImpl implements InboundWireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundWireTransfer>retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundWireTransferListPageAsync>list(InboundWireTransferListParams params, RequestOptions requestOptions)CompletableFuture<InboundWireTransfer>reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundWireTransferServiceAsync
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, reverse, reverse, reverse -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundWireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundWireTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<InboundWireTransfer> retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireTransferListPageAsync> list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
reverse
CompletableFuture<InboundWireTransfer> reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
-
-
-