Package com.increase.api.services.async
Class InboundWireTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundWireTransferServiceAsync.WithRawResponse
public final class InboundWireTransferServiceAsyncImpl.WithRawResponseImpl implements InboundWireTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundWireTransfer>>retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundWireTransferListPageAsync>>list(InboundWireTransferListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundWireTransfer>>reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.InboundWireTransferServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, reverse, reverse, reverse -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundWireTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<InboundWireTransfer>> retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<InboundWireTransferListPageAsync>> list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
reverse
CompletableFuture<HttpResponseFor<InboundWireTransfer>> reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
-
-
-