Package com.increase.api.services.async
Interface IntrafiAccountEnrollmentServiceAsync
-
- All Implemented Interfaces:
public interface IntrafiAccountEnrollmentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIntrafiAccountEnrollmentServiceAsync.WithRawResponseA view of IntrafiAccountEnrollmentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract IntrafiAccountEnrollmentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract IntrafiAccountEnrollmentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<IntrafiAccountEnrollment> create(IntrafiAccountEnrollmentCreateParams params)
Enroll an account in the IntraFi deposit sweep network
-
create
abstract CompletableFuture<IntrafiAccountEnrollment> create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiAccountEnrollment> retrieve(String intrafiAccountEnrollmentId)
Get an IntraFi Account Enrollment
-
retrieve
CompletableFuture<IntrafiAccountEnrollment> retrieve(String intrafiAccountEnrollmentId, IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiAccountEnrollment> retrieve(String intrafiAccountEnrollmentId, IntrafiAccountEnrollmentRetrieveParams params)
-
retrieve
abstract CompletableFuture<IntrafiAccountEnrollment> retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiAccountEnrollment> retrieve(IntrafiAccountEnrollmentRetrieveParams params)
-
retrieve
CompletableFuture<IntrafiAccountEnrollment> retrieve(String intrafiAccountEnrollmentId, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiAccountEnrollmentListPageAsync> list()
List IntraFi Account Enrollments
-
list
abstract CompletableFuture<IntrafiAccountEnrollmentListPageAsync> list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiAccountEnrollmentListPageAsync> list(IntrafiAccountEnrollmentListParams params)
-
list
CompletableFuture<IntrafiAccountEnrollmentListPageAsync> list(RequestOptions requestOptions)
-
unenroll
CompletableFuture<IntrafiAccountEnrollment> unenroll(String intrafiAccountEnrollmentId)
Unenroll an account from IntraFi
-
unenroll
CompletableFuture<IntrafiAccountEnrollment> unenroll(String intrafiAccountEnrollmentId, IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)
-
unenroll
CompletableFuture<IntrafiAccountEnrollment> unenroll(String intrafiAccountEnrollmentId, IntrafiAccountEnrollmentUnenrollParams params)
-
unenroll
abstract CompletableFuture<IntrafiAccountEnrollment> unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)
-
unenroll
CompletableFuture<IntrafiAccountEnrollment> unenroll(IntrafiAccountEnrollmentUnenrollParams params)
-
unenroll
CompletableFuture<IntrafiAccountEnrollment> unenroll(String intrafiAccountEnrollmentId, RequestOptions requestOptions)
-
-
-
-