Package com.increase.api.services.async
Class IntrafiAccountEnrollmentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiAccountEnrollmentServiceAsync
public final class IntrafiAccountEnrollmentServiceAsyncImpl implements IntrafiAccountEnrollmentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiAccountEnrollmentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiAccountEnrollmentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiAccountEnrollmentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<IntrafiAccountEnrollment>create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)CompletableFuture<IntrafiAccountEnrollment>retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<IntrafiAccountEnrollmentListPageAsync>list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)CompletableFuture<IntrafiAccountEnrollment>unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.IntrafiAccountEnrollmentServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, unenroll, unenroll, unenroll, unenroll, unenroll -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
IntrafiAccountEnrollmentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IntrafiAccountEnrollmentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<IntrafiAccountEnrollment> create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiAccountEnrollment> retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiAccountEnrollmentListPageAsync> list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)
-
unenroll
CompletableFuture<IntrafiAccountEnrollment> unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)
-
-
-
-