Package com.increase.api.services.async
Class IntrafiAccountEnrollmentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiAccountEnrollmentServiceAsync.WithRawResponse
public final class IntrafiAccountEnrollmentServiceAsyncImpl.WithRawResponseImpl implements IntrafiAccountEnrollmentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description IntrafiAccountEnrollmentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<IntrafiAccountEnrollment>>create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<IntrafiAccountEnrollment>>retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<IntrafiAccountEnrollmentListPageAsync>>list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<IntrafiAccountEnrollment>>unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.IntrafiAccountEnrollmentServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, unenroll, unenroll, unenroll, unenroll, unenroll -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
IntrafiAccountEnrollmentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<IntrafiAccountEnrollment>> create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<IntrafiAccountEnrollment>> retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<IntrafiAccountEnrollmentListPageAsync>> list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)
-
unenroll
CompletableFuture<HttpResponseFor<IntrafiAccountEnrollment>> unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)
-
-
-
-