Package com.increase.api.services.async
Interface IntrafiBalanceServiceAsync
-
- All Implemented Interfaces:
public interface IntrafiBalanceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIntrafiBalanceServiceAsync.WithRawResponseA view of IntrafiBalanceServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract IntrafiBalanceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<IntrafiBalance>intrafiBalance(IntrafiBalanceIntrafiBalanceParams params)Returns the IntraFi balance for the given account. abstract CompletableFuture<IntrafiBalance>intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract IntrafiBalanceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
intrafiBalance
CompletableFuture<IntrafiBalance> intrafiBalance(IntrafiBalanceIntrafiBalanceParams params)
Returns the IntraFi balance for the given account. IntraFi may sweep funds to multiple banks. This endpoint will include both the total balance and the amount swept to each institution.
-
intrafiBalance
abstract CompletableFuture<IntrafiBalance> intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)
-
-
-
-