Package com.increase.api.services.async
Class IntrafiBalanceServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiBalanceServiceAsync
public final class IntrafiBalanceServiceAsyncImpl implements IntrafiBalanceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiBalanceServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiBalanceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiBalanceServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<IntrafiBalance>intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.IntrafiBalanceServiceAsync
intrafiBalance, intrafiBalance, intrafiBalance, intrafiBalance, intrafiBalance -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
IntrafiBalanceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IntrafiBalanceServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
intrafiBalance
CompletableFuture<IntrafiBalance> intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)
-
-
-
-