Package com.increase.api.services.async
Interface IntrafiExclusionServiceAsync
-
- All Implemented Interfaces:
public interface IntrafiExclusionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIntrafiExclusionServiceAsync.WithRawResponseA view of IntrafiExclusionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract IntrafiExclusionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract IntrafiExclusionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<IntrafiExclusion> create(IntrafiExclusionCreateParams params)
Create an IntraFi Exclusion
-
create
abstract CompletableFuture<IntrafiExclusion> create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(String intrafiExclusionId)
Get an IntraFi Exclusion
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(String intrafiExclusionId, IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(String intrafiExclusionId, IntrafiExclusionRetrieveParams params)
-
retrieve
abstract CompletableFuture<IntrafiExclusion> retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(IntrafiExclusionRetrieveParams params)
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(String intrafiExclusionId, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiExclusionListPageAsync> list()
List IntraFi Exclusions
-
list
abstract CompletableFuture<IntrafiExclusionListPageAsync> list(IntrafiExclusionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiExclusionListPageAsync> list(RequestOptions requestOptions)
-
archive
CompletableFuture<IntrafiExclusion> archive(String intrafiExclusionId)
Archive an IntraFi Exclusion
-
archive
CompletableFuture<IntrafiExclusion> archive(String intrafiExclusionId, IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<IntrafiExclusion> archive(String intrafiExclusionId, IntrafiExclusionArchiveParams params)
-
archive
abstract CompletableFuture<IntrafiExclusion> archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<IntrafiExclusion> archive(IntrafiExclusionArchiveParams params)
-
archive
CompletableFuture<IntrafiExclusion> archive(String intrafiExclusionId, RequestOptions requestOptions)
-
-
-
-