Package com.increase.api.services.async
Class IntrafiExclusionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiExclusionServiceAsync
public final class IntrafiExclusionServiceAsyncImpl implements IntrafiExclusionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiExclusionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiExclusionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiExclusionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<IntrafiExclusion>create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)CompletableFuture<IntrafiExclusion>retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<IntrafiExclusionListPageAsync>list(IntrafiExclusionListParams params, RequestOptions requestOptions)CompletableFuture<IntrafiExclusion>archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.IntrafiExclusionServiceAsync
archive, archive, archive, archive, archive, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
IntrafiExclusionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IntrafiExclusionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<IntrafiExclusion> create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiExclusionListPageAsync> list(IntrafiExclusionListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<IntrafiExclusion> archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
-
-
-
-