Package com.increase.api.services.async
Class IntrafiExclusionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiExclusionServiceAsync.WithRawResponse
public final class IntrafiExclusionServiceAsyncImpl.WithRawResponseImpl implements IntrafiExclusionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description IntrafiExclusionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<IntrafiExclusion>>create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<IntrafiExclusion>>retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<IntrafiExclusionListPageAsync>>list(IntrafiExclusionListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<IntrafiExclusion>>archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.IntrafiExclusionServiceAsync.WithRawResponse
archive, archive, archive, archive, archive, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
IntrafiExclusionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<IntrafiExclusion>> create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<IntrafiExclusion>> retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<IntrafiExclusionListPageAsync>> list(IntrafiExclusionListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<HttpResponseFor<IntrafiExclusion>> archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
-
-
-
-