Package com.increase.api.services.async
Class LockboxAddressServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.LockboxAddressServiceAsync
public final class LockboxAddressServiceAsyncImpl implements LockboxAddressServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxAddressServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LockboxAddressServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LockboxAddressServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<LockboxAddress>create(LockboxAddressCreateParams params, RequestOptions requestOptions)CompletableFuture<LockboxAddress>retrieve(LockboxAddressRetrieveParams params, RequestOptions requestOptions)CompletableFuture<LockboxAddress>update(LockboxAddressUpdateParams params, RequestOptions requestOptions)CompletableFuture<LockboxAddressListPageAsync>list(LockboxAddressListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.LockboxAddressServiceAsync
create, create, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
LockboxAddressServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LockboxAddressServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<LockboxAddress> create(LockboxAddressCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<LockboxAddress> retrieve(LockboxAddressRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<LockboxAddress> update(LockboxAddressUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<LockboxAddressListPageAsync> list(LockboxAddressListParams params, RequestOptions requestOptions)
-
-
-
-