Package com.increase.api.services.async
Interface LockboxRecipientServiceAsync
-
- All Implemented Interfaces:
public interface LockboxRecipientServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLockboxRecipientServiceAsync.WithRawResponseA view of LockboxRecipientServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract LockboxRecipientServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LockboxRecipientServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<LockboxRecipient> create(LockboxRecipientCreateParams params)
Create a Lockbox Recipient
-
create
abstract CompletableFuture<LockboxRecipient> create(LockboxRecipientCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<LockboxRecipient> retrieve(String lockboxRecipientId)
Retrieve a Lockbox Recipient
-
retrieve
CompletableFuture<LockboxRecipient> retrieve(String lockboxRecipientId, LockboxRecipientRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<LockboxRecipient> retrieve(String lockboxRecipientId, LockboxRecipientRetrieveParams params)
-
retrieve
abstract CompletableFuture<LockboxRecipient> retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<LockboxRecipient> retrieve(LockboxRecipientRetrieveParams params)
-
retrieve
CompletableFuture<LockboxRecipient> retrieve(String lockboxRecipientId, RequestOptions requestOptions)
-
update
CompletableFuture<LockboxRecipient> update(String lockboxRecipientId)
Update a Lockbox Recipient
-
update
CompletableFuture<LockboxRecipient> update(String lockboxRecipientId, LockboxRecipientUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<LockboxRecipient> update(String lockboxRecipientId, LockboxRecipientUpdateParams params)
-
update
abstract CompletableFuture<LockboxRecipient> update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<LockboxRecipient> update(LockboxRecipientUpdateParams params)
-
update
CompletableFuture<LockboxRecipient> update(String lockboxRecipientId, RequestOptions requestOptions)
-
list
CompletableFuture<LockboxRecipientListPageAsync> list()
List Lockbox Recipients
-
list
abstract CompletableFuture<LockboxRecipientListPageAsync> list(LockboxRecipientListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<LockboxRecipientListPageAsync> list(RequestOptions requestOptions)
-
-
-
-