Package com.increase.api.services.async
Class LockboxRecipientServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.LockboxRecipientServiceAsync
public final class LockboxRecipientServiceAsyncImpl implements LockboxRecipientServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LockboxRecipientServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LockboxRecipientServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<LockboxRecipient>create(LockboxRecipientCreateParams params, RequestOptions requestOptions)CompletableFuture<LockboxRecipient>retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)CompletableFuture<LockboxRecipient>update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)CompletableFuture<LockboxRecipientListPageAsync>list(LockboxRecipientListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.LockboxRecipientServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
LockboxRecipientServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LockboxRecipientServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<LockboxRecipient> create(LockboxRecipientCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<LockboxRecipient> retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<LockboxRecipient> update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<LockboxRecipientListPageAsync> list(LockboxRecipientListParams params, RequestOptions requestOptions)
-
-
-
-