Package com.increase.api.services.async
Class LockboxRecipientServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.LockboxRecipientServiceAsync.WithRawResponse
public final class LockboxRecipientServiceAsyncImpl.WithRawResponseImpl implements LockboxRecipientServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LockboxRecipientServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<LockboxRecipient>>create(LockboxRecipientCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<LockboxRecipient>>retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<LockboxRecipient>>update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<LockboxRecipientListPageAsync>>list(LockboxRecipientListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.LockboxRecipientServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
LockboxRecipientServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<LockboxRecipient>> create(LockboxRecipientCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<LockboxRecipient>> retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<LockboxRecipient>> update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<LockboxRecipientListPageAsync>> list(LockboxRecipientListParams params, RequestOptions requestOptions)
-
-
-
-