Package com.increase.api.services.async
Interface LockboxServiceAsync
-
- All Implemented Interfaces:
public interface LockboxServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLockboxServiceAsync.WithRawResponseA view of LockboxServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract LockboxServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LockboxServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Lockbox> create(LockboxCreateParams params)
Create a Lockbox
-
create
abstract CompletableFuture<Lockbox> create(LockboxCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Lockbox> retrieve(String lockboxId)
Retrieve a Lockbox
-
retrieve
CompletableFuture<Lockbox> retrieve(String lockboxId, LockboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Lockbox> retrieve(String lockboxId, LockboxRetrieveParams params)
-
retrieve
abstract CompletableFuture<Lockbox> retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Lockbox> retrieve(LockboxRetrieveParams params)
-
retrieve
CompletableFuture<Lockbox> retrieve(String lockboxId, RequestOptions requestOptions)
-
update
CompletableFuture<Lockbox> update(String lockboxId)
Update a Lockbox
-
update
CompletableFuture<Lockbox> update(String lockboxId, LockboxUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Lockbox> update(String lockboxId, LockboxUpdateParams params)
-
update
abstract CompletableFuture<Lockbox> update(LockboxUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Lockbox> update(LockboxUpdateParams params)
-
update
CompletableFuture<Lockbox> update(String lockboxId, RequestOptions requestOptions)
-
list
CompletableFuture<LockboxListPageAsync> list()
List Lockboxes
-
list
abstract CompletableFuture<LockboxListPageAsync> list(LockboxListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<LockboxListPageAsync> list(LockboxListParams params)
-
list
CompletableFuture<LockboxListPageAsync> list(RequestOptions requestOptions)
-
-
-
-