Package com.increase.api.services.async
Class LockboxServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.LockboxServiceAsync.WithRawResponse
public final class LockboxServiceAsyncImpl.WithRawResponseImpl implements LockboxServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LockboxServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Lockbox>>create(LockboxCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Lockbox>>retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Lockbox>>update(LockboxUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<LockboxListPageAsync>>list(LockboxListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.LockboxServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
LockboxServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Lockbox>> create(LockboxCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<Lockbox>> retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<Lockbox>> update(LockboxUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<LockboxListPageAsync>> list(LockboxListParams params, RequestOptions requestOptions)
-
-
-
-