Package com.increase.api.services.async
Interface OAuthApplicationServiceAsync
-
- All Implemented Interfaces:
public interface OAuthApplicationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthApplicationServiceAsync.WithRawResponseA view of OAuthApplicationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract OAuthApplicationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OAuthApplicationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<OAuthApplication> retrieve(String oauthApplicationId)
Retrieve an OAuth Application
-
retrieve
CompletableFuture<OAuthApplication> retrieve(String oauthApplicationId, OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<OAuthApplication> retrieve(String oauthApplicationId, OAuthApplicationRetrieveParams params)
-
retrieve
abstract CompletableFuture<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params)
-
retrieve
CompletableFuture<OAuthApplication> retrieve(String oauthApplicationId, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthApplicationListPageAsync> list()
List OAuth Applications
-
list
abstract CompletableFuture<OAuthApplicationListPageAsync> list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthApplicationListPageAsync> list(RequestOptions requestOptions)
-
-
-
-