Package com.increase.api.services.async
Class OAuthApplicationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.OAuthApplicationServiceAsync
public final class OAuthApplicationServiceAsyncImpl implements OAuthApplicationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OAuthApplicationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthApplicationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<OAuthApplication>retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<OAuthApplicationListPageAsync>list(OAuthApplicationListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
OAuthApplicationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OAuthApplicationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthApplicationListPageAsync> list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
-
-
-