Package com.increase.api.services.async
Class OAuthApplicationServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.OAuthApplicationServiceAsync.WithRawResponse
public final class OAuthApplicationServiceAsyncImpl.WithRawResponseImpl implements OAuthApplicationServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OAuthApplicationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<OAuthApplication>>retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<OAuthApplicationListPageAsync>>list(OAuthApplicationListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.OAuthApplicationServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
OAuthApplicationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<OAuthApplication>> retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<OAuthApplicationListPageAsync>> list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
-
-
-