Package com.increase.api.services.async
Interface OAuthConnectionServiceAsync
-
- All Implemented Interfaces:
public interface OAuthConnectionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthConnectionServiceAsync.WithRawResponseA view of OAuthConnectionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract OAuthConnectionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OAuthConnectionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<OAuthConnection> retrieve(String oauthConnectionId)
Retrieve an OAuth Connection
-
retrieve
CompletableFuture<OAuthConnection> retrieve(String oauthConnectionId, OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<OAuthConnection> retrieve(String oauthConnectionId, OAuthConnectionRetrieveParams params)
-
retrieve
abstract CompletableFuture<OAuthConnection> retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<OAuthConnection> retrieve(OAuthConnectionRetrieveParams params)
-
retrieve
CompletableFuture<OAuthConnection> retrieve(String oauthConnectionId, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthConnectionListPageAsync> list()
List OAuth Connections
-
list
abstract CompletableFuture<OAuthConnectionListPageAsync> list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthConnectionListPageAsync> list(RequestOptions requestOptions)
-
-
-
-