Package com.increase.api.services.async
Class OAuthConnectionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.OAuthConnectionServiceAsync
public final class OAuthConnectionServiceAsyncImpl implements OAuthConnectionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnectionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OAuthConnectionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthConnectionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<OAuthConnection>retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<OAuthConnectionListPageAsync>list(OAuthConnectionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
OAuthConnectionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OAuthConnectionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<OAuthConnection> retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthConnectionListPageAsync> list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
-
-
-