Package com.increase.api.services.async
Class OAuthConnectionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.OAuthConnectionServiceAsync.WithRawResponse
public final class OAuthConnectionServiceAsyncImpl.WithRawResponseImpl implements OAuthConnectionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OAuthConnectionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<OAuthConnection>>retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<OAuthConnectionListPageAsync>>list(OAuthConnectionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.OAuthConnectionServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
OAuthConnectionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<OAuthConnection>> retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<OAuthConnectionListPageAsync>> list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
-
-
-