Package com.increase.api.services.async
Interface OAuthTokenServiceAsync
-
- All Implemented Interfaces:
public interface OAuthTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthTokenServiceAsync.WithRawResponseA view of OAuthTokenServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract OAuthTokenServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<OAuthToken>create(OAuthTokenCreateParams params)Create an OAuth Token abstract CompletableFuture<OAuthToken>create(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OAuthTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<OAuthToken> create(OAuthTokenCreateParams params)
Create an OAuth Token
-
create
abstract CompletableFuture<OAuthToken> create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-