Package com.increase.api.services.async
Interface OAuthTokenServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface OAuthTokenServiceAsync.WithRawResponseA view of OAuthTokenServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract OAuthTokenServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<OAuthToken>>create(OAuthTokenCreateParams params)Returns a raw HTTP response for post /oauth/tokens, but is otherwise the same as OAuthTokenServiceAsync.create.abstract CompletableFuture<HttpResponseFor<OAuthToken>>create(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract OAuthTokenServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<OAuthToken>> create(OAuthTokenCreateParams params)
Returns a raw HTTP response for
post /oauth/tokens, but is otherwise the same as OAuthTokenServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<OAuthToken>> create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-