Package com.increase.api.services.async
Class OAuthTokenServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.OAuthTokenServiceAsync.WithRawResponse
public final class OAuthTokenServiceAsyncImpl.WithRawResponseImpl implements OAuthTokenServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OAuthTokenServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<OAuthToken>>create(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
OAuthTokenServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<OAuthToken>> create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-