Interface PendingTransactionServiceAsync
-
- All Implemented Interfaces:
public interface PendingTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePendingTransactionServiceAsync.WithRawResponseA view of PendingTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract PendingTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PendingTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<PendingTransaction> create(PendingTransactionCreateParams params)
Creates a pending transaction on an account. This can be useful to hold funds for an external payment or known future transaction outside of Increase (only negative amounts are supported). The resulting Pending Transaction will have a
categoryofuser_initiated_holdand can be released via the API to unlock the held funds.
-
create
abstract CompletableFuture<PendingTransaction> create(PendingTransactionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PendingTransaction> retrieve(String pendingTransactionId)
Retrieve a Pending Transaction
-
retrieve
CompletableFuture<PendingTransaction> retrieve(String pendingTransactionId, PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PendingTransaction> retrieve(String pendingTransactionId, PendingTransactionRetrieveParams params)
-
retrieve
abstract CompletableFuture<PendingTransaction> retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PendingTransaction> retrieve(PendingTransactionRetrieveParams params)
-
retrieve
CompletableFuture<PendingTransaction> retrieve(String pendingTransactionId, RequestOptions requestOptions)
-
list
CompletableFuture<PendingTransactionListPageAsync> list()
List Pending Transactions
-
list
abstract CompletableFuture<PendingTransactionListPageAsync> list(PendingTransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PendingTransactionListPageAsync> list(RequestOptions requestOptions)
-
release
CompletableFuture<PendingTransaction> release(String pendingTransactionId)
Release a Pending Transaction you had previously created. The Pending Transaction must have a
categoryofuser_initiated_holdand astatusofpending. This will unlock the held funds and mark the Pending Transaction as complete.
-
release
CompletableFuture<PendingTransaction> release(String pendingTransactionId, PendingTransactionReleaseParams params, RequestOptions requestOptions)
-
release
CompletableFuture<PendingTransaction> release(String pendingTransactionId, PendingTransactionReleaseParams params)
-
release
abstract CompletableFuture<PendingTransaction> release(PendingTransactionReleaseParams params, RequestOptions requestOptions)
-
release
CompletableFuture<PendingTransaction> release(PendingTransactionReleaseParams params)
-
release
CompletableFuture<PendingTransaction> release(String pendingTransactionId, RequestOptions requestOptions)
-
-
-
-