Package com.increase.api.services.async
Class PendingTransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.PendingTransactionServiceAsync
public final class PendingTransactionServiceAsyncImpl implements PendingTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PendingTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PendingTransactionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<PendingTransaction>create(PendingTransactionCreateParams params, RequestOptions requestOptions)CompletableFuture<PendingTransaction>retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<PendingTransactionListPageAsync>list(PendingTransactionListParams params, RequestOptions requestOptions)CompletableFuture<PendingTransaction>release(PendingTransactionReleaseParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.PendingTransactionServiceAsync
create, list, list, list, release, release, release, release, release, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PendingTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PendingTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<PendingTransaction> create(PendingTransactionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PendingTransaction> retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PendingTransactionListPageAsync> list(PendingTransactionListParams params, RequestOptions requestOptions)
-
release
CompletableFuture<PendingTransaction> release(PendingTransactionReleaseParams params, RequestOptions requestOptions)
-
-
-
-