Package com.increase.api.services.async
Class PendingTransactionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.PendingTransactionServiceAsync.WithRawResponse
public final class PendingTransactionServiceAsyncImpl.WithRawResponseImpl implements PendingTransactionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PendingTransactionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<PendingTransaction>>create(PendingTransactionCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PendingTransaction>>retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PendingTransactionListPageAsync>>list(PendingTransactionListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PendingTransaction>>release(PendingTransactionReleaseParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.PendingTransactionServiceAsync.WithRawResponse
create, list, list, list, release, release, release, release, release, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
PendingTransactionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<PendingTransaction>> create(PendingTransactionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<PendingTransaction>> retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<PendingTransactionListPageAsync>> list(PendingTransactionListParams params, RequestOptions requestOptions)
-
release
CompletableFuture<HttpResponseFor<PendingTransaction>> release(PendingTransactionReleaseParams params, RequestOptions requestOptions)
-
-
-
-