Package com.increase.api.services.async
Class PhysicalCardProfileServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.PhysicalCardProfileServiceAsync
public final class PhysicalCardProfileServiceAsyncImpl implements PhysicalCardProfileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardProfileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardProfileServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<PhysicalCardProfile>create(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCardProfile>retrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCardProfileListPageAsync>list(PhysicalCardProfileListParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCardProfile>archive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCardProfile>clone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.PhysicalCardProfileServiceAsync
archive, archive, archive, archive, archive, clone, clone, clone, clone, clone, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PhysicalCardProfileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PhysicalCardProfileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<PhysicalCardProfile> create(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PhysicalCardProfile> retrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PhysicalCardProfileListPageAsync> list(PhysicalCardProfileListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<PhysicalCardProfile> archive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)
-
clone
CompletableFuture<PhysicalCardProfile> clone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)
-
-
-
-