Package com.increase.api.services.async
Class PhysicalCardServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.PhysicalCardServiceAsync
public final class PhysicalCardServiceAsyncImpl implements PhysicalCardServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<PhysicalCard>create(PhysicalCardCreateParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCard>retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCard>update(PhysicalCardUpdateParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCardListPageAsync>list(PhysicalCardListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.PhysicalCardServiceAsync
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PhysicalCardServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PhysicalCardServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<PhysicalCard> create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<PhysicalCard> retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<PhysicalCard> update(PhysicalCardUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PhysicalCardListPageAsync> list(PhysicalCardListParams params, RequestOptions requestOptions)
-
-
-
-