Package com.increase.api.services.async
Class PhysicalCardServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.PhysicalCardServiceAsync.WithRawResponse
public final class PhysicalCardServiceAsyncImpl.WithRawResponseImpl implements PhysicalCardServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PhysicalCardServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<PhysicalCard>>create(PhysicalCardCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PhysicalCard>>retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PhysicalCard>>update(PhysicalCardUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PhysicalCardListPageAsync>>list(PhysicalCardListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.PhysicalCardServiceAsync.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
PhysicalCardServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<PhysicalCard>> create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<PhysicalCard>> retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<PhysicalCard>> update(PhysicalCardUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<PhysicalCardListPageAsync>> list(PhysicalCardListParams params, RequestOptions requestOptions)
-
-
-
-