Package com.increase.api.services.async
Interface ProgramServiceAsync
-
- All Implemented Interfaces:
public interface ProgramServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProgramServiceAsync.WithRawResponseA view of ProgramServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ProgramServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProgramServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Program> retrieve(String programId)
Retrieve a Program
-
retrieve
CompletableFuture<Program> retrieve(String programId, ProgramRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Program> retrieve(String programId, ProgramRetrieveParams params)
-
retrieve
abstract CompletableFuture<Program> retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Program> retrieve(ProgramRetrieveParams params)
-
retrieve
CompletableFuture<Program> retrieve(String programId, RequestOptions requestOptions)
-
list
CompletableFuture<ProgramListPageAsync> list()
List Programs
-
list
abstract CompletableFuture<ProgramListPageAsync> list(ProgramListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProgramListPageAsync> list(ProgramListParams params)
-
list
CompletableFuture<ProgramListPageAsync> list(RequestOptions requestOptions)
-
-
-
-