Package com.increase.api.services.async
Class ProgramServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ProgramServiceAsync
public final class ProgramServiceAsyncImpl implements ProgramServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProgramServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ProgramServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Program>retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)CompletableFuture<ProgramListPageAsync>list(ProgramListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ProgramServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProgramServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Program> retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProgramListPageAsync> list(ProgramListParams params, RequestOptions requestOptions)
-
-
-
-