Package com.increase.api.services.async
Class ProgramServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ProgramServiceAsync.WithRawResponse
public final class ProgramServiceAsyncImpl.WithRawResponseImpl implements ProgramServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ProgramServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Program>>retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<ProgramListPageAsync>>list(ProgramListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.ProgramServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ProgramServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<Program>> retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<ProgramListPageAsync>> list(ProgramListParams params, RequestOptions requestOptions)
-
-
-
-