Package com.increase.api.services.async
Class ProofOfAuthorizationRequestServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ProofOfAuthorizationRequestServiceAsync
public final class ProofOfAuthorizationRequestServiceAsyncImpl implements ProofOfAuthorizationRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProofOfAuthorizationRequestServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProofOfAuthorizationRequestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<ProofOfAuthorizationRequest>retrieve(ProofOfAuthorizationRequestRetrieveParams params, RequestOptions requestOptions)CompletableFuture<ProofOfAuthorizationRequestListPageAsync>list(ProofOfAuthorizationRequestListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ProofOfAuthorizationRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<ProofOfAuthorizationRequest> retrieve(ProofOfAuthorizationRequestRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProofOfAuthorizationRequestListPageAsync> list(ProofOfAuthorizationRequestListParams params, RequestOptions requestOptions)
-
-
-
-