Package com.increase.api.services.async
Interface RealTimeDecisionServiceAsync
-
- All Implemented Interfaces:
public interface RealTimeDecisionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRealTimeDecisionServiceAsync.WithRawResponseA view of RealTimeDecisionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract RealTimeDecisionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RealTimeDecisionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(String realTimeDecisionId)
Retrieve a Real-Time Decision
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(String realTimeDecisionId, RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(String realTimeDecisionId, RealTimeDecisionRetrieveParams params)
-
retrieve
abstract CompletableFuture<RealTimeDecision> retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(RealTimeDecisionRetrieveParams params)
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(String realTimeDecisionId, RequestOptions requestOptions)
-
action
CompletableFuture<RealTimeDecision> action(String realTimeDecisionId)
Action a Real-Time Decision
-
action
CompletableFuture<RealTimeDecision> action(String realTimeDecisionId, RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
action
CompletableFuture<RealTimeDecision> action(String realTimeDecisionId, RealTimeDecisionActionParams params)
-
action
abstract CompletableFuture<RealTimeDecision> action(RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
action
CompletableFuture<RealTimeDecision> action(RealTimeDecisionActionParams params)
-
action
CompletableFuture<RealTimeDecision> action(String realTimeDecisionId, RequestOptions requestOptions)
-
-
-
-