Package com.increase.api.services.async
Class RealTimeDecisionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RealTimeDecisionServiceAsync
public final class RealTimeDecisionServiceAsyncImpl implements RealTimeDecisionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimeDecisionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RealTimeDecisionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RealTimeDecision>retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<RealTimeDecision>action(RealTimeDecisionActionParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.RealTimeDecisionServiceAsync
action, action, action, action, action, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RealTimeDecisionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RealTimeDecisionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
action
CompletableFuture<RealTimeDecision> action(RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
-
-
-