Package com.increase.api.services.async
Class RealTimeDecisionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RealTimeDecisionServiceAsync.WithRawResponse
public final class RealTimeDecisionServiceAsyncImpl.WithRawResponseImpl implements RealTimeDecisionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RealTimeDecisionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RealTimeDecision>>retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RealTimeDecision>>action(RealTimeDecisionActionParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.RealTimeDecisionServiceAsync.WithRawResponse
action, action, action, action, action, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RealTimeDecisionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<RealTimeDecision>> retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
action
CompletableFuture<HttpResponseFor<RealTimeDecision>> action(RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
-
-
-