Package com.increase.api.services.async
Interface RealTimePaymentsTransferServiceAsync
-
- All Implemented Interfaces:
public interface RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRealTimePaymentsTransferServiceAsync.WithRawResponseA view of RealTimePaymentsTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<RealTimePaymentsTransfer> create(RealTimePaymentsTransferCreateParams params)
Create a Real-Time Payments Transfer
-
create
abstract CompletableFuture<RealTimePaymentsTransfer> create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<RealTimePaymentsTransfer> retrieve(RealTimePaymentsTransferRetrieveParams params)
Retrieve a Real-Time Payments Transfer
-
retrieve
abstract CompletableFuture<RealTimePaymentsTransfer> retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RealTimePaymentsTransferListPageAsync> list()
List Real-Time Payments Transfers
-
list
abstract CompletableFuture<RealTimePaymentsTransferListPageAsync> list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RealTimePaymentsTransferListPageAsync> list(RealTimePaymentsTransferListParams params)
-
list
CompletableFuture<RealTimePaymentsTransferListPageAsync> list(RequestOptions requestOptions)
-
-
-
-