Package com.increase.api.services.async
Class RealTimePaymentsTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RealTimePaymentsTransferServiceAsync
public final class RealTimePaymentsTransferServiceAsyncImpl implements RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.increase.api.services.async.RealTimePaymentsTransferServiceAsync
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RealTimePaymentsTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<RealTimePaymentsTransfer> create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<RealTimePaymentsTransfer> retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RealTimePaymentsTransferListPageAsync> list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<RealTimePaymentsTransfer> approve(RealTimePaymentsTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<RealTimePaymentsTransfer> cancel(RealTimePaymentsTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-