Package com.increase.api.services.async
Class RealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RealTimePaymentsTransferServiceAsync.WithRawResponse
public final class RealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl implements RealTimePaymentsTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RealTimePaymentsTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>>create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>>retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RealTimePaymentsTransferListPageAsync>>list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>>approve(RealTimePaymentsTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>>cancel(RealTimePaymentsTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.RealTimePaymentsTransferServiceAsync.WithRawResponse
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RealTimePaymentsTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>> create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>> retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<RealTimePaymentsTransferListPageAsync>> list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>> approve(RealTimePaymentsTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<HttpResponseFor<RealTimePaymentsTransfer>> cancel(RealTimePaymentsTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-