Package com.increase.api.services.async
Interface RoutingNumberServiceAsync
-
- All Implemented Interfaces:
public interface RoutingNumberServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRoutingNumberServiceAsync.WithRawResponseA view of RoutingNumberServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RoutingNumberServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract RoutingNumberServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RoutingNumberListPageAsync>list(RoutingNumberListParams params)You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. abstract CompletableFuture<RoutingNumberListPageAsync>list(RoutingNumberListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RoutingNumberServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RoutingNumberServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<RoutingNumberListPageAsync> list(RoutingNumberListParams params)
You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. Since routing numbers uniquely identify a bank, this will always return 0 or 1 entry. In Sandbox, only a few /documentation/sandbox-test-values#routing-numbers.
110000000is an example of a Sandbox routing number.
-
list
abstract CompletableFuture<RoutingNumberListPageAsync> list(RoutingNumberListParams params, RequestOptions requestOptions)
-
-
-
-