Package com.increase.api.services.async
Class RoutingNumberServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RoutingNumberServiceAsync
public final class RoutingNumberServiceAsyncImpl implements RoutingNumberServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RoutingNumberServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RoutingNumberServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RoutingNumberListPageAsync>list(RoutingNumberListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RoutingNumberServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RoutingNumberServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<RoutingNumberListPageAsync> list(RoutingNumberListParams params, RequestOptions requestOptions)
-
-
-
-