Package com.increase.api.services.async
Class RoutingNumberServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RoutingNumberServiceAsync.WithRawResponse
public final class RoutingNumberServiceAsyncImpl.WithRawResponseImpl implements RoutingNumberServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RoutingNumberServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RoutingNumberListPageAsync>>list(RoutingNumberListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
RoutingNumberServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<RoutingNumberListPageAsync>> list(RoutingNumberListParams params, RequestOptions requestOptions)
-
-
-
-