Package com.increase.api.services.async
Interface SimulationServiceAsync
-
- All Implemented Interfaces:
public interface SimulationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSimulationServiceAsync.WithRawResponseA view of SimulationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SimulationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SimulationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
interestPayments
abstract InterestPaymentServiceAsync interestPayments()
-
accountRevenuePayments
abstract AccountRevenuePaymentServiceAsync accountRevenuePayments()
-
cardAuthorizations
abstract CardAuthorizationServiceAsync cardAuthorizations()
-
cardBalanceInquiries
abstract CardBalanceInquiryServiceAsync cardBalanceInquiries()
-
cardAuthorizationExpirations
abstract CardAuthorizationExpirationServiceAsync cardAuthorizationExpirations()
-
cardSettlements
abstract CardSettlementServiceAsync cardSettlements()
-
cardReversals
abstract CardReversalServiceAsync cardReversals()
-
cardIncrements
abstract CardIncrementServiceAsync cardIncrements()
-
cardFuelConfirmations
abstract CardFuelConfirmationServiceAsync cardFuelConfirmations()
-
cardRefunds
abstract CardRefundServiceAsync cardRefunds()
-
cardAuthentications
abstract CardAuthenticationServiceAsync cardAuthentications()
-
cardPurchaseSupplements
abstract CardPurchaseSupplementServiceAsync cardPurchaseSupplements()
-
cardDisputes
abstract CardDisputeServiceAsync cardDisputes()
-
physicalCards
abstract PhysicalCardServiceAsync physicalCards()
-
digitalWalletTokenRequests
abstract DigitalWalletTokenRequestServiceAsync digitalWalletTokenRequests()
-
pendingTransactions
abstract PendingTransactionServiceAsync pendingTransactions()
-
achTransfers
abstract AchTransferServiceAsync achTransfers()
-
inboundAchTransfers
abstract InboundAchTransferServiceAsync inboundAchTransfers()
-
wireTransfers
abstract WireTransferServiceAsync wireTransfers()
-
inboundWireTransfers
abstract InboundWireTransferServiceAsync inboundWireTransfers()
-
wireDrawdownRequests
abstract WireDrawdownRequestServiceAsync wireDrawdownRequests()
-
inboundWireDrawdownRequests
abstract InboundWireDrawdownRequestServiceAsync inboundWireDrawdownRequests()
-
checkTransfers
abstract CheckTransferServiceAsync checkTransfers()
-
inboundCheckDeposits
abstract InboundCheckDepositServiceAsync inboundCheckDeposits()
-
realTimePaymentsTransfers
abstract RealTimePaymentsTransferServiceAsync realTimePaymentsTransfers()
-
inboundRealTimePaymentsTransfers
abstract InboundRealTimePaymentsTransferServiceAsync inboundRealTimePaymentsTransfers()
-
inboundFednowTransfers
abstract InboundFednowTransferServiceAsync inboundFednowTransfers()
-
checkDeposits
abstract CheckDepositServiceAsync checkDeposits()
-
inboundMailItems
abstract InboundMailItemServiceAsync inboundMailItems()
-
entities
abstract EntityServiceAsync entities()
-
entityOnboardingSessions
abstract EntityOnboardingSessionServiceAsync entityOnboardingSessions()
-
programs
abstract ProgramServiceAsync programs()
-
accountStatements
abstract AccountStatementServiceAsync accountStatements()
-
exports
abstract ExportServiceAsync exports()
-
cardTokens
abstract CardTokenServiceAsync cardTokens()
-
-
-
-