Package com.increase.api.services.async
Interface SupplementalDocumentServiceAsync
-
- All Implemented Interfaces:
public interface SupplementalDocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSupplementalDocumentServiceAsync.WithRawResponseA view of SupplementalDocumentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SupplementalDocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SupplementalDocumentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EntitySupplementalDocument>create(SupplementalDocumentCreateParams params)Create a supplemental document for an Entity abstract CompletableFuture<EntitySupplementalDocument>create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)CompletableFuture<SupplementalDocumentListPageAsync>list(SupplementalDocumentListParams params)List Entity Supplemental Document Submissions abstract CompletableFuture<SupplementalDocumentListPageAsync>list(SupplementalDocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SupplementalDocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SupplementalDocumentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<EntitySupplementalDocument> create(SupplementalDocumentCreateParams params)
Create a supplemental document for an Entity
-
create
abstract CompletableFuture<EntitySupplementalDocument> create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<SupplementalDocumentListPageAsync> list(SupplementalDocumentListParams params)
List Entity Supplemental Document Submissions
-
list
abstract CompletableFuture<SupplementalDocumentListPageAsync> list(SupplementalDocumentListParams params, RequestOptions requestOptions)
-
-
-
-