Package com.increase.api.services.async
Class SupplementalDocumentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.SupplementalDocumentServiceAsync
public final class SupplementalDocumentServiceAsyncImpl implements SupplementalDocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SupplementalDocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SupplementalDocumentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<EntitySupplementalDocument>create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)CompletableFuture<SupplementalDocumentListPageAsync>list(SupplementalDocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SupplementalDocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SupplementalDocumentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<EntitySupplementalDocument> create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<SupplementalDocumentListPageAsync> list(SupplementalDocumentListParams params, RequestOptions requestOptions)
-
-
-
-