Package com.increase.api.services.async
Class SupplementalDocumentServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.SupplementalDocumentServiceAsync.WithRawResponse
public final class SupplementalDocumentServiceAsyncImpl.WithRawResponseImpl implements SupplementalDocumentServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SupplementalDocumentServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<EntitySupplementalDocument>>create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<SupplementalDocumentListPageAsync>>list(SupplementalDocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
SupplementalDocumentServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<EntitySupplementalDocument>> create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<SupplementalDocumentListPageAsync>> list(SupplementalDocumentListParams params, RequestOptions requestOptions)
-
-
-
-