Package com.increase.api.services.async
Interface TransactionServiceAsync
-
- All Implemented Interfaces:
public interface TransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransactionServiceAsync.WithRawResponseA view of TransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract TransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Transaction>retrieve(TransactionRetrieveParams params)Retrieve a Transaction abstract CompletableFuture<Transaction>retrieve(TransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<TransactionListPageAsync>list()List Transactions abstract CompletableFuture<TransactionListPageAsync>list(TransactionListParams params, RequestOptions requestOptions)CompletableFuture<TransactionListPageAsync>list(TransactionListParams params)CompletableFuture<TransactionListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract TransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Transaction> retrieve(TransactionRetrieveParams params)
Retrieve a Transaction
-
retrieve
abstract CompletableFuture<Transaction> retrieve(TransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<TransactionListPageAsync> list()
List Transactions
-
list
abstract CompletableFuture<TransactionListPageAsync> list(TransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<TransactionListPageAsync> list(TransactionListParams params)
-
list
CompletableFuture<TransactionListPageAsync> list(RequestOptions requestOptions)
-
-
-
-