Package com.increase.api.services.async
Class TransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.TransactionServiceAsync
public final class TransactionServiceAsyncImpl implements TransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description TransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. TransactionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Transaction>retrieve(TransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<TransactionListPageAsync>list(TransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
TransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
TransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<Transaction> retrieve(TransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<TransactionListPageAsync> list(TransactionListParams params, RequestOptions requestOptions)
-
-
-
-