Package com.increase.api.services.async
Class TransactionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.TransactionServiceAsync.WithRawResponse
public final class TransactionServiceAsyncImpl.WithRawResponseImpl implements TransactionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description TransactionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Transaction>>retrieve(TransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<TransactionListPageAsync>>list(TransactionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.TransactionServiceAsync.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
TransactionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<Transaction>> retrieve(TransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<TransactionListPageAsync>> list(TransactionListParams params, RequestOptions requestOptions)
-
-
-
-