Package com.increase.api.services.async
Class WireTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.WireTransferServiceAsync
public final class WireTransferServiceAsyncImpl implements WireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WireTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<WireTransfer>create(WireTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<WireTransfer>retrieve(WireTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<WireTransferListPageAsync>list(WireTransferListParams params, RequestOptions requestOptions)CompletableFuture<WireTransfer>approve(WireTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<WireTransfer>cancel(WireTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.WireTransferServiceAsync
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WireTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<WireTransfer> create(WireTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<WireTransfer> retrieve(WireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<WireTransferListPageAsync> list(WireTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<WireTransfer> approve(WireTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<WireTransfer> cancel(WireTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-