Interface AccountStatementServiceAsync
-
- All Implemented Interfaces:
public interface AccountStatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountStatementServiceAsync.WithRawResponseA view of AccountStatementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountStatementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AccountStatementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AccountStatement>create(AccountStatementCreateParams params)Simulates an #account-statements being created for an account. abstract CompletableFuture<AccountStatement>create(AccountStatementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountStatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountStatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AccountStatement> create(AccountStatementCreateParams params)
Simulates an #account-statements being created for an account. In production, Account Statements are generated once per month.
-
create
abstract CompletableFuture<AccountStatement> create(AccountStatementCreateParams params, RequestOptions requestOptions)
-
-
-
-