Interface AccountStatementServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface AccountStatementServiceAsync.WithRawResponseA view of AccountStatementServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AccountStatementServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<AccountStatement>>create(AccountStatementCreateParams params)Returns a raw HTTP response for post /simulations/account_statements, but is otherwise the same as AccountStatementServiceAsync.create.abstract CompletableFuture<HttpResponseFor<AccountStatement>>create(AccountStatementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract AccountStatementServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<AccountStatement>> create(AccountStatementCreateParams params)
Returns a raw HTTP response for
post /simulations/account_statements, but is otherwise the same as AccountStatementServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<AccountStatement>> create(AccountStatementCreateParams params, RequestOptions requestOptions)
-
-
-
-