Class AccountStatementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AccountStatementServiceAsync
public final class AccountStatementServiceAsyncImpl implements AccountStatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountStatementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountStatementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AccountStatement>create(AccountStatementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountStatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountStatementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<AccountStatement> create(AccountStatementCreateParams params, RequestOptions requestOptions)
-
-
-
-