Interface AccountTransferServiceAsync
-
- All Implemented Interfaces:
public interface AccountTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountTransferServiceAsync.WithRawResponseA view of AccountTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AccountTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AccountTransfer>complete(String accountTransferId)If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. CompletableFuture<AccountTransfer>complete(String accountTransferId, AccountTransferCompleteParams params, RequestOptions requestOptions)CompletableFuture<AccountTransfer>complete(String accountTransferId, AccountTransferCompleteParams params)abstract CompletableFuture<AccountTransfer>complete(AccountTransferCompleteParams params, RequestOptions requestOptions)CompletableFuture<AccountTransfer>complete(AccountTransferCompleteParams params)CompletableFuture<AccountTransfer>complete(String accountTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
CompletableFuture<AccountTransfer> complete(String accountTransferId)
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
complete
CompletableFuture<AccountTransfer> complete(String accountTransferId, AccountTransferCompleteParams params, RequestOptions requestOptions)
-
complete
CompletableFuture<AccountTransfer> complete(String accountTransferId, AccountTransferCompleteParams params)
-
complete
abstract CompletableFuture<AccountTransfer> complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
complete
CompletableFuture<AccountTransfer> complete(AccountTransferCompleteParams params)
-
complete
CompletableFuture<AccountTransfer> complete(String accountTransferId, RequestOptions requestOptions)
-
-
-
-