Class AccountTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AccountTransferServiceAsync
public final class AccountTransferServiceAsyncImpl implements AccountTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<AccountTransfer>complete(AccountTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
CompletableFuture<AccountTransfer> complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-