Class AccountTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AccountTransferServiceAsync.WithRawResponse
public final class AccountTransferServiceAsyncImpl.WithRawResponseImpl implements AccountTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<AccountTransfer>>complete(AccountTransferCompleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.AccountTransferServiceAsync.WithRawResponse
complete, complete, complete, complete, complete -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
CompletableFuture<HttpResponseFor<AccountTransfer>> complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-