Interface AchTransferServiceAsync
-
- All Implemented Interfaces:
public interface AchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchTransferServiceAsync.WithRawResponseA view of AchTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AchTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(String achTransferId)
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgement subresource to the ACH Transfer.
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(String achTransferId, AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(String achTransferId, AchTransferAcknowledgeParams params)
-
acknowledge
abstract CompletableFuture<AchTransfer> acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(AchTransferAcknowledgeParams params)
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(String achTransferId, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(String achTransferId, AchTransferCreateNotificationOfChangeParams params)
Simulates receiving a Notification of Change for an #ach-transfers.
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(String achTransferId, AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params)
-
createNotificationOfChange
abstract CompletableFuture<AchTransfer> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<AchTransfer> return_(String achTransferId)
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
return_
CompletableFuture<AchTransfer> return_(String achTransferId, AchTransferReturnParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<AchTransfer> return_(String achTransferId, AchTransferReturnParams params)
-
return_
abstract CompletableFuture<AchTransfer> return_(AchTransferReturnParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<AchTransfer> return_(AchTransferReturnParams params)
-
return_
CompletableFuture<AchTransfer> return_(String achTransferId, RequestOptions requestOptions)
-
settle
CompletableFuture<AchTransfer> settle(String achTransferId)
Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofpending_submissionorsubmitted. For convenience, if the transfer is instatus:pending_submission, the simulation will also submit the transfer. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production. Additionally, you can specify the behavior of the inbound funds hold that is created when the ACH Transfer is settled. If no behavior is specified, the inbound funds hold will be released immediately in order for the funds to be available for use.
-
settle
CompletableFuture<AchTransfer> settle(String achTransferId, AchTransferSettleParams params, RequestOptions requestOptions)
-
settle
CompletableFuture<AchTransfer> settle(String achTransferId, AchTransferSettleParams params)
-
settle
abstract CompletableFuture<AchTransfer> settle(AchTransferSettleParams params, RequestOptions requestOptions)
-
settle
CompletableFuture<AchTransfer> settle(AchTransferSettleParams params)
-
settle
CompletableFuture<AchTransfer> settle(String achTransferId, RequestOptions requestOptions)
-
submit
CompletableFuture<AchTransfer> submit(String achTransferId)
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
submit
CompletableFuture<AchTransfer> submit(String achTransferId, AchTransferSubmitParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<AchTransfer> submit(String achTransferId, AchTransferSubmitParams params)
-
submit
abstract CompletableFuture<AchTransfer> submit(AchTransferSubmitParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<AchTransfer> submit(AchTransferSubmitParams params)
-
submit
CompletableFuture<AchTransfer> submit(String achTransferId, RequestOptions requestOptions)
-
-
-
-