Class AchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AchTransferServiceAsync
public final class AchTransferServiceAsyncImpl implements AchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AchTransfer>acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>return_(AchTransferReturnParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>settle(AchTransferSettleParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>submit(AchTransferSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<AchTransfer> return_(AchTransferReturnParams params, RequestOptions requestOptions)
-
settle
CompletableFuture<AchTransfer> settle(AchTransferSettleParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<AchTransfer> submit(AchTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-