Class AchTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AchTransferServiceAsync.WithRawResponse
public final class AchTransferServiceAsyncImpl.WithRawResponseImpl implements AchTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AchTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<AchTransfer>>acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AchTransfer>>createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AchTransfer>>return_(AchTransferReturnParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AchTransfer>>settle(AchTransferSettleParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<AchTransfer>>submit(AchTransferSubmitParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.AchTransferServiceAsync.WithRawResponse
acknowledge, acknowledge, acknowledge, acknowledge, acknowledge, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, return_, return_, return_, return_, return_, settle, settle, settle, settle, settle, submit, submit, submit, submit, submit -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AchTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
acknowledge
CompletableFuture<HttpResponseFor<AchTransfer>> acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<HttpResponseFor<AchTransfer>> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<HttpResponseFor<AchTransfer>> return_(AchTransferReturnParams params, RequestOptions requestOptions)
-
settle
CompletableFuture<HttpResponseFor<AchTransfer>> settle(AchTransferSettleParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<HttpResponseFor<AchTransfer>> submit(AchTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-