Interface CardAuthenticationServiceAsync
-
- All Implemented Interfaces:
public interface CardAuthenticationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardAuthenticationServiceAsync.WithRawResponseA view of CardAuthenticationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CardAuthenticationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardAuthenticationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardAuthenticationCreateParams params)
Simulates a Card Authentication attempt on a #cards. The attempt always results in a #card_payments being created, either with a status that allows further action or a terminal failed status.
-
create
abstract CompletableFuture<CardPayment> create(CardAuthenticationCreateParams params, RequestOptions requestOptions)
-
challengeAttempts
CompletableFuture<CardPayment> challengeAttempts(String cardPaymentId, CardAuthenticationChallengeAttemptsParams params)
Simulates an attempt at a Card Authentication Challenge. This updates the
card_authenticationsobject under the #card_payments. You can also attempt the challenge by navigating to https://dashboard.increase.com/card_authentication_simulation/:card_payment_id.
-
challengeAttempts
CompletableFuture<CardPayment> challengeAttempts(String cardPaymentId, CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)
-
challengeAttempts
CompletableFuture<CardPayment> challengeAttempts(CardAuthenticationChallengeAttemptsParams params)
-
challengeAttempts
abstract CompletableFuture<CardPayment> challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)
-
challenges
CompletableFuture<CardPayment> challenges(String cardPaymentId)
Simulates starting a Card Authentication Challenge for an existing Card Authentication. This updates the
card_authenticationsobject under the #card_payments. To attempt the challenge, use the/simulations/card_authentications/:card_payment_id/challenge_attemptsendpoint or navigate to https://dashboard.increase.com/card_authentication_simulation/:card_payment_id.
-
challenges
CompletableFuture<CardPayment> challenges(String cardPaymentId, CardAuthenticationChallengesParams params, RequestOptions requestOptions)
-
challenges
CompletableFuture<CardPayment> challenges(String cardPaymentId, CardAuthenticationChallengesParams params)
-
challenges
abstract CompletableFuture<CardPayment> challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)
-
challenges
CompletableFuture<CardPayment> challenges(CardAuthenticationChallengesParams params)
-
challenges
CompletableFuture<CardPayment> challenges(String cardPaymentId, RequestOptions requestOptions)
-
-
-
-