Class CardAuthenticationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardAuthenticationServiceAsync
public final class CardAuthenticationServiceAsyncImpl implements CardAuthenticationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthenticationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthenticationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAuthenticationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>create(CardAuthenticationCreateParams params, RequestOptions requestOptions)CompletableFuture<CardPayment>challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)CompletableFuture<CardPayment>challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.CardAuthenticationServiceAsync
challengeAttempts, challengeAttempts, challengeAttempts, challenges, challenges, challenges, challenges, challenges, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardAuthenticationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardAuthenticationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardAuthenticationCreateParams params, RequestOptions requestOptions)
-
challengeAttempts
CompletableFuture<CardPayment> challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)
-
challenges
CompletableFuture<CardPayment> challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)
-
-
-
-