Class CardAuthenticationServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardAuthenticationServiceAsync.WithRawResponse
public final class CardAuthenticationServiceAsyncImpl.WithRawResponseImpl implements CardAuthenticationServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardAuthenticationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPayment>>create(CardAuthenticationCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPayment>>challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CardPayment>>challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.CardAuthenticationServiceAsync.WithRawResponse
challengeAttempts, challengeAttempts, challengeAttempts, challenges, challenges, challenges, challenges, challenges, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardAuthenticationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPayment>> create(CardAuthenticationCreateParams params, RequestOptions requestOptions)
-
challengeAttempts
CompletableFuture<HttpResponseFor<CardPayment>> challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)
-
challenges
CompletableFuture<HttpResponseFor<CardPayment>> challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)
-
-
-
-