Class CardAuthorizationServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardAuthorizationServiceAsync.WithRawResponse
public final class CardAuthorizationServiceAsyncImpl.WithRawResponseImpl implements CardAuthorizationServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardAuthorizationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardAuthorizationCreateResponse>>create(CardAuthorizationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardAuthorizationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardAuthorizationCreateResponse>> create(CardAuthorizationCreateParams params, RequestOptions requestOptions)
-
-
-
-