Class CardBalanceInquiryServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardBalanceInquiryServiceAsync
public final class CardBalanceInquiryServiceAsyncImpl implements CardBalanceInquiryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBalanceInquiryServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardBalanceInquiryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardBalanceInquiryServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>create(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardBalanceInquiryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardBalanceInquiryServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)
-
-
-
-