Interface CardDisputeServiceAsync
-
- All Implemented Interfaces:
public interface CardDisputeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardDisputeServiceAsync.WithRawResponseA view of CardDisputeServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardDisputeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CardDispute>action(CardDisputeActionParams params)After a #card-disputes is created in production, the dispute will be reviewed. abstract CompletableFuture<CardDispute>action(CardDisputeActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardDisputeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
action
CompletableFuture<CardDispute> action(CardDisputeActionParams params)
After a #card-disputes is created in production, the dispute will be reviewed. Since no review happens in sandbox, this endpoint simulates moving a Card Dispute into a rejected or accepted state. A Card Dispute can only be actioned one time and must have a status of
pending_reviewing.
-
action
abstract CompletableFuture<CardDispute> action(CardDisputeActionParams params, RequestOptions requestOptions)
-
-
-
-