Class CardDisputeServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardDisputeServiceAsync.WithRawResponse
public final class CardDisputeServiceAsyncImpl.WithRawResponseImpl implements CardDisputeServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardDisputeServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardDispute>>action(CardDisputeActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardDisputeServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
action
CompletableFuture<HttpResponseFor<CardDispute>> action(CardDisputeActionParams params, RequestOptions requestOptions)
-
-
-
-