Interface CardFuelConfirmationServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CardFuelConfirmationServiceAsync.WithRawResponseA view of CardFuelConfirmationServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardFuelConfirmationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPayment>>create(CardFuelConfirmationCreateParams params)Returns a raw HTTP response for post /simulations/card_fuel_confirmations, but is otherwise the same as CardFuelConfirmationServiceAsync.create.abstract CompletableFuture<HttpResponseFor<CardPayment>>create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardFuelConfirmationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPayment>> create(CardFuelConfirmationCreateParams params)
Returns a raw HTTP response for
post /simulations/card_fuel_confirmations, but is otherwise the same as CardFuelConfirmationServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<CardPayment>> create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)
-
-
-
-