Class CardFuelConfirmationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardFuelConfirmationServiceAsync
public final class CardFuelConfirmationServiceAsyncImpl implements CardFuelConfirmationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardFuelConfirmationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardFuelConfirmationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardFuelConfirmationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardFuelConfirmationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardFuelConfirmationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)
-
-
-
-