Class CardFuelConfirmationServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardFuelConfirmationServiceAsync.WithRawResponse
public final class CardFuelConfirmationServiceAsyncImpl.WithRawResponseImpl implements CardFuelConfirmationServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardFuelConfirmationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPayment>>create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardFuelConfirmationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPayment>> create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)
-
-
-
-