Interface CardIncrementServiceAsync
-
- All Implemented Interfaces:
public interface CardIncrementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardIncrementServiceAsync.WithRawResponseA view of CardIncrementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardIncrementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardIncrementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>create(CardIncrementCreateParams params)Simulates the increment of an authorization by a card acquirer. abstract CompletableFuture<CardPayment>create(CardIncrementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardIncrementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardIncrementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardIncrementCreateParams params)
Simulates the increment of an authorization by a card acquirer. An authorization can be incremented multiple times.
-
create
abstract CompletableFuture<CardPayment> create(CardIncrementCreateParams params, RequestOptions requestOptions)
-
-
-
-