Class CardIncrementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardIncrementServiceAsync
public final class CardIncrementServiceAsyncImpl implements CardIncrementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardIncrementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardIncrementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardIncrementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>create(CardIncrementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardIncrementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardIncrementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardIncrementCreateParams params, RequestOptions requestOptions)
-
-
-
-