Class CardIncrementServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardIncrementServiceAsync.WithRawResponse
public final class CardIncrementServiceAsyncImpl.WithRawResponseImpl implements CardIncrementServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardIncrementServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPayment>>create(CardIncrementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardIncrementServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPayment>> create(CardIncrementCreateParams params, RequestOptions requestOptions)
-
-
-
-