Interface CardPurchaseSupplementServiceAsync
-
- All Implemented Interfaces:
public interface CardPurchaseSupplementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPurchaseSupplementServiceAsync.WithRawResponseA view of CardPurchaseSupplementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardPurchaseSupplementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardPurchaseSupplementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPurchaseSupplement>create(CardPurchaseSupplementCreateParams params)Simulates the creation of a Card Purchase Supplement (Level 3 data) for a card settlement. abstract CompletableFuture<CardPurchaseSupplement>create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardPurchaseSupplementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardPurchaseSupplementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPurchaseSupplement> create(CardPurchaseSupplementCreateParams params)
Simulates the creation of a Card Purchase Supplement (Level 3 data) for a card settlement. This happens asynchronously in production when Visa sends enhanced transaction data about a purchase.
-
create
abstract CompletableFuture<CardPurchaseSupplement> create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)
-
-
-
-