Interface CardPurchaseSupplementServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CardPurchaseSupplementServiceAsync.WithRawResponseA view of CardPurchaseSupplementServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardPurchaseSupplementServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPurchaseSupplement>>create(CardPurchaseSupplementCreateParams params)Returns a raw HTTP response for post /simulations/card_purchase_supplements, but is otherwise the same as CardPurchaseSupplementServiceAsync.create.abstract CompletableFuture<HttpResponseFor<CardPurchaseSupplement>>create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardPurchaseSupplementServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPurchaseSupplement>> create(CardPurchaseSupplementCreateParams params)
Returns a raw HTTP response for
post /simulations/card_purchase_supplements, but is otherwise the same as CardPurchaseSupplementServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<CardPurchaseSupplement>> create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)
-
-
-
-