Class CardPurchaseSupplementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardPurchaseSupplementServiceAsync
public final class CardPurchaseSupplementServiceAsyncImpl implements CardPurchaseSupplementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPurchaseSupplementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPurchaseSupplementServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPurchaseSupplement>create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardPurchaseSupplementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardPurchaseSupplementServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPurchaseSupplement> create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)
-
-
-
-