Interface CardRefundServiceAsync
-
- All Implemented Interfaces:
public interface CardRefundServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardRefundServiceAsync.WithRawResponseA view of CardRefundServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardRefundServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardRefundServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Transaction>create()Simulates refunding a card transaction. abstract CompletableFuture<Transaction>create(CardRefundCreateParams params, RequestOptions requestOptions)CompletableFuture<Transaction>create(CardRefundCreateParams params)CompletableFuture<Transaction>create(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardRefundServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardRefundServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Transaction> create()
Simulates refunding a card transaction. The full value of the original sandbox transaction is refunded.
-
create
abstract CompletableFuture<Transaction> create(CardRefundCreateParams params, RequestOptions requestOptions)
-
create
CompletableFuture<Transaction> create(CardRefundCreateParams params)
-
create
CompletableFuture<Transaction> create(RequestOptions requestOptions)
-
-
-
-