Class CardRefundServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardRefundServiceAsync
public final class CardRefundServiceAsyncImpl implements CardRefundServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRefundServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardRefundServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardRefundServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Transaction>create(CardRefundCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardRefundServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardRefundServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Transaction> create(CardRefundCreateParams params, RequestOptions requestOptions)
-
-
-
-