Class CardRefundServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardRefundServiceAsync.WithRawResponse
public final class CardRefundServiceAsyncImpl.WithRawResponseImpl implements CardRefundServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardRefundServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Transaction>>create(CardRefundCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardRefundServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Transaction>> create(CardRefundCreateParams params, RequestOptions requestOptions)
-
-
-
-