Class CardReversalServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardReversalServiceAsync
public final class CardReversalServiceAsyncImpl implements CardReversalServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardReversalServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardReversalServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardReversalServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardPayment>create(CardReversalCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardReversalServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardReversalServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardPayment> create(CardReversalCreateParams params, RequestOptions requestOptions)
-
-
-
-