Class CardReversalServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardReversalServiceAsync.WithRawResponse
public final class CardReversalServiceAsyncImpl.WithRawResponseImpl implements CardReversalServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardReversalServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CardPayment>>create(CardReversalCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardReversalServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CardPayment>> create(CardReversalCreateParams params, RequestOptions requestOptions)
-
-
-
-