Interface CardSettlementServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CardSettlementServiceAsync.WithRawResponseA view of CardSettlementServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardSettlementServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Transaction>>create(CardSettlementCreateParams params)Returns a raw HTTP response for post /simulations/card_settlements, but is otherwise the same as CardSettlementServiceAsync.create.abstract CompletableFuture<HttpResponseFor<Transaction>>create(CardSettlementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardSettlementServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Transaction>> create(CardSettlementCreateParams params)
Returns a raw HTTP response for
post /simulations/card_settlements, but is otherwise the same as CardSettlementServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<Transaction>> create(CardSettlementCreateParams params, RequestOptions requestOptions)
-
-
-
-