Class CardSettlementServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardSettlementServiceAsync.WithRawResponse
public final class CardSettlementServiceAsyncImpl.WithRawResponseImpl implements CardSettlementServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardSettlementServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Transaction>>create(CardSettlementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardSettlementServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Transaction>> create(CardSettlementCreateParams params, RequestOptions requestOptions)
-
-
-
-