Class CardTokenServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardTokenServiceAsync
public final class CardTokenServiceAsyncImpl implements CardTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardTokenServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CardToken>create(CardTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardTokenServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CardToken> create(CardTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-