Interface CheckDepositServiceAsync
-
- All Implemented Interfaces:
public interface CheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckDepositServiceAsync.WithRawResponseA view of CheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CheckDeposit>reject(CheckDepositRejectParams params)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. abstract CompletableFuture<CheckDeposit>reject(CheckDepositRejectParams params, RequestOptions requestOptions)CompletableFuture<CheckDeposit>return_(CheckDepositReturnParams params)Simulates the return of a #check-deposits. abstract CompletableFuture<CheckDeposit>return_(CheckDepositReturnParams params, RequestOptions requestOptions)CompletableFuture<CheckDeposit>submit(CheckDepositSubmitParams params)Simulates the submission of a #check-deposits to the Federal Reserve. abstract CompletableFuture<CheckDeposit>submit(CheckDepositSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reject
CompletableFuture<CheckDeposit> reject(CheckDepositRejectParams params)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
reject
abstract CompletableFuture<CheckDeposit> reject(CheckDepositRejectParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<CheckDeposit> return_(CheckDepositReturnParams params)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
return_
abstract CompletableFuture<CheckDeposit> return_(CheckDepositReturnParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<CheckDeposit> submit(CheckDepositSubmitParams params)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
submit
abstract CompletableFuture<CheckDeposit> submit(CheckDepositSubmitParams params, RequestOptions requestOptions)
-
-
-
-