Class CheckDepositServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CheckDepositServiceAsync
public final class CheckDepositServiceAsyncImpl implements CheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CheckDeposit>reject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)CompletableFuture<CheckDeposit>return_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)CompletableFuture<CheckDeposit>submit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reject
CompletableFuture<CheckDeposit> reject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<CheckDeposit> return_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<CheckDeposit> submit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)
-
-
-
-