Interface CheckTransferServiceAsync
-
- All Implemented Interfaces:
public interface CheckTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckTransferServiceAsync.WithRawResponseA view of CheckTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CheckTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CheckTransfer>mail(String checkTransferId)Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. CompletableFuture<CheckTransfer>mail(String checkTransferId, CheckTransferMailParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>mail(String checkTransferId, CheckTransferMailParams params)abstract CompletableFuture<CheckTransfer>mail(CheckTransferMailParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>mail(CheckTransferMailParams params)CompletableFuture<CheckTransfer>mail(String checkTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CheckTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CheckTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
mail
CompletableFuture<CheckTransfer> mail(String checkTransferId)
Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. This transfer must first have a
statusofpending_approvalorpending_submission.
-
mail
CompletableFuture<CheckTransfer> mail(String checkTransferId, CheckTransferMailParams params, RequestOptions requestOptions)
-
mail
CompletableFuture<CheckTransfer> mail(String checkTransferId, CheckTransferMailParams params)
-
mail
abstract CompletableFuture<CheckTransfer> mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
mail
CompletableFuture<CheckTransfer> mail(CheckTransferMailParams params)
-
mail
CompletableFuture<CheckTransfer> mail(String checkTransferId, RequestOptions requestOptions)
-
-
-
-