Class CheckTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CheckTransferServiceAsync
public final class CheckTransferServiceAsyncImpl implements CheckTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CheckTransfer>mail(CheckTransferMailParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CheckTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CheckTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
mail
CompletableFuture<CheckTransfer> mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
-
-
-