Interface DigitalWalletTokenRequestServiceAsync
-
- All Implemented Interfaces:
public interface DigitalWalletTokenRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalWalletTokenRequestServiceAsync.WithRawResponseA view of DigitalWalletTokenRequestServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenRequestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DigitalWalletTokenRequestServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DigitalWalletTokenRequestCreateResponse>create(DigitalWalletTokenRequestCreateParams params)Simulates a user attempting to add a #cards to a digital wallet such as Apple Pay. abstract CompletableFuture<DigitalWalletTokenRequestCreateResponse>create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DigitalWalletTokenRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DigitalWalletTokenRequestServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<DigitalWalletTokenRequestCreateResponse> create(DigitalWalletTokenRequestCreateParams params)
Simulates a user attempting to add a #cards to a digital wallet such as Apple Pay.
-
create
abstract CompletableFuture<DigitalWalletTokenRequestCreateResponse> create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-