Interface DigitalWalletTokenRequestServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface DigitalWalletTokenRequestServiceAsync.WithRawResponseA view of DigitalWalletTokenRequestServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenRequestServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<DigitalWalletTokenRequestCreateResponse>>create(DigitalWalletTokenRequestCreateParams params)Returns a raw HTTP response for post /simulations/digital_wallet_token_requests, but is otherwise the same as DigitalWalletTokenRequestServiceAsync.create.abstract CompletableFuture<HttpResponseFor<DigitalWalletTokenRequestCreateResponse>>create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract DigitalWalletTokenRequestServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<DigitalWalletTokenRequestCreateResponse>> create(DigitalWalletTokenRequestCreateParams params)
Returns a raw HTTP response for
post /simulations/digital_wallet_token_requests, but is otherwise the same as DigitalWalletTokenRequestServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<DigitalWalletTokenRequestCreateResponse>> create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-