Class DigitalWalletTokenRequestServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.DigitalWalletTokenRequestServiceAsync
public final class DigitalWalletTokenRequestServiceAsyncImpl implements DigitalWalletTokenRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenRequestServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenRequestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalWalletTokenRequestServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<DigitalWalletTokenRequestCreateResponse>create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DigitalWalletTokenRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigitalWalletTokenRequestServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<DigitalWalletTokenRequestCreateResponse> create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-