Class DigitalWalletTokenRequestServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.DigitalWalletTokenRequestServiceAsync.WithRawResponse
public final class DigitalWalletTokenRequestServiceAsyncImpl.WithRawResponseImpl implements DigitalWalletTokenRequestServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenRequestServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<DigitalWalletTokenRequestCreateResponse>>create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
DigitalWalletTokenRequestServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<DigitalWalletTokenRequestCreateResponse>> create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-