Interface DocumentServiceAsync
-
- All Implemented Interfaces:
public interface DocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentServiceAsync.WithRawResponseA view of DocumentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DocumentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Document>create(DocumentCreateParams params)Simulates an tax document being created for an account. abstract CompletableFuture<Document>create(DocumentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DocumentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Document> create(DocumentCreateParams params)
Simulates an tax document being created for an account.
-
create
abstract CompletableFuture<Document> create(DocumentCreateParams params, RequestOptions requestOptions)
-
-
-
-