Class EntityOnboardingSessionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.EntityOnboardingSessionServiceAsync.WithRawResponse
public final class EntityOnboardingSessionServiceAsyncImpl.WithRawResponseImpl implements EntityOnboardingSessionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EntityOnboardingSessionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<EntityOnboardingSession>>submit(EntityOnboardingSessionSubmitParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.EntityOnboardingSessionServiceAsync.WithRawResponse
submit, submit, submit, submit, submit -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
EntityOnboardingSessionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
submit
CompletableFuture<HttpResponseFor<EntityOnboardingSession>> submit(EntityOnboardingSessionSubmitParams params, RequestOptions requestOptions)
-
-
-
-