Interface EntityServiceAsync
-
- All Implemented Interfaces:
public interface EntityServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityServiceAsync.WithRawResponseA view of EntityServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EntityServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EntityServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Entity>updateValidation(String entityId, EntityUpdateValidationParams params)Simulate updates to an /documentation/api/entities#entity-object. CompletableFuture<Entity>updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)CompletableFuture<Entity>updateValidation(EntityUpdateValidationParams params)abstract CompletableFuture<Entity>updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EntityServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EntityServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
CompletableFuture<Entity> updateValidation(String entityId, EntityUpdateValidationParams params)
Simulate updates to an /documentation/api/entities#entity-object.validation. In production, Know Your Customer validations /documentation/entity-validation#entity-validation for eligible programs. While developing, use this API to simulate issues with information submissions.
-
updateValidation
CompletableFuture<Entity> updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)
-
updateValidation
CompletableFuture<Entity> updateValidation(EntityUpdateValidationParams params)
-
updateValidation
abstract CompletableFuture<Entity> updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-