Interface EntityServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface EntityServiceAsync.WithRawResponseA view of EntityServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract EntityServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Entity>>updateValidation(String entityId, EntityUpdateValidationParams params)Returns a raw HTTP response for post /simulations/entities/{entity_id}/update_validation, but is otherwise the same as EntityServiceAsync.updateValidation.CompletableFuture<HttpResponseFor<Entity>>updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Entity>>updateValidation(EntityUpdateValidationParams params)abstract CompletableFuture<HttpResponseFor<Entity>>updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract EntityServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
CompletableFuture<HttpResponseFor<Entity>> updateValidation(String entityId, EntityUpdateValidationParams params)
Returns a raw HTTP response for
post /simulations/entities/{entity_id}/update_validation, but is otherwise the same as EntityServiceAsync.updateValidation.
-
updateValidation
CompletableFuture<HttpResponseFor<Entity>> updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)
-
updateValidation
CompletableFuture<HttpResponseFor<Entity>> updateValidation(EntityUpdateValidationParams params)
-
updateValidation
abstract CompletableFuture<HttpResponseFor<Entity>> updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-