Class EntityServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.EntityServiceAsync
public final class EntityServiceAsyncImpl implements EntityServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EntityServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EntityServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Entity>updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EntityServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EntityServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
CompletableFuture<Entity> updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-