Class EntityServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.EntityServiceAsync.WithRawResponse
public final class EntityServiceAsyncImpl.WithRawResponseImpl implements EntityServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EntityServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Entity>>updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EntityServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
CompletableFuture<HttpResponseFor<Entity>> updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-