Interface ExportServiceAsync
-
- All Implemented Interfaces:
public interface ExportServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportServiceAsync.WithRawResponseA view of ExportServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExportServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ExportServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Export>create(ExportCreateParams params)Many exports are created by you via POST /exports or in the Dashboard. abstract CompletableFuture<Export>create(ExportCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExportServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExportServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Export> create(ExportCreateParams params)
Many exports are created by you via POST /exports or in the Dashboard. Some exports are created automatically by Increase. For example, tax documents are published once a year. In sandbox, you can trigger the arrival of an export that would normally only be created automatically via this simulation.
-
create
abstract CompletableFuture<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
-
-
-