Class ExportServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.ExportServiceAsync.WithRawResponse
public final class ExportServiceAsyncImpl.WithRawResponseImpl implements ExportServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ExportServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Export>>create(ExportCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ExportServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Export>> create(ExportCreateParams params, RequestOptions requestOptions)
-
-
-
-