Interface InboundAchTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundAchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundAchTransferServiceAsync.WithRawResponseA view of InboundAchTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundAchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundAchTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundAchTransfer>create(InboundAchTransferCreateParams params)Simulates an inbound ACH transfer to your account. abstract CompletableFuture<InboundAchTransfer>create(InboundAchTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundAchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundAchTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundAchTransfer> create(InboundAchTransferCreateParams params)
Simulates an inbound ACH transfer to your account. This imitates initiating a transfer to an Increase account from a different financial institution. The transfer may be either a credit or a debit depending on if the
amountis positive or negative. The result of calling this API will contain the created transfer. You can pass aresolve_atparameter to allow for a window to action on the Inbound ACH Transfer. Alternatively, if you don't pass theresolve_atparameter the result will contain either a #transactions or a #declined-transactions depending on whether or not the transfer is allowed.
-
create
abstract CompletableFuture<InboundAchTransfer> create(InboundAchTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-