Interface InboundAchTransferServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundAchTransferServiceAsync.WithRawResponseA view of InboundAchTransferServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundAchTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundAchTransfer>>create(InboundAchTransferCreateParams params)Returns a raw HTTP response for post /simulations/inbound_ach_transfers, but is otherwise the same as InboundAchTransferServiceAsync.create.abstract CompletableFuture<HttpResponseFor<InboundAchTransfer>>create(InboundAchTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundAchTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundAchTransfer>> create(InboundAchTransferCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_ach_transfers, but is otherwise the same as InboundAchTransferServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<InboundAchTransfer>> create(InboundAchTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-