Interface InboundCheckDepositServiceAsync
-
- All Implemented Interfaces:
public interface InboundCheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundCheckDepositServiceAsync.WithRawResponseA view of InboundCheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundCheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundCheckDepositServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundCheckDeposit> create(InboundCheckDepositCreateParams params)
Simulates an Inbound Check Deposit against your account. This imitates someone depositing a check at their bank that was issued from your account. It may or may not be associated with a Check Transfer. Increase will evaluate the Inbound Check Deposit as we would in production and either create a Transaction or a Declined Transaction as a result. You can inspect the resulting Inbound Check Deposit object to see the result.
-
create
abstract CompletableFuture<InboundCheckDeposit> create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
adjustment
CompletableFuture<InboundCheckDeposit> adjustment(String inboundCheckDepositId)
Simulates an adjustment on an Inbound Check Deposit. The Inbound Check Deposit must have a
statusofaccepted.
-
adjustment
CompletableFuture<InboundCheckDeposit> adjustment(String inboundCheckDepositId, InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)
-
adjustment
CompletableFuture<InboundCheckDeposit> adjustment(String inboundCheckDepositId, InboundCheckDepositAdjustmentParams params)
-
adjustment
abstract CompletableFuture<InboundCheckDeposit> adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)
-
adjustment
CompletableFuture<InboundCheckDeposit> adjustment(InboundCheckDepositAdjustmentParams params)
-
adjustment
CompletableFuture<InboundCheckDeposit> adjustment(String inboundCheckDepositId, RequestOptions requestOptions)
-
-
-
-