Interface InboundCheckDepositServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundCheckDepositServiceAsync.WithRawResponseA view of InboundCheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundCheckDepositServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundCheckDeposit>>create(InboundCheckDepositCreateParams params)Returns a raw HTTP response for post /simulations/inbound_check_deposits, but is otherwise the same as InboundCheckDepositServiceAsync.create.abstract CompletableFuture<HttpResponseFor<InboundCheckDeposit>>create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundCheckDepositServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundCheckDeposit>> create(InboundCheckDepositCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_check_deposits, but is otherwise the same as InboundCheckDepositServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<InboundCheckDeposit>> create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-