Class InboundCheckDepositServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundCheckDepositServiceAsync
public final class InboundCheckDepositServiceAsyncImpl implements InboundCheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundCheckDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundCheckDepositServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundCheckDeposit>create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)CompletableFuture<InboundCheckDeposit>adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.InboundCheckDepositServiceAsync
adjustment, adjustment, adjustment, adjustment, adjustment, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundCheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundCheckDepositServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundCheckDeposit> create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
adjustment
CompletableFuture<InboundCheckDeposit> adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)
-
-
-
-