Class InboundCheckDepositServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundCheckDepositServiceAsync.WithRawResponse
public final class InboundCheckDepositServiceAsyncImpl.WithRawResponseImpl implements InboundCheckDepositServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundCheckDepositServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundCheckDeposit>>create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InboundCheckDeposit>>adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.InboundCheckDepositServiceAsync.WithRawResponse
adjustment, adjustment, adjustment, adjustment, adjustment, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundCheckDepositServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundCheckDeposit>> create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
adjustment
CompletableFuture<HttpResponseFor<InboundCheckDeposit>> adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)
-
-
-
-