Interface InboundFednowTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundFednowTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundFednowTransferServiceAsync.WithRawResponseA view of InboundFednowTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundFednowTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundFednowTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundFednowTransfer>create(InboundFednowTransferCreateParams params)Simulates an #inbound-fednow-transfers to your account. abstract CompletableFuture<InboundFednowTransfer>create(InboundFednowTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundFednowTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundFednowTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundFednowTransfer> create(InboundFednowTransferCreateParams params)
Simulates an #inbound-fednow-transfers to your account.
-
create
abstract CompletableFuture<InboundFednowTransfer> create(InboundFednowTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-