Class InboundFednowTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundFednowTransferServiceAsync
public final class InboundFednowTransferServiceAsyncImpl implements InboundFednowTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundFednowTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundFednowTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundFednowTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundFednowTransfer>create(InboundFednowTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundFednowTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundFednowTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundFednowTransfer> create(InboundFednowTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-