Class InboundFundsHoldServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundFundsHoldServiceAsync
public final class InboundFundsHoldServiceAsyncImpl implements InboundFundsHoldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundFundsHoldServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundFundsHoldServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundFundsHoldServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundFundsHoldReleaseResponse>release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundFundsHoldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundFundsHoldServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
-
-
-