Class InboundFundsHoldServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundFundsHoldServiceAsync.WithRawResponse
public final class InboundFundsHoldServiceAsyncImpl.WithRawResponseImpl implements InboundFundsHoldServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundFundsHoldServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundFundsHoldReleaseResponse>>release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundFundsHoldServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
release
CompletableFuture<HttpResponseFor<InboundFundsHoldReleaseResponse>> release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
-
-
-