Interface InboundMailItemServiceAsync
-
- All Implemented Interfaces:
public interface InboundMailItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundMailItemServiceAsync.WithRawResponseA view of InboundMailItemServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundMailItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundMailItemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundMailItem>create(InboundMailItemCreateParams params)Simulates an Inbound Mail Item to one of your Lockbox Addresses or Lockbox Recipients, as if someone had mailed a physical check. abstract CompletableFuture<InboundMailItem>create(InboundMailItemCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundMailItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundMailItemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundMailItem> create(InboundMailItemCreateParams params)
Simulates an Inbound Mail Item to one of your Lockbox Addresses or Lockbox Recipients, as if someone had mailed a physical check.
-
create
abstract CompletableFuture<InboundMailItem> create(InboundMailItemCreateParams params, RequestOptions requestOptions)
-
-
-
-