Interface InboundMailItemServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundMailItemServiceAsync.WithRawResponseA view of InboundMailItemServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundMailItemServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundMailItem>>create(InboundMailItemCreateParams params)Returns a raw HTTP response for post /simulations/inbound_mail_items, but is otherwise the same as InboundMailItemServiceAsync.create.abstract CompletableFuture<HttpResponseFor<InboundMailItem>>create(InboundMailItemCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundMailItemServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundMailItem>> create(InboundMailItemCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_mail_items, but is otherwise the same as InboundMailItemServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<InboundMailItem>> create(InboundMailItemCreateParams params, RequestOptions requestOptions)
-
-
-
-