Interface InboundRealTimePaymentsTransferServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundRealTimePaymentsTransferServiceAsync.WithRawResponseA view of InboundRealTimePaymentsTransferServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundRealTimePaymentsTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>>create(InboundRealTimePaymentsTransferCreateParams params)Returns a raw HTTP response for post /simulations/inbound_real_time_payments_transfers, but is otherwise the same as InboundRealTimePaymentsTransferServiceAsync.create.abstract CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>>create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundRealTimePaymentsTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>> create(InboundRealTimePaymentsTransferCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_real_time_payments_transfers, but is otherwise the same as InboundRealTimePaymentsTransferServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>> create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-