Class InboundRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundRealTimePaymentsTransferServiceAsync.WithRawResponse
public final class InboundRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl implements InboundRealTimePaymentsTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundRealTimePaymentsTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>>create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundRealTimePaymentsTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundRealTimePaymentsTransfer>> create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-