Interface InboundWireDrawdownRequestServiceAsync
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireDrawdownRequestServiceAsync.WithRawResponseA view of InboundWireDrawdownRequestServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireDrawdownRequestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundWireDrawdownRequestServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundWireDrawdownRequest>create(InboundWireDrawdownRequestCreateParams params)Simulates receiving an #inbound-wire-drawdown-requests. abstract CompletableFuture<InboundWireDrawdownRequest>create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireDrawdownRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundWireDrawdownRequestServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundWireDrawdownRequest> create(InboundWireDrawdownRequestCreateParams params)
Simulates receiving an #inbound-wire-drawdown-requests.
-
create
abstract CompletableFuture<InboundWireDrawdownRequest> create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-