Interface InboundWireDrawdownRequestServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestServiceAsync.WithRawResponseA view of InboundWireDrawdownRequestServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundWireDrawdownRequestServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>>create(InboundWireDrawdownRequestCreateParams params)Returns a raw HTTP response for post /simulations/inbound_wire_drawdown_requests, but is otherwise the same as InboundWireDrawdownRequestServiceAsync.create.abstract CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>>create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundWireDrawdownRequestServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>> create(InboundWireDrawdownRequestCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_wire_drawdown_requests, but is otherwise the same as InboundWireDrawdownRequestServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>> create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-