Class InboundWireDrawdownRequestServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundWireDrawdownRequestServiceAsync.WithRawResponse
public final class InboundWireDrawdownRequestServiceAsyncImpl.WithRawResponseImpl implements InboundWireDrawdownRequestServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>>create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundWireDrawdownRequestServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundWireDrawdownRequest>> create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-