Interface InboundWireTransferServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundWireTransferServiceAsync.WithRawResponseA view of InboundWireTransferServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundWireTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InboundWireTransfer>>create(InboundWireTransferCreateParams params)Returns a raw HTTP response for post /simulations/inbound_wire_transfers, but is otherwise the same as InboundWireTransferServiceAsync.create.abstract CompletableFuture<HttpResponseFor<InboundWireTransfer>>create(InboundWireTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundWireTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InboundWireTransfer>> create(InboundWireTransferCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_wire_transfers, but is otherwise the same as InboundWireTransferServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<InboundWireTransfer>> create(InboundWireTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-