Class InboundWireTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundWireTransferServiceAsync
public final class InboundWireTransferServiceAsyncImpl implements InboundWireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundWireTransfer>create(InboundWireTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundWireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundWireTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundWireTransfer> create(InboundWireTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-