Interface InterestPaymentServiceAsync
-
- All Implemented Interfaces:
public interface InterestPaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInterestPaymentServiceAsync.WithRawResponseA view of InterestPaymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InterestPaymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InterestPaymentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Transaction>create(InterestPaymentCreateParams params)Simulates an interest payment to your account. abstract CompletableFuture<Transaction>create(InterestPaymentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InterestPaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InterestPaymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Transaction> create(InterestPaymentCreateParams params)
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
create
abstract CompletableFuture<Transaction> create(InterestPaymentCreateParams params, RequestOptions requestOptions)
-
-
-
-