Class InterestPaymentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InterestPaymentServiceAsync
public final class InterestPaymentServiceAsyncImpl implements InterestPaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInterestPaymentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InterestPaymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InterestPaymentServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Transaction>create(InterestPaymentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InterestPaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InterestPaymentServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Transaction> create(InterestPaymentCreateParams params, RequestOptions requestOptions)
-
-
-
-