Interface PendingTransactionServiceAsync
-
- All Implemented Interfaces:
public interface PendingTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePendingTransactionServiceAsync.WithRawResponseA view of PendingTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract PendingTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PendingTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
releaseInboundFundsHold
CompletableFuture<PendingTransaction> releaseInboundFundsHold(String pendingTransactionId)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of, for example, an ACH debit.
-
releaseInboundFundsHold
CompletableFuture<PendingTransaction> releaseInboundFundsHold(String pendingTransactionId, PendingTransactionReleaseInboundFundsHoldParams params, RequestOptions requestOptions)
-
releaseInboundFundsHold
CompletableFuture<PendingTransaction> releaseInboundFundsHold(String pendingTransactionId, PendingTransactionReleaseInboundFundsHoldParams params)
-
releaseInboundFundsHold
abstract CompletableFuture<PendingTransaction> releaseInboundFundsHold(PendingTransactionReleaseInboundFundsHoldParams params, RequestOptions requestOptions)
-
releaseInboundFundsHold
CompletableFuture<PendingTransaction> releaseInboundFundsHold(PendingTransactionReleaseInboundFundsHoldParams params)
-
releaseInboundFundsHold
CompletableFuture<PendingTransaction> releaseInboundFundsHold(String pendingTransactionId, RequestOptions requestOptions)
-
-
-
-