Class PendingTransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.PendingTransactionServiceAsync
public final class PendingTransactionServiceAsyncImpl implements PendingTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PendingTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PendingTransactionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<PendingTransaction>releaseInboundFundsHold(PendingTransactionReleaseInboundFundsHoldParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.PendingTransactionServiceAsync
releaseInboundFundsHold, releaseInboundFundsHold, releaseInboundFundsHold, releaseInboundFundsHold, releaseInboundFundsHold -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PendingTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PendingTransactionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
releaseInboundFundsHold
CompletableFuture<PendingTransaction> releaseInboundFundsHold(PendingTransactionReleaseInboundFundsHoldParams params, RequestOptions requestOptions)
-
-
-
-