Interface PhysicalCardServiceAsync
-
- All Implemented Interfaces:
public interface PhysicalCardServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePhysicalCardServiceAsync.WithRawResponseA view of PhysicalCardServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PhysicalCardServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<PhysicalCard>advanceShipment(PhysicalCardAdvanceShipmentParams params)This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery. abstract CompletableFuture<PhysicalCard>advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PhysicalCardServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
advanceShipment
CompletableFuture<PhysicalCard> advanceShipment(PhysicalCardAdvanceShipmentParams params)
This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery.
-
advanceShipment
abstract CompletableFuture<PhysicalCard> advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
-
-
-