Class PhysicalCardServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.PhysicalCardServiceAsync
public final class PhysicalCardServiceAsyncImpl implements PhysicalCardServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<PhysicalCard>create(PhysicalCardCreateParams params, RequestOptions requestOptions)CompletableFuture<PhysicalCard>advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.PhysicalCardServiceAsync
advanceShipment, advanceShipment, advanceShipment, create, create, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PhysicalCardServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PhysicalCardServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<PhysicalCard> create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
advanceShipment
CompletableFuture<PhysicalCard> advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
-
-
-