Class PhysicalCardServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.PhysicalCardServiceAsync.WithRawResponse
public final class PhysicalCardServiceAsyncImpl.WithRawResponseImpl implements PhysicalCardServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description PhysicalCardServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<PhysicalCard>>create(PhysicalCardCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<PhysicalCard>>advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.PhysicalCardServiceAsync.WithRawResponse
advanceShipment, advanceShipment, advanceShipment, create, create, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
PhysicalCardServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<PhysicalCard>> create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
advanceShipment
CompletableFuture<HttpResponseFor<PhysicalCard>> advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
-
-
-