Interface ProgramServiceAsync
-
- All Implemented Interfaces:
public interface ProgramServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProgramServiceAsync.WithRawResponseA view of ProgramServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ProgramServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ProgramServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Program>create(ProgramCreateParams params)Simulates a #programs being created in your group. abstract CompletableFuture<Program>create(ProgramCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ProgramServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProgramServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Program> create(ProgramCreateParams params)
Simulates a #programs being created in your group. By default, your group has one program called Commercial Banking. Note that when your group operates more than one program,
program_idis a required field when creating accounts.
-
create
abstract CompletableFuture<Program> create(ProgramCreateParams params, RequestOptions requestOptions)
-
-
-
-