Interface ProgramServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ProgramServiceAsync.WithRawResponseA view of ProgramServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ProgramServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Program>>create(ProgramCreateParams params)Returns a raw HTTP response for post /simulations/programs, but is otherwise the same as ProgramServiceAsync.create.abstract CompletableFuture<HttpResponseFor<Program>>create(ProgramCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ProgramServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<Program>> create(ProgramCreateParams params)
Returns a raw HTTP response for
post /simulations/programs, but is otherwise the same as ProgramServiceAsync.create.
-
create
abstract CompletableFuture<HttpResponseFor<Program>> create(ProgramCreateParams params, RequestOptions requestOptions)
-
-
-
-