Interface RealTimePaymentsTransferServiceAsync
-
- All Implemented Interfaces:
public interface RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRealTimePaymentsTransferServiceAsync.WithRawResponseA view of RealTimePaymentsTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RealTimePaymentsTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(String realTimePaymentsTransferId)
Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. This transfer must first have a
statusofpending_submission.
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(String realTimePaymentsTransferId, RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(String realTimePaymentsTransferId, RealTimePaymentsTransferCompleteParams params)
-
complete
abstract CompletableFuture<RealTimePaymentsTransfer> complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(RealTimePaymentsTransferCompleteParams params)
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(String realTimePaymentsTransferId, RequestOptions requestOptions)
-
-
-
-