Class RealTimePaymentsTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.RealTimePaymentsTransferServiceAsync
public final class RealTimePaymentsTransferServiceAsyncImpl implements RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimePaymentsTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RealTimePaymentsTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RealTimePaymentsTransfer>complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RealTimePaymentsTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-