Interface WireTransferServiceAsync
-
- All Implemented Interfaces:
public interface WireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWireTransferServiceAsync.WithRawResponseA view of WireTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract WireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WireTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
reverse
CompletableFuture<WireTransfer> reverse(String wireTransferId)
Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a
statusofcomplete.
-
reverse
CompletableFuture<WireTransfer> reverse(String wireTransferId, WireTransferReverseParams params, RequestOptions requestOptions)
-
reverse
CompletableFuture<WireTransfer> reverse(String wireTransferId, WireTransferReverseParams params)
-
reverse
abstract CompletableFuture<WireTransfer> reverse(WireTransferReverseParams params, RequestOptions requestOptions)
-
reverse
CompletableFuture<WireTransfer> reverse(WireTransferReverseParams params)
-
reverse
CompletableFuture<WireTransfer> reverse(String wireTransferId, RequestOptions requestOptions)
-
submit
CompletableFuture<WireTransfer> submit(String wireTransferId)
Simulates the submission of a #wire-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_creating.
-
submit
CompletableFuture<WireTransfer> submit(String wireTransferId, WireTransferSubmitParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<WireTransfer> submit(String wireTransferId, WireTransferSubmitParams params)
-
submit
abstract CompletableFuture<WireTransfer> submit(WireTransferSubmitParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<WireTransfer> submit(WireTransferSubmitParams params)
-
submit
CompletableFuture<WireTransfer> submit(String wireTransferId, RequestOptions requestOptions)
-
-
-
-