Class WireTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.WireTransferServiceAsync
public final class WireTransferServiceAsyncImpl implements WireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WireTransferServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<WireTransfer>reverse(WireTransferReverseParams params, RequestOptions requestOptions)CompletableFuture<WireTransfer>submit(WireTransferSubmitParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.WireTransferServiceAsync
reverse, reverse, reverse, reverse, reverse, submit, submit, submit, submit, submit -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
WireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WireTransferServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
reverse
CompletableFuture<WireTransfer> reverse(WireTransferReverseParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<WireTransfer> submit(WireTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-