Class WireTransferServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.WireTransferServiceAsync.WithRawResponse
public final class WireTransferServiceAsyncImpl.WithRawResponseImpl implements WireTransferServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description WireTransferServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<WireTransfer>>reverse(WireTransferReverseParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<WireTransfer>>submit(WireTransferSubmitParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.simulations.WireTransferServiceAsync.WithRawResponse
reverse, reverse, reverse, reverse, reverse, submit, submit, submit, submit, submit -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
WireTransferServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
reverse
CompletableFuture<HttpResponseFor<WireTransfer>> reverse(WireTransferReverseParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<HttpResponseFor<WireTransfer>> submit(WireTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-