Interface AccountStatementService
-
- All Implemented Interfaces:
public interface AccountStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountStatementService.WithRawResponseA view of AccountStatementService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AccountStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountStatementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
AccountStatement retrieve(String accountStatementId)
Retrieve an Account Statement
-
retrieve
AccountStatement retrieve(String accountStatementId, AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AccountStatement retrieve(String accountStatementId, AccountStatementRetrieveParams params)
-
retrieve
abstract AccountStatement retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AccountStatement retrieve(AccountStatementRetrieveParams params)
-
retrieve
AccountStatement retrieve(String accountStatementId, RequestOptions requestOptions)
-
list
AccountStatementListPage list()
List Account Statements
-
list
abstract AccountStatementListPage list(AccountStatementListParams params, RequestOptions requestOptions)
-
list
AccountStatementListPage list(AccountStatementListParams params)
-
list
AccountStatementListPage list(RequestOptions requestOptions)
-
-
-
-