Class AccountStatementServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.AccountStatementService.WithRawResponse
public final class AccountStatementServiceImpl.WithRawResponseImpl implements AccountStatementService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountStatementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<AccountStatement>retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<AccountStatementListPage>list(AccountStatementListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.AccountStatementService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountStatementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<AccountStatement> retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<AccountStatementListPage> list(AccountStatementListParams params, RequestOptions requestOptions)
-
-
-
-