Class AccountTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.AccountTransferService
public final class AccountTransferServiceImpl implements AccountTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccountTransfercreate(AccountTransferCreateParams params, RequestOptions requestOptions)AccountTransferretrieve(AccountTransferRetrieveParams params, RequestOptions requestOptions)AccountTransferListPagelist(AccountTransferListParams params, RequestOptions requestOptions)AccountTransferapprove(AccountTransferApproveParams params, RequestOptions requestOptions)AccountTransfercancel(AccountTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.AccountTransferService
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AccountTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
AccountTransfer create(AccountTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
AccountTransfer retrieve(AccountTransferRetrieveParams params, RequestOptions requestOptions)
-
list
AccountTransferListPage list(AccountTransferListParams params, RequestOptions requestOptions)
-
approve
AccountTransfer approve(AccountTransferApproveParams params, RequestOptions requestOptions)
-
cancel
AccountTransfer cancel(AccountTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-