Interface AchPrenotificationService
-
- All Implemented Interfaces:
public interface AchPrenotificationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchPrenotificationService.WithRawResponseA view of AchPrenotificationService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AchPrenotificationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AchPrenotificationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
AchPrenotification create(AchPrenotificationCreateParams params)
Create an ACH Prenotification
-
create
abstract AchPrenotification create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
AchPrenotification retrieve(String achPrenotificationId)
Retrieve an ACH Prenotification
-
retrieve
AchPrenotification retrieve(String achPrenotificationId, AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AchPrenotification retrieve(String achPrenotificationId, AchPrenotificationRetrieveParams params)
-
retrieve
abstract AchPrenotification retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
retrieve
AchPrenotification retrieve(AchPrenotificationRetrieveParams params)
-
retrieve
AchPrenotification retrieve(String achPrenotificationId, RequestOptions requestOptions)
-
list
AchPrenotificationListPage list()
List ACH Prenotifications
-
list
abstract AchPrenotificationListPage list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
list
AchPrenotificationListPage list(AchPrenotificationListParams params)
-
list
AchPrenotificationListPage list(RequestOptions requestOptions)
-
-
-
-