Class AchPrenotificationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.AchPrenotificationService
public final class AchPrenotificationServiceImpl implements AchPrenotificationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotificationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchPrenotificationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AchPrenotificationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AchPrenotificationcreate(AchPrenotificationCreateParams params, RequestOptions requestOptions)AchPrenotificationretrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)AchPrenotificationListPagelist(AchPrenotificationListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.AchPrenotificationService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
AchPrenotificationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AchPrenotificationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
AchPrenotification create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
AchPrenotification retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
list
AchPrenotificationListPage list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
-
-
-