Class AchPrenotificationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.AchPrenotificationService.WithRawResponse
public final class AchPrenotificationServiceImpl.WithRawResponseImpl implements AchPrenotificationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AchPrenotificationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<AchPrenotification>create(AchPrenotificationCreateParams params, RequestOptions requestOptions)HttpResponseFor<AchPrenotification>retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<AchPrenotificationListPage>list(AchPrenotificationListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.AchPrenotificationService.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AchPrenotificationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<AchPrenotification> create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<AchPrenotification> retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<AchPrenotificationListPage> list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
-
-
-