Interface BookkeepingAccountService
-
- All Implemented Interfaces:
public interface BookkeepingAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingAccountService.WithRawResponseA view of BookkeepingAccountService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract BookkeepingAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BookkeepingAccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
BookkeepingAccount create(BookkeepingAccountCreateParams params)
Create a Bookkeeping Account
-
create
abstract BookkeepingAccount create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
BookkeepingAccount update(String bookkeepingAccountId, BookkeepingAccountUpdateParams params)
Update a Bookkeeping Account
-
update
BookkeepingAccount update(String bookkeepingAccountId, BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
update
BookkeepingAccount update(BookkeepingAccountUpdateParams params)
-
update
abstract BookkeepingAccount update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
BookkeepingAccountListPage list()
List Bookkeeping Accounts
-
list
abstract BookkeepingAccountListPage list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
list
BookkeepingAccountListPage list(BookkeepingAccountListParams params)
-
list
BookkeepingAccountListPage list(RequestOptions requestOptions)
-
balance
BookkeepingBalanceLookup balance(String bookkeepingAccountId)
Retrieve a Bookkeeping Account Balance
-
balance
BookkeepingBalanceLookup balance(String bookkeepingAccountId, BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
balance
BookkeepingBalanceLookup balance(String bookkeepingAccountId, BookkeepingAccountBalanceParams params)
-
balance
abstract BookkeepingBalanceLookup balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
balance
BookkeepingBalanceLookup balance(BookkeepingAccountBalanceParams params)
-
balance
BookkeepingBalanceLookup balance(String bookkeepingAccountId, RequestOptions requestOptions)
-
-
-
-