Class BookkeepingAccountServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingAccountService.WithRawResponse
public final class BookkeepingAccountServiceImpl.WithRawResponseImpl implements BookkeepingAccountService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BookkeepingAccountService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<BookkeepingAccount>create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)HttpResponseFor<BookkeepingAccount>update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)HttpResponseFor<BookkeepingAccountListPage>list(BookkeepingAccountListParams params, RequestOptions requestOptions)HttpResponseFor<BookkeepingBalanceLookup>balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.BookkeepingAccountService.WithRawResponse
balance, balance, balance, balance, balance, create, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
BookkeepingAccountService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<BookkeepingAccount> create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<BookkeepingAccount> update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<BookkeepingAccountListPage> list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
balance
HttpResponseFor<BookkeepingBalanceLookup> balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
-
-
-