Interface BookkeepingEntryService
-
- All Implemented Interfaces:
public interface BookkeepingEntryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingEntryService.WithRawResponseA view of BookkeepingEntryService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract BookkeepingEntryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BookkeepingEntryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
BookkeepingEntry retrieve(String bookkeepingEntryId)
Retrieve a Bookkeeping Entry
-
retrieve
BookkeepingEntry retrieve(String bookkeepingEntryId, BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
retrieve
BookkeepingEntry retrieve(String bookkeepingEntryId, BookkeepingEntryRetrieveParams params)
-
retrieve
abstract BookkeepingEntry retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
retrieve
BookkeepingEntry retrieve(BookkeepingEntryRetrieveParams params)
-
retrieve
BookkeepingEntry retrieve(String bookkeepingEntryId, RequestOptions requestOptions)
-
list
BookkeepingEntryListPage list()
List Bookkeeping Entries
-
list
abstract BookkeepingEntryListPage list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
list
BookkeepingEntryListPage list(BookkeepingEntryListParams params)
-
list
BookkeepingEntryListPage list(RequestOptions requestOptions)
-
-
-
-