Class BookkeepingEntryServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingEntryService
public final class BookkeepingEntryServiceImpl implements BookkeepingEntryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingEntryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingEntryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BookkeepingEntryretrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)BookkeepingEntryListPagelist(BookkeepingEntryListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BookkeepingEntryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BookkeepingEntryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
BookkeepingEntry retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
list
BookkeepingEntryListPage list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
-
-
-