Class BookkeepingEntryServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingEntryService.WithRawResponse
public final class BookkeepingEntryServiceImpl.WithRawResponseImpl implements BookkeepingEntryService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description BookkeepingEntryService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<BookkeepingEntry>retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<BookkeepingEntryListPage>list(BookkeepingEntryListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.BookkeepingEntryService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
BookkeepingEntryService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<BookkeepingEntry> retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<BookkeepingEntryListPage> list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
-
-
-