Interface BookkeepingEntrySetService
-
- All Implemented Interfaces:
public interface BookkeepingEntrySetService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingEntrySetService.WithRawResponseA view of BookkeepingEntrySetService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BookkeepingEntrySetService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BookkeepingEntrySetcreate(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)Create a Bookkeeping Entry Set abstract BookkeepingEntrySetcreate(BookkeepingEntrySetCreateParams params)Create a Bookkeeping Entry Set abstract BookkeepingEntrySetretrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)Retrieve a Bookkeeping Entry Set abstract BookkeepingEntrySetretrieve(BookkeepingEntrySetRetrieveParams params)Retrieve a Bookkeeping Entry Set abstract BookkeepingEntrySetListPagelist(BookkeepingEntrySetListParams params, RequestOptions requestOptions)List Bookkeeping Entry Sets abstract BookkeepingEntrySetListPagelist(BookkeepingEntrySetListParams params)List Bookkeeping Entry Sets abstract BookkeepingEntrySetListPagelist()List Bookkeeping Entry Sets BookkeepingEntrySetListPagelist(RequestOptions requestOptions)List Bookkeeping Entry Sets -
-
Method Detail
-
withRawResponse
abstract BookkeepingEntrySetService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract BookkeepingEntrySet create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
Create a Bookkeeping Entry Set
-
create
abstract BookkeepingEntrySet create(BookkeepingEntrySetCreateParams params)
Create a Bookkeeping Entry Set
-
retrieve
abstract BookkeepingEntrySet retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
Retrieve a Bookkeeping Entry Set
-
retrieve
abstract BookkeepingEntrySet retrieve(BookkeepingEntrySetRetrieveParams params)
Retrieve a Bookkeeping Entry Set
-
list
abstract BookkeepingEntrySetListPage list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
List Bookkeeping Entry Sets
-
list
abstract BookkeepingEntrySetListPage list(BookkeepingEntrySetListParams params)
List Bookkeeping Entry Sets
-
list
abstract BookkeepingEntrySetListPage list()
List Bookkeeping Entry Sets
-
list
BookkeepingEntrySetListPage list(RequestOptions requestOptions)
List Bookkeeping Entry Sets
-
-
-
-