Class BookkeepingEntrySetServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingEntrySetService
public final class BookkeepingEntrySetServiceImpl implements BookkeepingEntrySetService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingEntrySetService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingEntrySetServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BookkeepingEntrySetcreate(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)BookkeepingEntrySetretrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)BookkeepingEntrySetListPagelist(BookkeepingEntrySetListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.BookkeepingEntrySetService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
BookkeepingEntrySetService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BookkeepingEntrySetService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
BookkeepingEntrySet create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
-
retrieve
BookkeepingEntrySet retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
-
list
BookkeepingEntrySetListPage list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
-
-
-
-