Class CardDetailServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardDetailService
public final class CardDetailServiceImpl implements CardDetailService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDetailServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardDetailService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardDetailServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardDetailsupdate(CardDetailUpdateParams params, RequestOptions requestOptions)CardIframeUrlcreateDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)CardDetailsdetails(CardDetailDetailsParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.CardDetailService
createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, details, details, details, details, details, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardDetailService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardDetailService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CardDetails update(CardDetailUpdateParams params, RequestOptions requestOptions)
-
createDetailsIframe
CardIframeUrl createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)
-
details
CardDetails details(CardDetailDetailsParams params, RequestOptions requestOptions)
-
-
-
-