Class CardDetailServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardDetailService.WithRawResponse
public final class CardDetailServiceImpl.WithRawResponseImpl implements CardDetailService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardDetailService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardDetails>update(CardDetailUpdateParams params, RequestOptions requestOptions)HttpResponseFor<CardIframeUrl>createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)HttpResponseFor<CardDetails>details(CardDetailDetailsParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.CardDetailService.WithRawResponse
createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, details, details, details, details, details, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardDetailService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
HttpResponseFor<CardDetails> update(CardDetailUpdateParams params, RequestOptions requestOptions)
-
createDetailsIframe
HttpResponseFor<CardIframeUrl> createDetailsIframe(CardDetailCreateDetailsIframeParams params, RequestOptions requestOptions)
-
details
HttpResponseFor<CardDetails> details(CardDetailDetailsParams params, RequestOptions requestOptions)
-
-
-
-