Interface CardDisputeService
-
- All Implemented Interfaces:
public interface CardDisputeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardDisputeService.WithRawResponseA view of CardDisputeService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardDisputeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardDisputecreate(CardDisputeCreateParams params)Create a Card Dispute abstract CardDisputecreate(CardDisputeCreateParams params, RequestOptions requestOptions)CardDisputeretrieve(CardDisputeRetrieveParams params)Retrieve a Card Dispute abstract CardDisputeretrieve(CardDisputeRetrieveParams params, RequestOptions requestOptions)CardDisputeListPagelist()List Card Disputes abstract CardDisputeListPagelist(CardDisputeListParams params, RequestOptions requestOptions)CardDisputeListPagelist(CardDisputeListParams params)CardDisputeListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardDisputeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CardDispute create(CardDisputeCreateParams params)
Create a Card Dispute
-
create
abstract CardDispute create(CardDisputeCreateParams params, RequestOptions requestOptions)
-
retrieve
CardDispute retrieve(CardDisputeRetrieveParams params)
Retrieve a Card Dispute
-
retrieve
abstract CardDispute retrieve(CardDisputeRetrieveParams params, RequestOptions requestOptions)
-
list
CardDisputeListPage list()
List Card Disputes
-
list
abstract CardDisputeListPage list(CardDisputeListParams params, RequestOptions requestOptions)
-
list
CardDisputeListPage list(CardDisputeListParams params)
-
list
CardDisputeListPage list(RequestOptions requestOptions)
-
-
-
-