Class CardDisputeServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardDisputeService
public final class CardDisputeServiceImpl implements CardDisputeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardDisputeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardDisputeServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardDisputecreate(CardDisputeCreateParams params, RequestOptions requestOptions)CardDisputeretrieve(CardDisputeRetrieveParams params, RequestOptions requestOptions)CardDisputeListPagelist(CardDisputeListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardDisputeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardDisputeService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardDispute create(CardDisputeCreateParams params, RequestOptions requestOptions)
-
retrieve
CardDispute retrieve(CardDisputeRetrieveParams params, RequestOptions requestOptions)
-
list
CardDisputeListPage list(CardDisputeListParams params, RequestOptions requestOptions)
-
-
-
-