Interface CardPaymentService
-
- All Implemented Interfaces:
public interface CardPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPaymentService.WithRawResponseA view of CardPaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CardPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardPaymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CardPayment retrieve(String cardPaymentId)
Retrieve a Card Payment
-
retrieve
CardPayment retrieve(String cardPaymentId, CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CardPayment retrieve(String cardPaymentId, CardPaymentRetrieveParams params)
-
retrieve
abstract CardPayment retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CardPayment retrieve(CardPaymentRetrieveParams params)
-
retrieve
CardPayment retrieve(String cardPaymentId, RequestOptions requestOptions)
-
list
CardPaymentListPage list()
List Card Payments
-
list
abstract CardPaymentListPage list(CardPaymentListParams params, RequestOptions requestOptions)
-
list
CardPaymentListPage list(CardPaymentListParams params)
-
list
CardPaymentListPage list(RequestOptions requestOptions)
-
-
-
-