Interface CardPurchaseSupplementService
-
- All Implemented Interfaces:
public interface CardPurchaseSupplementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPurchaseSupplementService.WithRawResponseA view of CardPurchaseSupplementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardPurchaseSupplementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardPurchaseSupplementretrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)Retrieve a Card Purchase Supplement abstract CardPurchaseSupplementretrieve(CardPurchaseSupplementRetrieveParams params)Retrieve a Card Purchase Supplement abstract CardPurchaseSupplementListPagelist(CardPurchaseSupplementListParams params, RequestOptions requestOptions)List Card Purchase Supplements abstract CardPurchaseSupplementListPagelist(CardPurchaseSupplementListParams params)List Card Purchase Supplements abstract CardPurchaseSupplementListPagelist()List Card Purchase Supplements CardPurchaseSupplementListPagelist(RequestOptions requestOptions)List Card Purchase Supplements -
-
Method Detail
-
withRawResponse
abstract CardPurchaseSupplementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract CardPurchaseSupplement retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
Retrieve a Card Purchase Supplement
-
retrieve
abstract CardPurchaseSupplement retrieve(CardPurchaseSupplementRetrieveParams params)
Retrieve a Card Purchase Supplement
-
list
abstract CardPurchaseSupplementListPage list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)
List Card Purchase Supplements
-
list
abstract CardPurchaseSupplementListPage list(CardPurchaseSupplementListParams params)
List Card Purchase Supplements
-
list
abstract CardPurchaseSupplementListPage list()
List Card Purchase Supplements
-
list
CardPurchaseSupplementListPage list(RequestOptions requestOptions)
List Card Purchase Supplements
-
-
-
-