Class CardPurchaseSupplementServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardPurchaseSupplementService
public final class CardPurchaseSupplementServiceImpl implements CardPurchaseSupplementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPurchaseSupplementServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPurchaseSupplementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPurchaseSupplementServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPurchaseSupplementretrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)CardPurchaseSupplementListPagelist(CardPurchaseSupplementListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardPurchaseSupplementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardPurchaseSupplementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CardPurchaseSupplement retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
-
list
CardPurchaseSupplementListPage list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)
-
-
-
-