Class CardPurchaseSupplementServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardPurchaseSupplementService.WithRawResponse
public final class CardPurchaseSupplementServiceImpl.WithRawResponseImpl implements CardPurchaseSupplementService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardPurchaseSupplementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPurchaseSupplement>retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<CardPurchaseSupplementListPage>list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.CardPurchaseSupplementService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardPurchaseSupplementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<CardPurchaseSupplement> retrieve(CardPurchaseSupplementRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<CardPurchaseSupplementListPage> list(CardPurchaseSupplementListParams params, RequestOptions requestOptions)
-
-
-
-