Class CardPushTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardPushTransferService
public final class CardPushTransferServiceImpl implements CardPushTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPushTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPushTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPushTransfercreate(CardPushTransferCreateParams params, RequestOptions requestOptions)CardPushTransferretrieve(CardPushTransferRetrieveParams params, RequestOptions requestOptions)CardPushTransferListPagelist(CardPushTransferListParams params, RequestOptions requestOptions)CardPushTransferapprove(CardPushTransferApproveParams params, RequestOptions requestOptions)CardPushTransfercancel(CardPushTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.CardPushTransferService
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardPushTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardPushTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPushTransfer create(CardPushTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CardPushTransfer retrieve(CardPushTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CardPushTransferListPage list(CardPushTransferListParams params, RequestOptions requestOptions)
-
approve
CardPushTransfer approve(CardPushTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CardPushTransfer cancel(CardPushTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-