Interface CardService
-
- All Implemented Interfaces:
public interface CardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardService.WithRawResponseA view of CardService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Cardcreate(CardCreateParams params)Create a Card abstract Cardcreate(CardCreateParams params, RequestOptions requestOptions)Cardretrieve(String cardId)Retrieve a Card Cardretrieve(String cardId, CardRetrieveParams params, RequestOptions requestOptions)Cardretrieve(String cardId, CardRetrieveParams params)abstract Cardretrieve(CardRetrieveParams params, RequestOptions requestOptions)Cardretrieve(CardRetrieveParams params)Cardretrieve(String cardId, RequestOptions requestOptions)Cardupdate(String cardId)Update a Card Cardupdate(String cardId, CardUpdateParams params, RequestOptions requestOptions)Cardupdate(String cardId, CardUpdateParams params)abstract Cardupdate(CardUpdateParams params, RequestOptions requestOptions)Cardupdate(CardUpdateParams params)Cardupdate(String cardId, RequestOptions requestOptions)CardListPagelist()List Cards abstract CardListPagelist(CardListParams params, RequestOptions requestOptions)CardListPagelist(CardListParams params)CardListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Card create(CardCreateParams params)
Create a Card
-
create
abstract Card create(CardCreateParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(String cardId, CardRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(String cardId, CardRetrieveParams params)
-
retrieve
abstract Card retrieve(CardRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(CardRetrieveParams params)
-
retrieve
Card retrieve(String cardId, RequestOptions requestOptions)
-
update
Card update(String cardId, CardUpdateParams params, RequestOptions requestOptions)
-
update
Card update(String cardId, CardUpdateParams params)
-
update
abstract Card update(CardUpdateParams params, RequestOptions requestOptions)
-
update
Card update(CardUpdateParams params)
-
update
Card update(String cardId, RequestOptions requestOptions)
-
list
CardListPage list()
List Cards
-
list
abstract CardListPage list(CardListParams params, RequestOptions requestOptions)
-
list
CardListPage list(CardListParams params)
-
list
CardListPage list(RequestOptions requestOptions)
-
-
-
-