Class CardServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardService
public final class CardServiceImpl implements CardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Cardcreate(CardCreateParams params, RequestOptions requestOptions)Cardretrieve(CardRetrieveParams params, RequestOptions requestOptions)Cardupdate(CardUpdateParams params, RequestOptions requestOptions)CardListPagelist(CardListParams params, RequestOptions requestOptions)CardIframeUrlcreateDetailsIframe(CardCreateDetailsIframeParams params, RequestOptions requestOptions)CardDetailsdetails(CardDetailsParams params, RequestOptions requestOptions)CardDetailsupdatePin(CardUpdatePinParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.CardService
create, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, details, details, details, details, details, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update, updatePin, updatePin, updatePin -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Card create(CardCreateParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(CardRetrieveParams params, RequestOptions requestOptions)
-
update
Card update(CardUpdateParams params, RequestOptions requestOptions)
-
list
CardListPage list(CardListParams params, RequestOptions requestOptions)
-
createDetailsIframe
CardIframeUrl createDetailsIframe(CardCreateDetailsIframeParams params, RequestOptions requestOptions)
-
details
CardDetails details(CardDetailsParams params, RequestOptions requestOptions)
-
updatePin
CardDetails updatePin(CardUpdatePinParams params, RequestOptions requestOptions)
-
-
-
-