Class CardValidationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardValidationService
public final class CardValidationServiceImpl implements CardValidationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardValidationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardValidationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardValidationcreate(CardValidationCreateParams params, RequestOptions requestOptions)CardValidationretrieve(CardValidationRetrieveParams params, RequestOptions requestOptions)CardValidationListPagelist(CardValidationListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardValidationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardValidationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardValidation create(CardValidationCreateParams params, RequestOptions requestOptions)
-
retrieve
CardValidation retrieve(CardValidationRetrieveParams params, RequestOptions requestOptions)
-
list
CardValidationListPage list(CardValidationListParams params, RequestOptions requestOptions)
-
-
-
-