Class CheckTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CheckTransferService
public final class CheckTransferServiceImpl implements CheckTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CheckTransfercreate(CheckTransferCreateParams params, RequestOptions requestOptions)CheckTransferretrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)CheckTransferListPagelist(CheckTransferListParams params, RequestOptions requestOptions)CheckTransferapprove(CheckTransferApproveParams params, RequestOptions requestOptions)CheckTransfercancel(CheckTransferCancelParams params, RequestOptions requestOptions)CheckTransferstopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.CheckTransferService
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, stopPayment, stopPayment, stopPayment, stopPayment, stopPayment -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CheckTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CheckTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CheckTransfer create(CheckTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CheckTransfer retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CheckTransferListPage list(CheckTransferListParams params, RequestOptions requestOptions)
-
approve
CheckTransfer approve(CheckTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CheckTransfer cancel(CheckTransferCancelParams params, RequestOptions requestOptions)
-
stopPayment
CheckTransfer stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)
-
-
-
-