Class DeclinedTransactionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.DeclinedTransactionService
public final class DeclinedTransactionServiceImpl implements DeclinedTransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransactionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DeclinedTransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DeclinedTransactionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DeclinedTransactionretrieve(DeclinedTransactionRetrieveParams params, RequestOptions requestOptions)DeclinedTransactionListPagelist(DeclinedTransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DeclinedTransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DeclinedTransactionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
DeclinedTransaction retrieve(DeclinedTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
DeclinedTransactionListPage list(DeclinedTransactionListParams params, RequestOptions requestOptions)
-
-
-
-