Interface DigitalCardProfileService
-
- All Implemented Interfaces:
public interface DigitalCardProfileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalCardProfileService.WithRawResponseA view of DigitalCardProfileService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract DigitalCardProfileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
DigitalCardProfile create(DigitalCardProfileCreateParams params)
Create a Digital Card Profile
-
create
abstract DigitalCardProfile create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
DigitalCardProfile retrieve(DigitalCardProfileRetrieveParams params)
Retrieve a Digital Card Profile
-
retrieve
abstract DigitalCardProfile retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)
-
list
DigitalCardProfileListPage list()
List Card Profiles
-
list
abstract DigitalCardProfileListPage list(DigitalCardProfileListParams params, RequestOptions requestOptions)
-
list
DigitalCardProfileListPage list(DigitalCardProfileListParams params)
-
list
DigitalCardProfileListPage list(RequestOptions requestOptions)
-
archive
DigitalCardProfile archive(DigitalCardProfileArchiveParams params)
Archive a Digital Card Profile
-
archive
abstract DigitalCardProfile archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)
-
clone
DigitalCardProfile clone(DigitalCardProfileCloneParams params)
Clones a Digital Card Profile
-
clone
abstract DigitalCardProfile clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)
-
-
-
-