Class DigitalCardProfileServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.DigitalCardProfileService
public final class DigitalCardProfileServiceImpl implements DigitalCardProfileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalCardProfileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalCardProfileServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DigitalCardProfilecreate(DigitalCardProfileCreateParams params, RequestOptions requestOptions)DigitalCardProfileretrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)DigitalCardProfileListPagelist(DigitalCardProfileListParams params, RequestOptions requestOptions)DigitalCardProfilearchive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)DigitalCardProfileclone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.DigitalCardProfileService
archive, archive, archive, archive, archive, clone, clone, clone, clone, clone, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
DigitalCardProfileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigitalCardProfileService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
DigitalCardProfile create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
DigitalCardProfile retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)
-
list
DigitalCardProfileListPage list(DigitalCardProfileListParams params, RequestOptions requestOptions)
-
archive
DigitalCardProfile archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)
-
clone
DigitalCardProfile clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)
-
-
-
-