Class DigitalCardProfileServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.DigitalCardProfileService.WithRawResponse
public final class DigitalCardProfileServiceImpl.WithRawResponseImpl implements DigitalCardProfileService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DigitalCardProfileService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<DigitalCardProfile>create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)HttpResponseFor<DigitalCardProfile>retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<DigitalCardProfileListPage>list(DigitalCardProfileListParams params, RequestOptions requestOptions)HttpResponseFor<DigitalCardProfile>archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)HttpResponseFor<DigitalCardProfile>clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.DigitalCardProfileService.WithRawResponse
archive, archive, archive, archive, archive, clone, clone, clone, clone, clone, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DigitalCardProfileService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<DigitalCardProfile> create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<DigitalCardProfile> retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<DigitalCardProfileListPage> list(DigitalCardProfileListParams params, RequestOptions requestOptions)
-
archive
HttpResponseFor<DigitalCardProfile> archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)
-
clone
HttpResponseFor<DigitalCardProfile> clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)
-
-
-
-