Interface DigitalWalletTokenService
-
- All Implemented Interfaces:
public interface DigitalWalletTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalWalletTokenService.WithRawResponseA view of DigitalWalletTokenService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalWalletTokenretrieve(DigitalWalletTokenRetrieveParams params)Retrieve a Digital Wallet Token abstract DigitalWalletTokenretrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)DigitalWalletTokenListPagelist()List Digital Wallet Tokens abstract DigitalWalletTokenListPagelist(DigitalWalletTokenListParams params, RequestOptions requestOptions)DigitalWalletTokenListPagelist(DigitalWalletTokenListParams params)DigitalWalletTokenListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DigitalWalletTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
DigitalWalletToken retrieve(DigitalWalletTokenRetrieveParams params)
Retrieve a Digital Wallet Token
-
retrieve
abstract DigitalWalletToken retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
list
DigitalWalletTokenListPage list()
List Digital Wallet Tokens
-
list
abstract DigitalWalletTokenListPage list(DigitalWalletTokenListParams params, RequestOptions requestOptions)
-
list
DigitalWalletTokenListPage list(DigitalWalletTokenListParams params)
-
list
DigitalWalletTokenListPage list(RequestOptions requestOptions)
-
-
-
-