Class DigitalWalletTokenServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.DigitalWalletTokenService
public final class DigitalWalletTokenServiceImpl implements DigitalWalletTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalWalletTokenServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DigitalWalletTokenretrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)DigitalWalletTokenListPagelist(DigitalWalletTokenListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DigitalWalletTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigitalWalletTokenService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
DigitalWalletToken retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
list
DigitalWalletTokenListPage list(DigitalWalletTokenListParams params, RequestOptions requestOptions)
-
-
-
-