Class DigitalWalletTokenServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.DigitalWalletTokenService.WithRawResponse
public final class DigitalWalletTokenServiceImpl.WithRawResponseImpl implements DigitalWalletTokenService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<DigitalWalletToken>retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<DigitalWalletTokenListPage>list(DigitalWalletTokenListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.DigitalWalletTokenService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
DigitalWalletTokenService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<DigitalWalletToken> retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<DigitalWalletTokenListPage> list(DigitalWalletTokenListParams params, RequestOptions requestOptions)
-
-
-
-