Interface DocumentService
-
- All Implemented Interfaces:
public interface DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentService.WithRawResponseA view of DocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Documentretrieve(DocumentRetrieveParams params)Retrieve a Document abstract Documentretrieve(DocumentRetrieveParams params, RequestOptions requestOptions)DocumentListPagelist()List Documents abstract DocumentListPagelist(DocumentListParams params, RequestOptions requestOptions)DocumentListPagelist(DocumentListParams params)DocumentListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
Document retrieve(DocumentRetrieveParams params)
Retrieve a Document
-
retrieve
abstract Document retrieve(DocumentRetrieveParams params, RequestOptions requestOptions)
-
list
DocumentListPage list()
List Documents
-
list
abstract DocumentListPage list(DocumentListParams params, RequestOptions requestOptions)
-
list
DocumentListPage list(DocumentListParams params)
-
list
DocumentListPage list(RequestOptions requestOptions)
-
-
-
-