Interface EntityService
-
- All Implemented Interfaces:
public interface EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityService.WithRawResponseA view of EntityService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EntityService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Entity create(EntityCreateParams params)
Create an Entity
-
create
abstract Entity create(EntityCreateParams params, RequestOptions requestOptions)
-
retrieve
Entity retrieve(String entityId, EntityRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Entity retrieve(String entityId, EntityRetrieveParams params)
-
retrieve
abstract Entity retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Entity retrieve(EntityRetrieveParams params)
-
retrieve
Entity retrieve(String entityId, RequestOptions requestOptions)
-
update
Entity update(String entityId, EntityUpdateParams params, RequestOptions requestOptions)
-
update
Entity update(String entityId, EntityUpdateParams params)
-
update
abstract Entity update(EntityUpdateParams params, RequestOptions requestOptions)
-
update
Entity update(EntityUpdateParams params)
-
update
Entity update(String entityId, RequestOptions requestOptions)
-
list
EntityListPage list()
List Entities
-
list
abstract EntityListPage list(EntityListParams params, RequestOptions requestOptions)
-
list
EntityListPage list(EntityListParams params)
-
list
EntityListPage list(RequestOptions requestOptions)
-
archive
Entity archive(String entityId, EntityArchiveParams params, RequestOptions requestOptions)
-
archive
Entity archive(String entityId, EntityArchiveParams params)
-
archive
abstract Entity archive(EntityArchiveParams params, RequestOptions requestOptions)
-
archive
Entity archive(EntityArchiveParams params)
-
archive
Entity archive(String entityId, RequestOptions requestOptions)
-
archiveBeneficialOwner
Entity archiveBeneficialOwner(String entityId, EntityArchiveBeneficialOwnerParams params)
Archive a beneficial owner for a corporate Entity
-
archiveBeneficialOwner
Entity archiveBeneficialOwner(String entityId, EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)
-
archiveBeneficialOwner
Entity archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params)
-
archiveBeneficialOwner
abstract Entity archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)
-
createBeneficialOwner
Entity createBeneficialOwner(String entityId, EntityCreateBeneficialOwnerParams params)
Create a beneficial owner for a corporate Entity
-
createBeneficialOwner
Entity createBeneficialOwner(String entityId, EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)
-
createBeneficialOwner
Entity createBeneficialOwner(EntityCreateBeneficialOwnerParams params)
-
createBeneficialOwner
abstract Entity createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)
-
updateBeneficialOwnerAddress
Entity updateBeneficialOwnerAddress(String entityId, EntityUpdateBeneficialOwnerAddressParams params)
Update the address for a beneficial owner belonging to a corporate Entity
-
updateBeneficialOwnerAddress
Entity updateBeneficialOwnerAddress(String entityId, EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)
-
updateBeneficialOwnerAddress
Entity updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params)
-
updateBeneficialOwnerAddress
abstract Entity updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)
-
-
-
-