Class EntityServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EntityService
public final class EntityServiceImpl implements EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EntityService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EntityServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Entitycreate(EntityCreateParams params, RequestOptions requestOptions)Entityretrieve(EntityRetrieveParams params, RequestOptions requestOptions)Entityupdate(EntityUpdateParams params, RequestOptions requestOptions)EntityListPagelist(EntityListParams params, RequestOptions requestOptions)Entityarchive(EntityArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.EntityService
archive, archive, archive, archive, archive, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EntityService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Entity create(EntityCreateParams params, RequestOptions requestOptions)
-
retrieve
Entity retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
-
update
Entity update(EntityUpdateParams params, RequestOptions requestOptions)
-
list
EntityListPage list(EntityListParams params, RequestOptions requestOptions)
-
archive
Entity archive(EntityArchiveParams params, RequestOptions requestOptions)
-
-
-
-