Interface EventService
-
- All Implemented Interfaces:
public interface EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EventServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Eventretrieve(String eventId)Retrieve an Event Eventretrieve(String eventId, EventRetrieveParams params, RequestOptions requestOptions)Eventretrieve(String eventId, EventRetrieveParams params)abstract Eventretrieve(EventRetrieveParams params, RequestOptions requestOptions)Eventretrieve(EventRetrieveParams params)Eventretrieve(String eventId, RequestOptions requestOptions)EventListPagelist()List Events abstract EventListPagelist(EventListParams params, RequestOptions requestOptions)EventListPagelist(EventListParams params)EventListPagelist(RequestOptions requestOptions)abstract UnwrapWebhookEventunwrap(String body)Unwraps a webhook event from its JSON representation. abstract UnwrapWebhookEventunwrap(UnwrapWebhookParams unwrapParams)Unwraps a webhook event from its JSON representation. -
-
Method Detail
-
withRawResponse
abstract EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EventService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
Event retrieve(String eventId, EventRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Event retrieve(String eventId, EventRetrieveParams params)
-
retrieve
abstract Event retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Event retrieve(EventRetrieveParams params)
-
retrieve
Event retrieve(String eventId, RequestOptions requestOptions)
-
list
EventListPage list()
List Events
-
list
abstract EventListPage list(EventListParams params, RequestOptions requestOptions)
-
list
EventListPage list(EventListParams params)
-
list
EventListPage list(RequestOptions requestOptions)
-
unwrap
abstract UnwrapWebhookEvent unwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
abstract UnwrapWebhookEvent unwrap(UnwrapWebhookParams unwrapParams)
Unwraps a webhook event from its JSON representation.
-
-
-
-