Class EventServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EventService
public final class EventServiceImpl implements EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Eventretrieve(EventRetrieveParams params, RequestOptions requestOptions)EventListPagelist(EventListParams params, RequestOptions requestOptions)UnwrapWebhookEventunwrap(String body)Unwraps a webhook event from its JSON representation. UnwrapWebhookEventunwrap(UnwrapWebhookParams unwrapParams)Unwraps a webhook event from its JSON representation. -
-
Method Detail
-
withRawResponse
EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
Event retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
EventListPage list(EventListParams params, RequestOptions requestOptions)
-
unwrap
UnwrapWebhookEvent unwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
UnwrapWebhookEvent unwrap(UnwrapWebhookParams unwrapParams)
Unwraps a webhook event from its JSON representation.
-
-
-
-