Class EventServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EventService.WithRawResponse
public final class EventServiceImpl.WithRawResponseImpl implements EventService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Event>retrieve(EventRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<EventListPage>list(EventListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EventService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<Event> retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<EventListPage> list(EventListParams params, RequestOptions requestOptions)
-
-
-
-