Interface EventSubscriptionService
-
- All Implemented Interfaces:
public interface EventSubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventSubscriptionService.WithRawResponseA view of EventSubscriptionService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract EventSubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
EventSubscription create(EventSubscriptionCreateParams params)
Create an Event Subscription
-
create
abstract EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params)
Retrieve an Event Subscription
-
retrieve
abstract EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
EventSubscription update(EventSubscriptionUpdateParams params)
Update an Event Subscription
-
update
abstract EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list()
List Event Subscriptions
-
list
abstract EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params)
-
list
EventSubscriptionListPage list(RequestOptions requestOptions)
-
-
-
-