Class EventSubscriptionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EventSubscriptionService
public final class EventSubscriptionServiceImpl implements EventSubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventSubscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventSubscriptionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EventSubscriptioncreate(EventSubscriptionCreateParams params, RequestOptions requestOptions)EventSubscriptionretrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)EventSubscriptionupdate(EventSubscriptionUpdateParams params, RequestOptions requestOptions)EventSubscriptionListPagelist(EventSubscriptionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.EventSubscriptionService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EventSubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EventSubscriptionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
-
-
-