Class EventSubscriptionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EventSubscriptionService.WithRawResponse
public final class EventSubscriptionServiceImpl.WithRawResponseImpl implements EventSubscriptionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EventSubscriptionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<EventSubscription>create(EventSubscriptionCreateParams params, RequestOptions requestOptions)HttpResponseFor<EventSubscription>retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<EventSubscription>update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)HttpResponseFor<EventSubscriptionListPage>list(EventSubscriptionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.EventSubscriptionService.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
EventSubscriptionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<EventSubscription> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<EventSubscription> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<EventSubscription> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<EventSubscriptionListPage> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
-
-
-