Interface ExportService
-
- All Implemented Interfaces:
public interface ExportService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportService.WithRawResponseA view of ExportService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExportService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ExportServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Exportcreate(ExportCreateParams params)Create an Export abstract Exportcreate(ExportCreateParams params, RequestOptions requestOptions)Exportretrieve(String exportId)Retrieve an Export Exportretrieve(String exportId, ExportRetrieveParams params, RequestOptions requestOptions)Exportretrieve(String exportId, ExportRetrieveParams params)abstract Exportretrieve(ExportRetrieveParams params, RequestOptions requestOptions)Exportretrieve(ExportRetrieveParams params)Exportretrieve(String exportId, RequestOptions requestOptions)ExportListPagelist()List Exports abstract ExportListPagelist(ExportListParams params, RequestOptions requestOptions)ExportListPagelist(ExportListParams params)ExportListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExportService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExportService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Export create(ExportCreateParams params)
Create an Export
-
create
abstract Export create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
Export retrieve(String exportId, ExportRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Export retrieve(String exportId, ExportRetrieveParams params)
-
retrieve
abstract Export retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Export retrieve(ExportRetrieveParams params)
-
retrieve
Export retrieve(String exportId, RequestOptions requestOptions)
-
list
ExportListPage list()
List Exports
-
list
abstract ExportListPage list(ExportListParams params, RequestOptions requestOptions)
-
list
ExportListPage list(ExportListParams params)
-
list
ExportListPage list(RequestOptions requestOptions)
-
-
-
-