Class ExportServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.ExportService
public final class ExportServiceImpl implements ExportService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ExportService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Exportcreate(ExportCreateParams params, RequestOptions requestOptions)Exportretrieve(ExportRetrieveParams params, RequestOptions requestOptions)ExportListPagelist(ExportListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ExportService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Export create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
Export retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
list
ExportListPage list(ExportListParams params, RequestOptions requestOptions)
-
-
-
-