Class ExportServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.ExportService.WithRawResponse
public final class ExportServiceImpl.WithRawResponseImpl implements ExportService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ExportService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Export>create(ExportCreateParams params, RequestOptions requestOptions)HttpResponseFor<Export>retrieve(ExportRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<ExportListPage>list(ExportListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.ExportService.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
ExportService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<Export> retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<ExportListPage> list(ExportListParams params, RequestOptions requestOptions)
-
-
-
-