Interface ExternalAccountService
-
- All Implemented Interfaces:
public interface ExternalAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExternalAccountService.WithRawResponseA view of ExternalAccountService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract ExternalAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExternalAccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ExternalAccount create(ExternalAccountCreateParams params)
Create an External Account
-
create
abstract ExternalAccount create(ExternalAccountCreateParams params, RequestOptions requestOptions)
-
retrieve
ExternalAccount retrieve(String externalAccountId)
Retrieve an External Account
-
retrieve
ExternalAccount retrieve(String externalAccountId, ExternalAccountRetrieveParams params, RequestOptions requestOptions)
-
retrieve
ExternalAccount retrieve(String externalAccountId, ExternalAccountRetrieveParams params)
-
retrieve
abstract ExternalAccount retrieve(ExternalAccountRetrieveParams params, RequestOptions requestOptions)
-
retrieve
ExternalAccount retrieve(ExternalAccountRetrieveParams params)
-
retrieve
ExternalAccount retrieve(String externalAccountId, RequestOptions requestOptions)
-
update
ExternalAccount update(String externalAccountId)
Update an External Account
-
update
ExternalAccount update(String externalAccountId, ExternalAccountUpdateParams params, RequestOptions requestOptions)
-
update
ExternalAccount update(String externalAccountId, ExternalAccountUpdateParams params)
-
update
abstract ExternalAccount update(ExternalAccountUpdateParams params, RequestOptions requestOptions)
-
update
ExternalAccount update(ExternalAccountUpdateParams params)
-
update
ExternalAccount update(String externalAccountId, RequestOptions requestOptions)
-
list
ExternalAccountListPage list()
List External Accounts
-
list
abstract ExternalAccountListPage list(ExternalAccountListParams params, RequestOptions requestOptions)
-
list
ExternalAccountListPage list(ExternalAccountListParams params)
-
list
ExternalAccountListPage list(RequestOptions requestOptions)
-
-
-
-