Interface FileLinkService
-
- All Implemented Interfaces:
public interface FileLinkService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileLinkService.WithRawResponseA view of FileLinkService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FileLinkService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FileLinkServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileLinkcreate(FileLinkCreateParams params)Create a File Link abstract FileLinkcreate(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FileLinkService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FileLinkService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
FileLink create(FileLinkCreateParams params)
Create a File Link
-
create
abstract FileLink create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-