Interface FileLinkService.WithRawResponse
-
- All Implemented Interfaces:
public interface FileLinkService.WithRawResponseA view of FileLinkService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract FileLinkService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<FileLink>create(FileLinkCreateParams params)Returns a raw HTTP response for post /file_links, but is otherwise the same as FileLinkService.create.abstract HttpResponseFor<FileLink>create(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract FileLinkService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<FileLink> create(FileLinkCreateParams params)
Returns a raw HTTP response for
post /file_links, but is otherwise the same as FileLinkService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<FileLink> create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-