Class FileLinkServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.FileLinkService
public final class FileLinkServiceImpl implements FileLinkService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileLinkServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileLinkService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileLinkServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileLinkcreate(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileLinkService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileLinkService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
FileLink create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-