Class FileLinkServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.FileLinkService.WithRawResponse
public final class FileLinkServiceImpl.WithRawResponseImpl implements FileLinkService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FileLinkService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<FileLink>create(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
FileLinkService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<FileLink> create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-