Interface FileService
-
- All Implemented Interfaces:
public interface FileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileService.WithRawResponseA view of FileService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Filecreate(FileCreateParams params, RequestOptions requestOptions)To upload a file to Increase, you'll need to send a request of Content-Type multipart/form-data.abstract Filecreate(FileCreateParams params)To upload a file to Increase, you'll need to send a request of Content-Type multipart/form-data.abstract Fileretrieve(FileRetrieveParams params, RequestOptions requestOptions)Retrieve a File abstract Fileretrieve(FileRetrieveParams params)Retrieve a File abstract FileListPagelist(FileListParams params, RequestOptions requestOptions)List Files abstract FileListPagelist(FileListParams params)List Files abstract FileListPagelist()List Files FileListPagelist(RequestOptions requestOptions)List Files -
-
Method Detail
-
withRawResponse
abstract FileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract File create(FileCreateParams params, RequestOptions requestOptions)
To upload a file to Increase, you'll need to send a request of Content-Type
multipart/form-data. The request should contain the file you would like to upload, as well as the parameters for creating a file.
-
create
abstract File create(FileCreateParams params)
To upload a file to Increase, you'll need to send a request of Content-Type
multipart/form-data. The request should contain the file you would like to upload, as well as the parameters for creating a file.
-
retrieve
abstract File retrieve(FileRetrieveParams params, RequestOptions requestOptions)
Retrieve a File
-
retrieve
abstract File retrieve(FileRetrieveParams params)
Retrieve a File
-
list
abstract FileListPage list(FileListParams params, RequestOptions requestOptions)
List Files
-
list
abstract FileListPage list(FileListParams params)
List Files
-
list
abstract FileListPage list()
List Files
-
list
FileListPage list(RequestOptions requestOptions)
List Files
-
-
-
-