Class FileServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.FileService
public final class FileServiceImpl implements FileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Filecreate(FileCreateParams params, RequestOptions requestOptions)To upload a file to Increase, you'll need to send a request of Content-Type multipart/form-data.Fileretrieve(FileRetrieveParams params, RequestOptions requestOptions)Retrieve a File FileListPagelist(FileListParams params, RequestOptions requestOptions)List Files -
-
Method Detail
-
withRawResponse
FileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
File create(FileCreateParams params, RequestOptions requestOptions)
To upload a file to Increase, you'll need to send a request of Content-Type
multipart/form-data. The request should contain the file you would like to upload, as well as the parameters for creating a file.
-
retrieve
File retrieve(FileRetrieveParams params, RequestOptions requestOptions)
Retrieve a File
-
list
FileListPage list(FileListParams params, RequestOptions requestOptions)
List Files
-
-
-
-