Interface GroupService
-
- All Implemented Interfaces:
public interface GroupService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupService.WithRawResponseA view of GroupService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract GroupServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Groupretrieve()Returns details for the currently authenticated Group. abstract Groupretrieve(GroupRetrieveParams params, RequestOptions requestOptions)Groupretrieve(GroupRetrieveParams params)Groupretrieve(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract GroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract GroupService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
abstract Group retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Group retrieve(GroupRetrieveParams params)
-
retrieve
Group retrieve(RequestOptions requestOptions)
-
-
-
-