Interface GroupService.WithRawResponse
-
- All Implemented Interfaces:
public interface GroupService.WithRawResponseA view of GroupService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract GroupService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Group>retrieve()Returns a raw HTTP response for get /groups/current, but is otherwise the same as GroupService.retrieve.abstract HttpResponseFor<Group>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<Group>retrieve(GroupRetrieveParams params)HttpResponseFor<Group>retrieve(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract GroupService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
@MustBeClosed() HttpResponseFor<Group> retrieve()
Returns a raw HTTP response for
get /groups/current, but is otherwise the same as GroupService.retrieve.
-
retrieve
@MustBeClosed() abstract HttpResponseFor<Group> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
@MustBeClosed() HttpResponseFor<Group> retrieve(GroupRetrieveParams params)
-
retrieve
@MustBeClosed() HttpResponseFor<Group> retrieve(RequestOptions requestOptions)
-
-
-
-