Class GroupServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.GroupService
public final class GroupServiceImpl implements GroupService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. GroupServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Groupretrieve(GroupRetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
GroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
GroupService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
Group retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
-
-
-