Class GroupServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.GroupService.WithRawResponse
public final class GroupServiceImpl.WithRawResponseImpl implements GroupService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description GroupService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Group>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
GroupService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<Group> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
-
-
-