Interface InboundAchTransferService
-
- All Implemented Interfaces:
public interface InboundAchTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundAchTransferService.WithRawResponseA view of InboundAchTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundAchTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundAchTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
InboundAchTransfer retrieve(String inboundAchTransferId)
Retrieve an Inbound ACH Transfer
-
retrieve
InboundAchTransfer retrieve(String inboundAchTransferId, InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
InboundAchTransfer retrieve(String inboundAchTransferId, InboundAchTransferRetrieveParams params)
-
retrieve
abstract InboundAchTransfer retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
InboundAchTransfer retrieve(InboundAchTransferRetrieveParams params)
-
retrieve
InboundAchTransfer retrieve(String inboundAchTransferId, RequestOptions requestOptions)
-
list
InboundAchTransferListPage list()
List Inbound ACH Transfers
-
list
abstract InboundAchTransferListPage list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
list
InboundAchTransferListPage list(InboundAchTransferListParams params)
-
list
InboundAchTransferListPage list(RequestOptions requestOptions)
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(String inboundAchTransferId)
Create a notification of change for an Inbound ACH Transfer
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(String inboundAchTransferId, InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(String inboundAchTransferId, InboundAchTransferCreateNotificationOfChangeParams params)
-
createNotificationOfChange
abstract InboundAchTransfer createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params)
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(String inboundAchTransferId, RequestOptions requestOptions)
-
decline
InboundAchTransfer decline(String inboundAchTransferId)
Decline an Inbound ACH Transfer
-
decline
InboundAchTransfer decline(String inboundAchTransferId, InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
decline
InboundAchTransfer decline(String inboundAchTransferId, InboundAchTransferDeclineParams params)
-
decline
abstract InboundAchTransfer decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
decline
InboundAchTransfer decline(InboundAchTransferDeclineParams params)
-
decline
InboundAchTransfer decline(String inboundAchTransferId, RequestOptions requestOptions)
-
transferReturn
InboundAchTransfer transferReturn(String inboundAchTransferId, InboundAchTransferTransferReturnParams params)
Return an Inbound ACH Transfer
-
transferReturn
InboundAchTransfer transferReturn(String inboundAchTransferId, InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
transferReturn
InboundAchTransfer transferReturn(InboundAchTransferTransferReturnParams params)
-
transferReturn
abstract InboundAchTransfer transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-