Class InboundAchTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundAchTransferService
public final class InboundAchTransferServiceImpl implements InboundAchTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundAchTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundAchTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundAchTransferretrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)InboundAchTransferListPagelist(InboundAchTransferListParams params, RequestOptions requestOptions)InboundAchTransfercreateNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)InboundAchTransferdecline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)InboundAchTransfertransferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundAchTransferService
createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, transferReturn, transferReturn, transferReturn -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundAchTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundAchTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
InboundAchTransfer retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
list
InboundAchTransferListPage list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
decline
InboundAchTransfer decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
transferReturn
InboundAchTransfer transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-