Class InboundAchTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundAchTransferService.WithRawResponse
public final class InboundAchTransferServiceImpl.WithRawResponseImpl implements InboundAchTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundAchTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundAchTransfer>retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<InboundAchTransferListPage>list(InboundAchTransferListParams params, RequestOptions requestOptions)HttpResponseFor<InboundAchTransfer>createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)HttpResponseFor<InboundAchTransfer>decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)HttpResponseFor<InboundAchTransfer>transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundAchTransferService.WithRawResponse
createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, transferReturn, transferReturn, transferReturn -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundAchTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<InboundAchTransferListPage> list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
createNotificationOfChange
HttpResponseFor<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
decline
HttpResponseFor<InboundAchTransfer> decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
transferReturn
HttpResponseFor<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-