Class InboundCheckDepositServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundCheckDepositService
public final class InboundCheckDepositServiceImpl implements InboundCheckDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundCheckDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundCheckDepositServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundCheckDepositretrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)InboundCheckDepositListPagelist(InboundCheckDepositListParams params, RequestOptions requestOptions)InboundCheckDepositdecline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)InboundCheckDepositreturn_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundCheckDepositService
decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, return_, return_, return_ -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundCheckDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundCheckDepositService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
InboundCheckDeposit retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
list
InboundCheckDepositListPage list(InboundCheckDepositListParams params, RequestOptions requestOptions)
-
decline
InboundCheckDeposit decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
return_
InboundCheckDeposit return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
-
-
-