Class InboundCheckDepositServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundCheckDepositService.WithRawResponse
public final class InboundCheckDepositServiceImpl.WithRawResponseImpl implements InboundCheckDepositService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundCheckDepositService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundCheckDeposit>retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<InboundCheckDepositListPage>list(InboundCheckDepositListParams params, RequestOptions requestOptions)HttpResponseFor<InboundCheckDeposit>decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)HttpResponseFor<InboundCheckDeposit>return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundCheckDepositService.WithRawResponse
decline, decline, decline, decline, decline, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, return_, return_, return_ -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundCheckDepositService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<InboundCheckDeposit> retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<InboundCheckDepositListPage> list(InboundCheckDepositListParams params, RequestOptions requestOptions)
-
decline
HttpResponseFor<InboundCheckDeposit> decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
return_
HttpResponseFor<InboundCheckDeposit> return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
-
-
-