Interface InboundMailItemService
-
- All Implemented Interfaces:
public interface InboundMailItemService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundMailItemService.WithRawResponseA view of InboundMailItemService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundMailItemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundMailItemretrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)Retrieve an Inbound Mail Item abstract InboundMailItemretrieve(InboundMailItemRetrieveParams params)Retrieve an Inbound Mail Item abstract InboundMailItemListPagelist(InboundMailItemListParams params, RequestOptions requestOptions)List Inbound Mail Items abstract InboundMailItemListPagelist(InboundMailItemListParams params)List Inbound Mail Items abstract InboundMailItemListPagelist()List Inbound Mail Items InboundMailItemListPagelist(RequestOptions requestOptions)List Inbound Mail Items -
-
Method Detail
-
withRawResponse
abstract InboundMailItemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract InboundMailItem retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)
Retrieve an Inbound Mail Item
-
retrieve
abstract InboundMailItem retrieve(InboundMailItemRetrieveParams params)
Retrieve an Inbound Mail Item
-
list
abstract InboundMailItemListPage list(InboundMailItemListParams params, RequestOptions requestOptions)
List Inbound Mail Items
-
list
abstract InboundMailItemListPage list(InboundMailItemListParams params)
List Inbound Mail Items
-
list
abstract InboundMailItemListPage list()
List Inbound Mail Items
-
list
InboundMailItemListPage list(RequestOptions requestOptions)
List Inbound Mail Items
-
-
-
-