Class InboundRealTimePaymentsTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundRealTimePaymentsTransferService.WithRawResponse
public final class InboundRealTimePaymentsTransferServiceImpl.WithRawResponseImpl implements InboundRealTimePaymentsTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundRealTimePaymentsTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundRealTimePaymentsTransfer>retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<InboundRealTimePaymentsTransferListPage>list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundRealTimePaymentsTransferService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundRealTimePaymentsTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<InboundRealTimePaymentsTransfer> retrieve(InboundRealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<InboundRealTimePaymentsTransferListPage> list(InboundRealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
-
-
-