Interface InboundWireDrawdownRequestService
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireDrawdownRequestService.WithRawResponseA view of InboundWireDrawdownRequestService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireDrawdownRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireDrawdownRequestretrieve(InboundWireDrawdownRequestRetrieveParams params)Retrieve an Inbound Wire Drawdown Request abstract InboundWireDrawdownRequestretrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)InboundWireDrawdownRequestListPagelist()List Inbound Wire Drawdown Requests abstract InboundWireDrawdownRequestListPagelist(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)InboundWireDrawdownRequestListPagelist(InboundWireDrawdownRequestListParams params)InboundWireDrawdownRequestListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireDrawdownRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
InboundWireDrawdownRequest retrieve(InboundWireDrawdownRequestRetrieveParams params)
Retrieve an Inbound Wire Drawdown Request
-
retrieve
abstract InboundWireDrawdownRequest retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
list
InboundWireDrawdownRequestListPage list()
List Inbound Wire Drawdown Requests
-
list
abstract InboundWireDrawdownRequestListPage list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
list
InboundWireDrawdownRequestListPage list(RequestOptions requestOptions)
-
-
-
-