Class InboundWireDrawdownRequestServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundWireDrawdownRequestService
public final class InboundWireDrawdownRequestServiceImpl implements InboundWireDrawdownRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireDrawdownRequestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundWireDrawdownRequestretrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)InboundWireDrawdownRequestListPagelist(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundWireDrawdownRequestService
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundWireDrawdownRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundWireDrawdownRequestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
InboundWireDrawdownRequest retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
list
InboundWireDrawdownRequestListPage list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
-
-
-