Class InboundWireDrawdownRequestServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundWireDrawdownRequestService.WithRawResponse
public final class InboundWireDrawdownRequestServiceImpl.WithRawResponseImpl implements InboundWireDrawdownRequestService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundWireDrawdownRequest>retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<InboundWireDrawdownRequestListPage>list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundWireDrawdownRequestService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundWireDrawdownRequestService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<InboundWireDrawdownRequest> retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<InboundWireDrawdownRequestListPage> list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
-
-
-