Interface InboundWireTransferService
-
- All Implemented Interfaces:
public interface InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireTransferService.WithRawResponseA view of InboundWireTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundWireTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
InboundWireTransfer retrieve(String inboundWireTransferId)
Retrieve an Inbound Wire Transfer
-
retrieve
InboundWireTransfer retrieve(String inboundWireTransferId, InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
InboundWireTransfer retrieve(String inboundWireTransferId, InboundWireTransferRetrieveParams params)
-
retrieve
abstract InboundWireTransfer retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
retrieve
InboundWireTransfer retrieve(InboundWireTransferRetrieveParams params)
-
retrieve
InboundWireTransfer retrieve(String inboundWireTransferId, RequestOptions requestOptions)
-
list
InboundWireTransferListPage list()
List Inbound Wire Transfers
-
list
abstract InboundWireTransferListPage list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
list
InboundWireTransferListPage list(InboundWireTransferListParams params)
-
list
InboundWireTransferListPage list(RequestOptions requestOptions)
-
reverse
InboundWireTransfer reverse(String inboundWireTransferId, InboundWireTransferReverseParams params)
Reverse an Inbound Wire Transfer
-
reverse
InboundWireTransfer reverse(String inboundWireTransferId, InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
reverse
InboundWireTransfer reverse(InboundWireTransferReverseParams params)
-
reverse
abstract InboundWireTransfer reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
-
-
-