Class InboundWireTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundWireTransferService
public final class InboundWireTransferServiceImpl implements InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundWireTransferretrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)InboundWireTransferListPagelist(InboundWireTransferListParams params, RequestOptions requestOptions)InboundWireTransferreverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundWireTransferService
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, reverse, reverse, reverse -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundWireTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
InboundWireTransfer retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
InboundWireTransferListPage list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
reverse
InboundWireTransfer reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
-
-
-