Class InboundWireTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundWireTransferService.WithRawResponse
public final class InboundWireTransferServiceImpl.WithRawResponseImpl implements InboundWireTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundWireTransfer>retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<InboundWireTransferListPage>list(InboundWireTransferListParams params, RequestOptions requestOptions)HttpResponseFor<InboundWireTransfer>reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.InboundWireTransferService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, reverse, reverse, reverse -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundWireTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<InboundWireTransfer> retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<InboundWireTransferListPage> list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
reverse
HttpResponseFor<InboundWireTransfer> reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
-
-
-