Class IntrafiAccountEnrollmentServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.IntrafiAccountEnrollmentService
public final class IntrafiAccountEnrollmentServiceImpl implements IntrafiAccountEnrollmentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiAccountEnrollmentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiAccountEnrollmentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiAccountEnrollmentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. IntrafiAccountEnrollmentcreate(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)IntrafiAccountEnrollmentretrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)IntrafiAccountEnrollmentListPagelist(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)IntrafiAccountEnrollmentunenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.IntrafiAccountEnrollmentService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, unenroll, unenroll, unenroll, unenroll, unenroll -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
IntrafiAccountEnrollmentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
IntrafiAccountEnrollmentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
IntrafiAccountEnrollment create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)
-
retrieve
IntrafiAccountEnrollment retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)
-
list
IntrafiAccountEnrollmentListPage list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)
-
unenroll
IntrafiAccountEnrollment unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)
-
-
-
-