Interface IntrafiBalanceService
-
- All Implemented Interfaces:
public interface IntrafiBalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceIntrafiBalanceService.WithRawResponseA view of IntrafiBalanceService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract IntrafiBalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiBalanceintrafiBalance(IntrafiBalanceIntrafiBalanceParams params)Returns the IntraFi balance for the given account. abstract IntrafiBalanceintrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract IntrafiBalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
intrafiBalance
IntrafiBalance intrafiBalance(IntrafiBalanceIntrafiBalanceParams params)
Returns the IntraFi balance for the given account. IntraFi may sweep funds to multiple banks. This endpoint will include both the total balance and the amount swept to each institution.
-
intrafiBalance
abstract IntrafiBalance intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)
-
-
-
-