Class IntrafiBalanceServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.IntrafiBalanceService
public final class IntrafiBalanceServiceImpl implements IntrafiBalanceService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiBalanceServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiBalanceService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiBalanceintrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
IntrafiBalanceService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
intrafiBalance
IntrafiBalance intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)
-
-
-
-