Class IntrafiExclusionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.IntrafiExclusionService.WithRawResponse
public final class IntrafiExclusionServiceImpl.WithRawResponseImpl implements IntrafiExclusionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description IntrafiExclusionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<IntrafiExclusion>create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)HttpResponseFor<IntrafiExclusion>retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<IntrafiExclusionListPage>list(IntrafiExclusionListParams params, RequestOptions requestOptions)HttpResponseFor<IntrafiExclusion>archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.IntrafiExclusionService.WithRawResponse
archive, archive, archive, archive, archive, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
IntrafiExclusionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<IntrafiExclusion> create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<IntrafiExclusion> retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<IntrafiExclusionListPage> list(IntrafiExclusionListParams params, RequestOptions requestOptions)
-
archive
HttpResponseFor<IntrafiExclusion> archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
-
-
-
-