Class LockboxRecipientServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.LockboxRecipientService
public final class LockboxRecipientServiceImpl implements LockboxRecipientService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LockboxRecipientService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LockboxRecipientServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. LockboxRecipientcreate(LockboxRecipientCreateParams params, RequestOptions requestOptions)LockboxRecipientretrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)LockboxRecipientupdate(LockboxRecipientUpdateParams params, RequestOptions requestOptions)LockboxRecipientListPagelist(LockboxRecipientListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.LockboxRecipientService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
LockboxRecipientService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LockboxRecipientService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
LockboxRecipient create(LockboxRecipientCreateParams params, RequestOptions requestOptions)
-
retrieve
LockboxRecipient retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)
-
update
LockboxRecipient update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)
-
list
LockboxRecipientListPage list(LockboxRecipientListParams params, RequestOptions requestOptions)
-
-
-
-