Class LockboxRecipientServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.LockboxRecipientService.WithRawResponse
public final class LockboxRecipientServiceImpl.WithRawResponseImpl implements LockboxRecipientService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LockboxRecipientService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<LockboxRecipient>create(LockboxRecipientCreateParams params, RequestOptions requestOptions)HttpResponseFor<LockboxRecipient>retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<LockboxRecipient>update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)HttpResponseFor<LockboxRecipientListPage>list(LockboxRecipientListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.LockboxRecipientService.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
LockboxRecipientService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<LockboxRecipient> create(LockboxRecipientCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<LockboxRecipient> retrieve(LockboxRecipientRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<LockboxRecipient> update(LockboxRecipientUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<LockboxRecipientListPage> list(LockboxRecipientListParams params, RequestOptions requestOptions)
-
-
-
-