Interface LockboxService
-
- All Implemented Interfaces:
public interface LockboxService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceLockboxService.WithRawResponseA view of LockboxService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract LockboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract LockboxService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Lockbox create(LockboxCreateParams params)
Create a Lockbox
-
create
abstract Lockbox create(LockboxCreateParams params, RequestOptions requestOptions)
-
retrieve
Lockbox retrieve(String lockboxId, LockboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Lockbox retrieve(String lockboxId, LockboxRetrieveParams params)
-
retrieve
abstract Lockbox retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
-
retrieve
Lockbox retrieve(LockboxRetrieveParams params)
-
retrieve
Lockbox retrieve(String lockboxId, RequestOptions requestOptions)
-
update
Lockbox update(String lockboxId, LockboxUpdateParams params, RequestOptions requestOptions)
-
update
Lockbox update(String lockboxId, LockboxUpdateParams params)
-
update
abstract Lockbox update(LockboxUpdateParams params, RequestOptions requestOptions)
-
update
Lockbox update(LockboxUpdateParams params)
-
update
Lockbox update(String lockboxId, RequestOptions requestOptions)
-
list
LockboxListPage list()
List Lockboxes
-
list
abstract LockboxListPage list(LockboxListParams params, RequestOptions requestOptions)
-
list
LockboxListPage list(LockboxListParams params)
-
list
LockboxListPage list(RequestOptions requestOptions)
-
-
-
-