Class LockboxServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.LockboxService
public final class LockboxServiceImpl implements LockboxService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LockboxService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. LockboxServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Lockboxcreate(LockboxCreateParams params, RequestOptions requestOptions)Lockboxretrieve(LockboxRetrieveParams params, RequestOptions requestOptions)Lockboxupdate(LockboxUpdateParams params, RequestOptions requestOptions)LockboxListPagelist(LockboxListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.LockboxService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
LockboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
LockboxService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Lockbox create(LockboxCreateParams params, RequestOptions requestOptions)
-
retrieve
Lockbox retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
-
update
Lockbox update(LockboxUpdateParams params, RequestOptions requestOptions)
-
list
LockboxListPage list(LockboxListParams params, RequestOptions requestOptions)
-
-
-
-