Class LockboxServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.LockboxService.WithRawResponse
public final class LockboxServiceImpl.WithRawResponseImpl implements LockboxService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description LockboxService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Lockbox>create(LockboxCreateParams params, RequestOptions requestOptions)HttpResponseFor<Lockbox>retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<Lockbox>update(LockboxUpdateParams params, RequestOptions requestOptions)HttpResponseFor<LockboxListPage>list(LockboxListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.LockboxService.WithRawResponse
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
LockboxService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<Lockbox> create(LockboxCreateParams params, RequestOptions requestOptions)
-
retrieve
HttpResponseFor<Lockbox> retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<Lockbox> update(LockboxUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<LockboxListPage> list(LockboxListParams params, RequestOptions requestOptions)
-
-
-
-