Interface OAuthApplicationService
-
- All Implemented Interfaces:
public interface OAuthApplicationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthApplicationService.WithRawResponseA view of OAuthApplicationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthApplicationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthApplicationretrieve(OAuthApplicationRetrieveParams params)Retrieve an OAuth Application abstract OAuthApplicationretrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)OAuthApplicationListPagelist()List OAuth Applications abstract OAuthApplicationListPagelist(OAuthApplicationListParams params, RequestOptions requestOptions)OAuthApplicationListPagelist(OAuthApplicationListParams params)OAuthApplicationListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthApplicationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
OAuthApplication retrieve(OAuthApplicationRetrieveParams params)
Retrieve an OAuth Application
-
retrieve
abstract OAuthApplication retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
list
OAuthApplicationListPage list()
List OAuth Applications
-
list
abstract OAuthApplicationListPage list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
list
OAuthApplicationListPage list(OAuthApplicationListParams params)
-
list
OAuthApplicationListPage list(RequestOptions requestOptions)
-
-
-
-