Class OAuthApplicationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.OAuthApplicationService
public final class OAuthApplicationServiceImpl implements OAuthApplicationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OAuthApplicationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthApplicationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. OAuthApplicationretrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)OAuthApplicationListPagelist(OAuthApplicationListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
OAuthApplicationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OAuthApplicationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
OAuthApplication retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
list
OAuthApplicationListPage list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
-
-
-