Class OAuthApplicationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.OAuthApplicationService.WithRawResponse
public final class OAuthApplicationServiceImpl.WithRawResponseImpl implements OAuthApplicationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OAuthApplicationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<OAuthApplication>retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<OAuthApplicationListPage>list(OAuthApplicationListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.OAuthApplicationService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
OAuthApplicationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<OAuthApplicationListPage> list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
-
-
-