Interface OAuthConnectionService
-
- All Implemented Interfaces:
public interface OAuthConnectionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthConnectionService.WithRawResponseA view of OAuthConnectionService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract OAuthConnectionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OAuthConnectionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
OAuthConnection retrieve(String oauthConnectionId)
Retrieve an OAuth Connection
-
retrieve
OAuthConnection retrieve(String oauthConnectionId, OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
OAuthConnection retrieve(String oauthConnectionId, OAuthConnectionRetrieveParams params)
-
retrieve
abstract OAuthConnection retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
retrieve
OAuthConnection retrieve(OAuthConnectionRetrieveParams params)
-
retrieve
OAuthConnection retrieve(String oauthConnectionId, RequestOptions requestOptions)
-
list
OAuthConnectionListPage list()
List OAuth Connections
-
list
abstract OAuthConnectionListPage list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
list
OAuthConnectionListPage list(OAuthConnectionListParams params)
-
list
OAuthConnectionListPage list(RequestOptions requestOptions)
-
-
-
-