Class OAuthConnectionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.OAuthConnectionService
public final class OAuthConnectionServiceImpl implements OAuthConnectionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthConnectionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OAuthConnectionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthConnectionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. OAuthConnectionretrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)OAuthConnectionListPagelist(OAuthConnectionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
OAuthConnectionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OAuthConnectionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
OAuthConnection retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
list
OAuthConnectionListPage list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
-
-
-