Class OAuthConnectionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.OAuthConnectionService.WithRawResponse
public final class OAuthConnectionServiceImpl.WithRawResponseImpl implements OAuthConnectionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OAuthConnectionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<OAuthConnection>retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<OAuthConnectionListPage>list(OAuthConnectionListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.OAuthConnectionService.WithRawResponse
list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
OAuthConnectionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<OAuthConnection> retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<OAuthConnectionListPage> list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
-
-
-