Interface OAuthTokenService
-
- All Implemented Interfaces:
public interface OAuthTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthTokenService.WithRawResponseA view of OAuthTokenService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract OAuthTokenServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. OAuthTokencreate(OAuthTokenCreateParams params)Create an OAuth Token abstract OAuthTokencreate(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OAuthTokenService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
OAuthToken create(OAuthTokenCreateParams params)
Create an OAuth Token
-
create
abstract OAuthToken create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-