Class OAuthTokenServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.OAuthTokenService
public final class OAuthTokenServiceImpl implements OAuthTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthTokenServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OAuthTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthTokenServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. OAuthTokencreate(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
OAuthTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OAuthTokenService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
OAuthToken create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-