Class OAuthTokenServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.OAuthTokenService.WithRawResponse
public final class OAuthTokenServiceImpl.WithRawResponseImpl implements OAuthTokenService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description OAuthTokenService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<OAuthToken>create(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
OAuthTokenService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<OAuthToken> create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-