Interface PendingTransactionService
-
- All Implemented Interfaces:
public interface PendingTransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePendingTransactionService.WithRawResponseA view of PendingTransactionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PendingTransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PendingTransactionretrieve(PendingTransactionRetrieveParams params)Retrieve a Pending Transaction abstract PendingTransactionretrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)PendingTransactionListPagelist()List Pending Transactions abstract PendingTransactionListPagelist(PendingTransactionListParams params, RequestOptions requestOptions)PendingTransactionListPagelist(PendingTransactionListParams params)PendingTransactionListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PendingTransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
PendingTransaction retrieve(PendingTransactionRetrieveParams params)
Retrieve a Pending Transaction
-
retrieve
abstract PendingTransaction retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
PendingTransactionListPage list()
List Pending Transactions
-
list
abstract PendingTransactionListPage list(PendingTransactionListParams params, RequestOptions requestOptions)
-
list
PendingTransactionListPage list(PendingTransactionListParams params)
-
list
PendingTransactionListPage list(RequestOptions requestOptions)
-
-
-
-