Class PendingTransactionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.PendingTransactionService
public final class PendingTransactionServiceImpl implements PendingTransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PendingTransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PendingTransactionretrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)PendingTransactionListPagelist(PendingTransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PendingTransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
PendingTransaction retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
PendingTransactionListPage list(PendingTransactionListParams params, RequestOptions requestOptions)
-
-
-
-