Interface PhysicalCardProfileService
-
- All Implemented Interfaces:
public interface PhysicalCardProfileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePhysicalCardProfileService.WithRawResponseA view of PhysicalCardProfileService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PhysicalCardProfileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PhysicalCardProfilecreate(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)Create a Physical Card Profile abstract PhysicalCardProfilecreate(PhysicalCardProfileCreateParams params)Create a Physical Card Profile abstract PhysicalCardProfileretrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)Retrieve a Card Profile abstract PhysicalCardProfileretrieve(PhysicalCardProfileRetrieveParams params)Retrieve a Card Profile abstract PhysicalCardProfileListPagelist(PhysicalCardProfileListParams params, RequestOptions requestOptions)List Physical Card Profiles abstract PhysicalCardProfileListPagelist(PhysicalCardProfileListParams params)List Physical Card Profiles abstract PhysicalCardProfileListPagelist()List Physical Card Profiles PhysicalCardProfileListPagelist(RequestOptions requestOptions)List Physical Card Profiles abstract PhysicalCardProfilearchive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)Archive a Physical Card Profile abstract PhysicalCardProfilearchive(PhysicalCardProfileArchiveParams params)Archive a Physical Card Profile abstract PhysicalCardProfileclone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)Clone a Physical Card Profile abstract PhysicalCardProfileclone(PhysicalCardProfileCloneParams params)Clone a Physical Card Profile -
-
Method Detail
-
withRawResponse
abstract PhysicalCardProfileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract PhysicalCardProfile create(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)
Create a Physical Card Profile
-
create
abstract PhysicalCardProfile create(PhysicalCardProfileCreateParams params)
Create a Physical Card Profile
-
retrieve
abstract PhysicalCardProfile retrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)
Retrieve a Card Profile
-
retrieve
abstract PhysicalCardProfile retrieve(PhysicalCardProfileRetrieveParams params)
Retrieve a Card Profile
-
list
abstract PhysicalCardProfileListPage list(PhysicalCardProfileListParams params, RequestOptions requestOptions)
List Physical Card Profiles
-
list
abstract PhysicalCardProfileListPage list(PhysicalCardProfileListParams params)
List Physical Card Profiles
-
list
abstract PhysicalCardProfileListPage list()
List Physical Card Profiles
-
list
PhysicalCardProfileListPage list(RequestOptions requestOptions)
List Physical Card Profiles
-
archive
abstract PhysicalCardProfile archive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)
Archive a Physical Card Profile
-
archive
abstract PhysicalCardProfile archive(PhysicalCardProfileArchiveParams params)
Archive a Physical Card Profile
-
clone
abstract PhysicalCardProfile clone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)
Clone a Physical Card Profile
-
clone
abstract PhysicalCardProfile clone(PhysicalCardProfileCloneParams params)
Clone a Physical Card Profile
-
-
-
-