Class PhysicalCardProfileServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.PhysicalCardProfileService
public final class PhysicalCardProfileServiceImpl implements PhysicalCardProfileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardProfileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardProfileServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PhysicalCardProfilecreate(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)PhysicalCardProfileretrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)PhysicalCardProfileListPagelist(PhysicalCardProfileListParams params, RequestOptions requestOptions)PhysicalCardProfilearchive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)PhysicalCardProfileclone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.PhysicalCardProfileService
archive, archive, archive, archive, archive, clone, clone, clone, clone, clone, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PhysicalCardProfileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PhysicalCardProfileService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
PhysicalCardProfile create(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)
-
retrieve
PhysicalCardProfile retrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)
-
list
PhysicalCardProfileListPage list(PhysicalCardProfileListParams params, RequestOptions requestOptions)
-
archive
PhysicalCardProfile archive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)
-
clone
PhysicalCardProfile clone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)
-
-
-
-