Interface PhysicalCardService
-
- All Implemented Interfaces:
public interface PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePhysicalCardService.WithRawResponseA view of PhysicalCardService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardcreate(PhysicalCardCreateParams params)Create a Physical Card abstract PhysicalCardcreate(PhysicalCardCreateParams params, RequestOptions requestOptions)PhysicalCardretrieve(PhysicalCardRetrieveParams params)Retrieve a Physical Card abstract PhysicalCardretrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)PhysicalCardupdate(PhysicalCardUpdateParams params)Update a Physical Card abstract PhysicalCardupdate(PhysicalCardUpdateParams params, RequestOptions requestOptions)PhysicalCardListPagelist()List Physical Cards abstract PhysicalCardListPagelist(PhysicalCardListParams params, RequestOptions requestOptions)PhysicalCardListPagelist(PhysicalCardListParams params)PhysicalCardListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
PhysicalCard create(PhysicalCardCreateParams params)
Create a Physical Card
-
create
abstract PhysicalCard create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
retrieve
PhysicalCard retrieve(PhysicalCardRetrieveParams params)
Retrieve a Physical Card
-
retrieve
abstract PhysicalCard retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)
-
update
PhysicalCard update(PhysicalCardUpdateParams params)
Update a Physical Card
-
update
abstract PhysicalCard update(PhysicalCardUpdateParams params, RequestOptions requestOptions)
-
list
PhysicalCardListPage list()
List Physical Cards
-
list
abstract PhysicalCardListPage list(PhysicalCardListParams params, RequestOptions requestOptions)
-
list
PhysicalCardListPage list(PhysicalCardListParams params)
-
list
PhysicalCardListPage list(RequestOptions requestOptions)
-
-
-
-