Class PhysicalCardServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.PhysicalCardService
public final class PhysicalCardServiceImpl implements PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PhysicalCardcreate(PhysicalCardCreateParams params, RequestOptions requestOptions)PhysicalCardretrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)PhysicalCardupdate(PhysicalCardUpdateParams params, RequestOptions requestOptions)PhysicalCardListPagelist(PhysicalCardListParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.PhysicalCardService
create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PhysicalCardService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
PhysicalCard create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
retrieve
PhysicalCard retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)
-
update
PhysicalCard update(PhysicalCardUpdateParams params, RequestOptions requestOptions)
-
list
PhysicalCardListPage list(PhysicalCardListParams params, RequestOptions requestOptions)
-
-
-
-