Interface ProgramService
-
- All Implemented Interfaces:
public interface ProgramService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProgramService.WithRawResponseA view of ProgramService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ProgramService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Programretrieve(ProgramRetrieveParams params, RequestOptions requestOptions)Retrieve a Program abstract Programretrieve(ProgramRetrieveParams params)Retrieve a Program abstract ProgramListPagelist(ProgramListParams params, RequestOptions requestOptions)List Programs abstract ProgramListPagelist(ProgramListParams params)List Programs abstract ProgramListPagelist()List Programs ProgramListPagelist(RequestOptions requestOptions)List Programs -
-
Method Detail
-
withRawResponse
abstract ProgramService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract Program retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
Retrieve a Program
-
retrieve
abstract Program retrieve(ProgramRetrieveParams params)
Retrieve a Program
-
list
abstract ProgramListPage list(ProgramListParams params, RequestOptions requestOptions)
List Programs
-
list
abstract ProgramListPage list(ProgramListParams params)
List Programs
-
list
abstract ProgramListPage list()
List Programs
-
list
ProgramListPage list(RequestOptions requestOptions)
List Programs
-
-
-
-