Class ProgramServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.ProgramService.WithRawResponse
public final class ProgramServiceImpl.WithRawResponseImpl implements ProgramService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ProgramService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Program>retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<ProgramListPage>list(ProgramListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ProgramService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<Program> retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<ProgramListPage> list(ProgramListParams params, RequestOptions requestOptions)
-
-
-
-