Class RealTimeDecisionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.RealTimeDecisionService
public final class RealTimeDecisionServiceImpl implements RealTimeDecisionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimeDecisionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RealTimeDecisionretrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)RealTimeDecisionaction(RealTimeDecisionActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RealTimeDecisionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
RealTimeDecision retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
action
RealTimeDecision action(RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
-
-
-