Class RealTimeDecisionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.RealTimeDecisionService.WithRawResponse
public final class RealTimeDecisionServiceImpl.WithRawResponseImpl implements RealTimeDecisionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RealTimeDecisionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<RealTimeDecision>retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)HttpResponseFor<RealTimeDecision>action(RealTimeDecisionActionParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.RealTimeDecisionService.WithRawResponse
action, action, action, action, action, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RealTimeDecisionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
HttpResponseFor<RealTimeDecision> retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
action
HttpResponseFor<RealTimeDecision> action(RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
-
-
-