Class RealTimePaymentsTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.RealTimePaymentsTransferService
public final class RealTimePaymentsTransferServiceImpl implements RealTimePaymentsTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimePaymentsTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RealTimePaymentsTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RealTimePaymentsTransfercreate(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)RealTimePaymentsTransferretrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)RealTimePaymentsTransferListPagelist(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)RealTimePaymentsTransferapprove(RealTimePaymentsTransferApproveParams params, RequestOptions requestOptions)RealTimePaymentsTransfercancel(RealTimePaymentsTransferCancelParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.RealTimePaymentsTransferService
approve, approve, approve, approve, approve, cancel, cancel, cancel, cancel, cancel, create, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RealTimePaymentsTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RealTimePaymentsTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
RealTimePaymentsTransfer create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
RealTimePaymentsTransfer retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
RealTimePaymentsTransferListPage list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
approve
RealTimePaymentsTransfer approve(RealTimePaymentsTransferApproveParams params, RequestOptions requestOptions)
-
cancel
RealTimePaymentsTransfer cancel(RealTimePaymentsTransferCancelParams params, RequestOptions requestOptions)
-
-
-
-