Interface RoutingNumberService
-
- All Implemented Interfaces:
public interface RoutingNumberService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRoutingNumberService.WithRawResponseA view of RoutingNumberService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RoutingNumberService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract RoutingNumberServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RoutingNumberListPagelist(RoutingNumberListParams params)You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. abstract RoutingNumberListPagelist(RoutingNumberListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RoutingNumberService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RoutingNumberService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
RoutingNumberListPage list(RoutingNumberListParams params)
You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. Since routing numbers uniquely identify a bank, this will always return 0 or 1 entry. In Sandbox, the only valid routing number for this method is 110000000.
-
list
abstract RoutingNumberListPage list(RoutingNumberListParams params, RequestOptions requestOptions)
-
-
-
-