Class RoutingNumberServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.RoutingNumberService
public final class RoutingNumberServiceImpl implements RoutingNumberService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RoutingNumberService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RoutingNumberServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RoutingNumberListPagelist(RoutingNumberListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RoutingNumberService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RoutingNumberService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
RoutingNumberListPage list(RoutingNumberListParams params, RequestOptions requestOptions)
-
-
-
-