Class RoutingNumberServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.RoutingNumberService.WithRawResponse
public final class RoutingNumberServiceImpl.WithRawResponseImpl implements RoutingNumberService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RoutingNumberService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<RoutingNumberListPage>list(RoutingNumberListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
RoutingNumberService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<RoutingNumberListPage> list(RoutingNumberListParams params, RequestOptions requestOptions)
-
-
-
-