Interface SupplementalDocumentService
-
- All Implemented Interfaces:
public interface SupplementalDocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSupplementalDocumentService.WithRawResponseA view of SupplementalDocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SupplementalDocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SupplementalDocumentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EntitySupplementalDocumentcreate(SupplementalDocumentCreateParams params)Create a supplemental document for an Entity abstract EntitySupplementalDocumentcreate(SupplementalDocumentCreateParams params, RequestOptions requestOptions)SupplementalDocumentListPagelist(SupplementalDocumentListParams params)List Entity Supplemental Document Submissions abstract SupplementalDocumentListPagelist(SupplementalDocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SupplementalDocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SupplementalDocumentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
EntitySupplementalDocument create(SupplementalDocumentCreateParams params)
Create a supplemental document for an Entity
-
create
abstract EntitySupplementalDocument create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
-
list
SupplementalDocumentListPage list(SupplementalDocumentListParams params)
List Entity Supplemental Document Submissions
-
list
abstract SupplementalDocumentListPage list(SupplementalDocumentListParams params, RequestOptions requestOptions)
-
-
-
-