Interface SupplementalDocumentService.WithRawResponse
-
- All Implemented Interfaces:
public interface SupplementalDocumentService.WithRawResponseA view of SupplementalDocumentService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract SupplementalDocumentService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<EntitySupplementalDocument>create(SupplementalDocumentCreateParams params)Returns a raw HTTP response for post /entity_supplemental_documents, but is otherwise the same as SupplementalDocumentService.create.abstract HttpResponseFor<EntitySupplementalDocument>create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)HttpResponseFor<SupplementalDocumentListPage>list(SupplementalDocumentListParams params)Returns a raw HTTP response for get /entity_supplemental_documents, but is otherwise the same as SupplementalDocumentService.list.abstract HttpResponseFor<SupplementalDocumentListPage>list(SupplementalDocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract SupplementalDocumentService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<EntitySupplementalDocument> create(SupplementalDocumentCreateParams params)
Returns a raw HTTP response for
post /entity_supplemental_documents, but is otherwise the same as SupplementalDocumentService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<EntitySupplementalDocument> create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<SupplementalDocumentListPage> list(SupplementalDocumentListParams params)
Returns a raw HTTP response for
get /entity_supplemental_documents, but is otherwise the same as SupplementalDocumentService.list.
-
list
@MustBeClosed() abstract HttpResponseFor<SupplementalDocumentListPage> list(SupplementalDocumentListParams params, RequestOptions requestOptions)
-
-
-
-