Class SupplementalDocumentServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.SupplementalDocumentService
public final class SupplementalDocumentServiceImpl implements SupplementalDocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SupplementalDocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SupplementalDocumentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EntitySupplementalDocumentcreate(SupplementalDocumentCreateParams params, RequestOptions requestOptions)SupplementalDocumentListPagelist(SupplementalDocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
SupplementalDocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SupplementalDocumentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
EntitySupplementalDocument create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
-
list
SupplementalDocumentListPage list(SupplementalDocumentListParams params, RequestOptions requestOptions)
-
-
-
-