Class AccountRevenuePaymentServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.AccountRevenuePaymentService
public final class AccountRevenuePaymentServiceImpl implements AccountRevenuePaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountRevenuePaymentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountRevenuePaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountRevenuePaymentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Transactioncreate(AccountRevenuePaymentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountRevenuePaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountRevenuePaymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Transaction create(AccountRevenuePaymentCreateParams params, RequestOptions requestOptions)
-
-
-
-