Interface AccountStatementService.WithRawResponse
-
- All Implemented Interfaces:
public interface AccountStatementService.WithRawResponseA view of AccountStatementService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AccountStatementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<AccountStatement>create(AccountStatementCreateParams params)Returns a raw HTTP response for post /simulations/account_statements, but is otherwise the same as AccountStatementService.create.abstract HttpResponseFor<AccountStatement>create(AccountStatementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract AccountStatementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<AccountStatement> create(AccountStatementCreateParams params)
Returns a raw HTTP response for
post /simulations/account_statements, but is otherwise the same as AccountStatementService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<AccountStatement> create(AccountStatementCreateParams params, RequestOptions requestOptions)
-
-
-
-