Class AccountTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.AccountTransferService
public final class AccountTransferServiceImpl implements AccountTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. AccountTransfercomplete(AccountTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
AccountTransfer complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-