Class AccountTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.AccountTransferService.WithRawResponse
public final class AccountTransferServiceImpl.WithRawResponseImpl implements AccountTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<AccountTransfer>complete(AccountTransferCompleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.AccountTransferService.WithRawResponse
complete, complete, complete, complete, complete -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AccountTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
HttpResponseFor<AccountTransfer> complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-