Class AchTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.AchTransferService.WithRawResponse
public final class AchTransferServiceImpl.WithRawResponseImpl implements AchTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AchTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<AchTransfer>acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)HttpResponseFor<AchTransfer>createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)HttpResponseFor<AchTransfer>return_(AchTransferReturnParams params, RequestOptions requestOptions)HttpResponseFor<AchTransfer>settle(AchTransferSettleParams params, RequestOptions requestOptions)HttpResponseFor<AchTransfer>submit(AchTransferSubmitParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.AchTransferService.WithRawResponse
acknowledge, acknowledge, acknowledge, acknowledge, acknowledge, createNotificationOfChange, createNotificationOfChange, createNotificationOfChange, return_, return_, return_, return_, return_, settle, settle, settle, settle, settle, submit, submit, submit, submit, submit -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
AchTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
acknowledge
HttpResponseFor<AchTransfer> acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
HttpResponseFor<AchTransfer> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
HttpResponseFor<AchTransfer> return_(AchTransferReturnParams params, RequestOptions requestOptions)
-
settle
HttpResponseFor<AchTransfer> settle(AchTransferSettleParams params, RequestOptions requestOptions)
-
submit
HttpResponseFor<AchTransfer> submit(AchTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-