Class CardAuthenticationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardAuthenticationService
public final class CardAuthenticationServiceImpl implements CardAuthenticationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthenticationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthenticationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAuthenticationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPaymentcreate(CardAuthenticationCreateParams params, RequestOptions requestOptions)CardPaymentchallengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)CardPaymentchallenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.CardAuthenticationService
challengeAttempts, challengeAttempts, challengeAttempts, challenges, challenges, challenges, challenges, challenges, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardAuthenticationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardAuthenticationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPayment create(CardAuthenticationCreateParams params, RequestOptions requestOptions)
-
challengeAttempts
CardPayment challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)
-
challenges
CardPayment challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)
-
-
-
-