Class CardAuthenticationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardAuthenticationService.WithRawResponse
public final class CardAuthenticationServiceImpl.WithRawResponseImpl implements CardAuthenticationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardAuthenticationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPayment>create(CardAuthenticationCreateParams params, RequestOptions requestOptions)HttpResponseFor<CardPayment>challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)HttpResponseFor<CardPayment>challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.CardAuthenticationService.WithRawResponse
challengeAttempts, challengeAttempts, challengeAttempts, challenges, challenges, challenges, challenges, challenges, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CardAuthenticationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<CardPayment> create(CardAuthenticationCreateParams params, RequestOptions requestOptions)
-
challengeAttempts
HttpResponseFor<CardPayment> challengeAttempts(CardAuthenticationChallengeAttemptsParams params, RequestOptions requestOptions)
-
challenges
HttpResponseFor<CardPayment> challenges(CardAuthenticationChallengesParams params, RequestOptions requestOptions)
-
-
-
-