Interface CardAuthorizationExpirationService
-
- All Implemented Interfaces:
public interface CardAuthorizationExpirationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardAuthorizationExpirationService.WithRawResponseA view of CardAuthorizationExpirationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationExpirationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardPaymentcreate(SimulationCardAuthorizationExpirationCreateParams params, RequestOptions requestOptions)Simulates expiring a Card Authorization immediately. abstract CardPaymentcreate(SimulationCardAuthorizationExpirationCreateParams params)Simulates expiring a Card Authorization immediately. -
-
Method Detail
-
withRawResponse
abstract CardAuthorizationExpirationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract CardPayment create(SimulationCardAuthorizationExpirationCreateParams params, RequestOptions requestOptions)
Simulates expiring a Card Authorization immediately.
-
create
abstract CardPayment create(SimulationCardAuthorizationExpirationCreateParams params)
Simulates expiring a Card Authorization immediately.
-
-
-
-