Interface CardAuthorizationService
-
- All Implemented Interfaces:
public interface CardAuthorizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardAuthorizationService.WithRawResponseA view of CardAuthorizationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardAuthorizationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardAuthorizationCreateResponsecreate(CardAuthorizationCreateParams params)Simulates a purchase authorization on a #cards. abstract CardAuthorizationCreateResponsecreate(CardAuthorizationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardAuthorizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardAuthorizationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardAuthorizationCreateResponse create(CardAuthorizationCreateParams params)
Simulates a purchase authorization on a #cards. Depending on the balance available to the card and the
amountsubmitted, the authorization activity will result in a #pending-transactions of typecard_authorizationor a #declined-transactions of typecard_decline. You can pass either a Card id or a #digital-wallet-tokens id to simulate the two different ways purchases can be made.
-
create
abstract CardAuthorizationCreateResponse create(CardAuthorizationCreateParams params, RequestOptions requestOptions)
-
-
-
-