Interface CardAuthorizationService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardAuthorizationService.WithRawResponseA view of CardAuthorizationService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardAuthorizationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardAuthorizationCreateResponse>create(CardAuthorizationCreateParams params)Returns a raw HTTP response for post /simulations/card_authorizations, but is otherwise the same as CardAuthorizationService.create.abstract HttpResponseFor<CardAuthorizationCreateResponse>create(CardAuthorizationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardAuthorizationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<CardAuthorizationCreateResponse> create(CardAuthorizationCreateParams params)
Returns a raw HTTP response for
post /simulations/card_authorizations, but is otherwise the same as CardAuthorizationService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<CardAuthorizationCreateResponse> create(CardAuthorizationCreateParams params, RequestOptions requestOptions)
-
-
-
-