Class CardAuthorizationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardAuthorizationService
public final class CardAuthorizationServiceImpl implements CardAuthorizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthorizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAuthorizationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardAuthorizationCreateResponsecreate(CardAuthorizationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardAuthorizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardAuthorizationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardAuthorizationCreateResponse create(CardAuthorizationCreateParams params, RequestOptions requestOptions)
-
-
-
-