Class CardAuthorizationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardAuthorizationService.WithRawResponse
public final class CardAuthorizationServiceImpl.WithRawResponseImpl implements CardAuthorizationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardAuthorizationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardAuthorizationCreateResponse>create(CardAuthorizationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardAuthorizationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<CardAuthorizationCreateResponse> create(CardAuthorizationCreateParams params, RequestOptions requestOptions)
-
-
-
-