Interface CardBalanceInquiryService
-
- All Implemented Interfaces:
public interface CardBalanceInquiryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardBalanceInquiryService.WithRawResponseA view of CardBalanceInquiryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardBalanceInquiryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardBalanceInquiryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPaymentcreate()Simulates a balance inquiry on a #cards. abstract CardPaymentcreate(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)CardPaymentcreate(CardBalanceInquiryCreateParams params)CardPaymentcreate(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardBalanceInquiryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardBalanceInquiryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPayment create()
Simulates a balance inquiry on a #cards.
-
create
abstract CardPayment create(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)
-
create
CardPayment create(CardBalanceInquiryCreateParams params)
-
create
CardPayment create(RequestOptions requestOptions)
-
-
-
-