Interface CardBalanceInquiryService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardBalanceInquiryService.WithRawResponseA view of CardBalanceInquiryService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardBalanceInquiryService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPayment>create()Returns a raw HTTP response for post /simulations/card_balance_inquiries, but is otherwise the same as CardBalanceInquiryService.create.abstract HttpResponseFor<CardPayment>create(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)HttpResponseFor<CardPayment>create(CardBalanceInquiryCreateParams params)HttpResponseFor<CardPayment>create(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardBalanceInquiryService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<CardPayment> create()
Returns a raw HTTP response for
post /simulations/card_balance_inquiries, but is otherwise the same as CardBalanceInquiryService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<CardPayment> create(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponseFor<CardPayment> create(CardBalanceInquiryCreateParams params)
-
create
@MustBeClosed() HttpResponseFor<CardPayment> create(RequestOptions requestOptions)
-
-
-
-