Class CardBalanceInquiryServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardBalanceInquiryService
public final class CardBalanceInquiryServiceImpl implements CardBalanceInquiryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardBalanceInquiryServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardBalanceInquiryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardBalanceInquiryServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPaymentcreate(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardBalanceInquiryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardBalanceInquiryService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPayment create(CardBalanceInquiryCreateParams params, RequestOptions requestOptions)
-
-
-
-