Interface CardDisputeService
-
- All Implemented Interfaces:
public interface CardDisputeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardDisputeService.WithRawResponseA view of CardDisputeService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardDisputeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardDisputeServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardDisputeaction(String cardDisputeId, CardDisputeActionParams params)After a #card-disputes is created in production, the dispute will be reviewed. CardDisputeaction(String cardDisputeId, CardDisputeActionParams params, RequestOptions requestOptions)CardDisputeaction(CardDisputeActionParams params)abstract CardDisputeaction(CardDisputeActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardDisputeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardDisputeService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
action
CardDispute action(String cardDisputeId, CardDisputeActionParams params)
After a #card-disputes is created in production, the dispute will be reviewed. Since no review happens in sandbox, this endpoint simulates moving a Card Dispute into a rejected or accepted state. A Card Dispute can only be actioned one time and must have a status of
pending_reviewing.
-
action
CardDispute action(String cardDisputeId, CardDisputeActionParams params, RequestOptions requestOptions)
-
action
CardDispute action(CardDisputeActionParams params)
-
action
abstract CardDispute action(CardDisputeActionParams params, RequestOptions requestOptions)
-
-
-
-