Class CardDisputeServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardDisputeService
public final class CardDisputeServiceImpl implements CardDisputeService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardDisputeService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardDisputeaction(SimulationCardDisputeActionParams params, RequestOptions requestOptions)After a #card-disputes is created in production, the dispute will be reviewed. -
-
Method Detail
-
withRawResponse
CardDisputeService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
action
CardDispute action(SimulationCardDisputeActionParams params, RequestOptions requestOptions)
After a #card-disputes is created in production, the dispute will be reviewed. Since no review happens in sandbox, this endpoint simulates moving a Card Dispute into a rejected or accepted state. A Card Dispute can only be actioned one time and must have a status of
pending_reviewing.
-
-
-
-