Class CardDisputeServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardDisputeService.WithRawResponse
public final class CardDisputeServiceImpl.WithRawResponseImpl implements CardDisputeService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardDisputeService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardDispute>action(CardDisputeActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardDisputeService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
action
HttpResponseFor<CardDispute> action(CardDisputeActionParams params, RequestOptions requestOptions)
-
-
-
-