Interface CardFuelConfirmationService
-
- All Implemented Interfaces:
public interface CardFuelConfirmationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardFuelConfirmationService.WithRawResponseA view of CardFuelConfirmationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardFuelConfirmationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardFuelConfirmationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPaymentcreate(CardFuelConfirmationCreateParams params)Simulates the fuel confirmation of an authorization by a card acquirer. abstract CardPaymentcreate(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardFuelConfirmationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardFuelConfirmationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPayment create(CardFuelConfirmationCreateParams params)
Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.
-
create
abstract CardPayment create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)
-
-
-
-