Class CardFuelConfirmationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardFuelConfirmationService
public final class CardFuelConfirmationServiceImpl implements CardFuelConfirmationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardFuelConfirmationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardFuelConfirmationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPaymentcreate(SimulationCardFuelConfirmationCreateParams params, RequestOptions requestOptions)Simulates the fuel confirmation of an authorization by a card acquirer. -
-
Method Detail
-
withRawResponse
CardFuelConfirmationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CardPayment create(SimulationCardFuelConfirmationCreateParams params, RequestOptions requestOptions)
Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.
-
-
-
-