Class CardFuelConfirmationServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardFuelConfirmationService.WithRawResponse
public final class CardFuelConfirmationServiceImpl.WithRawResponseImpl implements CardFuelConfirmationService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardFuelConfirmationService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPayment>create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardFuelConfirmationService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<CardPayment> create(CardFuelConfirmationCreateParams params, RequestOptions requestOptions)
-
-
-
-