Interface CardIncrementService
-
- All Implemented Interfaces:
public interface CardIncrementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardIncrementService.WithRawResponseA view of CardIncrementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardIncrementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardIncrementServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPaymentcreate(CardIncrementCreateParams params)Simulates the increment of an authorization by a card acquirer. abstract CardPaymentcreate(CardIncrementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardIncrementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardIncrementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPayment create(CardIncrementCreateParams params)
Simulates the increment of an authorization by a card acquirer. An authorization can be incremented multiple times.
-
create
abstract CardPayment create(CardIncrementCreateParams params, RequestOptions requestOptions)
-
-
-
-