Interface CardIncrementService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardIncrementService.WithRawResponseA view of CardIncrementService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardIncrementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPayment>create(CardIncrementCreateParams params)Returns a raw HTTP response for post /simulations/card_increments, but is otherwise the same as CardIncrementService.create.abstract HttpResponseFor<CardPayment>create(CardIncrementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardIncrementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<CardPayment> create(CardIncrementCreateParams params)
Returns a raw HTTP response for
post /simulations/card_increments, but is otherwise the same as CardIncrementService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<CardPayment> create(CardIncrementCreateParams params, RequestOptions requestOptions)
-
-
-
-