Class CardIncrementServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardIncrementService
public final class CardIncrementServiceImpl implements CardIncrementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardIncrementServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardIncrementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPaymentcreate(CardIncrementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardIncrementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CardPayment create(CardIncrementCreateParams params, RequestOptions requestOptions)
-
-
-
-