Interface CardPurchaseSupplementService
-
- All Implemented Interfaces:
public interface CardPurchaseSupplementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPurchaseSupplementService.WithRawResponseA view of CardPurchaseSupplementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardPurchaseSupplementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardPurchaseSupplementServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPurchaseSupplementcreate(CardPurchaseSupplementCreateParams params)Simulates the creation of a Card Purchase Supplement (Level 3 data) for a card settlement. abstract CardPurchaseSupplementcreate(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardPurchaseSupplementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardPurchaseSupplementService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPurchaseSupplement create(CardPurchaseSupplementCreateParams params)
Simulates the creation of a Card Purchase Supplement (Level 3 data) for a card settlement. This happens asynchronously in production when Visa sends enhanced transaction data about a purchase.
-
create
abstract CardPurchaseSupplement create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)
-
-
-
-