Interface CardPurchaseSupplementService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardPurchaseSupplementService.WithRawResponseA view of CardPurchaseSupplementService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardPurchaseSupplementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPurchaseSupplement>create(CardPurchaseSupplementCreateParams params)Returns a raw HTTP response for post /simulations/card_purchase_supplements, but is otherwise the same as CardPurchaseSupplementService.create.abstract HttpResponseFor<CardPurchaseSupplement>create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardPurchaseSupplementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<CardPurchaseSupplement> create(CardPurchaseSupplementCreateParams params)
Returns a raw HTTP response for
post /simulations/card_purchase_supplements, but is otherwise the same as CardPurchaseSupplementService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<CardPurchaseSupplement> create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)
-
-
-
-