Class CardPurchaseSupplementServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardPurchaseSupplementService.WithRawResponse
public final class CardPurchaseSupplementServiceImpl.WithRawResponseImpl implements CardPurchaseSupplementService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CardPurchaseSupplementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CardPurchaseSupplement>create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CardPurchaseSupplementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<CardPurchaseSupplement> create(CardPurchaseSupplementCreateParams params, RequestOptions requestOptions)
-
-
-
-