Interface CardRefundService
-
- All Implemented Interfaces:
public interface CardRefundService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardRefundService.WithRawResponseA view of CardRefundService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardRefundService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardRefundServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Transactioncreate()Simulates refunding a card transaction. abstract Transactioncreate(CardRefundCreateParams params, RequestOptions requestOptions)Transactioncreate(CardRefundCreateParams params)Transactioncreate(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardRefundService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardRefundService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Transaction create()
Simulates refunding a card transaction. The full value of the original sandbox transaction is refunded.
-
create
abstract Transaction create(CardRefundCreateParams params, RequestOptions requestOptions)
-
create
Transaction create(CardRefundCreateParams params)
-
create
Transaction create(RequestOptions requestOptions)
-
-
-
-