Interface CardRefundService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardRefundService.WithRawResponseA view of CardRefundService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardRefundService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Transaction>create()Returns a raw HTTP response for post /simulations/card_refunds, but is otherwise the same as CardRefundService.create.abstract HttpResponseFor<Transaction>create(CardRefundCreateParams params, RequestOptions requestOptions)HttpResponseFor<Transaction>create(CardRefundCreateParams params)HttpResponseFor<Transaction>create(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardRefundService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<Transaction> create()
Returns a raw HTTP response for
post /simulations/card_refunds, but is otherwise the same as CardRefundService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<Transaction> create(CardRefundCreateParams params, RequestOptions requestOptions)
-
create
@MustBeClosed() HttpResponseFor<Transaction> create(CardRefundCreateParams params)
-
create
@MustBeClosed() HttpResponseFor<Transaction> create(RequestOptions requestOptions)
-
-
-
-