Class CardRefundServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardRefundService
public final class CardRefundServiceImpl implements CardRefundService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRefundServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardRefundService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardRefundServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Transactioncreate(CardRefundCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardRefundService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardRefundService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Transaction create(CardRefundCreateParams params, RequestOptions requestOptions)
-
-
-
-