Interface CardReversalService
-
- All Implemented Interfaces:
public interface CardReversalService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardReversalService.WithRawResponseA view of CardReversalService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardReversalService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardReversalServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardPaymentcreate(CardReversalCreateParams params)Simulates the reversal of an authorization by a card acquirer. abstract CardPaymentcreate(CardReversalCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardReversalService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardReversalService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CardPayment create(CardReversalCreateParams params)
Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.
-
create
abstract CardPayment create(CardReversalCreateParams params, RequestOptions requestOptions)
-
-
-
-