Interface CardSettlementService.WithRawResponse
-
- All Implemented Interfaces:
public interface CardSettlementService.WithRawResponseA view of CardSettlementService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CardSettlementService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Transaction>create(CardSettlementCreateParams params)Returns a raw HTTP response for post /simulations/card_settlements, but is otherwise the same as CardSettlementService.create.abstract HttpResponseFor<Transaction>create(CardSettlementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CardSettlementService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<Transaction> create(CardSettlementCreateParams params)
Returns a raw HTTP response for
post /simulations/card_settlements, but is otherwise the same as CardSettlementService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<Transaction> create(CardSettlementCreateParams params, RequestOptions requestOptions)
-
-
-
-