Interface CardTokenService
-
- All Implemented Interfaces:
public interface CardTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardTokenService.WithRawResponseA view of CardTokenService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardTokenServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CardTokencreate()Simulates tokenizing a card in the sandbox environment. abstract CardTokencreate(CardTokenCreateParams params, RequestOptions requestOptions)CardTokencreate(CardTokenCreateParams params)CardTokencreate(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CardTokenService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
abstract CardToken create(CardTokenCreateParams params, RequestOptions requestOptions)
-
create
CardToken create(CardTokenCreateParams params)
-
create
CardToken create(RequestOptions requestOptions)
-
-
-
-