Interface CheckDepositService
-
- All Implemented Interfaces:
public interface CheckDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckDepositService.WithRawResponseA view of CheckDepositService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckDepositreject(CheckDepositRejectParams params)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. abstract CheckDepositreject(CheckDepositRejectParams params, RequestOptions requestOptions)CheckDepositreturn_(CheckDepositReturnParams params)Simulates the return of a #check-deposits. abstract CheckDepositreturn_(CheckDepositReturnParams params, RequestOptions requestOptions)CheckDepositsubmit(CheckDepositSubmitParams params)Simulates the submission of a #check-deposits to the Federal Reserve. abstract CheckDepositsubmit(CheckDepositSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CheckDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reject
CheckDeposit reject(CheckDepositRejectParams params)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
reject
abstract CheckDeposit reject(CheckDepositRejectParams params, RequestOptions requestOptions)
-
return_
CheckDeposit return_(CheckDepositReturnParams params)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
return_
abstract CheckDeposit return_(CheckDepositReturnParams params, RequestOptions requestOptions)
-
submit
CheckDeposit submit(CheckDepositSubmitParams params)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
submit
abstract CheckDeposit submit(CheckDepositSubmitParams params, RequestOptions requestOptions)
-
-
-
-