Class CheckDepositServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CheckDepositService
public final class CheckDepositServiceImpl implements CheckDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckDepositreject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. CheckDepositreturn_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)Simulates the return of a #check-deposits. CheckDepositsubmit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)Simulates the submission of a #check-deposits to the Federal Reserve. -
-
Method Detail
-
withRawResponse
CheckDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reject
CheckDeposit reject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
return_
CheckDeposit return_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
submit
CheckDeposit submit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
-
-
-