Interface CheckTransferService
-
- All Implemented Interfaces:
public interface CheckTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckTransferService.WithRawResponseA view of CheckTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CheckTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CheckTransfermail(String checkTransferId)Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. CheckTransfermail(String checkTransferId, CheckTransferMailParams params, RequestOptions requestOptions)CheckTransfermail(String checkTransferId, CheckTransferMailParams params)abstract CheckTransfermail(CheckTransferMailParams params, RequestOptions requestOptions)CheckTransfermail(CheckTransferMailParams params)CheckTransfermail(String checkTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CheckTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CheckTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
mail
CheckTransfer mail(String checkTransferId)
Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. This transfer must first have a
statusofpending_approvalorpending_submission.
-
mail
CheckTransfer mail(String checkTransferId, CheckTransferMailParams params, RequestOptions requestOptions)
-
mail
CheckTransfer mail(String checkTransferId, CheckTransferMailParams params)
-
mail
abstract CheckTransfer mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
mail
CheckTransfer mail(CheckTransferMailParams params)
-
mail
CheckTransfer mail(String checkTransferId, RequestOptions requestOptions)
-
-
-
-