Interface CheckTransferService.WithRawResponse
-
- All Implemented Interfaces:
public interface CheckTransferService.WithRawResponseA view of CheckTransferService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CheckTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CheckTransfer>mail(String checkTransferId)Returns a raw HTTP response for post /simulations/check_transfers/{check_transfer_id}/mail, but is otherwise the same as CheckTransferService.mail.HttpResponseFor<CheckTransfer>mail(String checkTransferId, CheckTransferMailParams params, RequestOptions requestOptions)HttpResponseFor<CheckTransfer>mail(String checkTransferId, CheckTransferMailParams params)abstract HttpResponseFor<CheckTransfer>mail(CheckTransferMailParams params, RequestOptions requestOptions)HttpResponseFor<CheckTransfer>mail(CheckTransferMailParams params)HttpResponseFor<CheckTransfer>mail(String checkTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract CheckTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
mail
@MustBeClosed() HttpResponseFor<CheckTransfer> mail(String checkTransferId)
Returns a raw HTTP response for
post /simulations/check_transfers/{check_transfer_id}/mail, but is otherwise the same as CheckTransferService.mail.
-
mail
@MustBeClosed() HttpResponseFor<CheckTransfer> mail(String checkTransferId, CheckTransferMailParams params, RequestOptions requestOptions)
-
mail
@MustBeClosed() HttpResponseFor<CheckTransfer> mail(String checkTransferId, CheckTransferMailParams params)
-
mail
@MustBeClosed() abstract HttpResponseFor<CheckTransfer> mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
mail
@MustBeClosed() HttpResponseFor<CheckTransfer> mail(CheckTransferMailParams params)
-
mail
@MustBeClosed() HttpResponseFor<CheckTransfer> mail(String checkTransferId, RequestOptions requestOptions)
-
-
-
-