Class CheckTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CheckTransferService
public final class CheckTransferServiceImpl implements CheckTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CheckTransfermail(CheckTransferMailParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CheckTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CheckTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
mail
CheckTransfer mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
-
-
-