Class CheckTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CheckTransferService.WithRawResponse
public final class CheckTransferServiceImpl.WithRawResponseImpl implements CheckTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CheckTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CheckTransfer>mail(CheckTransferMailParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
CheckTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
mail
HttpResponseFor<CheckTransfer> mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
-
-
-