Interface DigitalWalletTokenRequestService
-
- All Implemented Interfaces:
public interface DigitalWalletTokenRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalWalletTokenRequestService.WithRawResponseA view of DigitalWalletTokenRequestService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DigitalWalletTokenRequestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DigitalWalletTokenRequestCreateResponsecreate(DigitalWalletTokenRequestCreateParams params)Simulates a user attempting to add a #cards to a digital wallet such as Apple Pay. abstract DigitalWalletTokenRequestCreateResponsecreate(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DigitalWalletTokenRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DigitalWalletTokenRequestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
DigitalWalletTokenRequestCreateResponse create(DigitalWalletTokenRequestCreateParams params)
Simulates a user attempting to add a #cards to a digital wallet such as Apple Pay.
-
create
abstract DigitalWalletTokenRequestCreateResponse create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-