Interface DigitalWalletTokenRequestService.WithRawResponse
-
- All Implemented Interfaces:
public interface DigitalWalletTokenRequestService.WithRawResponseA view of DigitalWalletTokenRequestService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenRequestService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<DigitalWalletTokenRequestCreateResponse>create(DigitalWalletTokenRequestCreateParams params)Returns a raw HTTP response for post /simulations/digital_wallet_token_requests, but is otherwise the same as DigitalWalletTokenRequestService.create.abstract HttpResponseFor<DigitalWalletTokenRequestCreateResponse>create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract DigitalWalletTokenRequestService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<DigitalWalletTokenRequestCreateResponse> create(DigitalWalletTokenRequestCreateParams params)
Returns a raw HTTP response for
post /simulations/digital_wallet_token_requests, but is otherwise the same as DigitalWalletTokenRequestService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<DigitalWalletTokenRequestCreateResponse> create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-