Class DigitalWalletTokenRequestServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.DigitalWalletTokenRequestService
public final class DigitalWalletTokenRequestServiceImpl implements DigitalWalletTokenRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalWalletTokenRequestServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigitalWalletTokenRequestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. DigitalWalletTokenRequestCreateResponsecreate(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DigitalWalletTokenRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigitalWalletTokenRequestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
DigitalWalletTokenRequestCreateResponse create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-