Class DigitalWalletTokenRequestServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.DigitalWalletTokenRequestService.WithRawResponse
public final class DigitalWalletTokenRequestServiceImpl.WithRawResponseImpl implements DigitalWalletTokenRequestService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description DigitalWalletTokenRequestService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<DigitalWalletTokenRequestCreateResponse>create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
DigitalWalletTokenRequestService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<DigitalWalletTokenRequestCreateResponse> create(DigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-