Interface DocumentService
-
- All Implemented Interfaces:
public interface DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentService.WithRawResponseA view of DocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DocumentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Documentcreate(DocumentCreateParams params)Simulates an tax document being created for an account. abstract Documentcreate(DocumentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract DocumentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Document create(DocumentCreateParams params)
Simulates an tax document being created for an account.
-
create
abstract Document create(DocumentCreateParams params, RequestOptions requestOptions)
-
-
-
-