Class EntityOnboardingSessionServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.EntityOnboardingSessionService.WithRawResponse
public final class EntityOnboardingSessionServiceImpl.WithRawResponseImpl implements EntityOnboardingSessionService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description EntityOnboardingSessionService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<EntityOnboardingSession>submit(EntityOnboardingSessionSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
EntityOnboardingSessionService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
submit
HttpResponseFor<EntityOnboardingSession> submit(EntityOnboardingSessionSubmitParams params, RequestOptions requestOptions)
-
-
-
-