Interface EntityService
-
- All Implemented Interfaces:
public interface EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityService.WithRawResponseA view of EntityService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EntityService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EntityServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EntityupdateValidation(String entityId, EntityUpdateValidationParams params)Simulate updates to an /documentation/api/entities#entity-object. EntityupdateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)EntityupdateValidation(EntityUpdateValidationParams params)abstract EntityupdateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EntityService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
Entity updateValidation(String entityId, EntityUpdateValidationParams params)
Simulate updates to an /documentation/api/entities#entity-object.validation. In production, Know Your Customer validations /documentation/entity-validation#entity-validation for eligible programs. While developing, use this API to simulate issues with information submissions.
-
updateValidation
Entity updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)
-
updateValidation
Entity updateValidation(EntityUpdateValidationParams params)
-
updateValidation
abstract Entity updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-