Interface EntityService.WithRawResponse
-
- All Implemented Interfaces:
public interface EntityService.WithRawResponseA view of EntityService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract EntityService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Entity>updateValidation(String entityId, EntityUpdateValidationParams params)Returns a raw HTTP response for post /simulations/entities/{entity_id}/update_validation, but is otherwise the same as EntityService.updateValidation.HttpResponseFor<Entity>updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)HttpResponseFor<Entity>updateValidation(EntityUpdateValidationParams params)abstract HttpResponseFor<Entity>updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract EntityService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
@MustBeClosed() HttpResponseFor<Entity> updateValidation(String entityId, EntityUpdateValidationParams params)
Returns a raw HTTP response for
post /simulations/entities/{entity_id}/update_validation, but is otherwise the same as EntityService.updateValidation.
-
updateValidation
@MustBeClosed() HttpResponseFor<Entity> updateValidation(String entityId, EntityUpdateValidationParams params, RequestOptions requestOptions)
-
updateValidation
@MustBeClosed() HttpResponseFor<Entity> updateValidation(EntityUpdateValidationParams params)
-
updateValidation
@MustBeClosed() abstract HttpResponseFor<Entity> updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-