Class EntityServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.EntityService
public final class EntityServiceImpl implements EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EntityService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EntityServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. EntityupdateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EntityService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
updateValidation
Entity updateValidation(EntityUpdateValidationParams params, RequestOptions requestOptions)
-
-
-
-