Interface ExportService.WithRawResponse
-
- All Implemented Interfaces:
public interface ExportService.WithRawResponseA view of ExportService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ExportService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Export>create(ExportCreateParams params)Returns a raw HTTP response for post /simulations/exports, but is otherwise the same as ExportService.create.abstract HttpResponseFor<Export>create(ExportCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract ExportService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<Export> create(ExportCreateParams params)
Returns a raw HTTP response for
post /simulations/exports, but is otherwise the same as ExportService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
-
-
-