Class ExportServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.ExportService.WithRawResponse
public final class ExportServiceImpl.WithRawResponseImpl implements ExportService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ExportService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Export>create(ExportCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
ExportService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
-
-
-