Class InboundAchTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundAchTransferService
public final class InboundAchTransferServiceImpl implements InboundAchTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundAchTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundAchTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundAchTransfercreate(InboundAchTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundAchTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundAchTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundAchTransfer create(InboundAchTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-