Class InboundAchTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundAchTransferService.WithRawResponse
public final class InboundAchTransferServiceImpl.WithRawResponseImpl implements InboundAchTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundAchTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundAchTransfer>create(InboundAchTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundAchTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<InboundAchTransfer> create(InboundAchTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-