Class InboundCheckDepositServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundCheckDepositService
public final class InboundCheckDepositServiceImpl implements InboundCheckDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundCheckDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundCheckDepositServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundCheckDepositcreate(InboundCheckDepositCreateParams params, RequestOptions requestOptions)InboundCheckDepositadjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.InboundCheckDepositService
adjustment, adjustment, adjustment, adjustment, adjustment, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
InboundCheckDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundCheckDepositService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundCheckDeposit create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
adjustment
InboundCheckDeposit adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)
-
-
-
-