Class InboundCheckDepositServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundCheckDepositService.WithRawResponse
public final class InboundCheckDepositServiceImpl.WithRawResponseImpl implements InboundCheckDepositService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundCheckDepositService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundCheckDeposit>create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)HttpResponseFor<InboundCheckDeposit>adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.InboundCheckDepositService.WithRawResponse
adjustment, adjustment, adjustment, adjustment, adjustment, create -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
InboundCheckDepositService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<InboundCheckDeposit> create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
adjustment
HttpResponseFor<InboundCheckDeposit> adjustment(InboundCheckDepositAdjustmentParams params, RequestOptions requestOptions)
-
-
-
-