Interface InboundFednowTransferService
-
- All Implemented Interfaces:
public interface InboundFednowTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundFednowTransferService.WithRawResponseA view of InboundFednowTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundFednowTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundFednowTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundFednowTransfercreate(InboundFednowTransferCreateParams params)Simulates an #inbound-fednow-transfers to your account. abstract InboundFednowTransfercreate(InboundFednowTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundFednowTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundFednowTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundFednowTransfer create(InboundFednowTransferCreateParams params)
Simulates an #inbound-fednow-transfers to your account.
-
create
abstract InboundFednowTransfer create(InboundFednowTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-