Class InboundFednowTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundFednowTransferService
public final class InboundFednowTransferServiceImpl implements InboundFednowTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundFednowTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundFednowTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundFednowTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundFednowTransfercreate(InboundFednowTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundFednowTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundFednowTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundFednowTransfer create(InboundFednowTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-