Interface InboundFundsHoldService
-
- All Implemented Interfaces:
public interface InboundFundsHoldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundFundsHoldService.WithRawResponseA view of InboundFundsHoldService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundFundsHoldService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundFundsHoldServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundFundsHoldReleaseResponserelease(String inboundFundsHoldId)This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit. InboundFundsHoldReleaseResponserelease(String inboundFundsHoldId, InboundFundsHoldReleaseParams params, RequestOptions requestOptions)InboundFundsHoldReleaseResponserelease(String inboundFundsHoldId, InboundFundsHoldReleaseParams params)abstract InboundFundsHoldReleaseResponserelease(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)InboundFundsHoldReleaseResponserelease(InboundFundsHoldReleaseParams params)InboundFundsHoldReleaseResponserelease(String inboundFundsHoldId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundFundsHoldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundFundsHoldService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
release
InboundFundsHoldReleaseResponse release(String inboundFundsHoldId)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.
-
release
InboundFundsHoldReleaseResponse release(String inboundFundsHoldId, InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
release
InboundFundsHoldReleaseResponse release(String inboundFundsHoldId, InboundFundsHoldReleaseParams params)
-
release
abstract InboundFundsHoldReleaseResponse release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
release
InboundFundsHoldReleaseResponse release(InboundFundsHoldReleaseParams params)
-
release
InboundFundsHoldReleaseResponse release(String inboundFundsHoldId, RequestOptions requestOptions)
-
-
-
-