Class InboundFundsHoldServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundFundsHoldService
public final class InboundFundsHoldServiceImpl implements InboundFundsHoldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundFundsHoldServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundFundsHoldService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SimulationInboundFundsHoldReleaseResponserelease(SimulationInboundFundsHoldReleaseParams params, RequestOptions requestOptions)This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit. -
-
Method Detail
-
withRawResponse
InboundFundsHoldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
release
SimulationInboundFundsHoldReleaseResponse release(SimulationInboundFundsHoldReleaseParams params, RequestOptions requestOptions)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.
-
-
-
-