Class InboundMailItemServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundMailItemService
public final class InboundMailItemServiceImpl implements InboundMailItemService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundMailItemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundMailItemServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundMailItemcreate(InboundMailItemCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundMailItemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundMailItemService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundMailItem create(InboundMailItemCreateParams params, RequestOptions requestOptions)
-
-
-
-