Interface InboundRealTimePaymentsTransferService
-
- All Implemented Interfaces:
public interface InboundRealTimePaymentsTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundRealTimePaymentsTransferService.WithRawResponseA view of InboundRealTimePaymentsTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundRealTimePaymentsTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundRealTimePaymentsTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundRealTimePaymentsTransfercreate(InboundRealTimePaymentsTransferCreateParams params)Simulates an #inbound-real-time-payments-transfers to your account. abstract InboundRealTimePaymentsTransfercreate(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundRealTimePaymentsTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundRealTimePaymentsTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundRealTimePaymentsTransfer create(InboundRealTimePaymentsTransferCreateParams params)
Simulates an #inbound-real-time-payments-transfers to your account. Real-Time Payments are a beta feature.
-
create
abstract InboundRealTimePaymentsTransfer create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-