Interface InboundRealTimePaymentsTransferService.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundRealTimePaymentsTransferService.WithRawResponseA view of InboundRealTimePaymentsTransferService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundRealTimePaymentsTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundRealTimePaymentsTransfer>create(InboundRealTimePaymentsTransferCreateParams params)Returns a raw HTTP response for post /simulations/inbound_real_time_payments_transfers, but is otherwise the same as InboundRealTimePaymentsTransferService.create.abstract HttpResponseFor<InboundRealTimePaymentsTransfer>create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundRealTimePaymentsTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<InboundRealTimePaymentsTransfer> create(InboundRealTimePaymentsTransferCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_real_time_payments_transfers, but is otherwise the same as InboundRealTimePaymentsTransferService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<InboundRealTimePaymentsTransfer> create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-