Class InboundRealTimePaymentsTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundRealTimePaymentsTransferService.WithRawResponse
public final class InboundRealTimePaymentsTransferServiceImpl.WithRawResponseImpl implements InboundRealTimePaymentsTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundRealTimePaymentsTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundRealTimePaymentsTransfer>create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundRealTimePaymentsTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<InboundRealTimePaymentsTransfer> create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-