Interface InboundWireDrawdownRequestService
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireDrawdownRequestService.WithRawResponseA view of InboundWireDrawdownRequestService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireDrawdownRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundWireDrawdownRequestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundWireDrawdownRequestcreate(InboundWireDrawdownRequestCreateParams params)Simulates receiving an #inbound-wire-drawdown-requests. abstract InboundWireDrawdownRequestcreate(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireDrawdownRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundWireDrawdownRequestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundWireDrawdownRequest create(InboundWireDrawdownRequestCreateParams params)
Simulates receiving an #inbound-wire-drawdown-requests.
-
create
abstract InboundWireDrawdownRequest create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-