Interface InboundWireDrawdownRequestService.WithRawResponse
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestService.WithRawResponseA view of InboundWireDrawdownRequestService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract InboundWireDrawdownRequestService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundWireDrawdownRequest>create(InboundWireDrawdownRequestCreateParams params)Returns a raw HTTP response for post /simulations/inbound_wire_drawdown_requests, but is otherwise the same as InboundWireDrawdownRequestService.create.abstract HttpResponseFor<InboundWireDrawdownRequest>create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract InboundWireDrawdownRequestService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
@MustBeClosed() HttpResponseFor<InboundWireDrawdownRequest> create(InboundWireDrawdownRequestCreateParams params)
Returns a raw HTTP response for
post /simulations/inbound_wire_drawdown_requests, but is otherwise the same as InboundWireDrawdownRequestService.create.
-
create
@MustBeClosed() abstract HttpResponseFor<InboundWireDrawdownRequest> create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-