Class InboundWireDrawdownRequestServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundWireDrawdownRequestService
public final class InboundWireDrawdownRequestServiceImpl implements InboundWireDrawdownRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireDrawdownRequestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundWireDrawdownRequestcreate(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundWireDrawdownRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundWireDrawdownRequestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundWireDrawdownRequest create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-