Class InboundWireDrawdownRequestServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundWireDrawdownRequestService.WithRawResponse
public final class InboundWireDrawdownRequestServiceImpl.WithRawResponseImpl implements InboundWireDrawdownRequestService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundWireDrawdownRequest>create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundWireDrawdownRequestService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<InboundWireDrawdownRequest> create(InboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
-
-
-
-