Interface InboundWireTransferService
-
- All Implemented Interfaces:
public interface InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireTransferService.WithRawResponseA view of InboundWireTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundWireTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundWireTransfercreate(InboundWireTransferCreateParams params)Simulates an #inbound-wire-transfers to your account. abstract InboundWireTransfercreate(InboundWireTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundWireTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundWireTransfer create(InboundWireTransferCreateParams params)
Simulates an #inbound-wire-transfers to your account.
-
create
abstract InboundWireTransfer create(InboundWireTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-