Class InboundWireTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundWireTransferService
public final class InboundWireTransferServiceImpl implements InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundWireTransfercreate(InboundWireTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InboundWireTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundWireTransfer create(InboundWireTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-