Class InboundWireTransferServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundWireTransferService.WithRawResponse
public final class InboundWireTransferServiceImpl.WithRawResponseImpl implements InboundWireTransferService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InboundWireTransferService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<InboundWireTransfer>create(InboundWireTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InboundWireTransferService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<InboundWireTransfer> create(InboundWireTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-