Interface InterestPaymentService
-
- All Implemented Interfaces:
public interface InterestPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInterestPaymentService.WithRawResponseA view of InterestPaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InterestPaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InterestPaymentServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Transactioncreate(InterestPaymentCreateParams params)Simulates an interest payment to your account. abstract Transactioncreate(InterestPaymentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InterestPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InterestPaymentService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Transaction create(InterestPaymentCreateParams params)
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
create
abstract Transaction create(InterestPaymentCreateParams params, RequestOptions requestOptions)
-
-
-
-