Class InterestPaymentServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InterestPaymentService
public final class InterestPaymentServiceImpl implements InterestPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInterestPaymentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InterestPaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Transactioncreate(SimulationInterestPaymentCreateParams params, RequestOptions requestOptions)Simulates an interest payment to your account. -
-
Method Detail
-
withRawResponse
InterestPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Transaction create(SimulationInterestPaymentCreateParams params, RequestOptions requestOptions)
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
-
-
-