Class PendingTransactionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.PendingTransactionService
public final class PendingTransactionServiceImpl implements PendingTransactionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PendingTransactionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PendingTransactionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PendingTransactionreleaseInboundFundsHold(PendingTransactionReleaseInboundFundsHoldParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.blocking.simulations.PendingTransactionService
releaseInboundFundsHold, releaseInboundFundsHold, releaseInboundFundsHold, releaseInboundFundsHold, releaseInboundFundsHold -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
PendingTransactionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
PendingTransactionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
releaseInboundFundsHold
PendingTransaction releaseInboundFundsHold(PendingTransactionReleaseInboundFundsHoldParams params, RequestOptions requestOptions)
-
-
-
-