Interface PhysicalCardService
-
- All Implemented Interfaces:
public interface PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePhysicalCardService.WithRawResponseA view of PhysicalCardService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract PhysicalCardServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. PhysicalCardcreate(String physicalCardId, PhysicalCardCreateParams params)This endpoint allows you to simulate receiving a tracking update for a Physical Card, to simulate the progress of a shipment. PhysicalCardcreate(String physicalCardId, PhysicalCardCreateParams params, RequestOptions requestOptions)PhysicalCardcreate(PhysicalCardCreateParams params)abstract PhysicalCardcreate(PhysicalCardCreateParams params, RequestOptions requestOptions)PhysicalCardadvanceShipment(String physicalCardId, PhysicalCardAdvanceShipmentParams params)This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery. PhysicalCardadvanceShipment(String physicalCardId, PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)PhysicalCardadvanceShipment(PhysicalCardAdvanceShipmentParams params)abstract PhysicalCardadvanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract PhysicalCardService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
PhysicalCard create(String physicalCardId, PhysicalCardCreateParams params)
This endpoint allows you to simulate receiving a tracking update for a Physical Card, to simulate the progress of a shipment.
-
create
PhysicalCard create(String physicalCardId, PhysicalCardCreateParams params, RequestOptions requestOptions)
-
create
PhysicalCard create(PhysicalCardCreateParams params)
-
create
abstract PhysicalCard create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
advanceShipment
PhysicalCard advanceShipment(String physicalCardId, PhysicalCardAdvanceShipmentParams params)
This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery.
-
advanceShipment
PhysicalCard advanceShipment(String physicalCardId, PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
advanceShipment
PhysicalCard advanceShipment(PhysicalCardAdvanceShipmentParams params)
-
advanceShipment
abstract PhysicalCard advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
-
-
-