Class PhysicalCardServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.PhysicalCardService
public final class PhysicalCardServiceImpl implements PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardadvanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
advanceShipment
PhysicalCard advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
-
-
-