Interface ProgramService
-
- All Implemented Interfaces:
public interface ProgramService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProgramService.WithRawResponseA view of ProgramService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ProgramService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ProgramServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Programcreate(ProgramCreateParams params)Simulates a #programs being created in your group. abstract Programcreate(ProgramCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ProgramService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ProgramService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Program create(ProgramCreateParams params)
Simulates a #programs being created in your group. By default, your group has one program called Commercial Banking. Note that when your group operates more than one program,
program_idis a required field when creating accounts.
-
create
abstract Program create(ProgramCreateParams params, RequestOptions requestOptions)
-
-
-
-