Class ProgramServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.ProgramService
public final class ProgramServiceImpl implements ProgramService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProgramService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ProgramServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Programcreate(ProgramCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
ProgramService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ProgramService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Program create(ProgramCreateParams params, RequestOptions requestOptions)
-
-
-
-