Interface RealTimePaymentsTransferService
-
- All Implemented Interfaces:
public interface RealTimePaymentsTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRealTimePaymentsTransferService.WithRawResponseA view of RealTimePaymentsTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RealTimePaymentsTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract RealTimePaymentsTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RealTimePaymentsTransfercomplete(String realTimePaymentsTransferId)Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. RealTimePaymentsTransfercomplete(String realTimePaymentsTransferId, RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)RealTimePaymentsTransfercomplete(String realTimePaymentsTransferId, RealTimePaymentsTransferCompleteParams params)abstract RealTimePaymentsTransfercomplete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)RealTimePaymentsTransfercomplete(RealTimePaymentsTransferCompleteParams params)RealTimePaymentsTransfercomplete(String realTimePaymentsTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RealTimePaymentsTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RealTimePaymentsTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
complete
RealTimePaymentsTransfer complete(String realTimePaymentsTransferId)
Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. This transfer must first have a
statusofpending_submission.
-
complete
RealTimePaymentsTransfer complete(String realTimePaymentsTransferId, RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
complete
RealTimePaymentsTransfer complete(String realTimePaymentsTransferId, RealTimePaymentsTransferCompleteParams params)
-
complete
abstract RealTimePaymentsTransfer complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
complete
RealTimePaymentsTransfer complete(RealTimePaymentsTransferCompleteParams params)
-
complete
RealTimePaymentsTransfer complete(String realTimePaymentsTransferId, RequestOptions requestOptions)
-
-
-
-