Interface WireDrawdownRequestService
-
- All Implemented Interfaces:
public interface WireDrawdownRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWireDrawdownRequestService.WithRawResponseA view of WireDrawdownRequestService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WireDrawdownRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WireDrawdownRequestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WireDrawdownRequestrefuse(String wireDrawdownRequestId)Simulates a Wire Drawdown Request being refused by the debtor. WireDrawdownRequestrefuse(String wireDrawdownRequestId, WireDrawdownRequestRefuseParams params, RequestOptions requestOptions)WireDrawdownRequestrefuse(String wireDrawdownRequestId, WireDrawdownRequestRefuseParams params)abstract WireDrawdownRequestrefuse(WireDrawdownRequestRefuseParams params, RequestOptions requestOptions)WireDrawdownRequestrefuse(WireDrawdownRequestRefuseParams params)WireDrawdownRequestrefuse(String wireDrawdownRequestId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WireDrawdownRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WireDrawdownRequestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
refuse
WireDrawdownRequest refuse(String wireDrawdownRequestId)
Simulates a Wire Drawdown Request being refused by the debtor.
-
refuse
WireDrawdownRequest refuse(String wireDrawdownRequestId, WireDrawdownRequestRefuseParams params, RequestOptions requestOptions)
-
refuse
WireDrawdownRequest refuse(String wireDrawdownRequestId, WireDrawdownRequestRefuseParams params)
-
refuse
abstract WireDrawdownRequest refuse(WireDrawdownRequestRefuseParams params, RequestOptions requestOptions)
-
refuse
WireDrawdownRequest refuse(WireDrawdownRequestRefuseParams params)
-
refuse
WireDrawdownRequest refuse(String wireDrawdownRequestId, RequestOptions requestOptions)
-
-
-
-