Interface WireTransferService
-
- All Implemented Interfaces:
public interface WireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWireTransferService.WithRawResponseA view of WireTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract WireTransferServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. WireTransferreverse(String wireTransferId)Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. WireTransferreverse(String wireTransferId, WireTransferReverseParams params, RequestOptions requestOptions)WireTransferreverse(String wireTransferId, WireTransferReverseParams params)abstract WireTransferreverse(WireTransferReverseParams params, RequestOptions requestOptions)WireTransferreverse(WireTransferReverseParams params)WireTransferreverse(String wireTransferId, RequestOptions requestOptions)WireTransfersubmit(String wireTransferId)Simulates the submission of a #wire-transfers to the Federal Reserve. WireTransfersubmit(String wireTransferId, WireTransferSubmitParams params, RequestOptions requestOptions)WireTransfersubmit(String wireTransferId, WireTransferSubmitParams params)abstract WireTransfersubmit(WireTransferSubmitParams params, RequestOptions requestOptions)WireTransfersubmit(WireTransferSubmitParams params)WireTransfersubmit(String wireTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract WireTransferService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
reverse
WireTransfer reverse(String wireTransferId)
Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a
statusofcomplete.
-
reverse
WireTransfer reverse(String wireTransferId, WireTransferReverseParams params, RequestOptions requestOptions)
-
reverse
WireTransfer reverse(String wireTransferId, WireTransferReverseParams params)
-
reverse
abstract WireTransfer reverse(WireTransferReverseParams params, RequestOptions requestOptions)
-
reverse
WireTransfer reverse(WireTransferReverseParams params)
-
reverse
WireTransfer reverse(String wireTransferId, RequestOptions requestOptions)
-
submit
WireTransfer submit(String wireTransferId)
Simulates the submission of a #wire-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_creating.
-
submit
WireTransfer submit(String wireTransferId, WireTransferSubmitParams params, RequestOptions requestOptions)
-
submit
WireTransfer submit(String wireTransferId, WireTransferSubmitParams params)
-
submit
abstract WireTransfer submit(WireTransferSubmitParams params, RequestOptions requestOptions)
-
submit
WireTransfer submit(WireTransferSubmitParams params)
-
submit
WireTransfer submit(String wireTransferId, RequestOptions requestOptions)
-
-
-
-