Class WireTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.WireTransferService
public final class WireTransferServiceImpl implements WireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WireTransferreverse(SimulationWireTransferReverseParams params, RequestOptions requestOptions)Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. WireTransfersubmit(SimulationWireTransferSubmitParams params, RequestOptions requestOptions)Simulates the submission of a #wire-transfers to the Federal Reserve. -
-
Method Detail
-
withRawResponse
WireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reverse
WireTransfer reverse(SimulationWireTransferReverseParams params, RequestOptions requestOptions)
Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a
statusofcomplete.
-
submit
WireTransfer submit(SimulationWireTransferSubmitParams params, RequestOptions requestOptions)
Simulates the submission of a #wire-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_creating.
-
-
-
-