Package com.increase.api.client.okhttp
Class IncreaseOkHttpClientAsync
-
- All Implemented Interfaces:
public final class IncreaseOkHttpClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIncreaseOkHttpClientAsync.BuilderA builder for IncreaseOkHttpClientAsync.
-
Method Summary
Modifier and Type Method Description final static IncreaseOkHttpClientAsync.Builderbuilder()Returns a mutable builder for constructing an instance of IncreaseOkHttpClientAsync. final static IncreaseClientAsyncfromEnv()-
-
Method Detail
-
builder
final static IncreaseOkHttpClientAsync.Builder builder()
Returns a mutable builder for constructing an instance of IncreaseOkHttpClientAsync.
-
fromEnv
final static IncreaseClientAsync fromEnv()
-
-
-
-