Class IncreaseOkHttpClientAsync.Builder
-
- All Implemented Interfaces:
public final class IncreaseOkHttpClientAsync.BuilderA builder for IncreaseOkHttpClientAsync.
-
-
Method Summary
-
-
Method Detail
-
proxy
final IncreaseOkHttpClientAsync.Builder proxy(Proxy proxy)
-
proxy
final IncreaseOkHttpClientAsync.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
sslSocketFactory
final IncreaseOkHttpClientAsync.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final IncreaseOkHttpClientAsync.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final IncreaseOkHttpClientAsync.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final IncreaseOkHttpClientAsync.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final IncreaseOkHttpClientAsync.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final IncreaseOkHttpClientAsync.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final IncreaseOkHttpClientAsync.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final IncreaseOkHttpClientAsync.Builder jsonMapper(JsonMapper jsonMapper)
-
streamHandlerExecutor
final IncreaseOkHttpClientAsync.Builder streamHandlerExecutor(Executor streamHandlerExecutor)
-
clock
final IncreaseOkHttpClientAsync.Builder clock(Clock clock)
-
baseUrl
final IncreaseOkHttpClientAsync.Builder baseUrl(String baseUrl)
-
baseUrl
final IncreaseOkHttpClientAsync.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
sandbox
final IncreaseOkHttpClientAsync.Builder sandbox()
-
responseValidation
final IncreaseOkHttpClientAsync.Builder responseValidation(Boolean responseValidation)
-
timeout
final IncreaseOkHttpClientAsync.Builder timeout(Timeout timeout)
-
timeout
final IncreaseOkHttpClientAsync.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final IncreaseOkHttpClientAsync.Builder maxRetries(Integer maxRetries)
-
apiKey
final IncreaseOkHttpClientAsync.Builder apiKey(String apiKey)
-
webhookSecret
final IncreaseOkHttpClientAsync.Builder webhookSecret(String webhookSecret)
-
webhookSecret
final IncreaseOkHttpClientAsync.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final IncreaseOkHttpClientAsync.Builder headers(Headers headers)
-
putHeader
final IncreaseOkHttpClientAsync.Builder putHeader(String name, String value)
-
putHeaders
final IncreaseOkHttpClientAsync.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final IncreaseOkHttpClientAsync.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final IncreaseOkHttpClientAsync.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final IncreaseOkHttpClientAsync.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final IncreaseOkHttpClientAsync.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final IncreaseOkHttpClientAsync.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final IncreaseOkHttpClientAsync.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final IncreaseOkHttpClientAsync.Builder removeHeaders(String name)
-
removeAllHeaders
final IncreaseOkHttpClientAsync.Builder removeAllHeaders(Set<String> names)
-
queryParams
final IncreaseOkHttpClientAsync.Builder queryParams(QueryParams queryParams)
-
queryParams
final IncreaseOkHttpClientAsync.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final IncreaseOkHttpClientAsync.Builder putQueryParam(String key, String value)
-
putQueryParams
final IncreaseOkHttpClientAsync.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final IncreaseOkHttpClientAsync.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final IncreaseOkHttpClientAsync.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final IncreaseOkHttpClientAsync.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final IncreaseOkHttpClientAsync.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final IncreaseOkHttpClientAsync.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final IncreaseOkHttpClientAsync.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final IncreaseOkHttpClientAsync.Builder removeQueryParams(String key)
-
removeAllQueryParams
final IncreaseOkHttpClientAsync.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final IncreaseOkHttpClientAsync.Builder fromEnv()
-
build
final IncreaseClientAsync build()
Returns an immutable instance of IncreaseClientAsync.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-