Enum CardDispute.Status.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum CardDispute.Status.Value extends Enum<CardDispute.Status.Value>
An enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<CardDispute.Status.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description PENDING_REVIEWINGThe Card Dispute is pending review.
PENDING_USER_INFORMATIONIncrease has requested more information related to the Card Dispute from you.
ACCEPTEDThe Card Dispute has been accepted and your funds have been returned. The card dispute will eventually transition into
wonorlostdepending on the outcome.REJECTEDThe Card Dispute has been rejected.
LOSTThe Card Dispute has been lost and funds previously credited from the acceptance have been debited.
WONThe Card Dispute has been won and no further action can be taken.
_UNKNOWNAn enum member indicating that Status was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final CardDispute.Status.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<CardDispute.Status.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<CardDispute.Status.Value>getEntries()An enum containing Status's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final CardDispute.Status.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<CardDispute.Status.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<CardDispute.Status.Value> getEntries()
An enum containing Status's known values, as well as an _UNKNOWN member.
An instance of Status can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-