Class IntrafiExclusion
-
- All Implemented Interfaces:
public final class IntrafiExclusionCertain institutions may be excluded per Entity when sweeping funds into the IntraFi network. This is useful when an Entity already has deposits at a particular bank, and does not want to sweep additional funds to it. It may take 5 business days for an exclusion to be processed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiExclusion.BuilderA builder for IntrafiExclusion.
public final classIntrafiExclusion.StatusThe status of the exclusion request.
public final classIntrafiExclusion.TypeA constant representing the object's type. For this resource it will always be
intrafi_exclusion.
-
Method Summary
Modifier and Type Method Description final Stringid()The identifier of this exclusion request. final StringbankName()The name of the excluded institution. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the exclusion was created. final StringentityId()The entity for which this institution is excluded. final Optional<OffsetDateTime>excludedAt()When this was exclusion was confirmed by IntraFi. final Optional<String>fdicCertificateNumber()The Federal Deposit Insurance Corporation's certificate number for the institution. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final IntrafiExclusion.Statusstatus()The status of the exclusion request. final Optional<OffsetDateTime>submittedAt()When this was exclusion was submitted to IntraFi by Increase. final IntrafiExclusion.Typetype()A constant representing the object's type. final JsonField<String>_id()The identifier of this exclusion request. final JsonField<String>_bankName()The name of the excluded institution. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the exclusion was created. final JsonField<String>_entityId()The entity for which this institution is excluded. final JsonField<OffsetDateTime>_excludedAt()When this was exclusion was confirmed by IntraFi. final JsonField<String>_fdicCertificateNumber()The Federal Deposit Insurance Corporation's certificate number for the institution. final JsonField<String>_idempotencyKey()The idempotency key you chose for this object. final JsonField<IntrafiExclusion.Status>_status()The status of the exclusion request. final JsonField<OffsetDateTime>_submittedAt()When this was exclusion was submitted to IntraFi by Increase. final JsonField<IntrafiExclusion.Type>_type()A constant representing the object's type. final Map<String, JsonValue>_additionalProperties()final IntrafiExclusionvalidate()final IntrafiExclusion.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiExclusion.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the exclusion was created.
-
excludedAt
final Optional<OffsetDateTime> excludedAt()
When this was exclusion was confirmed by IntraFi.
-
fdicCertificateNumber
final Optional<String> fdicCertificateNumber()
The Federal Deposit Insurance Corporation's certificate number for the institution.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final IntrafiExclusion.Status status()
The status of the exclusion request.
-
submittedAt
final Optional<OffsetDateTime> submittedAt()
When this was exclusion was submitted to IntraFi by Increase.
-
type
final IntrafiExclusion.Type type()
A constant representing the object's type. For this resource it will always be
intrafi_exclusion.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the exclusion was created.
-
_excludedAt
final JsonField<OffsetDateTime> _excludedAt()
When this was exclusion was confirmed by IntraFi.
-
_fdicCertificateNumber
final JsonField<String> _fdicCertificateNumber()
The Federal Deposit Insurance Corporation's certificate number for the institution.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
_status
final JsonField<IntrafiExclusion.Status> _status()
The status of the exclusion request.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
When this was exclusion was submitted to IntraFi by Increase.
-
_type
final JsonField<IntrafiExclusion.Type> _type()
A constant representing the object's type. For this resource it will always be
intrafi_exclusion.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final IntrafiExclusion validate()
-
toBuilder
final IntrafiExclusion.Builder toBuilder()
-
builder
final static IntrafiExclusion.Builder builder()
-
-
-
-