Package com.increase.api.models
Class SimulationAccountTransferCompleteParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationAccountTransferCompleteParams implements Params
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationAccountTransferCompleteParams.BuilderA builder for SimulationAccountTransferCompleteParams.
-
Method Summary
Modifier and Type Method Description final StringaccountTransferId()The identifier of the Account Transfer you wish to complete. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final Map<String, JsonValue>_additionalBodyProperties()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationAccountTransferCompleteParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationAccountTransferCompleteParams.Builderbuilder()-
-
Method Detail
-
accountTransferId
final String accountTransferId()
The identifier of the Account Transfer you wish to complete.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationAccountTransferCompleteParams.Builder toBuilder()
-
builder
final static SimulationAccountTransferCompleteParams.Builder builder()
-
-
-
-