Package com.increase.api.models
Class SimulationAchTransferAcknowledgeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationAchTransferAcknowledgeParams implements Params
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationAchTransferAcknowledgeParams.BuilderA builder for SimulationAchTransferAcknowledgeParams.
-
Method Summary
Modifier and Type Method Description final StringachTransferId()The identifier of the ACH Transfer you wish to become acknowledged. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final Map<String, JsonValue>_additionalBodyProperties()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationAchTransferAcknowledgeParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationAchTransferAcknowledgeParams.Builderbuilder()-
-
Method Detail
-
achTransferId
final String achTransferId()
The identifier of the ACH Transfer you wish to become acknowledged.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationAchTransferAcknowledgeParams.Builder toBuilder()
-
builder
final static SimulationAchTransferAcknowledgeParams.Builder builder()
-
-
-
-