Class SimulationAchTransferReturnParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationAchTransferReturnParams implements Params
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationAchTransferReturnParams.Bodypublic final classSimulationAchTransferReturnParams.BuilderA builder for SimulationAchTransferReturnParams.
public final classSimulationAchTransferReturnParams.ReasonThe reason why the Federal Reserve or destination bank returned this transfer. Defaults to
no_account.
-
Method Summary
Modifier and Type Method Description final StringachTransferId()The identifier of the ACH Transfer you wish to return. final Optional<SimulationAchTransferReturnParams.Reason>reason()The reason why the Federal Reserve or destination bank returned this transfer. final JsonField<SimulationAchTransferReturnParams.Reason>_reason()The reason why the Federal Reserve or destination bank returned this transfer. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationAchTransferReturnParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationAchTransferReturnParams.Builderbuilder()-
-
Method Detail
-
achTransferId
final String achTransferId()
The identifier of the ACH Transfer you wish to return.
-
reason
final Optional<SimulationAchTransferReturnParams.Reason> reason()
The reason why the Federal Reserve or destination bank returned this transfer. Defaults to
no_account.
-
_reason
final JsonField<SimulationAchTransferReturnParams.Reason> _reason()
The reason why the Federal Reserve or destination bank returned this transfer. Defaults to
no_account.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationAchTransferReturnParams.Builder toBuilder()
-
builder
final static SimulationAchTransferReturnParams.Builder builder()
-
-
-
-