Package com.increase.api.models
Class SimulationAchTransferSubmitParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationAchTransferSubmitParams implements Params
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationAchTransferSubmitParams.BuilderA builder for SimulationAchTransferSubmitParams.
-
Method Summary
Modifier and Type Method Description final StringachTransferId()The identifier of the ACH Transfer you wish to submit. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final Map<String, JsonValue>_additionalBodyProperties()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationAchTransferSubmitParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationAchTransferSubmitParams.Builderbuilder()-
-
Method Detail
-
achTransferId
final String achTransferId()
The identifier of the ACH Transfer you wish to submit.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationAchTransferSubmitParams.Builder toBuilder()
-
builder
final static SimulationAchTransferSubmitParams.Builder builder()
-
-
-
-