Class SimulationCardFuelConfirmationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationCardFuelConfirmationCreateParams implements Params
Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardFuelConfirmationCreateParams.Bodypublic final classSimulationCardFuelConfirmationCreateParams.BuilderA builder for SimulationCardFuelConfirmationCreateParams.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the fuel_confirmation in minor units in the card authorization's currency. final StringcardPaymentId()The identifier of the Card Payment to create a fuel_confirmation on. final JsonField<Long>_amount()The amount of the fuel_confirmation in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()The identifier of the Card Payment to create a fuel_confirmation on. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationCardFuelConfirmationCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardFuelConfirmationCreateParams.Builderbuilder()-
-
Method Detail
-
amount
final Long amount()
The amount of the fuel_confirmation in minor units in the card authorization's currency.
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a fuel_confirmation on.
-
_amount
final JsonField<Long> _amount()
The amount of the fuel_confirmation in minor units in the card authorization's currency.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The identifier of the Card Payment to create a fuel_confirmation on.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationCardFuelConfirmationCreateParams.Builder toBuilder()
-
builder
final static SimulationCardFuelConfirmationCreateParams.Builder builder()
-
-
-
-