Class SimulationCardReversalCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationCardReversalCreateParams implements Params
Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationCardReversalCreateParams.Bodypublic final classSimulationCardReversalCreateParams.BuilderA builder for SimulationCardReversalCreateParams.
-
Method Summary
Modifier and Type Method Description final StringcardPaymentId()The identifier of the Card Payment to create a reversal on. final Optional<Long>amount()The amount of the reversal in minor units in the card authorization's currency. final JsonField<String>_cardPaymentId()The identifier of the Card Payment to create a reversal on. final JsonField<Long>_amount()The amount of the reversal in minor units in the card authorization's currency. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationCardReversalCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationCardReversalCreateParams.Builderbuilder()-
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The identifier of the Card Payment to create a reversal on.
-
amount
final Optional<Long> amount()
The amount of the reversal in minor units in the card authorization's currency. This defaults to the authorization amount.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
The identifier of the Card Payment to create a reversal on.
-
_amount
final JsonField<Long> _amount()
The amount of the reversal in minor units in the card authorization's currency. This defaults to the authorization amount.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationCardReversalCreateParams.Builder toBuilder()
-
builder
final static SimulationCardReversalCreateParams.Builder builder()
-
-
-
-