Class SimulationInboundAchTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationInboundAchTransferCreateParams implements Params
Simulates an inbound ACH transfer to your account. This imitates initiating a transfer to an Increase account from a different financial institution. The transfer may be either a credit or a debit depending on if the
amountis positive or negative. The result of calling this API will contain the created transfer. You can pass aresolve_atparameter to allow for a window to action on the Inbound ACH Transfer. Alternatively, if you don't pass theresolve_atparameter the result will contain either a #transactions or a #declined-transactions depending on whether or not the transfer is allowed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationInboundAchTransferCreateParams.Bodypublic final classSimulationInboundAchTransferCreateParams.BuilderA builder for SimulationInboundAchTransferCreateParams.
public final classSimulationInboundAchTransferCreateParams.StandardEntryClassCodeThe standard entry class code for the transfer.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the inbound ACH Transfer is for. final Longamount()The transfer amount in cents. final Optional<String>companyDescriptiveDate()The description of the date of the transfer. final Optional<String>companyDiscretionaryData()Data associated with the transfer set by the sender. final Optional<String>companyEntryDescription()The description of the transfer set by the sender. final Optional<String>companyId()The sender's company ID. final Optional<String>companyName()The name of the sender. final Optional<String>receiverIdNumber()The ID of the receiver of the transfer. final Optional<String>receiverName()The name of the receiver of the transfer. final Optional<OffsetDateTime>resolveAt()The time at which the transfer should be resolved. final Optional<SimulationInboundAchTransferCreateParams.StandardEntryClassCode>standardEntryClassCode()The standard entry class code for the transfer. final JsonField<String>_accountNumberId()The identifier of the Account Number the inbound ACH Transfer is for. final JsonField<Long>_amount()The transfer amount in cents. final JsonField<String>_companyDescriptiveDate()The description of the date of the transfer. final JsonField<String>_companyDiscretionaryData()Data associated with the transfer set by the sender. final JsonField<String>_companyEntryDescription()The description of the transfer set by the sender. final JsonField<String>_companyId()The sender's company ID. final JsonField<String>_companyName()The name of the sender. final JsonField<String>_receiverIdNumber()The ID of the receiver of the transfer. final JsonField<String>_receiverName()The name of the receiver of the transfer. final JsonField<OffsetDateTime>_resolveAt()The time at which the transfer should be resolved. final JsonField<SimulationInboundAchTransferCreateParams.StandardEntryClassCode>_standardEntryClassCode()The standard entry class code for the transfer. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final SimulationInboundAchTransferCreateParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationInboundAchTransferCreateParams.Builderbuilder()-
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the inbound ACH Transfer is for.
-
amount
final Long amount()
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
Data associated with the transfer set by the sender.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
The description of the transfer set by the sender.
-
companyName
final Optional<String> companyName()
The name of the sender.
-
receiverIdNumber
final Optional<String> receiverIdNumber()
The ID of the receiver of the transfer.
-
receiverName
final Optional<String> receiverName()
The name of the receiver of the transfer.
-
resolveAt
final Optional<OffsetDateTime> resolveAt()
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
standardEntryClassCode
final Optional<SimulationInboundAchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode()
The standard entry class code for the transfer.
-
_accountNumberId
final JsonField<String> _accountNumberId()
The identifier of the Account Number the inbound ACH Transfer is for.
-
_amount
final JsonField<Long> _amount()
The transfer amount in cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
The description of the date of the transfer.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Data associated with the transfer set by the sender.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
The description of the transfer set by the sender.
-
_companyId
final JsonField<String> _companyId()
The sender's company ID.
-
_companyName
final JsonField<String> _companyName()
The name of the sender.
-
_receiverIdNumber
final JsonField<String> _receiverIdNumber()
The ID of the receiver of the transfer.
-
_receiverName
final JsonField<String> _receiverName()
The name of the receiver of the transfer.
-
_resolveAt
final JsonField<OffsetDateTime> _resolveAt()
The time at which the transfer should be resolved. If not provided will resolve immediately.
-
_standardEntryClassCode
final JsonField<SimulationInboundAchTransferCreateParams.StandardEntryClassCode> _standardEntryClassCode()
The standard entry class code for the transfer.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
toBuilder
final SimulationInboundAchTransferCreateParams.Builder toBuilder()
-
builder
final static SimulationInboundAchTransferCreateParams.Builder builder()
-
-
-
-