Package com.increase.api.models
Class SimulationRealTimePaymentsTransferCompleteParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationRealTimePaymentsTransferCompleteParams implements Params
Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. This transfer must first have a
statusofpending_submission.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationRealTimePaymentsTransferCompleteParams.Bodypublic final classSimulationRealTimePaymentsTransferCompleteParams.BuilderA builder for SimulationRealTimePaymentsTransferCompleteParams.
public final classSimulationRealTimePaymentsTransferCompleteParams.RejectionIf set, the simulation will reject the transfer.
-
Method Summary
Modifier and Type Method Description final StringrealTimePaymentsTransferId()The identifier of the Real-Time Payments Transfer you wish to complete. final Optional<SimulationRealTimePaymentsTransferCompleteParams.Rejection>rejection()If set, the simulation will reject the transfer. final JsonField<SimulationRealTimePaymentsTransferCompleteParams.Rejection>_rejection()If set, the simulation will reject the transfer. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationRealTimePaymentsTransferCompleteParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationRealTimePaymentsTransferCompleteParams.Builderbuilder()-
-
Method Detail
-
realTimePaymentsTransferId
final String realTimePaymentsTransferId()
The identifier of the Real-Time Payments Transfer you wish to complete.
-
rejection
final Optional<SimulationRealTimePaymentsTransferCompleteParams.Rejection> rejection()
If set, the simulation will reject the transfer.
-
_rejection
final JsonField<SimulationRealTimePaymentsTransferCompleteParams.Rejection> _rejection()
If set, the simulation will reject the transfer.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationRealTimePaymentsTransferCompleteParams.Builder toBuilder()
-
builder
final static SimulationRealTimePaymentsTransferCompleteParams.Builder builder()
-
-
-
-