Package com.increase.api.models
Class SimulationWireTransferReverseParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class SimulationWireTransferReverseParams implements Params
Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a
statusofcomplete.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSimulationWireTransferReverseParams.BuilderA builder for SimulationWireTransferReverseParams.
-
Method Summary
Modifier and Type Method Description final StringwireTransferId()The identifier of the Wire Transfer you wish to reverse. final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final Map<String, JsonValue>_additionalBodyProperties()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. final StringgetPathParam(Integer index)final SimulationWireTransferReverseParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SimulationWireTransferReverseParams.Builderbuilder()-
-
Method Detail
-
wireTransferId
final String wireTransferId()
The identifier of the Wire Transfer you wish to reverse.
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
getPathParam
final String getPathParam(Integer index)
-
toBuilder
final SimulationWireTransferReverseParams.Builder toBuilder()
-
builder
final static SimulationWireTransferReverseParams.Builder builder()
-
-
-
-