Class Transaction.Source
-
- All Implemented Interfaces:
public final class Transaction.SourceThis is an object giving more details on the network-level event that caused the Transaction. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.BuilderA builder for Source.
public final classTransaction.Source.AccountTransferIntentionAn Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.public final classTransaction.Source.AchTransferIntentionAn ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.public final classTransaction.Source.AchTransferRejectionAn ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.public final classTransaction.Source.AchTransferReturnAn ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.public final classTransaction.Source.CardDisputeAcceptanceA Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.public final classTransaction.Source.CardDisputeLossA Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.public final classTransaction.Source.CardRefundA Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.public final classTransaction.Source.CardRevenuePaymentA Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.public final classTransaction.Source.CardSettlementA Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.public final classTransaction.Source.CashbackPaymentA Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.public final classTransaction.Source.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classTransaction.Source.CheckDepositAcceptanceA Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.public final classTransaction.Source.CheckDepositReturnA Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.public final classTransaction.Source.CheckTransferDepositA Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.public final classTransaction.Source.FeePaymentA Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.public final classTransaction.Source.InboundAchTransferAn Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundAchTransferReturnIntentionAn Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.public final classTransaction.Source.InboundCheckAdjustmentAn Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.public final classTransaction.Source.InboundCheckDepositReturnIntentionAn Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.public final classTransaction.Source.InboundRealTimePaymentsTransferConfirmationAn Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundRealTimePaymentsTransferDeclineAn Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.public final classTransaction.Source.InboundWireReversalAn Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.public final classTransaction.Source.InboundWireTransferAn Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundWireTransferReversalAn Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.public final classTransaction.Source.InterestPaymentAn Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.public final classTransaction.Source.InternalSourceAn Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.public final classTransaction.Source.RealTimePaymentsTransferAcknowledgementA Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.public final classTransaction.Source.SampleFundsA Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.public final classTransaction.Source.WireTransferIntentionA Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
Method Summary
-
-
Method Detail
-
accountTransferIntention
final Optional<Transaction.Source.AccountTransferIntention> accountTransferIntention()
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
achTransferIntention
final Optional<Transaction.Source.AchTransferIntention> achTransferIntention()
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
achTransferRejection
final Optional<Transaction.Source.AchTransferRejection> achTransferRejection()
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
achTransferReturn
final Optional<Transaction.Source.AchTransferReturn> achTransferReturn()
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
cardDisputeAcceptance
final Optional<Transaction.Source.CardDisputeAcceptance> cardDisputeAcceptance()
A Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
cardDisputeLoss
final Optional<Transaction.Source.CardDisputeLoss> cardDisputeLoss()
A Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
cardRefund
final Optional<Transaction.Source.CardRefund> cardRefund()
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRevenuePayment
final Optional<Transaction.Source.CardRevenuePayment> cardRevenuePayment()
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
cardSettlement
final Optional<Transaction.Source.CardSettlement> cardSettlement()
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cashbackPayment
final Optional<Transaction.Source.CashbackPayment> cashbackPayment()
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
category
final Transaction.Source.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
checkDepositAcceptance
final Optional<Transaction.Source.CheckDepositAcceptance> checkDepositAcceptance()
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
checkDepositReturn
final Optional<Transaction.Source.CheckDepositReturn> checkDepositReturn()
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
checkTransferDeposit
final Optional<Transaction.Source.CheckTransferDeposit> checkTransferDeposit()
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
feePayment
final Optional<Transaction.Source.FeePayment> feePayment()
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
inboundAchTransfer
final Optional<Transaction.Source.InboundAchTransfer> inboundAchTransfer()
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
inboundAchTransferReturnIntention
final Optional<Transaction.Source.InboundAchTransferReturnIntention> inboundAchTransferReturnIntention()
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
inboundCheckAdjustment
final Optional<Transaction.Source.InboundCheckAdjustment> inboundCheckAdjustment()
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
inboundCheckDepositReturnIntention
final Optional<Transaction.Source.InboundCheckDepositReturnIntention> inboundCheckDepositReturnIntention()
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
inboundRealTimePaymentsTransferConfirmation
final Optional<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> inboundRealTimePaymentsTransferConfirmation()
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
inboundRealTimePaymentsTransferDecline
final Optional<Transaction.Source.InboundRealTimePaymentsTransferDecline> inboundRealTimePaymentsTransferDecline()
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
inboundWireReversal
final Optional<Transaction.Source.InboundWireReversal> inboundWireReversal()
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
inboundWireTransfer
final Optional<Transaction.Source.InboundWireTransfer> inboundWireTransfer()
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
inboundWireTransferReversal
final Optional<Transaction.Source.InboundWireTransferReversal> inboundWireTransferReversal()
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
interestPayment
final Optional<Transaction.Source.InterestPayment> interestPayment()
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
internalSource
final Optional<Transaction.Source.InternalSource> internalSource()
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
_other
final JsonValue _other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
realTimePaymentsTransferAcknowledgement
final Optional<Transaction.Source.RealTimePaymentsTransferAcknowledgement> realTimePaymentsTransferAcknowledgement()
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
sampleFunds
final Optional<Transaction.Source.SampleFunds> sampleFunds()
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
wireTransferIntention
final Optional<Transaction.Source.WireTransferIntention> wireTransferIntention()
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
_accountTransferIntention
final JsonField<Transaction.Source.AccountTransferIntention> _accountTransferIntention()
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
_achTransferIntention
final JsonField<Transaction.Source.AchTransferIntention> _achTransferIntention()
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
_achTransferRejection
final JsonField<Transaction.Source.AchTransferRejection> _achTransferRejection()
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
_achTransferReturn
final JsonField<Transaction.Source.AchTransferReturn> _achTransferReturn()
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
_cardDisputeAcceptance
final JsonField<Transaction.Source.CardDisputeAcceptance> _cardDisputeAcceptance()
A Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
_cardDisputeLoss
final JsonField<Transaction.Source.CardDisputeLoss> _cardDisputeLoss()
A Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
_cardRefund
final JsonField<Transaction.Source.CardRefund> _cardRefund()
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement an acquirer can also refund money directly to a card without relation to a transaction.
-
_cardRevenuePayment
final JsonField<Transaction.Source.CardRevenuePayment> _cardRevenuePayment()
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
_cardSettlement
final JsonField<Transaction.Source.CardSettlement> _cardSettlement()
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
_cashbackPayment
final JsonField<Transaction.Source.CashbackPayment> _cashbackPayment()
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
_category
final JsonField<Transaction.Source.Category> _category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
_checkDepositAcceptance
final JsonField<Transaction.Source.CheckDepositAcceptance> _checkDepositAcceptance()
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
_checkDepositReturn
final JsonField<Transaction.Source.CheckDepositReturn> _checkDepositReturn()
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
_checkTransferDeposit
final JsonField<Transaction.Source.CheckTransferDeposit> _checkTransferDeposit()
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
_feePayment
final JsonField<Transaction.Source.FeePayment> _feePayment()
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
_inboundAchTransfer
final JsonField<Transaction.Source.InboundAchTransfer> _inboundAchTransfer()
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
_inboundAchTransferReturnIntention
final JsonField<Transaction.Source.InboundAchTransferReturnIntention> _inboundAchTransferReturnIntention()
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
_inboundCheckAdjustment
final JsonField<Transaction.Source.InboundCheckAdjustment> _inboundCheckAdjustment()
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
_inboundCheckDepositReturnIntention
final JsonField<Transaction.Source.InboundCheckDepositReturnIntention> _inboundCheckDepositReturnIntention()
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
_inboundRealTimePaymentsTransferConfirmation
final JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> _inboundRealTimePaymentsTransferConfirmation()
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
_inboundRealTimePaymentsTransferDecline
final JsonField<Transaction.Source.InboundRealTimePaymentsTransferDecline> _inboundRealTimePaymentsTransferDecline()
An Inbound Real-Time Payments Transfer Decline object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_decline.
-
_inboundWireReversal
final JsonField<Transaction.Source.InboundWireReversal> _inboundWireReversal()
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
_inboundWireTransfer
final JsonField<Transaction.Source.InboundWireTransfer> _inboundWireTransfer()
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
_inboundWireTransferReversal
final JsonField<Transaction.Source.InboundWireTransferReversal> _inboundWireTransferReversal()
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
_interestPayment
final JsonField<Transaction.Source.InterestPayment> _interestPayment()
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
_internalSource
final JsonField<Transaction.Source.InternalSource> _internalSource()
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
_realTimePaymentsTransferAcknowledgement
final JsonField<Transaction.Source.RealTimePaymentsTransferAcknowledgement> _realTimePaymentsTransferAcknowledgement()
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
_sampleFunds
final JsonField<Transaction.Source.SampleFunds> _sampleFunds()
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
_wireTransferIntention
final JsonField<Transaction.Source.WireTransferIntention> _wireTransferIntention()
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source validate()
-
toBuilder
final Transaction.Source.Builder toBuilder()
-
builder
final static Transaction.Source.Builder builder()
-
-
-
-