Class Transaction.Source.AchTransferReturn
-
- All Implemented Interfaces:
public final class Transaction.Source.AchTransferReturnAn ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.AchTransferReturn.BuilderA builder for AchTransferReturn.
public final classTransaction.Source.AchTransferReturn.ReturnReasonCodeWhy the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final StringrawReturnReasonCode()The three character ACH return code, in the range R01 to R85. final Transaction.Source.AchTransferReturn.ReturnReasonCodereturnReasonCode()Why the ACH Transfer was returned. final StringtraceNumber()A 15 digit number that was generated by the bank that initiated the return. final StringtransactionId()The identifier of the Transaction associated with this return. final StringtransferId()The identifier of the ACH Transfer associated with this return. final JsonField<OffsetDateTime>_createdAt()The ISO 8601 date and time at which the transfer was created. final JsonField<String>_rawReturnReasonCode()The three character ACH return code, in the range R01 to R85. final JsonField<Transaction.Source.AchTransferReturn.ReturnReasonCode>_returnReasonCode()Why the ACH Transfer was returned. final JsonField<String>_traceNumber()A 15 digit number that was generated by the bank that initiated the return. final JsonField<String>_transactionId()The identifier of the Transaction associated with this return. final JsonField<String>_transferId()The identifier of the ACH Transfer associated with this return. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.AchTransferReturnvalidate()final Transaction.Source.AchTransferReturn.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.AchTransferReturn.Builderbuilder()-
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
rawReturnReasonCode
final String rawReturnReasonCode()
The three character ACH return code, in the range R01 to R85.
-
returnReasonCode
final Transaction.Source.AchTransferReturn.ReturnReasonCode returnReasonCode()
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
traceNumber
final String traceNumber()
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
transactionId
final String transactionId()
The identifier of the Transaction associated with this return.
-
transferId
final String transferId()
The identifier of the ACH Transfer associated with this return.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
The ISO 8601 date and time at which the transfer was created.
-
_rawReturnReasonCode
final JsonField<String> _rawReturnReasonCode()
The three character ACH return code, in the range R01 to R85.
-
_returnReasonCode
final JsonField<Transaction.Source.AchTransferReturn.ReturnReasonCode> _returnReasonCode()
Why the ACH Transfer was returned. This reason code is sent by the receiving bank back to Increase.
-
_traceNumber
final JsonField<String> _traceNumber()
A 15 digit number that was generated by the bank that initiated the return. The trace number of the return is different than that of the original transfer. ACH trace numbers are not unique, but along with the amount and date this number can be used to identify the ACH return at the bank that initiated it.
-
_transactionId
final JsonField<String> _transactionId()
The identifier of the Transaction associated with this return.
-
_transferId
final JsonField<String> _transferId()
The identifier of the ACH Transfer associated with this return.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.AchTransferReturn validate()
-
toBuilder
final Transaction.Source.AchTransferReturn.Builder toBuilder()
-
builder
final static Transaction.Source.AchTransferReturn.Builder builder()
-
-
-
-