Package com.increase.api.models
Class Transaction.Source.InboundCheckDepositReturnIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundCheckDepositReturnIntentionAn Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundCheckDepositReturnIntention.BuilderA builder for InboundCheckDepositReturnIntention.
-
Method Summary
Modifier and Type Method Description final StringinboundCheckDepositId()The ID of the Inbound Check Deposit that is being returned. final Optional<String>transferId()The identifier of the Check Transfer object that was deposited. final JsonField<String>_inboundCheckDepositId()The ID of the Inbound Check Deposit that is being returned. final JsonField<String>_transferId()The identifier of the Check Transfer object that was deposited. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundCheckDepositReturnIntentionvalidate()final Transaction.Source.InboundCheckDepositReturnIntention.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundCheckDepositReturnIntention.Builderbuilder()-
-
Method Detail
-
inboundCheckDepositId
final String inboundCheckDepositId()
The ID of the Inbound Check Deposit that is being returned.
-
transferId
final Optional<String> transferId()
The identifier of the Check Transfer object that was deposited.
-
_inboundCheckDepositId
final JsonField<String> _inboundCheckDepositId()
The ID of the Inbound Check Deposit that is being returned.
-
_transferId
final JsonField<String> _transferId()
The identifier of the Check Transfer object that was deposited.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.InboundCheckDepositReturnIntention validate()
-
toBuilder
final Transaction.Source.InboundCheckDepositReturnIntention.Builder toBuilder()
-
builder
final static Transaction.Source.InboundCheckDepositReturnIntention.Builder builder()
-
-
-
-