Class AccountNumberCreateParams.Body
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the Account Number should belong to. final Stringname()The name you choose for the Account Number. final Optional<AccountNumberCreateParams.InboundAch>inboundAch()Options related to how this Account Number should handle inbound ACH transfers. final Optional<AccountNumberCreateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AccountNumberCreateParams.InboundAch>_inboundAch()Returns the raw JSON value of inboundAch. final JsonField<AccountNumberCreateParams.InboundChecks>_inboundChecks()Returns the raw JSON value of inboundChecks. final Map<String, JsonValue>_additionalProperties()final AccountNumberCreateParams.Body.BuildertoBuilder()final AccountNumberCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
inboundAch
final Optional<AccountNumberCreateParams.InboundAch> inboundAch()
Options related to how this Account Number should handle inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberCreateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundAch
final JsonField<AccountNumberCreateParams.InboundAch> _inboundAch()
Returns the raw JSON value of inboundAch.
Unlike inboundAch, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundChecks
final JsonField<AccountNumberCreateParams.InboundChecks> _inboundChecks()
Returns the raw JSON value of inboundChecks.
Unlike inboundChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumberCreateParams.Body.Builder toBuilder()
-
validate
final AccountNumberCreateParams.Body validate()
-
builder
final static AccountNumberCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .name()
-
-
-
-