Class AccountNumberCreateParams.InboundChecks
-
- All Implemented Interfaces:
public final class AccountNumberCreateParams.InboundChecksOptions related to how this Account Number should handle inbound check withdrawals.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberCreateParams.InboundChecks.BuilderA builder for InboundChecks.
public final classAccountNumberCreateParams.InboundChecks.StatusHow Increase should process checks with this account number printed on them. If you do not specify this field, the default is
check_transfers_only.
-
Method Summary
Modifier and Type Method Description final AccountNumberCreateParams.InboundChecks.Statusstatus()How Increase should process checks with this account number printed on them. final JsonField<AccountNumberCreateParams.InboundChecks.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final AccountNumberCreateParams.InboundChecks.BuildertoBuilder()final AccountNumberCreateParams.InboundChecksvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberCreateParams.InboundChecks.Builderbuilder()Returns a mutable builder for constructing an instance of InboundChecks. -
-
Method Detail
-
status
final AccountNumberCreateParams.InboundChecks.Status status()
How Increase should process checks with this account number printed on them. If you do not specify this field, the default is
check_transfers_only.
-
_status
final JsonField<AccountNumberCreateParams.InboundChecks.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumberCreateParams.InboundChecks.Builder toBuilder()
-
validate
final AccountNumberCreateParams.InboundChecks validate()
-
builder
final static AccountNumberCreateParams.InboundChecks.Builder builder()
Returns a mutable builder for constructing an instance of InboundChecks.
The following fields are required:
.status()
-
-
-
-