Class AccountNumberListPageAsync
-
- All Implemented Interfaces:
public final class AccountNumberListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberListPageAsync.BuilderA builder for AccountNumberListPageAsync.
public final classAccountNumberListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AccountNumber>data()Delegates to AccountNumberListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AccountNumberListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AccountNumberListParams>getNextPageParams()final CompletableFuture<Optional<AccountNumberListPageAsync>>getNextPage()final AccountNumberListPageAsync.AutoPagerautoPager()final AccountNumberListParamsparams()The parameters that were used to request this page. final AccountNumberListPageResponseresponse()The response that this page was parsed from. final AccountNumberListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountNumberListPageAsync. -
-
Method Detail
-
data
final List<AccountNumber> data()
Delegates to AccountNumberListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AccountNumberListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AccountNumberListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<AccountNumberListPageAsync>> getNextPage()
-
autoPager
final AccountNumberListPageAsync.AutoPager autoPager()
-
params
final AccountNumberListParams params()
The parameters that were used to request this page.
-
response
final AccountNumberListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountNumberListPageAsync.Builder toBuilder()
-
builder
final static AccountNumberListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountNumberListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-