Class AccountNumberUpdateParams.Body
-
- All Implemented Interfaces:
public final class AccountNumberUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountNumberUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<AccountNumberUpdateParams.InboundAch>inboundAch()Options related to how this Account Number handles inbound ACH transfers. final Optional<AccountNumberUpdateParams.InboundChecks>inboundChecks()Options related to how this Account Number should handle inbound check withdrawals. final Optional<String>name()The name you choose for the Account Number. final Optional<AccountNumberUpdateParams.Status>status()This indicates if transfers can be made to the Account Number. final JsonField<AccountNumberUpdateParams.InboundAch>_inboundAch()Returns the raw JSON value of inboundAch. final JsonField<AccountNumberUpdateParams.InboundChecks>_inboundChecks()Returns the raw JSON value of inboundChecks. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<AccountNumberUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final AccountNumberUpdateParams.Body.BuildertoBuilder()final AccountNumberUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountNumberUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
inboundAch
final Optional<AccountNumberUpdateParams.InboundAch> inboundAch()
Options related to how this Account Number handles inbound ACH transfers.
-
inboundChecks
final Optional<AccountNumberUpdateParams.InboundChecks> inboundChecks()
Options related to how this Account Number should handle inbound check withdrawals.
-
status
final Optional<AccountNumberUpdateParams.Status> status()
This indicates if transfers can be made to the Account Number.
-
_inboundAch
final JsonField<AccountNumberUpdateParams.InboundAch> _inboundAch()
Returns the raw JSON value of inboundAch.
Unlike inboundAch, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundChecks
final JsonField<AccountNumberUpdateParams.InboundChecks> _inboundChecks()
Returns the raw JSON value of inboundChecks.
Unlike inboundChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<AccountNumberUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountNumberUpdateParams.Body.Builder toBuilder()
-
validate
final AccountNumberUpdateParams.Body validate()
-
builder
final static AccountNumberUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-