Class AccountCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountCreateParams implements Params
Create an Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountCreateParams.BuilderA builder for AccountCreateParams.
public final classAccountCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringname()The name you choose for the Account. final Optional<String>entityId()The identifier for the Entity that will own the Account. final Optional<String>informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final Optional<String>programId()The identifier for the Program that this Account falls under. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<String>_informationalEntityId()Returns the raw JSON value of informationalEntityId. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountCreateParams.BuildertoBuilder()final AccountCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountCreateParams. -
-
Method Detail
-
informationalEntityId
final Optional<String> informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity. Its relationship to your group must be
informational.
-
programId
final Optional<String> programId()
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_informationalEntityId
final JsonField<String> _informationalEntityId()
Returns the raw JSON value of informationalEntityId.
Unlike informationalEntityId, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountCreateParams.Builder toBuilder()
-
_body
final AccountCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AccountCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountCreateParams.
The following fields are required:
.name()
-
-
-
-