Class AccountCreateParams.Body
-
- All Implemented Interfaces:
public final class AccountCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringname()The name you choose for the Account. final Optional<String>entityId()The identifier for the Entity that will own the Account. final Optional<AccountCreateParams.Funding>funding()Whether the Account is funded by a loan or by deposits. final Optional<String>informationalEntityId()The identifier of an Entity that, while not owning the Account, is associated with its activity. final Optional<AccountCreateParams.Loan>loan()The loan details for the account. final Optional<String>programId()The identifier for the Program that this Account falls under. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<AccountCreateParams.Funding>_funding()Returns the raw JSON value of funding. final JsonField<String>_informationalEntityId()Returns the raw JSON value of informationalEntityId. final JsonField<AccountCreateParams.Loan>_loan()Returns the raw JSON value of loan. final JsonField<String>_programId()Returns the raw JSON value of programId. final Map<String, JsonValue>_additionalProperties()final AccountCreateParams.Body.BuildertoBuilder()final AccountCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
funding
final Optional<AccountCreateParams.Funding> funding()
Whether the Account is funded by a loan or by deposits.
-
informationalEntityId
final Optional<String> informationalEntityId()
The identifier of an Entity that, while not owning the Account, is associated with its activity. This is generally the beneficiary of the funds.
-
loan
final Optional<AccountCreateParams.Loan> loan()
The loan details for the account.
-
programId
final Optional<String> programId()
The identifier for the Program that this Account falls under. Required if you operate more than one Program.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<AccountCreateParams.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_informationalEntityId
final JsonField<String> _informationalEntityId()
Returns the raw JSON value of informationalEntityId.
Unlike informationalEntityId, this method doesn't throw if the JSON field has an unexpected type.
-
_loan
final JsonField<AccountCreateParams.Loan> _loan()
Returns the raw JSON value of loan.
Unlike loan, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountCreateParams.Body.Builder toBuilder()
-
validate
final AccountCreateParams.Body validate()
-
builder
final static AccountCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.name()
-
-
-
-