Package com.increase.api.models.accounts
Class AccountUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AccountUpdateParams implements Params
Update an Account
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateParams.BuilderA builder for AccountUpdateParams.
public final classAccountUpdateParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()The identifier of the Account to update. final Optional<Long>creditLimit()The new credit limit of the Account, if and only if the Account is a loan account. final Optional<String>name()The new name of the Account. final JsonField<Long>_creditLimit()Returns the raw JSON value of creditLimit. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AccountUpdateParams.BuildertoBuilder()final AccountUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateParamsnone()final static AccountUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AccountUpdateParams. -
-
Method Detail
-
creditLimit
final Optional<Long> creditLimit()
The new credit limit of the Account, if and only if the Account is a loan account.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AccountUpdateParams.Builder toBuilder()
-
_body
final AccountUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static AccountUpdateParams none()
-
builder
final static AccountUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of AccountUpdateParams.
-
-
-
-