Package com.increase.api.models.accounts
Class AccountUpdateParams.Body
-
- All Implemented Interfaces:
public final class AccountUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<AccountUpdateParams.Loan>loan()The loan details for the account. final Optional<String>name()The new name of the Account. final JsonField<AccountUpdateParams.Loan>_loan()Returns the raw JSON value of loan. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final AccountUpdateParams.Body.BuildertoBuilder()final AccountUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
loan
final Optional<AccountUpdateParams.Loan> loan()
The loan details for the account.
-
_loan
final JsonField<AccountUpdateParams.Loan> _loan()
Returns the raw JSON value of loan.
Unlike loan, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateParams.Body.Builder toBuilder()
-
validate
final AccountUpdateParams.Body validate()
-
builder
final static AccountUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-