Package com.increase.api.models.accounts
Class AccountUpdateParams.Body
-
- All Implemented Interfaces:
public final class AccountUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<Long>creditLimit()The new credit limit of the Account, if and only if the Account is a loan account. final Optional<String>name()The new name of the Account. final JsonField<Long>_creditLimit()Returns the raw JSON value of creditLimit. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final AccountUpdateParams.Body.BuildertoBuilder()final AccountUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
creditLimit
final Optional<Long> creditLimit()
The new credit limit of the Account, if and only if the Account is a loan account.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateParams.Body.Builder toBuilder()
-
validate
final AccountUpdateParams.Body validate()
-
builder
final static AccountUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-