Package com.increase.api.models.accounts
Class AccountUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AccountUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
creditLimit
final AccountUpdateParams.Body.Builder creditLimit(Long creditLimit)
The new credit limit of the Account, if and only if the Account is a loan account.
-
creditLimit
final AccountUpdateParams.Body.Builder creditLimit(JsonField<Long> creditLimit)
Sets Builder.creditLimit to an arbitrary JSON value.
You should usually call Builder.creditLimit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final AccountUpdateParams.Body.Builder name(String name)
The new name of the Account.
-
name
final AccountUpdateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-