Package com.increase.api.models.accounts
Class AccountUpdateParams.Loan
-
- All Implemented Interfaces:
public final class AccountUpdateParams.LoanThe loan details for the account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountUpdateParams.Loan.BuilderA builder for Loan.
-
Method Summary
Modifier and Type Method Description final LongcreditLimit()The maximum amount of money that can be drawn from the Account. final JsonField<Long>_creditLimit()Returns the raw JSON value of creditLimit. final Map<String, JsonValue>_additionalProperties()final AccountUpdateParams.Loan.BuildertoBuilder()final AccountUpdateParams.Loanvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountUpdateParams.Loan.Builderbuilder()Returns a mutable builder for constructing an instance of Loan. -
-
Method Detail
-
creditLimit
final Long creditLimit()
The maximum amount of money that can be drawn from the Account.
-
_creditLimit
final JsonField<Long> _creditLimit()
Returns the raw JSON value of creditLimit.
Unlike creditLimit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountUpdateParams.Loan.Builder toBuilder()
-
validate
final AccountUpdateParams.Loan validate()
-
builder
final static AccountUpdateParams.Loan.Builder builder()
Returns a mutable builder for constructing an instance of Loan.
The following fields are required:
.creditLimit()
-
-
-
-