Class AccountStatement.Builder
-
- All Implemented Interfaces:
public final class AccountStatement.BuilderA builder for AccountStatement.
-
-
Method Summary
Modifier and Type Method Description final AccountStatement.Builderid(String id)The Account Statement identifier. final AccountStatement.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final AccountStatement.BuilderaccountId(String accountId)The identifier for the Account this Account Statement belongs to. final AccountStatement.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final AccountStatement.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Account Statement was created. final AccountStatement.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final AccountStatement.BuilderendingBalance(Long endingBalance)The Account's balance at the start of its statement period. final AccountStatement.BuilderendingBalance(JsonField<Long> endingBalance)Sets Builder.endingBalance to an arbitrary JSON value. final AccountStatement.BuilderfileId(String fileId)The identifier of the File containing a PDF of the statement. final AccountStatement.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final AccountStatement.BuilderstartingBalance(Long startingBalance)The Account's balance at the start of its statement period. final AccountStatement.BuilderstartingBalance(JsonField<Long> startingBalance)Sets Builder.startingBalance to an arbitrary JSON value. final AccountStatement.BuilderstatementPeriodEnd(OffsetDateTime statementPeriodEnd)The ISO 8601 time representing the end of the period the Account Statement covers. final AccountStatement.BuilderstatementPeriodEnd(JsonField<OffsetDateTime> statementPeriodEnd)Sets Builder.statementPeriodEnd to an arbitrary JSON value. final AccountStatement.BuilderstatementPeriodStart(OffsetDateTime statementPeriodStart)The ISO 8601 time representing the start of the period the Account Statement covers. final AccountStatement.BuilderstatementPeriodStart(JsonField<OffsetDateTime> statementPeriodStart)Sets Builder.statementPeriodStart to an arbitrary JSON value. final AccountStatement.Buildertype(AccountStatement.Type type)A constant representing the object's type. final AccountStatement.Buildertype(JsonField<AccountStatement.Type> type)Sets Builder.type to an arbitrary JSON value. final AccountStatement.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final AccountStatement.BuilderputAdditionalProperty(String key, JsonValue value)final AccountStatement.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final AccountStatement.BuilderremoveAdditionalProperty(String key)final AccountStatement.BuilderremoveAllAdditionalProperties(Set<String> keys)final AccountStatementbuild()Returns an immutable instance of AccountStatement. -
-
Method Detail
-
id
final AccountStatement.Builder id(String id)
The Account Statement identifier.
-
id
final AccountStatement.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final AccountStatement.Builder accountId(String accountId)
The identifier for the Account this Account Statement belongs to.
-
accountId
final AccountStatement.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final AccountStatement.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Account Statement was created.
-
createdAt
final AccountStatement.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endingBalance
final AccountStatement.Builder endingBalance(Long endingBalance)
The Account's balance at the start of its statement period.
-
endingBalance
final AccountStatement.Builder endingBalance(JsonField<Long> endingBalance)
Sets Builder.endingBalance to an arbitrary JSON value.
You should usually call Builder.endingBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final AccountStatement.Builder fileId(String fileId)
The identifier of the File containing a PDF of the statement.
-
fileId
final AccountStatement.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startingBalance
final AccountStatement.Builder startingBalance(Long startingBalance)
The Account's balance at the start of its statement period.
-
startingBalance
final AccountStatement.Builder startingBalance(JsonField<Long> startingBalance)
Sets Builder.startingBalance to an arbitrary JSON value.
You should usually call Builder.startingBalance with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementPeriodEnd
final AccountStatement.Builder statementPeriodEnd(OffsetDateTime statementPeriodEnd)
The ISO 8601 time representing the end of the period the Account Statement covers.
-
statementPeriodEnd
final AccountStatement.Builder statementPeriodEnd(JsonField<OffsetDateTime> statementPeriodEnd)
Sets Builder.statementPeriodEnd to an arbitrary JSON value.
You should usually call Builder.statementPeriodEnd with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementPeriodStart
final AccountStatement.Builder statementPeriodStart(OffsetDateTime statementPeriodStart)
The ISO 8601 time representing the start of the period the Account Statement covers.
-
statementPeriodStart
final AccountStatement.Builder statementPeriodStart(JsonField<OffsetDateTime> statementPeriodStart)
Sets Builder.statementPeriodStart to an arbitrary JSON value.
You should usually call Builder.statementPeriodStart with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final AccountStatement.Builder type(AccountStatement.Type type)
A constant representing the object's type. For this resource it will always be
account_statement.
-
type
final AccountStatement.Builder type(JsonField<AccountStatement.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AccountStatement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AccountStatement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AccountStatement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AccountStatement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AccountStatement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AccountStatement build()
Returns an immutable instance of AccountStatement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .createdAt() .endingBalance() .fileId() .startingBalance() .statementPeriodEnd() .statementPeriodStart() .type()
-
-
-
-