Class AccountStatement.Loan
-
- All Implemented Interfaces:
public final class AccountStatement.LoanThe loan balances.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatement.Loan.BuilderA builder for Loan.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>dueAt()The ISO 8601 time at which the loan payment is due. final LongdueBalance()The total amount due on the loan. final LongpastDueBalance()The amount past due on the loan. final JsonField<OffsetDateTime>_dueAt()Returns the raw JSON value of dueAt. final JsonField<Long>_dueBalance()Returns the raw JSON value of dueBalance. final JsonField<Long>_pastDueBalance()Returns the raw JSON value of pastDueBalance. final Map<String, JsonValue>_additionalProperties()final AccountStatement.Loan.BuildertoBuilder()final AccountStatement.Loanvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatement.Loan.Builderbuilder()Returns a mutable builder for constructing an instance of Loan. -
-
Method Detail
-
dueAt
final Optional<OffsetDateTime> dueAt()
The ISO 8601 time at which the loan payment is due.
-
dueBalance
final Long dueBalance()
The total amount due on the loan.
-
pastDueBalance
final Long pastDueBalance()
The amount past due on the loan.
-
_dueAt
final JsonField<OffsetDateTime> _dueAt()
Returns the raw JSON value of dueAt.
Unlike dueAt, this method doesn't throw if the JSON field has an unexpected type.
-
_dueBalance
final JsonField<Long> _dueBalance()
Returns the raw JSON value of dueBalance.
Unlike dueBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_pastDueBalance
final JsonField<Long> _pastDueBalance()
Returns the raw JSON value of pastDueBalance.
Unlike pastDueBalance, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AccountStatement.Loan.Builder toBuilder()
-
validate
final AccountStatement.Loan validate()
-
builder
final static AccountStatement.Loan.Builder builder()
Returns a mutable builder for constructing an instance of Loan.
The following fields are required:
.dueAt() .dueBalance() .pastDueBalance()
-
-
-
-