Class AccountStatementListPageAsync
-
- All Implemented Interfaces:
public final class AccountStatementListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementListPageAsync.BuilderA builder for AccountStatementListPageAsync.
public final classAccountStatementListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<AccountStatement>data()Delegates to AccountStatementListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to AccountStatementListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<AccountStatementListParams>getNextPageParams()final CompletableFuture<Optional<AccountStatementListPageAsync>>getNextPage()final AccountStatementListPageAsync.AutoPagerautoPager()final AccountStatementListParamsparams()The parameters that were used to request this page. final AccountStatementListPageResponseresponse()The response that this page was parsed from. final AccountStatementListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AccountStatementListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementListPageAsync. -
-
Method Detail
-
data
final List<AccountStatement> data()
Delegates to AccountStatementListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to AccountStatementListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<AccountStatementListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<AccountStatementListPageAsync>> getNextPage()
-
autoPager
final AccountStatementListPageAsync.AutoPager autoPager()
-
params
final AccountStatementListParams params()
The parameters that were used to request this page.
-
response
final AccountStatementListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final AccountStatementListPageAsync.Builder toBuilder()
-
builder
final static AccountStatementListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-