Package com.increase.api.models.achprenotifications
See: Description
-
Class Summary Class Description Builder A builder for AchPrenotification. CreditDebitIndicator If the notification is for a future credit or debit. Builder A builder for NotificationsOfChange. ChangeCode The required type of change that is being signaled by the receiving financial institution. NotificationsOfChange Builder A builder for PrenotificationReturn. ReturnReasonCode Why the Prenotification was returned. PrenotificationReturn If your prenotification is returned, this will contain details of the return. StandardEntryClassCode The /documentation/ach-standard-entry-class-codes to use for the ACH Prenotification. Status The lifecycle status of the ACH Prenotification. Type A constant representing the object's type. AchPrenotification ACH Prenotifications are one way you can verify account and routing numbers by Automated Clearing House (ACH). Builder A builder for AchPrenotificationCreateParams. Builder A builder for Body. Body CreditDebitIndicator Whether the Prenotification is for a future debit or credit. StandardEntryClassCode The /documentation/ach-standard-entry-class-codes to use for the ACH Prenotification. AchPrenotificationCreateParams Create an ACH Prenotification Builder A builder for AchPrenotificationListPage. AchPrenotificationListPage Builder A builder for AchPrenotificationListPageAsync. AchPrenotificationListPageAsync Builder A builder for AchPrenotificationListPageResponse. AchPrenotificationListPageResponse A list of ACH Prenotification objects. Builder A builder for AchPrenotificationListParams. Builder A builder for CreatedAt. CreatedAt AchPrenotificationListParams List ACH Prenotifications Builder A builder for AchPrenotificationRetrieveParams. AchPrenotificationRetrieveParams Retrieve an ACH Prenotification -
Enum Summary Enum Description Known An enum containing CreditDebitIndicator's known values. Value An enum containing CreditDebitIndicator's known values, as well as an _UNKNOWN member. Known An enum containing ChangeCode's known values. Value An enum containing ChangeCode's known values, as well as an _UNKNOWN member. Known An enum containing ReturnReasonCode's known values. Value An enum containing ReturnReasonCode's known values, as well as an _UNKNOWN member. Known An enum containing StandardEntryClassCode's known values. Value An enum containing StandardEntryClassCode's known values, as well as an _UNKNOWN member. Known An enum containing Status's known values. Value An enum containing Status's known values, as well as an _UNKNOWN member. Known An enum containing Type's known values. Value An enum containing Type's known values, as well as an _UNKNOWN member. Known An enum containing CreditDebitIndicator's known values. Value An enum containing CreditDebitIndicator's known values, as well as an _UNKNOWN member. Known An enum containing StandardEntryClassCode's known values. Value An enum containing StandardEntryClassCode's known values, as well as an _UNKNOWN member.