Class AchTransfer.NotificationsOfChange
-
- All Implemented Interfaces:
public final class AchTransfer.NotificationsOfChange
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransfer.NotificationsOfChange.BuilderA builder for NotificationsOfChange.
public final classAchTransfer.NotificationsOfChange.ChangeCodeThe required type of change that is being signaled by the receiving financial institution.
-
Method Summary
Modifier and Type Method Description final AchTransfer.NotificationsOfChange.ChangeCodechangeCode()The required type of change that is being signaled by the receiving financial institution. final StringcorrectedData()The corrected data that should be used in future ACHs to this account. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the notification occurred. final JsonField<AchTransfer.NotificationsOfChange.ChangeCode>_changeCode()Returns the raw JSON value of changeCode. final JsonField<String>_correctedData()Returns the raw JSON value of correctedData. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final AchTransfer.NotificationsOfChange.BuildertoBuilder()final AchTransfer.NotificationsOfChangevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransfer.NotificationsOfChange.Builderbuilder()Returns a mutable builder for constructing an instance of NotificationsOfChange. -
-
Method Detail
-
changeCode
final AchTransfer.NotificationsOfChange.ChangeCode changeCode()
The required type of change that is being signaled by the receiving financial institution.
-
correctedData
final String correctedData()
The corrected data that should be used in future ACHs to this account. This may contain the suggested new account number or routing number. When the
change_codeisincorrect_transaction_code, this field contains an integer. Numbers starting with a 2 encourage changing thefundingparameter to checking; numbers starting with a 3 encourage changing to savings.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the notification occurred.
-
_changeCode
final JsonField<AchTransfer.NotificationsOfChange.ChangeCode> _changeCode()
Returns the raw JSON value of changeCode.
Unlike changeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_correctedData
final JsonField<String> _correctedData()
Returns the raw JSON value of correctedData.
Unlike correctedData, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransfer.NotificationsOfChange.Builder toBuilder()
-
validate
final AchTransfer.NotificationsOfChange validate()
-
builder
final static AchTransfer.NotificationsOfChange.Builder builder()
Returns a mutable builder for constructing an instance of NotificationsOfChange.
The following fields are required:
.changeCode() .correctedData() .createdAt()
-
-
-
-