Class AchTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class AchTransferCreateParams implements Params
Create an ACH Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateParams.BuilderA builder for AchTransferCreateParams.
public final classAchTransferCreateParams.Bodypublic final classAchTransferCreateParams.AddendaAdditional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
public final classAchTransferCreateParams.DestinationAccountHolderThe type of entity that owns the account to which the ACH Transfer is being sent.
public final classAchTransferCreateParams.FundingThe type of the account to which the transfer will be sent.
public final classAchTransferCreateParams.PreferredEffectiveDateConfiguration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.public final classAchTransferCreateParams.StandardEntryClassCodeThe /documentation/ach-standard-entry-class-codes to use for the transfer.
public final classAchTransferCreateParams.TransactionTimingThe timing of the transaction.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Increase identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final StringstatementDescriptor()A description you choose to give the transfer. final Optional<String>accountNumber()The account number for the destination account. final Optional<AchTransferCreateParams.Addenda>addenda()Additional information that will be sent to the recipient. final Optional<String>companyDescriptiveDate()The description of the date of the transfer, usually in the format YYMMDD.final Optional<String>companyDiscretionaryData()The data you choose to associate with the transfer. final Optional<String>companyEntryDescription()A description of the transfer, included in the transfer data sent to the receiving bank. final Optional<String>companyName()The name by which the recipient knows you. final Optional<AchTransferCreateParams.DestinationAccountHolder>destinationAccountHolder()The type of entity that owns the account to which the ACH Transfer is being sent. final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<AchTransferCreateParams.Funding>funding()The type of the account to which the transfer will be sent. final Optional<String>individualId()Your identifier for the transfer recipient. final Optional<String>individualName()The name of the transfer recipient. final Optional<AchTransferCreateParams.PreferredEffectiveDate>preferredEffectiveDate()Configuration for how the effective date of the transfer will be set. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<AchTransferCreateParams.StandardEntryClassCode>standardEntryClassCode()The /documentation/ach-standard-entry-class-codes to use for the transfer. final Optional<AchTransferCreateParams.TransactionTiming>transactionTiming()The timing of the transaction. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_statementDescriptor()Returns the raw JSON value of statementDescriptor. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<AchTransferCreateParams.Addenda>_addenda()Returns the raw JSON value of addenda. final JsonField<String>_companyDescriptiveDate()Returns the raw JSON value of companyDescriptiveDate. final JsonField<String>_companyDiscretionaryData()Returns the raw JSON value of companyDiscretionaryData. final JsonField<String>_companyEntryDescription()Returns the raw JSON value of companyEntryDescription. final JsonField<String>_companyName()Returns the raw JSON value of companyName. final JsonField<AchTransferCreateParams.DestinationAccountHolder>_destinationAccountHolder()Returns the raw JSON value of destinationAccountHolder. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<AchTransferCreateParams.Funding>_funding()Returns the raw JSON value of funding. final JsonField<String>_individualId()Returns the raw JSON value of individualId. final JsonField<String>_individualName()Returns the raw JSON value of individualName. final JsonField<AchTransferCreateParams.PreferredEffectiveDate>_preferredEffectiveDate()Returns the raw JSON value of preferredEffectiveDate. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<AchTransferCreateParams.StandardEntryClassCode>_standardEntryClassCode()Returns the raw JSON value of standardEntryClassCode. final JsonField<AchTransferCreateParams.TransactionTiming>_transactionTiming()Returns the raw JSON value of transactionTiming. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final AchTransferCreateParams.BuildertoBuilder()final AchTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static AchTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransferCreateParams. -
-
Method Detail
-
accountId
final String accountId()
The Increase identifier for the account that will send the transfer.
-
amount
final Long amount()
The transfer amount in USD cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
statementDescriptor
final String statementDescriptor()
A description you choose to give the transfer. This will be saved with the transfer details, displayed in the dashboard, and returned by the API. If
individual_nameandcompany_nameare not explicitly set by this API, thestatement_descriptorwill be sent in those fields to the receiving bank to help the customer recognize the transfer. You are highly encouraged to passindividual_nameandcompany_nameinstead of relying on this fallback.
-
accountNumber
final Optional<String> accountNumber()
The account number for the destination account.
-
addenda
final Optional<AchTransferCreateParams.Addenda> addenda()
Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
companyDescriptiveDate
final Optional<String> companyDescriptiveDate()
The description of the date of the transfer, usually in the format
YYMMDD. This is included in the transfer data sent to the receiving bank.
-
companyDiscretionaryData
final Optional<String> companyDiscretionaryData()
The data you choose to associate with the transfer. This is included in the transfer data sent to the receiving bank.
-
companyEntryDescription
final Optional<String> companyEntryDescription()
A description of the transfer, included in the transfer data sent to the receiving bank. Standardized formatting may be required, for example
PAYROLLfor payroll-related Prearranged Payments and Deposits (PPD) credit transfers.
-
companyName
final Optional<String> companyName()
The name by which the recipient knows you. This is included in the transfer data sent to the receiving bank.
-
destinationAccountHolder
final Optional<AchTransferCreateParams.DestinationAccountHolder> destinationAccountHolder()
The type of entity that owns the account to which the ACH Transfer is being sent.
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_number,routing_number, andfundingmust be absent.
-
funding
final Optional<AchTransferCreateParams.Funding> funding()
The type of the account to which the transfer will be sent.
-
individualId
final Optional<String> individualId()
Your identifier for the transfer recipient.
-
individualName
final Optional<String> individualName()
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
preferredEffectiveDate
final Optional<AchTransferCreateParams.PreferredEffectiveDate> preferredEffectiveDate()
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
standardEntryClassCode
final Optional<AchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode()
The /documentation/ach-standard-entry-class-codes to use for the transfer.
-
transactionTiming
final Optional<AchTransferCreateParams.TransactionTiming> transactionTiming()
The timing of the transaction.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_statementDescriptor
final JsonField<String> _statementDescriptor()
Returns the raw JSON value of statementDescriptor.
Unlike statementDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_addenda
final JsonField<AchTransferCreateParams.Addenda> _addenda()
Returns the raw JSON value of addenda.
Unlike addenda, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDescriptiveDate
final JsonField<String> _companyDescriptiveDate()
Returns the raw JSON value of companyDescriptiveDate.
Unlike companyDescriptiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_companyDiscretionaryData
final JsonField<String> _companyDiscretionaryData()
Returns the raw JSON value of companyDiscretionaryData.
Unlike companyDiscretionaryData, this method doesn't throw if the JSON field has an unexpected type.
-
_companyEntryDescription
final JsonField<String> _companyEntryDescription()
Returns the raw JSON value of companyEntryDescription.
Unlike companyEntryDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_companyName
final JsonField<String> _companyName()
Returns the raw JSON value of companyName.
Unlike companyName, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountHolder
final JsonField<AchTransferCreateParams.DestinationAccountHolder> _destinationAccountHolder()
Returns the raw JSON value of destinationAccountHolder.
Unlike destinationAccountHolder, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<AchTransferCreateParams.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_individualId
final JsonField<String> _individualId()
Returns the raw JSON value of individualId.
Unlike individualId, this method doesn't throw if the JSON field has an unexpected type.
-
_individualName
final JsonField<String> _individualName()
Returns the raw JSON value of individualName.
Unlike individualName, this method doesn't throw if the JSON field has an unexpected type.
-
_preferredEffectiveDate
final JsonField<AchTransferCreateParams.PreferredEffectiveDate> _preferredEffectiveDate()
Returns the raw JSON value of preferredEffectiveDate.
Unlike preferredEffectiveDate, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_standardEntryClassCode
final JsonField<AchTransferCreateParams.StandardEntryClassCode> _standardEntryClassCode()
Returns the raw JSON value of standardEntryClassCode.
Unlike standardEntryClassCode, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionTiming
final JsonField<AchTransferCreateParams.TransactionTiming> _transactionTiming()
Returns the raw JSON value of transactionTiming.
Unlike transactionTiming, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final AchTransferCreateParams.Builder toBuilder()
-
_body
final AchTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static AchTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of AchTransferCreateParams.
The following fields are required:
.accountId() .amount() .statementDescriptor()
-
-
-
-