Class AchTransferCreateParams.Addenda

  • All Implemented Interfaces:

    
    public final class AchTransferCreateParams.Addenda
    
                        

    Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.