Class AchTransferCreateParams.Addenda
-
- All Implemented Interfaces:
public final class AchTransferCreateParams.AddendaAdditional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferCreateParams.Addenda.BuilderA builder for Addenda.
public final classAchTransferCreateParams.Addenda.CategoryThe type of addenda to pass with the transfer.
public final classAchTransferCreateParams.Addenda.FreeformUnstructured
payment_related_informationpassed through with the transfer. Required if and only ifcategoryisfreeform.public final classAchTransferCreateParams.Addenda.PaymentOrderRemittanceAdviceStructured ASC X12 820 remittance advice records. Please reach out to [email protected] for more information. Required if and only if
categoryispayment_order_remittance_advice.
-
Method Summary
-
-
Method Detail
-
category
final AchTransferCreateParams.Addenda.Category category()
The type of addenda to pass with the transfer.
-
freeform
final Optional<AchTransferCreateParams.Addenda.Freeform> freeform()
Unstructured
payment_related_informationpassed through with the transfer. Required if and only ifcategoryisfreeform.
-
paymentOrderRemittanceAdvice
final Optional<AchTransferCreateParams.Addenda.PaymentOrderRemittanceAdvice> paymentOrderRemittanceAdvice()
Structured ASC X12 820 remittance advice records. Please reach out to [email protected] for more information. Required if and only if
categoryispayment_order_remittance_advice.
-
_category
final JsonField<AchTransferCreateParams.Addenda.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_freeform
final JsonField<AchTransferCreateParams.Addenda.Freeform> _freeform()
Returns the raw JSON value of freeform.
Unlike freeform, this method doesn't throw if the JSON field has an unexpected type.
-
_paymentOrderRemittanceAdvice
final JsonField<AchTransferCreateParams.Addenda.PaymentOrderRemittanceAdvice> _paymentOrderRemittanceAdvice()
Returns the raw JSON value of paymentOrderRemittanceAdvice.
Unlike paymentOrderRemittanceAdvice, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AchTransferCreateParams.Addenda.Builder toBuilder()
-
validate
final AchTransferCreateParams.Addenda validate()
-
builder
final static AchTransferCreateParams.Addenda.Builder builder()
Returns a mutable builder for constructing an instance of Addenda.
The following fields are required:
.category()
-
-
-
-