Class AchTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class AchTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final AchTransferCreateParams.Body.Builder accountId(String accountId)
The Increase identifier for the account that will send the transfer.
-
accountId
final AchTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final AchTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents. A positive amount originates a credit transfer pushing funds to the receiving account. A negative amount originates a debit transfer pulling funds from the receiving account.
-
amount
final AchTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statementDescriptor
final AchTransferCreateParams.Body.Builder statementDescriptor(String statementDescriptor)
A description you choose to give the transfer. This will be saved with the transfer details, displayed in the dashboard, and returned by the API. If
individual_nameandcompany_nameare not explicitly set by this API, thestatement_descriptorwill be sent in those fields to the receiving bank to help the customer recognize the transfer. You are highly encouraged to passindividual_nameandcompany_nameinstead of relying on this fallback.
-
statementDescriptor
final AchTransferCreateParams.Body.Builder statementDescriptor(JsonField<String> statementDescriptor)
Sets Builder.statementDescriptor to an arbitrary JSON value.
You should usually call Builder.statementDescriptor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final AchTransferCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final AchTransferCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addenda
final AchTransferCreateParams.Body.Builder addenda(AchTransferCreateParams.Addenda addenda)
Additional information that will be sent to the recipient. This is included in the transfer data sent to the receiving bank.
-
addenda
final AchTransferCreateParams.Body.Builder addenda(JsonField<AchTransferCreateParams.Addenda> addenda)
Sets Builder.addenda to an arbitrary JSON value.
You should usually call Builder.addenda with a well-typed Addenda value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyDescriptiveDate
final AchTransferCreateParams.Body.Builder companyDescriptiveDate(String companyDescriptiveDate)
The description of the date of the transfer, usually in the format
YYMMDD. This is included in the transfer data sent to the receiving bank.
-
companyDescriptiveDate
final AchTransferCreateParams.Body.Builder companyDescriptiveDate(JsonField<String> companyDescriptiveDate)
Sets Builder.companyDescriptiveDate to an arbitrary JSON value.
You should usually call Builder.companyDescriptiveDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyDiscretionaryData
final AchTransferCreateParams.Body.Builder companyDiscretionaryData(String companyDiscretionaryData)
The data you choose to associate with the transfer. This is included in the transfer data sent to the receiving bank.
-
companyDiscretionaryData
final AchTransferCreateParams.Body.Builder companyDiscretionaryData(JsonField<String> companyDiscretionaryData)
Sets Builder.companyDiscretionaryData to an arbitrary JSON value.
You should usually call Builder.companyDiscretionaryData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyEntryDescription
final AchTransferCreateParams.Body.Builder companyEntryDescription(String companyEntryDescription)
A description of the transfer. This is included in the transfer data sent to the receiving bank.
-
companyEntryDescription
final AchTransferCreateParams.Body.Builder companyEntryDescription(JsonField<String> companyEntryDescription)
Sets Builder.companyEntryDescription to an arbitrary JSON value.
You should usually call Builder.companyEntryDescription with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
companyName
final AchTransferCreateParams.Body.Builder companyName(String companyName)
The name by which the recipient knows you. This is included in the transfer data sent to the receiving bank.
-
companyName
final AchTransferCreateParams.Body.Builder companyName(JsonField<String> companyName)
Sets Builder.companyName to an arbitrary JSON value.
You should usually call Builder.companyName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationAccountHolder
final AchTransferCreateParams.Body.Builder destinationAccountHolder(AchTransferCreateParams.DestinationAccountHolder destinationAccountHolder)
The type of entity that owns the account to which the ACH Transfer is being sent.
-
destinationAccountHolder
final AchTransferCreateParams.Body.Builder destinationAccountHolder(JsonField<AchTransferCreateParams.DestinationAccountHolder> destinationAccountHolder)
Sets Builder.destinationAccountHolder to an arbitrary JSON value.
You should usually call Builder.destinationAccountHolder with a well-typed DestinationAccountHolder value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalAccountId
final AchTransferCreateParams.Body.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_number,routing_number, andfundingmust be absent.
-
externalAccountId
final AchTransferCreateParams.Body.Builder externalAccountId(JsonField<String> externalAccountId)
Sets Builder.externalAccountId to an arbitrary JSON value.
You should usually call Builder.externalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
funding
final AchTransferCreateParams.Body.Builder funding(AchTransferCreateParams.Funding funding)
The type of the account to which the transfer will be sent.
-
funding
final AchTransferCreateParams.Body.Builder funding(JsonField<AchTransferCreateParams.Funding> funding)
Sets Builder.funding to an arbitrary JSON value.
You should usually call Builder.funding with a well-typed Funding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualId
final AchTransferCreateParams.Body.Builder individualId(String individualId)
Your identifier for the transfer recipient.
-
individualId
final AchTransferCreateParams.Body.Builder individualId(JsonField<String> individualId)
Sets Builder.individualId to an arbitrary JSON value.
You should usually call Builder.individualId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
individualName
final AchTransferCreateParams.Body.Builder individualName(String individualName)
The name of the transfer recipient. This value is informational and not verified by the recipient's bank.
-
individualName
final AchTransferCreateParams.Body.Builder individualName(JsonField<String> individualName)
Sets Builder.individualName to an arbitrary JSON value.
You should usually call Builder.individualName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
preferredEffectiveDate
final AchTransferCreateParams.Body.Builder preferredEffectiveDate(AchTransferCreateParams.PreferredEffectiveDate preferredEffectiveDate)
Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a
settlement_scheduleofsame_day. If set, exactly one of the child attributes must be set.
-
preferredEffectiveDate
final AchTransferCreateParams.Body.Builder preferredEffectiveDate(JsonField<AchTransferCreateParams.PreferredEffectiveDate> preferredEffectiveDate)
Sets Builder.preferredEffectiveDate to an arbitrary JSON value.
You should usually call Builder.preferredEffectiveDate with a well-typed PreferredEffectiveDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final AchTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final AchTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final AchTransferCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final AchTransferCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
standardEntryClassCode
final AchTransferCreateParams.Body.Builder standardEntryClassCode(AchTransferCreateParams.StandardEntryClassCode standardEntryClassCode)
The Standard Entry Class (SEC) code to use for the transfer.
-
standardEntryClassCode
final AchTransferCreateParams.Body.Builder standardEntryClassCode(JsonField<AchTransferCreateParams.StandardEntryClassCode> standardEntryClassCode)
Sets Builder.standardEntryClassCode to an arbitrary JSON value.
You should usually call Builder.standardEntryClassCode with a well-typed StandardEntryClassCode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionTiming
final AchTransferCreateParams.Body.Builder transactionTiming(AchTransferCreateParams.TransactionTiming transactionTiming)
The timing of the transaction.
-
transactionTiming
final AchTransferCreateParams.Body.Builder transactionTiming(JsonField<AchTransferCreateParams.TransactionTiming> transactionTiming)
Sets Builder.transactionTiming to an arbitrary JSON value.
You should usually call Builder.transactionTiming with a well-typed TransactionTiming value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final AchTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final AchTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final AchTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final AchTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final AchTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final AchTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .statementDescriptor()
-
-
-
-