Class AchTransferCreateParams.PreferredEffectiveDate

  • All Implemented Interfaces:

    
    public final class AchTransferCreateParams.PreferredEffectiveDate
    
                        

    Configuration for how the effective date of the transfer will be set. This determines same-day vs future-dated settlement timing. If not set, defaults to a settlement_schedule of same_day. If set, exactly one of the child attributes must be set.