Class CardPayment.Element.CardAuthentication
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthenticationA Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.BuilderA builder for CardAuthentication.
public final classCardPayment.Element.CardAuthentication.ChallengeDetails about the challenge, if one was requested.
public final classCardPayment.Element.CardAuthentication.DenyReasonThe reason why this authentication attempt was denied, if it was.
public final classCardPayment.Element.CardAuthentication.DeviceChannelThe device channel of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.MessageCategoryThe message category of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.RequestorAuthenticationIndicatorThe 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.
public final classCardPayment.Element.CardAuthentication.RequestorChallengeIndicatorIndicates whether a challenge is requested for this transaction.
public final classCardPayment.Element.CardAuthentication.StatusThe status of the card authentication.
public final classCardPayment.Element.CardAuthentication.TypeA constant representing the object's type. For this resource it will always be
card_authentication.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Authentication identifier. final StringaccessControlServerTransactionIdentifier()A unique identifier assigned by the Access Control Server (us) for this transaction. final Optional<String>billingAddressCity()The city of the cardholder billing address associated with the card used for this purchase. final Optional<String>billingAddressCountry()The country of the cardholder billing address associated with the card used for this purchase. final Optional<String>billingAddressLine1()The first line of the cardholder billing address associated with the card used for this purchase. final Optional<String>billingAddressLine2()The second line of the cardholder billing address associated with the card used for this purchase. final Optional<String>billingAddressLine3()The third line of the cardholder billing address associated with the card used for this purchase. final Optional<String>billingAddressPostalCode()The postal code of the cardholder billing address associated with the card used for this purchase. final Optional<String>billingAddressState()The US state of the cardholder billing address associated with the card used for this purchase. final StringcardId()The identifier of the Card. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final Optional<String>cardholderEmail()The email address of the cardholder. final Optional<String>cardholderName()The name of the cardholder. final Optional<CardPayment.Element.CardAuthentication.Challenge>challenge()Details about the challenge, if one was requested. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Card Authentication was attempted. final Optional<CardPayment.Element.CardAuthentication.DenyReason>denyReason()The reason why this authentication attempt was denied, if it was. final CardPayment.Element.CardAuthentication.DeviceChanneldeviceChannel()The device channel of the card authentication attempt. final StringdirectoryServerTransactionIdentifier()A unique identifier assigned by the Directory Server (the card network) for this transaction. final Optional<String>merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final Optional<String>merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCountry()The country the merchant resides in. final Optional<String>merchantName()The name of the merchant. final CardPayment.Element.CardAuthentication.MessageCategorymessageCategory()The message category of the card authentication attempt. final Optional<String>priorAuthenticatedCardPaymentId()The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this authentication attempt. final Optional<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator>requestorAuthenticationIndicator()The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction. final Optional<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator>requestorChallengeIndicator()Indicates whether a challenge is requested for this transaction. final StringrequestorName()The name of the 3DS requestor. final StringrequestorUrl()The URL of the 3DS requestor. final Optional<String>shippingAddressCity()The city of the shipping address associated with this purchase. final Optional<String>shippingAddressCountry()The country of the shipping address associated with this purchase. final Optional<String>shippingAddressLine1()The first line of the shipping address associated with this purchase. final Optional<String>shippingAddressLine2()The second line of the shipping address associated with this purchase. final Optional<String>shippingAddressLine3()The third line of the shipping address associated with this purchase. final Optional<String>shippingAddressPostalCode()The postal code of the shipping address associated with this purchase. final Optional<String>shippingAddressState()The US state of the shipping address associated with this purchase. final CardPayment.Element.CardAuthentication.Statusstatus()The status of the card authentication. final StringthreeDSecureServerTransactionIdentifier()A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction. final CardPayment.Element.CardAuthentication.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accessControlServerTransactionIdentifier()Returns the raw JSON value of accessControlServerTransactionIdentifier. final JsonField<String>_billingAddressCity()Returns the raw JSON value of billingAddressCity. final JsonField<String>_billingAddressCountry()Returns the raw JSON value of billingAddressCountry. final JsonField<String>_billingAddressLine1()Returns the raw JSON value of billingAddressLine1. final JsonField<String>_billingAddressLine2()Returns the raw JSON value of billingAddressLine2. final JsonField<String>_billingAddressLine3()Returns the raw JSON value of billingAddressLine3. final JsonField<String>_billingAddressPostalCode()Returns the raw JSON value of billingAddressPostalCode. final JsonField<String>_billingAddressState()Returns the raw JSON value of billingAddressState. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<String>_cardholderEmail()Returns the raw JSON value of cardholderEmail. final JsonField<String>_cardholderName()Returns the raw JSON value of cardholderName. final JsonField<CardPayment.Element.CardAuthentication.Challenge>_challenge()Returns the raw JSON value of challenge. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CardPayment.Element.CardAuthentication.DenyReason>_denyReason()Returns the raw JSON value of denyReason. final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel>_deviceChannel()Returns the raw JSON value of deviceChannel. final JsonField<String>_directoryServerTransactionIdentifier()Returns the raw JSON value of directoryServerTransactionIdentifier. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<CardPayment.Element.CardAuthentication.MessageCategory>_messageCategory()Returns the raw JSON value of messageCategory. final JsonField<String>_priorAuthenticatedCardPaymentId()Returns the raw JSON value of priorAuthenticatedCardPaymentId. final JsonField<String>_realTimeDecisionId()Returns the raw JSON value of realTimeDecisionId. final JsonField<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator>_requestorAuthenticationIndicator()Returns the raw JSON value of requestorAuthenticationIndicator. final JsonField<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator>_requestorChallengeIndicator()Returns the raw JSON value of requestorChallengeIndicator. final JsonField<String>_requestorName()Returns the raw JSON value of requestorName. final JsonField<String>_requestorUrl()Returns the raw JSON value of requestorUrl. final JsonField<String>_shippingAddressCity()Returns the raw JSON value of shippingAddressCity. final JsonField<String>_shippingAddressCountry()Returns the raw JSON value of shippingAddressCountry. final JsonField<String>_shippingAddressLine1()Returns the raw JSON value of shippingAddressLine1. final JsonField<String>_shippingAddressLine2()Returns the raw JSON value of shippingAddressLine2. final JsonField<String>_shippingAddressLine3()Returns the raw JSON value of shippingAddressLine3. final JsonField<String>_shippingAddressPostalCode()Returns the raw JSON value of shippingAddressPostalCode. final JsonField<String>_shippingAddressState()Returns the raw JSON value of shippingAddressState. final JsonField<CardPayment.Element.CardAuthentication.Status>_status()Returns the raw JSON value of status. final JsonField<String>_threeDSecureServerTransactionIdentifier()Returns the raw JSON value of threeDSecureServerTransactionIdentifier. final JsonField<CardPayment.Element.CardAuthentication.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthentication.BuildertoBuilder()final CardPayment.Element.CardAuthenticationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthentication. -
-
Method Detail
-
accessControlServerTransactionIdentifier
final String accessControlServerTransactionIdentifier()
A unique identifier assigned by the Access Control Server (us) for this transaction.
-
billingAddressCity
final Optional<String> billingAddressCity()
The city of the cardholder billing address associated with the card used for this purchase.
-
billingAddressCountry
final Optional<String> billingAddressCountry()
The country of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine1
final Optional<String> billingAddressLine1()
The first line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine2
final Optional<String> billingAddressLine2()
The second line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine3
final Optional<String> billingAddressLine3()
The third line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressPostalCode
final Optional<String> billingAddressPostalCode()
The postal code of the cardholder billing address associated with the card used for this purchase.
-
billingAddressState
final Optional<String> billingAddressState()
The US state of the cardholder billing address associated with the card used for this purchase.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
cardholderEmail
final Optional<String> cardholderEmail()
The email address of the cardholder.
-
cardholderName
final Optional<String> cardholderName()
The name of the cardholder.
-
challenge
final Optional<CardPayment.Element.CardAuthentication.Challenge> challenge()
Details about the challenge, if one was requested.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Authentication was attempted.
-
denyReason
final Optional<CardPayment.Element.CardAuthentication.DenyReason> denyReason()
The reason why this authentication attempt was denied, if it was.
-
deviceChannel
final CardPayment.Element.CardAuthentication.DeviceChannel deviceChannel()
The device channel of the card authentication attempt.
-
directoryServerTransactionIdentifier
final String directoryServerTransactionIdentifier()
A unique identifier assigned by the Directory Server (the card network) for this transaction.
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Optional<String> merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantName
final Optional<String> merchantName()
The name of the merchant.
-
messageCategory
final CardPayment.Element.CardAuthentication.MessageCategory messageCategory()
The message category of the card authentication attempt.
-
priorAuthenticatedCardPaymentId
final Optional<String> priorAuthenticatedCardPaymentId()
The ID of a prior Card Authentication that the requestor used to authenticate this cardholder for a previous transaction.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
requestorAuthenticationIndicator
final Optional<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator> requestorAuthenticationIndicator()
The 3DS requestor authentication indicator describes why the authentication attempt is performed, such as for a recurring transaction.
-
requestorChallengeIndicator
final Optional<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator> requestorChallengeIndicator()
Indicates whether a challenge is requested for this transaction.
-
requestorName
final String requestorName()
The name of the 3DS requestor.
-
requestorUrl
final String requestorUrl()
The URL of the 3DS requestor.
-
shippingAddressCity
final Optional<String> shippingAddressCity()
The city of the shipping address associated with this purchase.
-
shippingAddressCountry
final Optional<String> shippingAddressCountry()
The country of the shipping address associated with this purchase.
-
shippingAddressLine1
final Optional<String> shippingAddressLine1()
The first line of the shipping address associated with this purchase.
-
shippingAddressLine2
final Optional<String> shippingAddressLine2()
The second line of the shipping address associated with this purchase.
-
shippingAddressLine3
final Optional<String> shippingAddressLine3()
The third line of the shipping address associated with this purchase.
-
shippingAddressPostalCode
final Optional<String> shippingAddressPostalCode()
The postal code of the shipping address associated with this purchase.
-
shippingAddressState
final Optional<String> shippingAddressState()
The US state of the shipping address associated with this purchase.
-
status
final CardPayment.Element.CardAuthentication.Status status()
The status of the card authentication.
-
threeDSecureServerTransactionIdentifier
final String threeDSecureServerTransactionIdentifier()
A unique identifier assigned by the 3DS Server initiating the authentication attempt for this transaction.
-
type
final CardPayment.Element.CardAuthentication.Type type()
A constant representing the object's type. For this resource it will always be
card_authentication.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accessControlServerTransactionIdentifier
final JsonField<String> _accessControlServerTransactionIdentifier()
Returns the raw JSON value of accessControlServerTransactionIdentifier.
Unlike accessControlServerTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressCity
final JsonField<String> _billingAddressCity()
Returns the raw JSON value of billingAddressCity.
Unlike billingAddressCity, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressCountry
final JsonField<String> _billingAddressCountry()
Returns the raw JSON value of billingAddressCountry.
Unlike billingAddressCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressLine1
final JsonField<String> _billingAddressLine1()
Returns the raw JSON value of billingAddressLine1.
Unlike billingAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressLine2
final JsonField<String> _billingAddressLine2()
Returns the raw JSON value of billingAddressLine2.
Unlike billingAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressLine3
final JsonField<String> _billingAddressLine3()
Returns the raw JSON value of billingAddressLine3.
Unlike billingAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressPostalCode
final JsonField<String> _billingAddressPostalCode()
Returns the raw JSON value of billingAddressPostalCode.
Unlike billingAddressPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddressState
final JsonField<String> _billingAddressState()
Returns the raw JSON value of billingAddressState.
Unlike billingAddressState, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderEmail
final JsonField<String> _cardholderEmail()
Returns the raw JSON value of cardholderEmail.
Unlike cardholderEmail, this method doesn't throw if the JSON field has an unexpected type.
-
_cardholderName
final JsonField<String> _cardholderName()
Returns the raw JSON value of cardholderName.
Unlike cardholderName, this method doesn't throw if the JSON field has an unexpected type.
-
_challenge
final JsonField<CardPayment.Element.CardAuthentication.Challenge> _challenge()
Returns the raw JSON value of challenge.
Unlike challenge, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_denyReason
final JsonField<CardPayment.Element.CardAuthentication.DenyReason> _denyReason()
Returns the raw JSON value of denyReason.
Unlike denyReason, this method doesn't throw if the JSON field has an unexpected type.
-
_deviceChannel
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel> _deviceChannel()
Returns the raw JSON value of deviceChannel.
Unlike deviceChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_directoryServerTransactionIdentifier
final JsonField<String> _directoryServerTransactionIdentifier()
Returns the raw JSON value of directoryServerTransactionIdentifier.
Unlike directoryServerTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_messageCategory
final JsonField<CardPayment.Element.CardAuthentication.MessageCategory> _messageCategory()
Returns the raw JSON value of messageCategory.
Unlike messageCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_priorAuthenticatedCardPaymentId
final JsonField<String> _priorAuthenticatedCardPaymentId()
Returns the raw JSON value of priorAuthenticatedCardPaymentId.
Unlike priorAuthenticatedCardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_requestorAuthenticationIndicator
final JsonField<CardPayment.Element.CardAuthentication.RequestorAuthenticationIndicator> _requestorAuthenticationIndicator()
Returns the raw JSON value of requestorAuthenticationIndicator.
Unlike requestorAuthenticationIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_requestorChallengeIndicator
final JsonField<CardPayment.Element.CardAuthentication.RequestorChallengeIndicator> _requestorChallengeIndicator()
Returns the raw JSON value of requestorChallengeIndicator.
Unlike requestorChallengeIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_requestorName
final JsonField<String> _requestorName()
Returns the raw JSON value of requestorName.
Unlike requestorName, this method doesn't throw if the JSON field has an unexpected type.
-
_requestorUrl
final JsonField<String> _requestorUrl()
Returns the raw JSON value of requestorUrl.
Unlike requestorUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressCity
final JsonField<String> _shippingAddressCity()
Returns the raw JSON value of shippingAddressCity.
Unlike shippingAddressCity, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressCountry
final JsonField<String> _shippingAddressCountry()
Returns the raw JSON value of shippingAddressCountry.
Unlike shippingAddressCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressLine1
final JsonField<String> _shippingAddressLine1()
Returns the raw JSON value of shippingAddressLine1.
Unlike shippingAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressLine2
final JsonField<String> _shippingAddressLine2()
Returns the raw JSON value of shippingAddressLine2.
Unlike shippingAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressLine3
final JsonField<String> _shippingAddressLine3()
Returns the raw JSON value of shippingAddressLine3.
Unlike shippingAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressPostalCode
final JsonField<String> _shippingAddressPostalCode()
Returns the raw JSON value of shippingAddressPostalCode.
Unlike shippingAddressPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingAddressState
final JsonField<String> _shippingAddressState()
Returns the raw JSON value of shippingAddressState.
Unlike shippingAddressState, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardPayment.Element.CardAuthentication.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_threeDSecureServerTransactionIdentifier
final JsonField<String> _threeDSecureServerTransactionIdentifier()
Returns the raw JSON value of threeDSecureServerTransactionIdentifier.
Unlike threeDSecureServerTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardAuthentication.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthentication.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthentication validate()
-
builder
final static CardPayment.Element.CardAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthentication.
The following fields are required:
.id() .accessControlServerTransactionIdentifier() .billingAddressCity() .billingAddressCountry() .billingAddressLine1() .billingAddressLine2() .billingAddressLine3() .billingAddressPostalCode() .billingAddressState() .cardId() .cardPaymentId() .cardholderEmail() .cardholderName() .challenge() .createdAt() .denyReason() .deviceChannel() .directoryServerTransactionIdentifier() .merchantAcceptorId() .merchantCategoryCode() .merchantCountry() .merchantName() .messageCategory() .priorAuthenticatedCardPaymentId() .realTimeDecisionId() .requestorAuthenticationIndicator() .requestorChallengeIndicator() .requestorName() .requestorUrl() .shippingAddressCity() .shippingAddressCountry() .shippingAddressLine1() .shippingAddressLine2() .shippingAddressLine3() .shippingAddressPostalCode() .shippingAddressState() .status() .threeDSecureServerTransactionIdentifier() .type()
-
-
-
-