Class CardPayment.Element.CardAuthentication
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthenticationA Card Authentication object. This field will be present in the JSON response if and only if
categoryis equal tocard_authentication. Card Authentications are attempts to authenticate a transaction or a card with 3DS.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.BuilderA builder for CardAuthentication.
public final classCardPayment.Element.CardAuthentication.CategoryThe category of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.ChallengeDetails about the challenge, if one was requested.
public final classCardPayment.Element.CardAuthentication.DenyReasonThe reason why this authentication attempt was denied, if it was.
public final classCardPayment.Element.CardAuthentication.DeviceChannelThe device channel of the card authentication attempt.
public final classCardPayment.Element.CardAuthentication.StatusThe status of the card authentication.
public final classCardPayment.Element.CardAuthentication.TypeA constant representing the object's type. For this resource it will always be
card_authentication.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Authentication identifier. final StringcardId()The identifier of the Card. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final Optional<CardPayment.Element.CardAuthentication.Category>category()The category of the card authentication attempt. final Optional<CardPayment.Element.CardAuthentication.Challenge>challenge()Details about the challenge, if one was requested. final OffsetDateTimecreatedAt()The ISO 8601 time at which the Card Authentication was attempted. final Optional<CardPayment.Element.CardAuthentication.DenyReason>denyReason()The reason why this authentication attempt was denied, if it was. final Optional<CardPayment.Element.CardAuthentication.DeviceChannel>deviceChannel()The device channel of the card authentication attempt. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final StringmerchantCountry()The country the merchant resides in. final StringmerchantName()The name of the merchant. final Optional<Long>purchaseAmount()The purchase amount in minor units. final Optional<String>purchaseCurrency()The ISO 4217 code for the authentication attempt's purchase currency. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this authentication attempt. final CardPayment.Element.CardAuthentication.Statusstatus()The status of the card authentication. final CardPayment.Element.CardAuthentication.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<CardPayment.Element.CardAuthentication.Category>_category()Returns the raw JSON value of category. final JsonField<CardPayment.Element.CardAuthentication.Challenge>_challenge()Returns the raw JSON value of challenge. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CardPayment.Element.CardAuthentication.DenyReason>_denyReason()Returns the raw JSON value of denyReason. final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel>_deviceChannel()Returns the raw JSON value of deviceChannel. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<Long>_purchaseAmount()Returns the raw JSON value of purchaseAmount. final JsonField<String>_purchaseCurrency()Returns the raw JSON value of purchaseCurrency. final JsonField<String>_realTimeDecisionId()Returns the raw JSON value of realTimeDecisionId. final JsonField<CardPayment.Element.CardAuthentication.Status>_status()Returns the raw JSON value of status. final JsonField<CardPayment.Element.CardAuthentication.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthentication.BuildertoBuilder()final CardPayment.Element.CardAuthenticationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthentication. -
-
Method Detail
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
category
final Optional<CardPayment.Element.CardAuthentication.Category> category()
The category of the card authentication attempt.
-
challenge
final Optional<CardPayment.Element.CardAuthentication.Challenge> challenge()
Details about the challenge, if one was requested.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Authentication was attempted.
-
denyReason
final Optional<CardPayment.Element.CardAuthentication.DenyReason> denyReason()
The reason why this authentication attempt was denied, if it was.
-
deviceChannel
final Optional<CardPayment.Element.CardAuthentication.DeviceChannel> deviceChannel()
The device channel of the card authentication attempt.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantName
final String merchantName()
The name of the merchant.
-
purchaseAmount
final Optional<Long> purchaseAmount()
The purchase amount in minor units.
-
purchaseCurrency
final Optional<String> purchaseCurrency()
The ISO 4217 code for the authentication attempt's purchase currency.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
status
final CardPayment.Element.CardAuthentication.Status status()
The status of the card authentication.
-
type
final CardPayment.Element.CardAuthentication.Type type()
A constant representing the object's type. For this resource it will always be
card_authentication.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<CardPayment.Element.CardAuthentication.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_challenge
final JsonField<CardPayment.Element.CardAuthentication.Challenge> _challenge()
Returns the raw JSON value of challenge.
Unlike challenge, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_denyReason
final JsonField<CardPayment.Element.CardAuthentication.DenyReason> _denyReason()
Returns the raw JSON value of denyReason.
Unlike denyReason, this method doesn't throw if the JSON field has an unexpected type.
-
_deviceChannel
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel> _deviceChannel()
Returns the raw JSON value of deviceChannel.
Unlike deviceChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseAmount
final JsonField<Long> _purchaseAmount()
Returns the raw JSON value of purchaseAmount.
Unlike purchaseAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseCurrency
final JsonField<String> _purchaseCurrency()
Returns the raw JSON value of purchaseCurrency.
Unlike purchaseCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardPayment.Element.CardAuthentication.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardAuthentication.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthentication.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthentication validate()
-
builder
final static CardPayment.Element.CardAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthentication.
The following fields are required:
.id() .cardId() .cardPaymentId() .category() .challenge() .createdAt() .denyReason() .deviceChannel() .merchantAcceptorId() .merchantCategoryCode() .merchantCountry() .merchantName() .purchaseAmount() .purchaseCurrency() .realTimeDecisionId() .status() .type()
-
-
-
-