Class CardPayment.Element.CardAuthentication.Builder
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.BuilderA builder for CardAuthentication.
-
-
Method Summary
-
-
Method Detail
-
id
final CardPayment.Element.CardAuthentication.Builder id(String id)
The Card Authentication identifier.
-
id
final CardPayment.Element.CardAuthentication.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressCity
final CardPayment.Element.CardAuthentication.Builder billingAddressCity(String billingAddressCity)
The city of the cardholder billing address associated with the card used for this purchase.
-
billingAddressCity
final CardPayment.Element.CardAuthentication.Builder billingAddressCity(Optional<String> billingAddressCity)
Alias for calling Builder.billingAddressCity with
billingAddressCity.orElse(null).
-
billingAddressCity
final CardPayment.Element.CardAuthentication.Builder billingAddressCity(JsonField<String> billingAddressCity)
Sets Builder.billingAddressCity to an arbitrary JSON value.
You should usually call Builder.billingAddressCity with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressCountry
final CardPayment.Element.CardAuthentication.Builder billingAddressCountry(String billingAddressCountry)
The country of the cardholder billing address associated with the card used for this purchase.
-
billingAddressCountry
final CardPayment.Element.CardAuthentication.Builder billingAddressCountry(Optional<String> billingAddressCountry)
Alias for calling Builder.billingAddressCountry with
billingAddressCountry.orElse(null).
-
billingAddressCountry
final CardPayment.Element.CardAuthentication.Builder billingAddressCountry(JsonField<String> billingAddressCountry)
Sets Builder.billingAddressCountry to an arbitrary JSON value.
You should usually call Builder.billingAddressCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressLine1
final CardPayment.Element.CardAuthentication.Builder billingAddressLine1(String billingAddressLine1)
The first line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine1
final CardPayment.Element.CardAuthentication.Builder billingAddressLine1(Optional<String> billingAddressLine1)
Alias for calling Builder.billingAddressLine1 with
billingAddressLine1.orElse(null).
-
billingAddressLine1
final CardPayment.Element.CardAuthentication.Builder billingAddressLine1(JsonField<String> billingAddressLine1)
Sets Builder.billingAddressLine1 to an arbitrary JSON value.
You should usually call Builder.billingAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressLine2
final CardPayment.Element.CardAuthentication.Builder billingAddressLine2(String billingAddressLine2)
The second line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine2
final CardPayment.Element.CardAuthentication.Builder billingAddressLine2(Optional<String> billingAddressLine2)
Alias for calling Builder.billingAddressLine2 with
billingAddressLine2.orElse(null).
-
billingAddressLine2
final CardPayment.Element.CardAuthentication.Builder billingAddressLine2(JsonField<String> billingAddressLine2)
Sets Builder.billingAddressLine2 to an arbitrary JSON value.
You should usually call Builder.billingAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressLine3
final CardPayment.Element.CardAuthentication.Builder billingAddressLine3(String billingAddressLine3)
The third line of the cardholder billing address associated with the card used for this purchase.
-
billingAddressLine3
final CardPayment.Element.CardAuthentication.Builder billingAddressLine3(Optional<String> billingAddressLine3)
Alias for calling Builder.billingAddressLine3 with
billingAddressLine3.orElse(null).
-
billingAddressLine3
final CardPayment.Element.CardAuthentication.Builder billingAddressLine3(JsonField<String> billingAddressLine3)
Sets Builder.billingAddressLine3 to an arbitrary JSON value.
You should usually call Builder.billingAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressPostalCode
final CardPayment.Element.CardAuthentication.Builder billingAddressPostalCode(String billingAddressPostalCode)
The postal code of the cardholder billing address associated with the card used for this purchase.
-
billingAddressPostalCode
final CardPayment.Element.CardAuthentication.Builder billingAddressPostalCode(Optional<String> billingAddressPostalCode)
Alias for calling Builder.billingAddressPostalCode with
billingAddressPostalCode.orElse(null).
-
billingAddressPostalCode
final CardPayment.Element.CardAuthentication.Builder billingAddressPostalCode(JsonField<String> billingAddressPostalCode)
Sets Builder.billingAddressPostalCode to an arbitrary JSON value.
You should usually call Builder.billingAddressPostalCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
billingAddressState
final CardPayment.Element.CardAuthentication.Builder billingAddressState(String billingAddressState)
The US state of the cardholder billing address associated with the card used for this purchase.
-
billingAddressState
final CardPayment.Element.CardAuthentication.Builder billingAddressState(Optional<String> billingAddressState)
Alias for calling Builder.billingAddressState with
billingAddressState.orElse(null).
-
billingAddressState
final CardPayment.Element.CardAuthentication.Builder billingAddressState(JsonField<String> billingAddressState)
Sets Builder.billingAddressState to an arbitrary JSON value.
You should usually call Builder.billingAddressState with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final CardPayment.Element.CardAuthentication.Builder cardId(String cardId)
The identifier of the Card.
-
cardId
final CardPayment.Element.CardAuthentication.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardPaymentId
final CardPayment.Element.CardAuthentication.Builder cardPaymentId(String cardPaymentId)
The ID of the Card Payment this transaction belongs to.
-
cardPaymentId
final CardPayment.Element.CardAuthentication.Builder cardPaymentId(JsonField<String> cardPaymentId)
Sets Builder.cardPaymentId to an arbitrary JSON value.
You should usually call Builder.cardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderEmail
final CardPayment.Element.CardAuthentication.Builder cardholderEmail(String cardholderEmail)
The email address of the cardholder.
-
cardholderEmail
final CardPayment.Element.CardAuthentication.Builder cardholderEmail(Optional<String> cardholderEmail)
Alias for calling Builder.cardholderEmail with
cardholderEmail.orElse(null).
-
cardholderEmail
final CardPayment.Element.CardAuthentication.Builder cardholderEmail(JsonField<String> cardholderEmail)
Sets Builder.cardholderEmail to an arbitrary JSON value.
You should usually call Builder.cardholderEmail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardholderName
final CardPayment.Element.CardAuthentication.Builder cardholderName(String cardholderName)
The name of the cardholder.
-
cardholderName
final CardPayment.Element.CardAuthentication.Builder cardholderName(Optional<String> cardholderName)
Alias for calling Builder.cardholderName with
cardholderName.orElse(null).
-
cardholderName
final CardPayment.Element.CardAuthentication.Builder cardholderName(JsonField<String> cardholderName)
Sets Builder.cardholderName to an arbitrary JSON value.
You should usually call Builder.cardholderName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final CardPayment.Element.CardAuthentication.Builder category(CardPayment.Element.CardAuthentication.Category category)
The category of the card authentication attempt.
-
category
final CardPayment.Element.CardAuthentication.Builder category(Optional<CardPayment.Element.CardAuthentication.Category> category)
Alias for calling Builder.category with
category.orElse(null).
-
category
final CardPayment.Element.CardAuthentication.Builder category(JsonField<CardPayment.Element.CardAuthentication.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
challenge
final CardPayment.Element.CardAuthentication.Builder challenge(CardPayment.Element.CardAuthentication.Challenge challenge)
Details about the challenge, if one was requested.
-
challenge
final CardPayment.Element.CardAuthentication.Builder challenge(Optional<CardPayment.Element.CardAuthentication.Challenge> challenge)
Alias for calling Builder.challenge with
challenge.orElse(null).
-
challenge
final CardPayment.Element.CardAuthentication.Builder challenge(JsonField<CardPayment.Element.CardAuthentication.Challenge> challenge)
Sets Builder.challenge to an arbitrary JSON value.
You should usually call Builder.challenge with a well-typed Challenge value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CardPayment.Element.CardAuthentication.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Card Authentication was attempted.
-
createdAt
final CardPayment.Element.CardAuthentication.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
denyReason
final CardPayment.Element.CardAuthentication.Builder denyReason(CardPayment.Element.CardAuthentication.DenyReason denyReason)
The reason why this authentication attempt was denied, if it was.
-
denyReason
final CardPayment.Element.CardAuthentication.Builder denyReason(Optional<CardPayment.Element.CardAuthentication.DenyReason> denyReason)
Alias for calling Builder.denyReason with
denyReason.orElse(null).
-
denyReason
final CardPayment.Element.CardAuthentication.Builder denyReason(JsonField<CardPayment.Element.CardAuthentication.DenyReason> denyReason)
Sets Builder.denyReason to an arbitrary JSON value.
You should usually call Builder.denyReason with a well-typed DenyReason value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
deviceChannel
final CardPayment.Element.CardAuthentication.Builder deviceChannel(CardPayment.Element.CardAuthentication.DeviceChannel deviceChannel)
The device channel of the card authentication attempt.
-
deviceChannel
final CardPayment.Element.CardAuthentication.Builder deviceChannel(JsonField<CardPayment.Element.CardAuthentication.DeviceChannel> deviceChannel)
Sets Builder.deviceChannel to an arbitrary JSON value.
You should usually call Builder.deviceChannel with a well-typed DeviceChannel value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantAcceptorId
final CardPayment.Element.CardAuthentication.Builder merchantAcceptorId(String merchantAcceptorId)
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantAcceptorId
final CardPayment.Element.CardAuthentication.Builder merchantAcceptorId(JsonField<String> merchantAcceptorId)
Sets Builder.merchantAcceptorId to an arbitrary JSON value.
You should usually call Builder.merchantAcceptorId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCategoryCode
final CardPayment.Element.CardAuthentication.Builder merchantCategoryCode(String merchantCategoryCode)
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCategoryCode
final CardPayment.Element.CardAuthentication.Builder merchantCategoryCode(JsonField<String> merchantCategoryCode)
Sets Builder.merchantCategoryCode to an arbitrary JSON value.
You should usually call Builder.merchantCategoryCode with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantCountry
final CardPayment.Element.CardAuthentication.Builder merchantCountry(String merchantCountry)
The country the merchant resides in.
-
merchantCountry
final CardPayment.Element.CardAuthentication.Builder merchantCountry(JsonField<String> merchantCountry)
Sets Builder.merchantCountry to an arbitrary JSON value.
You should usually call Builder.merchantCountry with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
merchantName
final CardPayment.Element.CardAuthentication.Builder merchantName(String merchantName)
The name of the merchant.
-
merchantName
final CardPayment.Element.CardAuthentication.Builder merchantName(JsonField<String> merchantName)
Sets Builder.merchantName to an arbitrary JSON value.
You should usually call Builder.merchantName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(Long purchaseAmount)
The purchase amount in minor units.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(Long purchaseAmount)
Alias for Builder.purchaseAmount.
This unboxed primitive overload exists for backwards compatibility.
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(Optional<Long> purchaseAmount)
Alias for calling Builder.purchaseAmount with
purchaseAmount.orElse(null).
-
purchaseAmount
final CardPayment.Element.CardAuthentication.Builder purchaseAmount(JsonField<Long> purchaseAmount)
Sets Builder.purchaseAmount to an arbitrary JSON value.
You should usually call Builder.purchaseAmount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
purchaseCurrency
final CardPayment.Element.CardAuthentication.Builder purchaseCurrency(String purchaseCurrency)
The ISO 4217 code for the authentication attempt's purchase currency.
-
purchaseCurrency
final CardPayment.Element.CardAuthentication.Builder purchaseCurrency(Optional<String> purchaseCurrency)
Alias for calling Builder.purchaseCurrency with
purchaseCurrency.orElse(null).
-
purchaseCurrency
final CardPayment.Element.CardAuthentication.Builder purchaseCurrency(JsonField<String> purchaseCurrency)
Sets Builder.purchaseCurrency to an arbitrary JSON value.
You should usually call Builder.purchaseCurrency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
realTimeDecisionId
final CardPayment.Element.CardAuthentication.Builder realTimeDecisionId(String realTimeDecisionId)
The identifier of the Real-Time Decision sent to approve or decline this authentication attempt.
-
realTimeDecisionId
final CardPayment.Element.CardAuthentication.Builder realTimeDecisionId(Optional<String> realTimeDecisionId)
Alias for calling Builder.realTimeDecisionId with
realTimeDecisionId.orElse(null).
-
realTimeDecisionId
final CardPayment.Element.CardAuthentication.Builder realTimeDecisionId(JsonField<String> realTimeDecisionId)
Sets Builder.realTimeDecisionId to an arbitrary JSON value.
You should usually call Builder.realTimeDecisionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CardPayment.Element.CardAuthentication.Builder status(CardPayment.Element.CardAuthentication.Status status)
The status of the card authentication.
-
status
final CardPayment.Element.CardAuthentication.Builder status(JsonField<CardPayment.Element.CardAuthentication.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CardPayment.Element.CardAuthentication.Builder type(CardPayment.Element.CardAuthentication.Type type)
A constant representing the object's type. For this resource it will always be
card_authentication.
-
type
final CardPayment.Element.CardAuthentication.Builder type(JsonField<CardPayment.Element.CardAuthentication.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CardPayment.Element.CardAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CardPayment.Element.CardAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CardPayment.Element.CardAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CardPayment.Element.CardAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CardPayment.Element.CardAuthentication build()
Returns an immutable instance of CardAuthentication.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .billingAddressCity() .billingAddressCountry() .billingAddressLine1() .billingAddressLine2() .billingAddressLine3() .billingAddressPostalCode() .billingAddressState() .cardId() .cardPaymentId() .cardholderEmail() .cardholderName() .category() .challenge() .createdAt() .denyReason() .deviceChannel() .merchantAcceptorId() .merchantCategoryCode() .merchantCountry() .merchantName() .purchaseAmount() .purchaseCurrency() .realTimeDecisionId() .status() .type()
-
-
-
-