Class CardPayment.Element.CardAuthentication.Challenge
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.ChallengeDetails about the challenge, if one was requested.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.Challenge.BuilderA builder for Challenge.
public final classCardPayment.Element.CardAuthentication.Challenge.Attemptpublic final classCardPayment.Element.CardAuthentication.Challenge.VerificationMethodThe method used to verify the Card Authentication Challenge.
-
Method Summary
-
-
Method Detail
-
attempts
final List<CardPayment.Element.CardAuthentication.Challenge.Attempt> attempts()
Details about the challenge verification attempts, if any happened.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the Card Authentication Challenge was started.
-
oneTimeCode
final String oneTimeCode()
The one-time code used for the Card Authentication Challenge.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision used to deliver this challenge.
-
verificationMethod
final CardPayment.Element.CardAuthentication.Challenge.VerificationMethod verificationMethod()
The method used to verify the Card Authentication Challenge.
-
verificationValue
final Optional<String> verificationValue()
E.g., the email address or phone number used for the Card Authentication Challenge.
-
_attempts
final JsonField<List<CardPayment.Element.CardAuthentication.Challenge.Attempt>> _attempts()
Returns the raw JSON value of attempts.
Unlike attempts, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_oneTimeCode
final JsonField<String> _oneTimeCode()
Returns the raw JSON value of oneTimeCode.
Unlike oneTimeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_verificationMethod
final JsonField<CardPayment.Element.CardAuthentication.Challenge.VerificationMethod> _verificationMethod()
Returns the raw JSON value of verificationMethod.
Unlike verificationMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_verificationValue
final JsonField<String> _verificationValue()
Returns the raw JSON value of verificationValue.
Unlike verificationValue, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthentication.Challenge.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthentication.Challenge validate()
-
builder
final static CardPayment.Element.CardAuthentication.Challenge.Builder builder()
Returns a mutable builder for constructing an instance of Challenge.
The following fields are required:
.attempts() .createdAt() .oneTimeCode() .realTimeDecisionId() .verificationMethod() .verificationValue()
-
-
-
-