Class CardPayment.Element.CardAuthentication.Challenge.Attempt
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.Challenge.Attempt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.Challenge.Attempt.BuilderA builder for Attempt.
public final classCardPayment.Element.CardAuthentication.Challenge.Attempt.OutcomeThe outcome of the Card Authentication Challenge Attempt.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecreatedAt()The ISO 8601 time of the Card Authentication Challenge Attempt. final CardPayment.Element.CardAuthentication.Challenge.Attempt.Outcomeoutcome()The outcome of the Card Authentication Challenge Attempt. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<CardPayment.Element.CardAuthentication.Challenge.Attempt.Outcome>_outcome()Returns the raw JSON value of outcome. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardAuthentication.Challenge.Attempt.BuildertoBuilder()final CardPayment.Element.CardAuthentication.Challenge.Attemptvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardAuthentication.Challenge.Attempt.Builderbuilder()Returns a mutable builder for constructing an instance of Attempt. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time of the Card Authentication Challenge Attempt.
-
outcome
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Outcome outcome()
The outcome of the Card Authentication Challenge Attempt.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_outcome
final JsonField<CardPayment.Element.CardAuthentication.Challenge.Attempt.Outcome> _outcome()
Returns the raw JSON value of outcome.
Unlike outcome, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthentication.Challenge.Attempt validate()
-
builder
final static CardPayment.Element.CardAuthentication.Challenge.Attempt.Builder builder()
Returns a mutable builder for constructing an instance of Attempt.
The following fields are required:
.createdAt() .outcome()
-
-
-
-