Class CardPayment.Element.CardAuthentication.DeviceChannel
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardAuthentication.DeviceChannelThe device channel of the card authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardAuthentication.DeviceChannel.BuilderA builder for DeviceChannel.
public final classCardPayment.Element.CardAuthentication.DeviceChannel.BrowserFields specific to the browser device channel.
public final classCardPayment.Element.CardAuthentication.DeviceChannel.CategoryThe category of the device channel.
public final classCardPayment.Element.CardAuthentication.DeviceChannel.MerchantInitiatedFields specific to merchant initiated transactions.
-
Method Summary
-
-
Method Detail
-
browser
final Optional<CardPayment.Element.CardAuthentication.DeviceChannel.Browser> browser()
Fields specific to the browser device channel.
-
category
final CardPayment.Element.CardAuthentication.DeviceChannel.Category category()
The category of the device channel.
-
merchantInitiated
final Optional<CardPayment.Element.CardAuthentication.DeviceChannel.MerchantInitiated> merchantInitiated()
Fields specific to merchant initiated transactions.
-
_browser
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.Browser> _browser()
Returns the raw JSON value of browser.
Unlike browser, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantInitiated
final JsonField<CardPayment.Element.CardAuthentication.DeviceChannel.MerchantInitiated> _merchantInitiated()
Returns the raw JSON value of merchantInitiated.
Unlike merchantInitiated, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardAuthentication.DeviceChannel.Builder toBuilder()
-
validate
final CardPayment.Element.CardAuthentication.DeviceChannel validate()
-
builder
final static CardPayment.Element.CardAuthentication.DeviceChannel.Builder builder()
Returns a mutable builder for constructing an instance of DeviceChannel.
The following fields are required:
.browser() .category() .merchantInitiated()
-
-
-
-