Class CardPayment.Element.CardFuelConfirmation

  • All Implemented Interfaces:

    
    public final class CardPayment.Element.CardFuelConfirmation
    
                        

    A Card Fuel Confirmation object. This field will be present in the JSON response if and only if category is equal to card_fuel_confirmation. Card Fuel Confirmations update the amount of a Card Authorization after a fuel pump transaction is completed.