Class CardPayment.Element.CardIncrement
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardIncrementA Card Increment object. This field will be present in the JSON response if and only if
categoryis equal tocard_increment. Card Increments increase the pending amount of an authorized transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardIncrement.BuilderA builder for CardIncrement.
public final classCardPayment.Element.CardIncrement.ActionerWhether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classCardPayment.Element.CardIncrement.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.public final classCardPayment.Element.CardIncrement.CurrencyThe ISO 4217 code for the increment's currency.
public final classCardPayment.Element.CardIncrement.NetworkThe card network used to process this card authorization.
public final classCardPayment.Element.CardIncrement.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardIncrement.TypeA constant representing the object's type. For this resource it will always be
card_increment.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Increment identifier. final CardPayment.Element.CardIncrement.Actioneractioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardIncrement.AdditionalAmountsadditionalAmounts()Additional amounts associated with the card authorization, such as ATM surcharges fees. final Longamount()The amount of this increment in the minor unit of the transaction's currency. final StringcardAuthorizationId()The identifier for the Card Authorization this increments. final CardPayment.Element.CardIncrement.Currencycurrency()The ISO 4217 code for the increment's currency. final CardPayment.Element.CardIncrement.Networknetwork()The card network used to process this card authorization. final CardPayment.Element.CardIncrement.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction associated with this Card Increment. final LongpresentmentAmount()The amount of this increment in the minor unit of the transaction's presentment currency. final StringpresentmentCurrency()The ISO 4217 code for the transaction's presentment currency. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this incremental authorization. final CardPayment.Element.CardIncrement.Typetype()A constant representing the object's type. final LongupdatedAuthorizationAmount()The updated authorization amount after this increment, in the minor unit of the transaction's currency. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CardPayment.Element.CardIncrement.Actioner>_actioner()Returns the raw JSON value of actioner. final JsonField<CardPayment.Element.CardIncrement.AdditionalAmounts>_additionalAmounts()Returns the raw JSON value of additionalAmounts. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_cardAuthorizationId()Returns the raw JSON value of cardAuthorizationId. final JsonField<CardPayment.Element.CardIncrement.Currency>_currency()Returns the raw JSON value of currency. final JsonField<CardPayment.Element.CardIncrement.Network>_network()Returns the raw JSON value of network. final JsonField<CardPayment.Element.CardIncrement.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<Long>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final JsonField<String>_presentmentCurrency()Returns the raw JSON value of presentmentCurrency. final JsonField<String>_realTimeDecisionId()Returns the raw JSON value of realTimeDecisionId. final JsonField<CardPayment.Element.CardIncrement.Type>_type()Returns the raw JSON value of type. final JsonField<Long>_updatedAuthorizationAmount()Returns the raw JSON value of updatedAuthorizationAmount. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardIncrement.BuildertoBuilder()final CardPayment.Element.CardIncrementvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardIncrement.Builderbuilder()Returns a mutable builder for constructing an instance of CardIncrement. -
-
Method Detail
-
actioner
final CardPayment.Element.CardIncrement.Actioner actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
additionalAmounts
final CardPayment.Element.CardIncrement.AdditionalAmounts additionalAmounts()
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
amount
final Long amount()
The amount of this increment in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
cardAuthorizationId
final String cardAuthorizationId()
The identifier for the Card Authorization this increments.
-
currency
final CardPayment.Element.CardIncrement.Currency currency()
The ISO 4217 code for the increment's currency.
-
network
final CardPayment.Element.CardIncrement.Network network()
The card network used to process this card authorization.
-
networkIdentifiers
final CardPayment.Element.CardIncrement.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction associated with this Card Increment.
-
presentmentAmount
final Long presentmentAmount()
The amount of this increment in the minor unit of the transaction's presentment currency.
-
presentmentCurrency
final String presentmentCurrency()
The ISO 4217 code for the transaction's presentment currency.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this incremental authorization.
-
type
final CardPayment.Element.CardIncrement.Type type()
A constant representing the object's type. For this resource it will always be
card_increment.
-
updatedAuthorizationAmount
final Long updatedAuthorizationAmount()
The updated authorization amount after this increment, in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_actioner
final JsonField<CardPayment.Element.CardIncrement.Actioner> _actioner()
Returns the raw JSON value of actioner.
Unlike actioner, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalAmounts
final JsonField<CardPayment.Element.CardIncrement.AdditionalAmounts> _additionalAmounts()
Returns the raw JSON value of additionalAmounts.
Unlike additionalAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorizationId
final JsonField<String> _cardAuthorizationId()
Returns the raw JSON value of cardAuthorizationId.
Unlike cardAuthorizationId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CardPayment.Element.CardIncrement.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<CardPayment.Element.CardIncrement.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardIncrement.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentCurrency
final JsonField<String> _presentmentCurrency()
Returns the raw JSON value of presentmentCurrency.
Unlike presentmentCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardIncrement.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAuthorizationAmount
final JsonField<Long> _updatedAuthorizationAmount()
Returns the raw JSON value of updatedAuthorizationAmount.
Unlike updatedAuthorizationAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardIncrement.Builder toBuilder()
-
validate
final CardPayment.Element.CardIncrement validate()
-
builder
final static CardPayment.Element.CardIncrement.Builder builder()
Returns a mutable builder for constructing an instance of CardIncrement.
The following fields are required:
.id() .actioner() .additionalAmounts() .amount() .cardAuthorizationId() .currency() .network() .networkIdentifiers() .networkRiskScore() .pendingTransactionId() .presentmentAmount() .presentmentCurrency() .realTimeDecisionId() .type() .updatedAuthorizationAmount()
-
-
-
-