Class CardPayment.Element.CardValidation
-
- All Implemented Interfaces:
public final class CardPayment.Element.CardValidationAn Inbound Card Validation object. This field will be present in the JSON response if and only if
categoryis equal tocard_validation. Inbound Card Validations are requests from a merchant to verify that a card number and optionally its address and/or Card Verification Value are valid.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPayment.Element.CardValidation.BuilderA builder for CardValidation.
public final classCardPayment.Element.CardValidation.ActionerWhether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
public final classCardPayment.Element.CardValidation.AdditionalAmountsAdditional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.public final classCardPayment.Element.CardValidation.CurrencyThe ISO 4217 code for the transaction's currency.
public final classCardPayment.Element.CardValidation.NetworkDetailsFields specific to the
network.public final classCardPayment.Element.CardValidation.NetworkIdentifiersNetwork-specific identifiers for a specific request or transaction.
public final classCardPayment.Element.CardValidation.SchemeFeepublic final classCardPayment.Element.CardValidation.TypeA constant representing the object's type. For this resource it will always be
inbound_card_validation.public final classCardPayment.Element.CardValidation.VerificationFields related to verification of cardholder-provided values.
-
Method Summary
Modifier and Type Method Description final Stringid()The Card Validation identifier. final CardPayment.Element.CardValidation.Actioneractioner()Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision. final CardPayment.Element.CardValidation.AdditionalAmountsadditionalAmounts()Additional amounts associated with the card authorization, such as ATM surcharges fees. final StringcardPaymentId()The ID of the Card Payment this transaction belongs to. final CardPayment.Element.CardValidation.Currencycurrency()The ISO 4217 code for the transaction's currency. final Optional<String>digitalWalletTokenId()If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used. final StringmerchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final StringmerchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final StringmerchantCountry()The country the merchant resides in. final StringmerchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantPostalCode()The merchant's postal code. final Optional<String>merchantState()The state the merchant resides in. final CardPayment.Element.CardValidation.NetworkDetailsnetworkDetails()Fields specific to the network.final CardPayment.Element.CardValidation.NetworkIdentifiersnetworkIdentifiers()Network-specific identifiers for a specific request or transaction. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()If the authorization was made in-person with a physical card, the Physical Card that was used. final Optional<String>realTimeDecisionId()The identifier of the Real-Time Decision sent to approve or decline this transaction. final List<CardPayment.Element.CardValidation.SchemeFee>schemeFees()The scheme fees associated with this card validation. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final CardPayment.Element.CardValidation.Typetype()A constant representing the object's type. final CardPayment.Element.CardValidation.Verificationverification()Fields related to verification of cardholder-provided values. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CardPayment.Element.CardValidation.Actioner>_actioner()Returns the raw JSON value of actioner. final JsonField<CardPayment.Element.CardValidation.AdditionalAmounts>_additionalAmounts()Returns the raw JSON value of additionalAmounts. final JsonField<String>_cardPaymentId()Returns the raw JSON value of cardPaymentId. final JsonField<CardPayment.Element.CardValidation.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantPostalCode()Returns the raw JSON value of merchantPostalCode. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<CardPayment.Element.CardValidation.NetworkDetails>_networkDetails()Returns the raw JSON value of networkDetails. final JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers>_networkIdentifiers()Returns the raw JSON value of networkIdentifiers. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<String>_realTimeDecisionId()Returns the raw JSON value of realTimeDecisionId. final JsonField<List<CardPayment.Element.CardValidation.SchemeFee>>_schemeFees()Returns the raw JSON value of schemeFees. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final JsonField<CardPayment.Element.CardValidation.Type>_type()Returns the raw JSON value of type. final JsonField<CardPayment.Element.CardValidation.Verification>_verification()Returns the raw JSON value of verification. final Map<String, JsonValue>_additionalProperties()final CardPayment.Element.CardValidation.BuildertoBuilder()final CardPayment.Element.CardValidationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPayment.Element.CardValidation.Builderbuilder()Returns a mutable builder for constructing an instance of CardValidation. -
-
Method Detail
-
actioner
final CardPayment.Element.CardValidation.Actioner actioner()
Whether this authorization was approved by Increase, the card network through stand-in processing, or the user through a real-time decision.
-
additionalAmounts
final CardPayment.Element.CardValidation.AdditionalAmounts additionalAmounts()
Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the
amountfield and are used to provide more detailed information about the transaction.
-
cardPaymentId
final String cardPaymentId()
The ID of the Card Payment this transaction belongs to.
-
currency
final CardPayment.Element.CardValidation.Currency currency()
The ISO 4217 code for the transaction's currency.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
If the authorization was made via a Digital Wallet Token (such as an Apple Pay purchase), the identifier of the token that was used.
-
merchantAcceptorId
final String merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final String merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final String merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final String merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantPostalCode
final Optional<String> merchantPostalCode()
The merchant's postal code. For US merchants this is either a 5-digit or 9-digit ZIP code, where the first 5 and last 4 are separated by a dash.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final CardPayment.Element.CardValidation.NetworkDetails networkDetails()
Fields specific to the
network.
-
networkIdentifiers
final CardPayment.Element.CardValidation.NetworkIdentifiers networkIdentifiers()
Network-specific identifiers for a specific request or transaction.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest. For Pulse the score is from 0 to 999, where 999 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
If the authorization was made in-person with a physical card, the Physical Card that was used.
-
realTimeDecisionId
final Optional<String> realTimeDecisionId()
The identifier of the Real-Time Decision sent to approve or decline this transaction.
-
schemeFees
final List<CardPayment.Element.CardValidation.SchemeFee> schemeFees()
The scheme fees associated with this card validation.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
type
final CardPayment.Element.CardValidation.Type type()
A constant representing the object's type. For this resource it will always be
inbound_card_validation.
-
verification
final CardPayment.Element.CardValidation.Verification verification()
Fields related to verification of cardholder-provided values.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_actioner
final JsonField<CardPayment.Element.CardValidation.Actioner> _actioner()
Returns the raw JSON value of actioner.
Unlike actioner, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalAmounts
final JsonField<CardPayment.Element.CardValidation.AdditionalAmounts> _additionalAmounts()
Returns the raw JSON value of additionalAmounts.
Unlike additionalAmounts, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPaymentId
final JsonField<String> _cardPaymentId()
Returns the raw JSON value of cardPaymentId.
Unlike cardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<CardPayment.Element.CardValidation.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantPostalCode
final JsonField<String> _merchantPostalCode()
Returns the raw JSON value of merchantPostalCode.
Unlike merchantPostalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_networkDetails
final JsonField<CardPayment.Element.CardValidation.NetworkDetails> _networkDetails()
Returns the raw JSON value of networkDetails.
Unlike networkDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_networkIdentifiers
final JsonField<CardPayment.Element.CardValidation.NetworkIdentifiers> _networkIdentifiers()
Returns the raw JSON value of networkIdentifiers.
Unlike networkIdentifiers, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimeDecisionId
final JsonField<String> _realTimeDecisionId()
Returns the raw JSON value of realTimeDecisionId.
Unlike realTimeDecisionId, this method doesn't throw if the JSON field has an unexpected type.
-
_schemeFees
final JsonField<List<CardPayment.Element.CardValidation.SchemeFee>> _schemeFees()
Returns the raw JSON value of schemeFees.
Unlike schemeFees, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardPayment.Element.CardValidation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_verification
final JsonField<CardPayment.Element.CardValidation.Verification> _verification()
Returns the raw JSON value of verification.
Unlike verification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPayment.Element.CardValidation.Builder toBuilder()
-
validate
final CardPayment.Element.CardValidation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardPayment.Element.CardValidation.Builder builder()
Returns a mutable builder for constructing an instance of CardValidation.
The following fields are required:
.id() .actioner() .additionalAmounts() .cardPaymentId() .currency() .digitalWalletTokenId() .merchantAcceptorId() .merchantCategoryCode() .merchantCity() .merchantCountry() .merchantDescriptor() .merchantPostalCode() .merchantState() .networkDetails() .networkIdentifiers() .networkRiskScore() .physicalCardId() .realTimeDecisionId() .schemeFees() .terminalId() .type() .verification()
-
-
-
-