Class CardPushTransfer.Acceptance
-
- All Implemented Interfaces:
public final class CardPushTransfer.AcceptanceIf the transfer is accepted by the recipient bank, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.Acceptance.BuilderA builder for Acceptance.
public final classCardPushTransfer.Acceptance.CardVerificationValue2ResultThe result of the Card Verification Value 2 match.
-
Method Summary
-
-
Method Detail
-
acceptedAt
final OffsetDateTime acceptedAt()
The ISO 8601 date and time at which the transfer was accepted by the issuing bank.
-
authorizationIdentificationResponse
final String authorizationIdentificationResponse()
The authorization identification response from the issuing bank.
-
cardVerificationValue2Result
final Optional<CardPushTransfer.Acceptance.CardVerificationValue2Result> cardVerificationValue2Result()
The result of the Card Verification Value 2 match.
-
networkTransactionIdentifier
final Optional<String> networkTransactionIdentifier()
A unique identifier for the transaction on the card network.
-
settlementAmount
final Long settlementAmount()
The transfer amount in USD cents.
-
_acceptedAt
final JsonField<OffsetDateTime> _acceptedAt()
Returns the raw JSON value of acceptedAt.
Unlike acceptedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationIdentificationResponse
final JsonField<String> _authorizationIdentificationResponse()
Returns the raw JSON value of authorizationIdentificationResponse.
Unlike authorizationIdentificationResponse, this method doesn't throw if the JSON field has an unexpected type.
-
_cardVerificationValue2Result
final JsonField<CardPushTransfer.Acceptance.CardVerificationValue2Result> _cardVerificationValue2Result()
Returns the raw JSON value of cardVerificationValue2Result.
Unlike cardVerificationValue2Result, this method doesn't throw if the JSON field has an unexpected type.
-
_networkTransactionIdentifier
final JsonField<String> _networkTransactionIdentifier()
Returns the raw JSON value of networkTransactionIdentifier.
Unlike networkTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.Acceptance.Builder toBuilder()
-
validate
final CardPushTransfer.Acceptance validate()
-
builder
final static CardPushTransfer.Acceptance.Builder builder()
Returns a mutable builder for constructing an instance of Acceptance.
The following fields are required:
.acceptedAt() .authorizationIdentificationResponse() .cardVerificationValue2Result() .networkTransactionIdentifier() .settlementAmount()
-
-
-
-