Class CardPushTransfer.Decline
-
- All Implemented Interfaces:
public final class CardPushTransfer.DeclineIf the transfer is rejected by the card network or the destination financial institution, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPushTransfer.Decline.BuilderA builder for Decline.
public final classCardPushTransfer.Decline.ReasonThe reason why the transfer was declined.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimedeclinedAt()The ISO 8601 date and time at which the transfer declined. final Optional<String>networkTransactionIdentifier()A unique identifier for the transaction on the card network. final CardPushTransfer.Decline.Reasonreason()The reason why the transfer was declined. final JsonField<OffsetDateTime>_declinedAt()Returns the raw JSON value of declinedAt. final JsonField<String>_networkTransactionIdentifier()Returns the raw JSON value of networkTransactionIdentifier. final JsonField<CardPushTransfer.Decline.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final CardPushTransfer.Decline.BuildertoBuilder()final CardPushTransfer.Declinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardPushTransfer.Decline.Builderbuilder()Returns a mutable builder for constructing an instance of Decline. -
-
Method Detail
-
declinedAt
final OffsetDateTime declinedAt()
The ISO 8601 date and time at which the transfer declined.
-
networkTransactionIdentifier
final Optional<String> networkTransactionIdentifier()
A unique identifier for the transaction on the card network.
-
reason
final CardPushTransfer.Decline.Reason reason()
The reason why the transfer was declined.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
Returns the raw JSON value of declinedAt.
Unlike declinedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_networkTransactionIdentifier
final JsonField<String> _networkTransactionIdentifier()
Returns the raw JSON value of networkTransactionIdentifier.
Unlike networkTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<CardPushTransfer.Decline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardPushTransfer.Decline.Builder toBuilder()
-
validate
final CardPushTransfer.Decline validate()
-
builder
final static CardPushTransfer.Decline.Builder builder()
Returns a mutable builder for constructing an instance of Decline.
The following fields are required:
.declinedAt() .networkTransactionIdentifier() .reason()
-
-
-
-