Class Card.AuthorizationControls.Usage.MultiUse.SpendingLimit
-
- All Implemented Interfaces:
public final class Card.AuthorizationControls.Usage.MultiUse.SpendingLimit
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCard.AuthorizationControls.Usage.MultiUse.SpendingLimit.BuilderA builder for SpendingLimit.
public final classCard.AuthorizationControls.Usage.MultiUse.SpendingLimit.IntervalThe interval at which the spending limit is enforced.
public final classCard.AuthorizationControls.Usage.MultiUse.SpendingLimit.MerchantCategoryCode
-
Method Summary
-
-
Method Detail
-
interval
final Card.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval interval()
The interval at which the spending limit is enforced.
-
merchantCategoryCodes
final Optional<List<Card.AuthorizationControls.Usage.MultiUse.SpendingLimit.MerchantCategoryCode>> merchantCategoryCodes()
The Merchant Category Codes (MCCs) this spending limit applies to. If not set, the limit applies to all transactions.
-
settlementAmount
final Long settlementAmount()
The maximum settlement amount permitted in the given interval.
-
_interval
final JsonField<Card.AuthorizationControls.Usage.MultiUse.SpendingLimit.Interval> _interval()
Returns the raw JSON value of interval.
Unlike interval, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCodes
final JsonField<List<Card.AuthorizationControls.Usage.MultiUse.SpendingLimit.MerchantCategoryCode>> _merchantCategoryCodes()
Returns the raw JSON value of merchantCategoryCodes.
Unlike merchantCategoryCodes, this method doesn't throw if the JSON field has an unexpected type.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Card.AuthorizationControls.Usage.MultiUse.SpendingLimit.Builder toBuilder()
-
validate
final Card.AuthorizationControls.Usage.MultiUse.SpendingLimit validate()
-
builder
final static Card.AuthorizationControls.Usage.MultiUse.SpendingLimit.Builder builder()
Returns a mutable builder for constructing an instance of SpendingLimit.
The following fields are required:
.interval() .merchantCategoryCodes() .settlementAmount()
-
-
-
-