Class CardCreateDetailsIframeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardCreateDetailsIframeParams implements Params
Create an iframe URL for a Card to display the card details. More details about styling and usage can be found in the /documentation/embedded-card-component.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateDetailsIframeParams.BuilderA builder for CardCreateDetailsIframeParams.
public final classCardCreateDetailsIframeParams.Body
-
Method Summary
Modifier and Type Method Description final Optional<String>cardId()The identifier of the Card to create an iframe for. final Optional<String>physicalCardId()The identifier of the Physical Card to create an iframe for. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardCreateDetailsIframeParams.BuildertoBuilder()final CardCreateDetailsIframeParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateDetailsIframeParamsnone()final static CardCreateDetailsIframeParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardCreateDetailsIframeParams. -
-
Method Detail
-
physicalCardId
final Optional<String> physicalCardId()
The identifier of the Physical Card to create an iframe for. This will inform the appearance of the card rendered in the iframe.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardCreateDetailsIframeParams.Builder toBuilder()
-
_body
final CardCreateDetailsIframeParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardCreateDetailsIframeParams none()
-
builder
final static CardCreateDetailsIframeParams.Builder builder()
Returns a mutable builder for constructing an instance of CardCreateDetailsIframeParams.
-
-
-
-