Class CardCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardCreateParams implements Params
Create a Card
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.BuilderA builder for CardCreateParams.
public final classCardCreateParams.Bodypublic final classCardCreateParams.BillingAddressThe card's billing address.
public final classCardCreateParams.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the card should belong to. final Optional<CardCreateParams.BillingAddress>billingAddress()The card's billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardCreateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<CardCreateParams.BillingAddress>_billingAddress()Returns the raw JSON value of billingAddress. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<CardCreateParams.DigitalWallet>_digitalWallet()Returns the raw JSON value of digitalWallet. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardCreateParams.BuildertoBuilder()final CardCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardCreateParams. -
-
Method Detail
-
billingAddress
final Optional<CardCreateParams.BillingAddress> billingAddress()
The card's billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardCreateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddress
final JsonField<CardCreateParams.BillingAddress> _billingAddress()
Returns the raw JSON value of billingAddress.
Unlike billingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<CardCreateParams.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardCreateParams.Builder toBuilder()
-
_body
final CardCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardCreateParams.
The following fields are required:
.accountId()
-
-
-
-