Class CardCreateParams.Body
-
- All Implemented Interfaces:
public final class CardCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the card should belong to. final Optional<CardCreateParams.AuthorizationControls>authorizationControls()Controls that restrict how this card can be used. final Optional<CardCreateParams.BillingAddress>billingAddress()The card's billing address. final Optional<String>description()The description you choose to give the card. final Optional<CardCreateParams.DigitalWallet>digitalWallet()The contact information used in the two-factor steps for digital wallet card creation. final Optional<String>entityId()The Entity the card belongs to. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<CardCreateParams.AuthorizationControls>_authorizationControls()Returns the raw JSON value of authorizationControls. final JsonField<CardCreateParams.BillingAddress>_billingAddress()Returns the raw JSON value of billingAddress. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<CardCreateParams.DigitalWallet>_digitalWallet()Returns the raw JSON value of digitalWallet. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalProperties()final CardCreateParams.Body.BuildertoBuilder()final CardCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
authorizationControls
final Optional<CardCreateParams.AuthorizationControls> authorizationControls()
Controls that restrict how this card can be used.
-
billingAddress
final Optional<CardCreateParams.BillingAddress> billingAddress()
The card's billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardCreateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. To add the card to a digital wallet, you may supply an email or phone number with this request. Otherwise, subscribe and then action a Real Time Decision with the category
digital_wallet_token_requestedordigital_wallet_authentication_requested.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_authorizationControls
final JsonField<CardCreateParams.AuthorizationControls> _authorizationControls()
Returns the raw JSON value of authorizationControls.
Unlike authorizationControls, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddress
final JsonField<CardCreateParams.BillingAddress> _billingAddress()
Returns the raw JSON value of billingAddress.
Unlike billingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<CardCreateParams.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardCreateParams.Body.Builder toBuilder()
-
validate
final CardCreateParams.Body validate()
-
builder
final static CardCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId()
-
-
-
-