Class CardDetails
-
- All Implemented Interfaces:
public final class CardDetailsAn object containing the sensitive details (card number, CVC, PIN, etc) for a Card. These details are not included in the Card object. If you'd prefer to never access these details directly, you can use the /documentation/embedded-card-component to display the information to your users.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDetails.BuilderA builder for CardDetails.
public final classCardDetails.TypeA constant representing the object's type. For this resource it will always be
card_details.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier for the Card for which sensitive details have been returned. final LongexpirationMonth()The month the card expires in M format (e.g., August is 8). final LongexpirationYear()The year the card expires in YYYY format (e.g., 2025). final Stringpin()The 4-digit PIN for the card, for use with ATMs. final StringprimaryAccountNumber()The card number. final CardDetails.Typetype()A constant representing the object's type. final StringverificationCode()The three-digit verification code for the card. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<Long>_expirationMonth()Returns the raw JSON value of expirationMonth. final JsonField<Long>_expirationYear()Returns the raw JSON value of expirationYear. final JsonField<String>_pin()Returns the raw JSON value of pin. final JsonField<String>_primaryAccountNumber()Returns the raw JSON value of primaryAccountNumber. final JsonField<CardDetails.Type>_type()Returns the raw JSON value of type. final JsonField<String>_verificationCode()Returns the raw JSON value of verificationCode. final Map<String, JsonValue>_additionalProperties()final CardDetails.BuildertoBuilder()final CardDetailsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardDetails.Builderbuilder()Returns a mutable builder for constructing an instance of CardDetails. -
-
Method Detail
-
cardId
final String cardId()
The identifier for the Card for which sensitive details have been returned.
-
expirationMonth
final Long expirationMonth()
The month the card expires in M format (e.g., August is 8).
-
expirationYear
final Long expirationYear()
The year the card expires in YYYY format (e.g., 2025).
-
primaryAccountNumber
final String primaryAccountNumber()
The card number.
-
type
final CardDetails.Type type()
A constant representing the object's type. For this resource it will always be
card_details.
-
verificationCode
final String verificationCode()
The three-digit verification code for the card. It's also known as the Card Verification Code (CVC), the Card Verification Value (CVV), or the Card Identification (CID).
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationMonth
final JsonField<Long> _expirationMonth()
Returns the raw JSON value of expirationMonth.
Unlike expirationMonth, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationYear
final JsonField<Long> _expirationYear()
Returns the raw JSON value of expirationYear.
Unlike expirationYear, this method doesn't throw if the JSON field has an unexpected type.
-
_pin
final JsonField<String> _pin()
Returns the raw JSON value of pin.
Unlike pin, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryAccountNumber
final JsonField<String> _primaryAccountNumber()
Returns the raw JSON value of primaryAccountNumber.
Unlike primaryAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardDetails.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_verificationCode
final JsonField<String> _verificationCode()
Returns the raw JSON value of verificationCode.
Unlike verificationCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardDetails.Builder toBuilder()
-
validate
final CardDetails validate()
-
builder
final static CardDetails.Builder builder()
Returns a mutable builder for constructing an instance of CardDetails.
The following fields are required:
.cardId() .expirationMonth() .expirationYear() .pin() .primaryAccountNumber() .type() .verificationCode()
-
-
-
-