Class CardUpdateParams.AuthorizationControls
-
- All Implemented Interfaces:
public final class CardUpdateParams.AuthorizationControlsControls that restrict how this card can be used.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.AuthorizationControls.BuilderA builder for AuthorizationControls.
public final classCardUpdateParams.AuthorizationControls.MaximumAuthorizationCountLimits the number of authorizations that can be approved on this card.
public final classCardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifierRestricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
public final classCardUpdateParams.AuthorizationControls.MerchantCategoryCodeRestricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
public final classCardUpdateParams.AuthorizationControls.MerchantCountryRestricts which merchant countries are allowed or blocked for authorizations on this card.
public final classCardUpdateParams.AuthorizationControls.SpendingLimit
-
Method Summary
-
-
Method Detail
-
maximumAuthorizationCount
final Optional<CardUpdateParams.AuthorizationControls.MaximumAuthorizationCount> maximumAuthorizationCount()
Limits the number of authorizations that can be approved on this card.
-
merchantAcceptorIdentifier
final Optional<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier> merchantAcceptorIdentifier()
Restricts which Merchant Acceptor IDs are allowed or blocked for authorizations on this card.
-
merchantCategoryCode
final Optional<CardUpdateParams.AuthorizationControls.MerchantCategoryCode> merchantCategoryCode()
Restricts which Merchant Category Codes are allowed or blocked for authorizations on this card.
-
merchantCountry
final Optional<CardUpdateParams.AuthorizationControls.MerchantCountry> merchantCountry()
Restricts which merchant countries are allowed or blocked for authorizations on this card.
-
spendingLimits
final Optional<List<CardUpdateParams.AuthorizationControls.SpendingLimit>> spendingLimits()
Spending limits for this card. The most restrictive limit applies if multiple limits match.
-
_maximumAuthorizationCount
final JsonField<CardUpdateParams.AuthorizationControls.MaximumAuthorizationCount> _maximumAuthorizationCount()
Returns the raw JSON value of maximumAuthorizationCount.
Unlike maximumAuthorizationCount, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorIdentifier
final JsonField<CardUpdateParams.AuthorizationControls.MerchantAcceptorIdentifier> _merchantAcceptorIdentifier()
Returns the raw JSON value of merchantAcceptorIdentifier.
Unlike merchantAcceptorIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<CardUpdateParams.AuthorizationControls.MerchantCategoryCode> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<CardUpdateParams.AuthorizationControls.MerchantCountry> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_spendingLimits
final JsonField<List<CardUpdateParams.AuthorizationControls.SpendingLimit>> _spendingLimits()
Returns the raw JSON value of spendingLimits.
Unlike spendingLimits, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.AuthorizationControls.Builder toBuilder()
-
validate
final CardUpdateParams.AuthorizationControls validate()
-
builder
final static CardUpdateParams.AuthorizationControls.Builder builder()
Returns a mutable builder for constructing an instance of AuthorizationControls.
-
-
-
-