Class CardUpdateParams.Body
-
- All Implemented Interfaces:
public final class CardUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
authorizationControls
final Optional<CardUpdateParams.AuthorizationControls> authorizationControls()
Controls that restrict how this card can be used.
-
billingAddress
final Optional<CardUpdateParams.BillingAddress> billingAddress()
The card's updated billing address.
-
description
final Optional<String> description()
The description you choose to give the card.
-
digitalWallet
final Optional<CardUpdateParams.DigitalWallet> digitalWallet()
The contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
entityId
final Optional<String> entityId()
The Entity the card belongs to. You only need to supply this in rare situations when the card is not for the Account holder.
-
status
final Optional<CardUpdateParams.Status> status()
The status to update the Card with.
-
_authorizationControls
final JsonField<CardUpdateParams.AuthorizationControls> _authorizationControls()
Returns the raw JSON value of authorizationControls.
Unlike authorizationControls, this method doesn't throw if the JSON field has an unexpected type.
-
_billingAddress
final JsonField<CardUpdateParams.BillingAddress> _billingAddress()
Returns the raw JSON value of billingAddress.
Unlike billingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<CardUpdateParams.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CardUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.Body.Builder toBuilder()
-
validate
final CardUpdateParams.Body validate()
-
builder
final static CardUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-