Class CardUpdateParams.DigitalWallet
-
- All Implemented Interfaces:
public final class CardUpdateParams.DigitalWalletThe contact information used in the two-factor steps for digital wallet card creation. At least one field must be present to complete the digital wallet steps.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardUpdateParams.DigitalWallet.BuilderA builder for DigitalWallet.
-
Method Summary
Modifier and Type Method Description final Optional<String>digitalCardProfileId()The digital card profile assigned to this digital card. final Optional<String>email()An email address that can be used to verify the cardholder via one-time passcode over email. final Optional<String>phone()A phone number that can be used to verify the cardholder via one-time passcode over SMS. final JsonField<String>_digitalCardProfileId()Returns the raw JSON value of digitalCardProfileId. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_phone()Returns the raw JSON value of phone. final Map<String, JsonValue>_additionalProperties()final CardUpdateParams.DigitalWallet.BuildertoBuilder()final CardUpdateParams.DigitalWalletvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardUpdateParams.DigitalWallet.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalWallet. -
-
Method Detail
-
digitalCardProfileId
final Optional<String> digitalCardProfileId()
The digital card profile assigned to this digital card.
-
email
final Optional<String> email()
An email address that can be used to verify the cardholder via one-time passcode over email.
-
phone
final Optional<String> phone()
A phone number that can be used to verify the cardholder via one-time passcode over SMS.
-
_digitalCardProfileId
final JsonField<String> _digitalCardProfileId()
Returns the raw JSON value of digitalCardProfileId.
Unlike digitalCardProfileId, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_phone
final JsonField<String> _phone()
Returns the raw JSON value of phone.
Unlike phone, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardUpdateParams.DigitalWallet.Builder toBuilder()
-
validate
final CardUpdateParams.DigitalWallet validate()
-
builder
final static CardUpdateParams.DigitalWallet.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWallet.
-
-
-
-