Class CardTokenCapabilities
-
- All Implemented Interfaces:
public final class CardTokenCapabilitiesThe capabilities of a Card Token describe whether the card can be used for specific operations, such as Card Push Transfers. The capabilities can change over time based on the issuing bank's configuration of the card range.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenCapabilities.BuilderA builder for CardTokenCapabilities.
public final classCardTokenCapabilities.Routepublic final classCardTokenCapabilities.TypeA constant representing the object's type. For this resource it will always be
card_token_capabilities.
-
Method Summary
Modifier and Type Method Description final List<CardTokenCapabilities.Route>routes()Each route represent a path e.g., a push transfer can take. final CardTokenCapabilities.Typetype()A constant representing the object's type. final JsonField<List<CardTokenCapabilities.Route>>_routes()Returns the raw JSON value of routes. final JsonField<CardTokenCapabilities.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CardTokenCapabilities.BuildertoBuilder()final CardTokenCapabilitiesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenCapabilities.Builderbuilder()Returns a mutable builder for constructing an instance of CardTokenCapabilities. -
-
Method Detail
-
routes
final List<CardTokenCapabilities.Route> routes()
Each route represent a path e.g., a push transfer can take.
-
type
final CardTokenCapabilities.Type type()
A constant representing the object's type. For this resource it will always be
card_token_capabilities.
-
_routes
final JsonField<List<CardTokenCapabilities.Route>> _routes()
Returns the raw JSON value of routes.
Unlike routes, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CardTokenCapabilities.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardTokenCapabilities.Builder toBuilder()
-
validate
final CardTokenCapabilities validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CardTokenCapabilities.Builder builder()
Returns a mutable builder for constructing an instance of CardTokenCapabilities.
The following fields are required:
.routes() .type()
-
-
-
-