Class CardValidation.Decline
-
- All Implemented Interfaces:
public final class CardValidation.DeclineIf the validation is rejected by the card network or the destination financial institution, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidation.Decline.BuilderA builder for Decline.
public final classCardValidation.Decline.ReasonThe reason why the validation was declined.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimedeclinedAt()The ISO 8601 date and time at which the validation was declined. final Optional<String>networkTransactionIdentifier()A unique identifier for the transaction on the card network. final CardValidation.Decline.Reasonreason()The reason why the validation was declined. final JsonField<OffsetDateTime>_declinedAt()Returns the raw JSON value of declinedAt. final JsonField<String>_networkTransactionIdentifier()Returns the raw JSON value of networkTransactionIdentifier. final JsonField<CardValidation.Decline.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final CardValidation.Decline.BuildertoBuilder()final CardValidation.Declinevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidation.Decline.Builderbuilder()Returns a mutable builder for constructing an instance of Decline. -
-
Method Detail
-
declinedAt
final OffsetDateTime declinedAt()
The ISO 8601 date and time at which the validation was declined.
-
networkTransactionIdentifier
final Optional<String> networkTransactionIdentifier()
A unique identifier for the transaction on the card network.
-
reason
final CardValidation.Decline.Reason reason()
The reason why the validation was declined.
-
_declinedAt
final JsonField<OffsetDateTime> _declinedAt()
Returns the raw JSON value of declinedAt.
Unlike declinedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_networkTransactionIdentifier
final JsonField<String> _networkTransactionIdentifier()
Returns the raw JSON value of networkTransactionIdentifier.
Unlike networkTransactionIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<CardValidation.Decline.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidation.Decline.Builder toBuilder()
-
validate
final CardValidation.Decline validate()
-
builder
final static CardValidation.Decline.Builder builder()
Returns a mutable builder for constructing an instance of Decline.
The following fields are required:
.declinedAt() .networkTransactionIdentifier() .reason()
-
-
-
-