Class CardValidation.Submission
-
- All Implemented Interfaces:
public final class CardValidation.SubmissionAfter the validation is submitted to the card network, this will contain supplemental details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardValidation.Submission.BuilderA builder for Submission.
-
Method Summary
Modifier and Type Method Description final StringretrievalReferenceNumber()A 12-digit retrieval reference number that identifies the validation. final OffsetDateTimesubmittedAt()The ISO 8601 date and time at which the validation was submitted to the card network. final StringtraceNumber()A 6-digit trace number that identifies the validation within a short time window. final JsonField<String>_retrievalReferenceNumber()Returns the raw JSON value of retrievalReferenceNumber. final JsonField<OffsetDateTime>_submittedAt()Returns the raw JSON value of submittedAt. final JsonField<String>_traceNumber()Returns the raw JSON value of traceNumber. final Map<String, JsonValue>_additionalProperties()final CardValidation.Submission.BuildertoBuilder()final CardValidation.Submissionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardValidation.Submission.Builderbuilder()Returns a mutable builder for constructing an instance of Submission. -
-
Method Detail
-
retrievalReferenceNumber
final String retrievalReferenceNumber()
A 12-digit retrieval reference number that identifies the validation. Usually a combination of a timestamp and the trace number.
-
submittedAt
final OffsetDateTime submittedAt()
The ISO 8601 date and time at which the validation was submitted to the card network.
-
traceNumber
final String traceNumber()
A 6-digit trace number that identifies the validation within a short time window.
-
_retrievalReferenceNumber
final JsonField<String> _retrievalReferenceNumber()
Returns the raw JSON value of retrievalReferenceNumber.
Unlike retrievalReferenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_submittedAt
final JsonField<OffsetDateTime> _submittedAt()
Returns the raw JSON value of submittedAt.
Unlike submittedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_traceNumber
final JsonField<String> _traceNumber()
Returns the raw JSON value of traceNumber.
Unlike traceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardValidation.Submission.Builder toBuilder()
-
validate
final CardValidation.Submission validate()
-
builder
final static CardValidation.Submission.Builder builder()
Returns a mutable builder for constructing an instance of Submission.
The following fields are required:
.retrievalReferenceNumber() .submittedAt() .traceNumber()
-
-
-
-