Class CheckTransfer.Builder
-
- All Implemented Interfaces:
public final class CheckTransfer.BuilderA builder for CheckTransfer.
-
-
Method Summary
Modifier and Type Method Description final CheckTransfer.Builderid(String id)The Check transfer's identifier. final CheckTransfer.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final CheckTransfer.BuilderaccountId(String accountId)The identifier of the Account from which funds will be transferred. final CheckTransfer.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final CheckTransfer.BuilderaccountNumber(String accountNumber)The account number printed on the check. final CheckTransfer.BuilderaccountNumber(JsonField<String> accountNumber)Sets Builder.accountNumber to an arbitrary JSON value. final CheckTransfer.Builderamount(Long amount)The transfer amount in USD cents. final CheckTransfer.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final CheckTransfer.Builderapproval(CheckTransfer.Approval approval)If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final CheckTransfer.Builderapproval(Optional<CheckTransfer.Approval> approval)Alias for calling Builder.approval with approval.orElse(null).final CheckTransfer.Builderapproval(JsonField<CheckTransfer.Approval> approval)Sets Builder.approval to an arbitrary JSON value. final CheckTransfer.BuilderapprovedInboundCheckDepositId(String approvedInboundCheckDepositId)If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit. final CheckTransfer.BuilderapprovedInboundCheckDepositId(Optional<String> approvedInboundCheckDepositId)Alias for calling Builder.approvedInboundCheckDepositId with approvedInboundCheckDepositId.orElse(null).final CheckTransfer.BuilderapprovedInboundCheckDepositId(JsonField<String> approvedInboundCheckDepositId)Sets Builder.approvedInboundCheckDepositId to an arbitrary JSON value. final CheckTransfer.BuilderbalanceCheck(CheckTransfer.BalanceCheck balanceCheck)How the account's available balance should be checked. final CheckTransfer.BuilderbalanceCheck(Optional<CheckTransfer.BalanceCheck> balanceCheck)Alias for calling Builder.balanceCheck with balanceCheck.orElse(null).final CheckTransfer.BuilderbalanceCheck(JsonField<CheckTransfer.BalanceCheck> balanceCheck)Sets Builder.balanceCheck to an arbitrary JSON value. final CheckTransfer.Buildercancellation(CheckTransfer.Cancellation cancellation)If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final CheckTransfer.Buildercancellation(Optional<CheckTransfer.Cancellation> cancellation)Alias for calling Builder.cancellation with cancellation.orElse(null).final CheckTransfer.Buildercancellation(JsonField<CheckTransfer.Cancellation> cancellation)Sets Builder.cancellation to an arbitrary JSON value. final CheckTransfer.BuildercheckNumber(String checkNumber)The check number printed on the check. final CheckTransfer.BuildercheckNumber(JsonField<String> checkNumber)Sets Builder.checkNumber to an arbitrary JSON value. final CheckTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the transfer was created. final CheckTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final CheckTransfer.BuildercreatedBy(CheckTransfer.CreatedBy createdBy)What object created the transfer, either via the API or the dashboard. final CheckTransfer.BuildercreatedBy(Optional<CheckTransfer.CreatedBy> createdBy)Alias for calling Builder.createdBy with createdBy.orElse(null).final CheckTransfer.BuildercreatedBy(JsonField<CheckTransfer.CreatedBy> createdBy)Sets Builder.createdBy to an arbitrary JSON value. final CheckTransfer.Buildercurrency(CheckTransfer.Currency currency)The ISO 4217 code for the check's currency. final CheckTransfer.Buildercurrency(JsonField<CheckTransfer.Currency> currency)Sets Builder.currency to an arbitrary JSON value. final CheckTransfer.BuilderfulfillmentMethod(CheckTransfer.FulfillmentMethod fulfillmentMethod)Whether Increase will print and mail the check or if you will do it yourself. final CheckTransfer.BuilderfulfillmentMethod(JsonField<CheckTransfer.FulfillmentMethod> fulfillmentMethod)Sets Builder.fulfillmentMethod to an arbitrary JSON value. final CheckTransfer.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final CheckTransfer.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final CheckTransfer.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final CheckTransfer.Buildermailing(CheckTransfer.Mailing mailing)If the check has been mailed by Increase, this will contain details of the shipment. final CheckTransfer.Buildermailing(Optional<CheckTransfer.Mailing> mailing)Alias for calling Builder.mailing with mailing.orElse(null).final CheckTransfer.Buildermailing(JsonField<CheckTransfer.Mailing> mailing)Sets Builder.mailing to an arbitrary JSON value. final CheckTransfer.BuilderpendingTransactionId(String pendingTransactionId)The ID for the pending transaction representing the transfer. final CheckTransfer.BuilderpendingTransactionId(Optional<String> pendingTransactionId)Alias for calling Builder.pendingTransactionId with pendingTransactionId.orElse(null).final CheckTransfer.BuilderpendingTransactionId(JsonField<String> pendingTransactionId)Sets Builder.pendingTransactionId to an arbitrary JSON value. final CheckTransfer.BuilderphysicalCheck(CheckTransfer.PhysicalCheck physicalCheck)Details relating to the physical check that Increase will print and mail. final CheckTransfer.BuilderphysicalCheck(Optional<CheckTransfer.PhysicalCheck> physicalCheck)Alias for calling Builder.physicalCheck with physicalCheck.orElse(null).final CheckTransfer.BuilderphysicalCheck(JsonField<CheckTransfer.PhysicalCheck> physicalCheck)Sets Builder.physicalCheck to an arbitrary JSON value. final CheckTransfer.BuilderroutingNumber(String routingNumber)The routing number printed on the check. final CheckTransfer.BuilderroutingNumber(JsonField<String> routingNumber)Sets Builder.routingNumber to an arbitrary JSON value. final CheckTransfer.BuildersourceAccountNumberId(String sourceAccountNumberId)The identifier of the Account Number from which to send the transfer and print on the check. final CheckTransfer.BuildersourceAccountNumberId(Optional<String> sourceAccountNumberId)Alias for calling Builder.sourceAccountNumberId with sourceAccountNumberId.orElse(null).final CheckTransfer.BuildersourceAccountNumberId(JsonField<String> sourceAccountNumberId)Sets Builder.sourceAccountNumberId to an arbitrary JSON value. final CheckTransfer.Builderstatus(CheckTransfer.Status status)The lifecycle status of the transfer. final CheckTransfer.Builderstatus(JsonField<CheckTransfer.Status> status)Sets Builder.status to an arbitrary JSON value. final CheckTransfer.BuilderstopPaymentRequest(CheckTransfer.StopPaymentRequest stopPaymentRequest)After a stop-payment is requested on the check, this will contain supplemental details. final CheckTransfer.BuilderstopPaymentRequest(Optional<CheckTransfer.StopPaymentRequest> stopPaymentRequest)Alias for calling Builder.stopPaymentRequest with stopPaymentRequest.orElse(null).final CheckTransfer.BuilderstopPaymentRequest(JsonField<CheckTransfer.StopPaymentRequest> stopPaymentRequest)Sets Builder.stopPaymentRequest to an arbitrary JSON value. final CheckTransfer.Buildersubmission(CheckTransfer.Submission submission)After the transfer is submitted, this will contain supplemental details. final CheckTransfer.Buildersubmission(Optional<CheckTransfer.Submission> submission)Alias for calling Builder.submission with submission.orElse(null).final CheckTransfer.Buildersubmission(JsonField<CheckTransfer.Submission> submission)Sets Builder.submission to an arbitrary JSON value. final CheckTransfer.BuilderthirdParty(CheckTransfer.ThirdParty thirdParty)Details relating to the custom fulfillment you will perform. final CheckTransfer.BuilderthirdParty(Optional<CheckTransfer.ThirdParty> thirdParty)Alias for calling Builder.thirdParty with thirdParty.orElse(null).final CheckTransfer.BuilderthirdParty(JsonField<CheckTransfer.ThirdParty> thirdParty)Sets Builder.thirdParty to an arbitrary JSON value. final CheckTransfer.Buildertype(CheckTransfer.Type type)A constant representing the object's type. final CheckTransfer.Buildertype(JsonField<CheckTransfer.Type> type)Sets Builder.type to an arbitrary JSON value. final CheckTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final CheckTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final CheckTransfer.BuilderremoveAdditionalProperty(String key)final CheckTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final CheckTransferbuild()Returns an immutable instance of CheckTransfer. -
-
Method Detail
-
id
final CheckTransfer.Builder id(String id)
The Check transfer's identifier.
-
id
final CheckTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final CheckTransfer.Builder accountId(String accountId)
The identifier of the Account from which funds will be transferred.
-
accountId
final CheckTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final CheckTransfer.Builder accountNumber(String accountNumber)
The account number printed on the check.
-
accountNumber
final CheckTransfer.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final CheckTransfer.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final CheckTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approval
final CheckTransfer.Builder approval(CheckTransfer.Approval approval)
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
approval
final CheckTransfer.Builder approval(Optional<CheckTransfer.Approval> approval)
Alias for calling Builder.approval with
approval.orElse(null).
-
approval
final CheckTransfer.Builder approval(JsonField<CheckTransfer.Approval> approval)
Sets Builder.approval to an arbitrary JSON value.
You should usually call Builder.approval with a well-typed Approval value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
approvedInboundCheckDepositId
final CheckTransfer.Builder approvedInboundCheckDepositId(String approvedInboundCheckDepositId)
If the Check Transfer was successfully deposited, this will contain the identifier of the Inbound Check Deposit object with details of the deposit.
-
approvedInboundCheckDepositId
final CheckTransfer.Builder approvedInboundCheckDepositId(Optional<String> approvedInboundCheckDepositId)
Alias for calling Builder.approvedInboundCheckDepositId with
approvedInboundCheckDepositId.orElse(null).
-
approvedInboundCheckDepositId
final CheckTransfer.Builder approvedInboundCheckDepositId(JsonField<String> approvedInboundCheckDepositId)
Sets Builder.approvedInboundCheckDepositId to an arbitrary JSON value.
You should usually call Builder.approvedInboundCheckDepositId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balanceCheck
final CheckTransfer.Builder balanceCheck(CheckTransfer.BalanceCheck balanceCheck)
How the account's available balance should be checked.
-
balanceCheck
final CheckTransfer.Builder balanceCheck(Optional<CheckTransfer.BalanceCheck> balanceCheck)
Alias for calling Builder.balanceCheck with
balanceCheck.orElse(null).
-
balanceCheck
final CheckTransfer.Builder balanceCheck(JsonField<CheckTransfer.BalanceCheck> balanceCheck)
Sets Builder.balanceCheck to an arbitrary JSON value.
You should usually call Builder.balanceCheck with a well-typed BalanceCheck value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cancellation
final CheckTransfer.Builder cancellation(CheckTransfer.Cancellation cancellation)
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
cancellation
final CheckTransfer.Builder cancellation(Optional<CheckTransfer.Cancellation> cancellation)
Alias for calling Builder.cancellation with
cancellation.orElse(null).
-
cancellation
final CheckTransfer.Builder cancellation(JsonField<CheckTransfer.Cancellation> cancellation)
Sets Builder.cancellation to an arbitrary JSON value.
You should usually call Builder.cancellation with a well-typed Cancellation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkNumber
final CheckTransfer.Builder checkNumber(String checkNumber)
The check number printed on the check.
-
checkNumber
final CheckTransfer.Builder checkNumber(JsonField<String> checkNumber)
Sets Builder.checkNumber to an arbitrary JSON value.
You should usually call Builder.checkNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final CheckTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the transfer was created.
-
createdAt
final CheckTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdBy
final CheckTransfer.Builder createdBy(CheckTransfer.CreatedBy createdBy)
What object created the transfer, either via the API or the dashboard.
-
createdBy
final CheckTransfer.Builder createdBy(Optional<CheckTransfer.CreatedBy> createdBy)
Alias for calling Builder.createdBy with
createdBy.orElse(null).
-
createdBy
final CheckTransfer.Builder createdBy(JsonField<CheckTransfer.CreatedBy> createdBy)
Sets Builder.createdBy to an arbitrary JSON value.
You should usually call Builder.createdBy with a well-typed CreatedBy value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final CheckTransfer.Builder currency(CheckTransfer.Currency currency)
The ISO 4217 code for the check's currency.
-
currency
final CheckTransfer.Builder currency(JsonField<CheckTransfer.Currency> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed Currency value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fulfillmentMethod
final CheckTransfer.Builder fulfillmentMethod(CheckTransfer.FulfillmentMethod fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
fulfillmentMethod
final CheckTransfer.Builder fulfillmentMethod(JsonField<CheckTransfer.FulfillmentMethod> fulfillmentMethod)
Sets Builder.fulfillmentMethod to an arbitrary JSON value.
You should usually call Builder.fulfillmentMethod with a well-typed FulfillmentMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final CheckTransfer.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final CheckTransfer.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final CheckTransfer.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mailing
final CheckTransfer.Builder mailing(CheckTransfer.Mailing mailing)
If the check has been mailed by Increase, this will contain details of the shipment.
-
mailing
final CheckTransfer.Builder mailing(Optional<CheckTransfer.Mailing> mailing)
Alias for calling Builder.mailing with
mailing.orElse(null).
-
mailing
final CheckTransfer.Builder mailing(JsonField<CheckTransfer.Mailing> mailing)
Sets Builder.mailing to an arbitrary JSON value.
You should usually call Builder.mailing with a well-typed Mailing value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pendingTransactionId
final CheckTransfer.Builder pendingTransactionId(String pendingTransactionId)
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
pendingTransactionId
final CheckTransfer.Builder pendingTransactionId(Optional<String> pendingTransactionId)
Alias for calling Builder.pendingTransactionId with
pendingTransactionId.orElse(null).
-
pendingTransactionId
final CheckTransfer.Builder pendingTransactionId(JsonField<String> pendingTransactionId)
Sets Builder.pendingTransactionId to an arbitrary JSON value.
You should usually call Builder.pendingTransactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCheck
final CheckTransfer.Builder physicalCheck(CheckTransfer.PhysicalCheck physicalCheck)
Details relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
physicalCheck
final CheckTransfer.Builder physicalCheck(Optional<CheckTransfer.PhysicalCheck> physicalCheck)
Alias for calling Builder.physicalCheck with
physicalCheck.orElse(null).
-
physicalCheck
final CheckTransfer.Builder physicalCheck(JsonField<CheckTransfer.PhysicalCheck> physicalCheck)
Sets Builder.physicalCheck to an arbitrary JSON value.
You should usually call Builder.physicalCheck with a well-typed PhysicalCheck value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final CheckTransfer.Builder routingNumber(String routingNumber)
The routing number printed on the check.
-
routingNumber
final CheckTransfer.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final CheckTransfer.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
sourceAccountNumberId
final CheckTransfer.Builder sourceAccountNumberId(Optional<String> sourceAccountNumberId)
Alias for calling Builder.sourceAccountNumberId with
sourceAccountNumberId.orElse(null).
-
sourceAccountNumberId
final CheckTransfer.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final CheckTransfer.Builder status(CheckTransfer.Status status)
The lifecycle status of the transfer.
-
status
final CheckTransfer.Builder status(JsonField<CheckTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
stopPaymentRequest
final CheckTransfer.Builder stopPaymentRequest(CheckTransfer.StopPaymentRequest stopPaymentRequest)
After a stop-payment is requested on the check, this will contain supplemental details.
-
stopPaymentRequest
final CheckTransfer.Builder stopPaymentRequest(Optional<CheckTransfer.StopPaymentRequest> stopPaymentRequest)
Alias for calling Builder.stopPaymentRequest with
stopPaymentRequest.orElse(null).
-
stopPaymentRequest
final CheckTransfer.Builder stopPaymentRequest(JsonField<CheckTransfer.StopPaymentRequest> stopPaymentRequest)
Sets Builder.stopPaymentRequest to an arbitrary JSON value.
You should usually call Builder.stopPaymentRequest with a well-typed StopPaymentRequest value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submission
final CheckTransfer.Builder submission(CheckTransfer.Submission submission)
After the transfer is submitted, this will contain supplemental details.
-
submission
final CheckTransfer.Builder submission(Optional<CheckTransfer.Submission> submission)
Alias for calling Builder.submission with
submission.orElse(null).
-
submission
final CheckTransfer.Builder submission(JsonField<CheckTransfer.Submission> submission)
Sets Builder.submission to an arbitrary JSON value.
You should usually call Builder.submission with a well-typed Submission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
thirdParty
final CheckTransfer.Builder thirdParty(CheckTransfer.ThirdParty thirdParty)
Details relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
thirdParty
final CheckTransfer.Builder thirdParty(Optional<CheckTransfer.ThirdParty> thirdParty)
Alias for calling Builder.thirdParty with
thirdParty.orElse(null).
-
thirdParty
final CheckTransfer.Builder thirdParty(JsonField<CheckTransfer.ThirdParty> thirdParty)
Sets Builder.thirdParty to an arbitrary JSON value.
You should usually call Builder.thirdParty with a well-typed ThirdParty value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final CheckTransfer.Builder type(CheckTransfer.Type type)
A constant representing the object's type. For this resource it will always be
check_transfer.
-
type
final CheckTransfer.Builder type(JsonField<CheckTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransfer build()
Returns an immutable instance of CheckTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .accountNumber() .amount() .approval() .approvedInboundCheckDepositId() .balanceCheck() .cancellation() .checkNumber() .createdAt() .createdBy() .currency() .fulfillmentMethod() .idempotencyKey() .mailing() .pendingTransactionId() .physicalCheck() .routingNumber() .sourceAccountNumberId() .status() .stopPaymentRequest() .submission() .thirdParty() .type()
-
-
-
-