Class CheckTransfer.Cancellation
-
- All Implemented Interfaces:
public final class CheckTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Cancellation.BuilderA builder for Cancellation.
-
Method Summary
Modifier and Type Method Description final OffsetDateTimecanceledAt()The ISO 8601 date and time at which the Transfer was canceled. final Optional<String>canceledBy()If the Transfer was canceled by a user in the dashboard, the email address of that user. final JsonField<OffsetDateTime>_canceledAt()Returns the raw JSON value of canceledAt. final JsonField<String>_canceledBy()Returns the raw JSON value of canceledBy. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Cancellation.BuildertoBuilder()final CheckTransfer.Cancellationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Cancellation.Builderbuilder()Returns a mutable builder for constructing an instance of Cancellation. -
-
Method Detail
-
canceledAt
final OffsetDateTime canceledAt()
The ISO 8601 date and time at which the Transfer was canceled.
-
canceledBy
final Optional<String> canceledBy()
If the Transfer was canceled by a user in the dashboard, the email address of that user.
-
_canceledAt
final JsonField<OffsetDateTime> _canceledAt()
Returns the raw JSON value of canceledAt.
Unlike canceledAt, this method doesn't throw if the JSON field has an unexpected type.
-
_canceledBy
final JsonField<String> _canceledBy()
Returns the raw JSON value of canceledBy.
Unlike canceledBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Cancellation.Builder toBuilder()
-
validate
final CheckTransfer.Cancellation validate()
-
builder
final static CheckTransfer.Cancellation.Builder builder()
Returns a mutable builder for constructing an instance of Cancellation.
The following fields are required:
.canceledAt() .canceledBy()
-
-
-
-