Class CheckTransfer.Mailing
-
- All Implemented Interfaces:
public final class CheckTransfer.MailingIf the check has been mailed by Increase, this will contain details of the shipment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Mailing.BuilderA builder for Mailing.
-
Method Summary
Modifier and Type Method Description final Optional<String>imageId()The ID of the file corresponding to an image of the check that was mailed, if available. final OffsetDateTimemailedAt()The ISO 8601 date and time at which the check was mailed. final Optional<String>trackingNumber()The tracking number of the shipment, if available for the shipping method. final JsonField<String>_imageId()Returns the raw JSON value of imageId. final JsonField<OffsetDateTime>_mailedAt()Returns the raw JSON value of mailedAt. final JsonField<String>_trackingNumber()Returns the raw JSON value of trackingNumber. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Mailing.BuildertoBuilder()final CheckTransfer.Mailingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Mailing.Builderbuilder()Returns a mutable builder for constructing an instance of Mailing. -
-
Method Detail
-
imageId
final Optional<String> imageId()
The ID of the file corresponding to an image of the check that was mailed, if available.
-
mailedAt
final OffsetDateTime mailedAt()
The ISO 8601 date and time at which the check was mailed.
-
trackingNumber
final Optional<String> trackingNumber()
The tracking number of the shipment, if available for the shipping method.
-
_imageId
final JsonField<String> _imageId()
Returns the raw JSON value of imageId.
Unlike imageId, this method doesn't throw if the JSON field has an unexpected type.
-
_mailedAt
final JsonField<OffsetDateTime> _mailedAt()
Returns the raw JSON value of mailedAt.
Unlike mailedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_trackingNumber
final JsonField<String> _trackingNumber()
Returns the raw JSON value of trackingNumber.
Unlike trackingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Mailing.Builder toBuilder()
-
validate
final CheckTransfer.Mailing validate()
-
builder
final static CheckTransfer.Mailing.Builder builder()
Returns a mutable builder for constructing an instance of Mailing.
The following fields are required:
.imageId() .mailedAt() .trackingNumber()
-
-
-
-