Class CheckTransfer.PhysicalCheck
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheckDetails relating to the physical check that Increase will print and mail. Will be present if and only if
fulfillment_methodis equal tophysical_check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.PhysicalCheck.BuilderA builder for PhysicalCheck.
public final classCheckTransfer.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
public final classCheckTransfer.PhysicalCheck.ReturnAddressThe return address to be printed on the check.
public final classCheckTransfer.PhysicalCheck.ShippingMethodThe shipping method for the check.
public final classCheckTransfer.PhysicalCheck.TrackingUpdate
-
Method Summary
Modifier and Type Method Description final CheckTransfer.PhysicalCheck.MailingAddressmailingAddress()Details for where Increase will mail the check. final Optional<String>memo()The descriptor that will be printed on the memo field on the check. final Optional<String>note()The descriptor that will be printed on the letter included with the check. final StringrecipientName()The name that will be printed on the check. final Optional<CheckTransfer.PhysicalCheck.ReturnAddress>returnAddress()The return address to be printed on the check. final Optional<CheckTransfer.PhysicalCheck.ShippingMethod>shippingMethod()The shipping method for the check. final Optional<String>signatureText()The text that will appear as the signature on the check in cursive font. final List<CheckTransfer.PhysicalCheck.TrackingUpdate>trackingUpdates()Tracking updates relating to the physical check's delivery. final JsonField<CheckTransfer.PhysicalCheck.MailingAddress>_mailingAddress()Returns the raw JSON value of mailingAddress. final JsonField<String>_memo()Returns the raw JSON value of memo. final JsonField<String>_note()Returns the raw JSON value of note. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<CheckTransfer.PhysicalCheck.ReturnAddress>_returnAddress()Returns the raw JSON value of returnAddress. final JsonField<CheckTransfer.PhysicalCheck.ShippingMethod>_shippingMethod()Returns the raw JSON value of shippingMethod. final JsonField<String>_signatureText()Returns the raw JSON value of signatureText. final JsonField<List<CheckTransfer.PhysicalCheck.TrackingUpdate>>_trackingUpdates()Returns the raw JSON value of trackingUpdates. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.PhysicalCheck.BuildertoBuilder()final CheckTransfer.PhysicalCheckvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.PhysicalCheck.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCheck. -
-
Method Detail
-
mailingAddress
final CheckTransfer.PhysicalCheck.MailingAddress mailingAddress()
Details for where Increase will mail the check.
-
memo
final Optional<String> memo()
The descriptor that will be printed on the memo field on the check.
-
note
final Optional<String> note()
The descriptor that will be printed on the letter included with the check.
-
recipientName
final String recipientName()
The name that will be printed on the check.
-
returnAddress
final Optional<CheckTransfer.PhysicalCheck.ReturnAddress> returnAddress()
The return address to be printed on the check.
-
shippingMethod
final Optional<CheckTransfer.PhysicalCheck.ShippingMethod> shippingMethod()
The shipping method for the check.
-
signatureText
final Optional<String> signatureText()
The text that will appear as the signature on the check in cursive font. If blank, the check will be printed with 'No signature required'.
-
trackingUpdates
final List<CheckTransfer.PhysicalCheck.TrackingUpdate> trackingUpdates()
Tracking updates relating to the physical check's delivery.
-
_mailingAddress
final JsonField<CheckTransfer.PhysicalCheck.MailingAddress> _mailingAddress()
Returns the raw JSON value of mailingAddress.
Unlike mailingAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_memo
final JsonField<String> _memo()
Returns the raw JSON value of memo.
Unlike memo, this method doesn't throw if the JSON field has an unexpected type.
-
_note
final JsonField<String> _note()
Returns the raw JSON value of note.
Unlike note, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_returnAddress
final JsonField<CheckTransfer.PhysicalCheck.ReturnAddress> _returnAddress()
Returns the raw JSON value of returnAddress.
Unlike returnAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_shippingMethod
final JsonField<CheckTransfer.PhysicalCheck.ShippingMethod> _shippingMethod()
Returns the raw JSON value of shippingMethod.
Unlike shippingMethod, this method doesn't throw if the JSON field has an unexpected type.
-
_signatureText
final JsonField<String> _signatureText()
Returns the raw JSON value of signatureText.
Unlike signatureText, this method doesn't throw if the JSON field has an unexpected type.
-
_trackingUpdates
final JsonField<List<CheckTransfer.PhysicalCheck.TrackingUpdate>> _trackingUpdates()
Returns the raw JSON value of trackingUpdates.
Unlike trackingUpdates, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.PhysicalCheck.Builder toBuilder()
-
validate
final CheckTransfer.PhysicalCheck validate()
-
builder
final static CheckTransfer.PhysicalCheck.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCheck.
The following fields are required:
.mailingAddress() .memo() .note() .recipientName() .returnAddress() .shippingMethod() .signatureText() .trackingUpdates()
-
-
-
-