Class CheckTransfer.PhysicalCheck.MailingAddress
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.MailingAddressDetails for where Increase will mail the check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.PhysicalCheck.MailingAddress.BuilderA builder for MailingAddress.
-
Method Summary
Modifier and Type Method Description final Optional<String>city()The city of the check's destination. final Optional<String>line1()The street address of the check's destination. final Optional<String>line2()The second line of the address of the check's destination. final Optional<String>name()The name component of the check's mailing address. final Optional<String>phone()The phone number to be used in case of delivery issues at the check's mailing address. final Optional<String>postalCode()The postal code of the check's destination. final Optional<String>state()The state of the check's destination. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_phone()Returns the raw JSON value of phone. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.PhysicalCheck.MailingAddress.BuildertoBuilder()final CheckTransfer.PhysicalCheck.MailingAddressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.PhysicalCheck.MailingAddress.Builderbuilder()Returns a mutable builder for constructing an instance of MailingAddress. -
-
Method Detail
-
phone
final Optional<String> phone()
The phone number to be used in case of delivery issues at the check's mailing address. Only used for FedEx overnight shipping.
-
postalCode
final Optional<String> postalCode()
The postal code of the check's destination.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_phone
final JsonField<String> _phone()
Returns the raw JSON value of phone.
Unlike phone, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.PhysicalCheck.MailingAddress.Builder toBuilder()
-
validate
final CheckTransfer.PhysicalCheck.MailingAddress validate()
-
builder
final static CheckTransfer.PhysicalCheck.MailingAddress.Builder builder()
Returns a mutable builder for constructing an instance of MailingAddress.
The following fields are required:
.city() .line1() .line2() .name() .phone() .postalCode() .state()
-
-
-
-