Class CheckTransfer.PhysicalCheck.Signature
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.SignatureThe signature that will appear on the check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.PhysicalCheck.Signature.BuilderA builder for Signature.
-
Method Summary
Modifier and Type Method Description final Optional<String>imageFileId()The ID of a File containing a PNG of the signature. final Optional<String>text()The text that will appear as the signature on the check in cursive font. final JsonField<String>_imageFileId()Returns the raw JSON value of imageFileId. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.PhysicalCheck.Signature.BuildertoBuilder()final CheckTransfer.PhysicalCheck.Signaturevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.PhysicalCheck.Signature.Builderbuilder()Returns a mutable builder for constructing an instance of Signature. -
-
Method Detail
-
imageFileId
final Optional<String> imageFileId()
The ID of a File containing a PNG of the signature.
-
text
final Optional<String> text()
The text that will appear as the signature on the check in cursive font.
-
_imageFileId
final JsonField<String> _imageFileId()
Returns the raw JSON value of imageFileId.
Unlike imageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.PhysicalCheck.Signature.Builder toBuilder()
-
validate
final CheckTransfer.PhysicalCheck.Signature validate()
-
builder
final static CheckTransfer.PhysicalCheck.Signature.Builder builder()
Returns a mutable builder for constructing an instance of Signature.
The following fields are required:
.imageFileId() .text()
-
-
-
-