Class CheckTransfer.PhysicalCheck.TrackingUpdate
-
- All Implemented Interfaces:
public final class CheckTransfer.PhysicalCheck.TrackingUpdate
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.PhysicalCheck.TrackingUpdate.BuilderA builder for TrackingUpdate.
public final classCheckTransfer.PhysicalCheck.TrackingUpdate.CategoryThe type of tracking event.
-
Method Summary
-
-
Method Detail
-
category
final CheckTransfer.PhysicalCheck.TrackingUpdate.Category category()
The type of tracking event.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the tracking event took place.
-
postalCode
final String postalCode()
The postal code where the event took place.
-
_category
final JsonField<CheckTransfer.PhysicalCheck.TrackingUpdate.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.PhysicalCheck.TrackingUpdate.Builder toBuilder()
-
validate
final CheckTransfer.PhysicalCheck.TrackingUpdate validate()
-
builder
final static CheckTransfer.PhysicalCheck.TrackingUpdate.Builder builder()
Returns a mutable builder for constructing an instance of TrackingUpdate.
The following fields are required:
.category() .createdAt() .postalCode()
-
-
-
-