Class CheckTransfer.Submission.SubmittedAddress
-
- All Implemented Interfaces:
public final class CheckTransfer.Submission.SubmittedAddressThe address we submitted to the printer. This is what is physically printed on the check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.Submission.SubmittedAddress.BuilderA builder for SubmittedAddress.
-
Method Summary
Modifier and Type Method Description final Stringcity()The submitted address city. final Stringline1()The submitted address line 1. final Optional<String>line2()The submitted address line 2. final StringrecipientName()The submitted recipient name. final Stringstate()The submitted address state. final Stringzip()The submitted address zip. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<String>_state()Returns the raw JSON value of state. final JsonField<String>_zip()Returns the raw JSON value of zip. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.Submission.SubmittedAddress.BuildertoBuilder()final CheckTransfer.Submission.SubmittedAddressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.Submission.SubmittedAddress.Builderbuilder()Returns a mutable builder for constructing an instance of SubmittedAddress. -
-
Method Detail
-
recipientName
final String recipientName()
The submitted recipient name.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_zip
final JsonField<String> _zip()
Returns the raw JSON value of zip.
Unlike zip, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.Submission.SubmittedAddress.Builder toBuilder()
-
validate
final CheckTransfer.Submission.SubmittedAddress validate()
-
builder
final static CheckTransfer.Submission.SubmittedAddress.Builder builder()
Returns a mutable builder for constructing an instance of SubmittedAddress.
The following fields are required:
.city() .line1() .line2() .recipientName() .state() .zip()
-
-
-
-