Class CheckTransfer.ThirdParty
-
- All Implemented Interfaces:
public final class CheckTransfer.ThirdPartyDetails relating to the custom fulfillment you will perform. Will be present if and only if
fulfillment_methodis equal tothird_party.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransfer.ThirdParty.BuilderA builder for ThirdParty.
-
Method Summary
Modifier and Type Method Description final Optional<String>recipientName()The name that you will print on the check. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final Map<String, JsonValue>_additionalProperties()final CheckTransfer.ThirdParty.BuildertoBuilder()final CheckTransfer.ThirdPartyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransfer.ThirdParty.Builderbuilder()Returns a mutable builder for constructing an instance of ThirdParty. -
-
Method Detail
-
recipientName
final Optional<String> recipientName()
The name that you will print on the check.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransfer.ThirdParty.Builder toBuilder()
-
validate
final CheckTransfer.ThirdParty validate()
-
builder
final static CheckTransfer.ThirdParty.Builder builder()
Returns a mutable builder for constructing an instance of ThirdParty.
The following fields are required:
.recipientName()
-
-
-
-