Class CheckTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final CheckTransferCreateParams.Body.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final CheckTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final CheckTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final CheckTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fulfillmentMethod
final CheckTransferCreateParams.Body.Builder fulfillmentMethod(CheckTransferCreateParams.FulfillmentMethod fulfillmentMethod)
Whether Increase will print and mail the check or if you will do it yourself.
-
fulfillmentMethod
final CheckTransferCreateParams.Body.Builder fulfillmentMethod(JsonField<CheckTransferCreateParams.FulfillmentMethod> fulfillmentMethod)
Sets Builder.fulfillmentMethod to an arbitrary JSON value.
You should usually call Builder.fulfillmentMethod with a well-typed FulfillmentMethod value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final CheckTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The identifier of the Account Number from which to send the transfer and print on the check.
-
sourceAccountNumberId
final CheckTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
checkNumber
final CheckTransferCreateParams.Body.Builder checkNumber(String checkNumber)
The check number Increase should use for the check. This should not contain leading zeroes and must be unique across the
source_account_number. If this is omitted, Increase will generate a check number for you.
-
checkNumber
final CheckTransferCreateParams.Body.Builder checkNumber(JsonField<String> checkNumber)
Sets Builder.checkNumber to an arbitrary JSON value.
You should usually call Builder.checkNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
physicalCheck
final CheckTransferCreateParams.Body.Builder physicalCheck(CheckTransferCreateParams.PhysicalCheck physicalCheck)
Details relating to the physical check that Increase will print and mail. This is required if
fulfillment_methodis equal tophysical_check. It must not be included if any otherfulfillment_methodis provided.
-
physicalCheck
final CheckTransferCreateParams.Body.Builder physicalCheck(JsonField<CheckTransferCreateParams.PhysicalCheck> physicalCheck)
Sets Builder.physicalCheck to an arbitrary JSON value.
You should usually call Builder.physicalCheck with a well-typed PhysicalCheck value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final CheckTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final CheckTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
thirdParty
final CheckTransferCreateParams.Body.Builder thirdParty(CheckTransferCreateParams.ThirdParty thirdParty)
Details relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
thirdParty
final CheckTransferCreateParams.Body.Builder thirdParty(JsonField<CheckTransferCreateParams.ThirdParty> thirdParty)
Sets Builder.thirdParty to an arbitrary JSON value.
You should usually call Builder.thirdParty with a well-typed ThirdParty value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CheckTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CheckTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CheckTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CheckTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CheckTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CheckTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .fulfillmentMethod() .sourceAccountNumberId()
-
-
-
-