Class CheckTransferCreateParams.PhysicalCheck

  • All Implemented Interfaces:

    
    public final class CheckTransferCreateParams.PhysicalCheck
    
                        

    Details relating to the physical check that Increase will print and mail. This is required if fulfillment_method is equal to physical_check. It must not be included if any other fulfillment_method is provided.