Class CheckTransferCreateParams.ThirdParty

  • All Implemented Interfaces:

    
    public final class CheckTransferCreateParams.ThirdParty
    
                        

    Details relating to the custom fulfillment you will perform. This is required if fulfillment_method is equal to third_party. It must not be included if any other fulfillment_method is provided.