Class CheckTransferCreateParams.ThirdParty
-
- All Implemented Interfaces:
public final class CheckTransferCreateParams.ThirdPartyDetails relating to the custom fulfillment you will perform. This is required if
fulfillment_methodis equal tothird_party. It must not be included if any otherfulfillment_methodis provided.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferCreateParams.ThirdParty.BuilderA builder for ThirdParty.
-
Method Summary
Modifier and Type Method Description final Optional<String>checkNumber()The check number you will print on the check. final JsonField<String>_checkNumber()Returns the raw JSON value of checkNumber. final Map<String, JsonValue>_additionalProperties()final CheckTransferCreateParams.ThirdPartyvalidate()final CheckTransferCreateParams.ThirdParty.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferCreateParams.ThirdParty.Builderbuilder()Returns a mutable builder for constructing an instance of ThirdParty. -
-
Method Detail
-
checkNumber
final Optional<String> checkNumber()
The check number you will print on the check. This should not contain leading zeroes. If this is omitted, Increase will generate a check number for you; you should inspect the response and use that check number.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final CheckTransferCreateParams.ThirdParty validate()
-
toBuilder
final CheckTransferCreateParams.ThirdParty.Builder toBuilder()
-
builder
final static CheckTransferCreateParams.ThirdParty.Builder builder()
Returns a mutable builder for constructing an instance of ThirdParty.
-
-
-
-