Class CheckTransferStopPaymentParams.Body
-
- All Implemented Interfaces:
public final class CheckTransferStopPaymentParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferStopPaymentParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<CheckTransferStopPaymentParams.Reason>reason()The reason why this transfer should be stopped. final JsonField<CheckTransferStopPaymentParams.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final CheckTransferStopPaymentParams.Body.BuildertoBuilder()final CheckTransferStopPaymentParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckTransferStopPaymentParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
reason
final Optional<CheckTransferStopPaymentParams.Reason> reason()
The reason why this transfer should be stopped.
-
_reason
final JsonField<CheckTransferStopPaymentParams.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckTransferStopPaymentParams.Body.Builder toBuilder()
-
validate
final CheckTransferStopPaymentParams.Body validate()
-
builder
final static CheckTransferStopPaymentParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-