Class DeclinedTransaction.Source

  • All Implemented Interfaces:

    
    public final class DeclinedTransaction.Source
    
                        

    This is an object giving more details on the network-level event that caused the Declined Transaction. For example, for a card transaction this lists the merchant's industry and location. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.