Class DeclinedTransaction.Source.CheckDepositRejection
-
- All Implemented Interfaces:
public final class DeclinedTransaction.Source.CheckDepositRejectionA Check Deposit Rejection object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_rejection.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransaction.Source.CheckDepositRejection.BuilderA builder for CheckDepositRejection.
public final classDeclinedTransaction.Source.CheckDepositRejection.CurrencyThe ISO 4217 code for the check's currency.
public final classDeclinedTransaction.Source.CheckDepositRejection.ReasonWhy the check deposit was rejected.
-
Method Summary
-
-
Method Detail
-
amount
final Long amount()
The rejected amount in the minor unit of check's currency. For dollars, for example, this is cents.
-
checkDepositId
final String checkDepositId()
The identifier of the Check Deposit that was rejected.
-
currency
final DeclinedTransaction.Source.CheckDepositRejection.Currency currency()
The ISO 4217 code for the check's currency.
-
declinedTransactionId
final String declinedTransactionId()
The identifier of the associated declined transaction.
-
reason
final DeclinedTransaction.Source.CheckDepositRejection.Reason reason()
Why the check deposit was rejected.
-
rejectedAt
final OffsetDateTime rejectedAt()
The ISO 8601 date and time at which the check deposit was rejected.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositId
final JsonField<String> _checkDepositId()
Returns the raw JSON value of checkDepositId.
Unlike checkDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<DeclinedTransaction.Source.CheckDepositRejection.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_declinedTransactionId
final JsonField<String> _declinedTransactionId()
Returns the raw JSON value of declinedTransactionId.
Unlike declinedTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<DeclinedTransaction.Source.CheckDepositRejection.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_rejectedAt
final JsonField<OffsetDateTime> _rejectedAt()
Returns the raw JSON value of rejectedAt.
Unlike rejectedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DeclinedTransaction.Source.CheckDepositRejection.Builder toBuilder()
-
validate
final DeclinedTransaction.Source.CheckDepositRejection validate()
-
builder
final static DeclinedTransaction.Source.CheckDepositRejection.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositRejection.
The following fields are required:
.amount() .checkDepositId() .currency() .declinedTransactionId() .reason() .rejectedAt()
-
-
-
-