Class Document.Builder
-
- All Implemented Interfaces:
public final class Document.BuilderA builder for Document.
-
-
Method Summary
Modifier and Type Method Description final Document.Builderid(String id)The Document identifier. final Document.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Document.Buildercategory(Document.Category category)The type of document. final Document.Buildercategory(JsonField<Document.Category> category)Sets Builder.category to an arbitrary JSON value. final Document.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Document was created. final Document.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Document.BuilderentityId(String entityId)The identifier of the Entity the document was generated for. final Document.BuilderentityId(Optional<String> entityId)Alias for calling Builder.entityId with entityId.orElse(null).final Document.BuilderentityId(JsonField<String> entityId)Sets Builder.entityId to an arbitrary JSON value. final Document.BuilderfileId(String fileId)The identifier of the File containing the Document's contents. final Document.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final Document.Buildertype(Document.Type type)A constant representing the object's type. final Document.Buildertype(JsonField<Document.Type> type)Sets Builder.type to an arbitrary JSON value. final Document.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Document.BuilderputAdditionalProperty(String key, JsonValue value)final Document.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Document.BuilderremoveAdditionalProperty(String key)final Document.BuilderremoveAllAdditionalProperties(Set<String> keys)final Documentbuild()Returns an immutable instance of Document. -
-
Method Detail
-
id
final Document.Builder id(String id)
The Document identifier.
-
id
final Document.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Document.Builder category(Document.Category category)
The type of document.
-
category
final Document.Builder category(JsonField<Document.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Document.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Document was created.
-
createdAt
final Document.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityId
final Document.Builder entityId(String entityId)
The identifier of the Entity the document was generated for.
-
entityId
final Document.Builder entityId(Optional<String> entityId)
Alias for calling Builder.entityId with
entityId.orElse(null).
-
entityId
final Document.Builder entityId(JsonField<String> entityId)
Sets Builder.entityId to an arbitrary JSON value.
You should usually call Builder.entityId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final Document.Builder fileId(String fileId)
The identifier of the File containing the Document's contents.
-
fileId
final Document.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Document.Builder type(Document.Type type)
A constant representing the object's type. For this resource it will always be
document.
-
type
final Document.Builder type(JsonField<Document.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Document.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Document.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Document.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Document.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Document.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-