Class DocumentListPage
-
- All Implemented Interfaces:
public final class DocumentListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentListPage.BuilderA builder for DocumentListPage.
public final classDocumentListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Document>data()Delegates to DocumentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DocumentListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<DocumentListParams>getNextPageParams()final Optional<DocumentListPage>getNextPage()final DocumentListPage.AutoPagerautoPager()final DocumentListParamsparams()The parameters that were used to request this page. final DocumentListPageResponseresponse()The response that this page was parsed from. final DocumentListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentListPage.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentListPage. -
-
Method Detail
-
data
final List<Document> data()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<DocumentListParams> getNextPageParams()
-
getNextPage
final Optional<DocumentListPage> getNextPage()
-
autoPager
final DocumentListPage.AutoPager autoPager()
-
params
final DocumentListParams params()
The parameters that were used to request this page.
-
response
final DocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DocumentListPage.Builder toBuilder()
-
builder
final static DocumentListPage.Builder builder()
Returns a mutable builder for constructing an instance of DocumentListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-