Class DocumentListPageAsync
-
- All Implemented Interfaces:
public final class DocumentListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentListPageAsync.BuilderA builder for DocumentListPageAsync.
public final classDocumentListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Document>data()Delegates to DocumentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to DocumentListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<DocumentListParams>getNextPageParams()final CompletableFuture<Optional<DocumentListPageAsync>>getNextPage()final DocumentListPageAsync.AutoPagerautoPager()final DocumentListParamsparams()The parameters that were used to request this page. final DocumentListPageResponseresponse()The response that this page was parsed from. final DocumentListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DocumentListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of DocumentListPageAsync. -
-
Method Detail
-
data
final List<Document> data()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to DocumentListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<DocumentListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<DocumentListPageAsync>> getNextPage()
-
autoPager
final DocumentListPageAsync.AutoPager autoPager()
-
params
final DocumentListParams params()
The parameters that were used to request this page.
-
response
final DocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final DocumentListPageAsync.Builder toBuilder()
-
builder
final static DocumentListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of DocumentListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-