Class Entity.Joint.Individual
-
- All Implemented Interfaces:
public final class Entity.Joint.Individual
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Joint.Individual.BuilderA builder for Individual.
public final classEntity.Joint.Individual.AddressThe person's address.
public final classEntity.Joint.Individual.IdentificationA means of verifying the person's identity.
-
Method Summary
-
-
Method Detail
-
address
final Entity.Joint.Individual.Address address()
The person's address.
-
dateOfBirth
final LocalDate dateOfBirth()
The person's date of birth in YYYY-MM-DD format.
-
identification
final Entity.Joint.Individual.Identification identification()
A means of verifying the person's identity.
-
_address
final JsonField<Entity.Joint.Individual.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfBirth
final JsonField<LocalDate> _dateOfBirth()
Returns the raw JSON value of dateOfBirth.
Unlike dateOfBirth, this method doesn't throw if the JSON field has an unexpected type.
-
_identification
final JsonField<Entity.Joint.Individual.Identification> _identification()
Returns the raw JSON value of identification.
Unlike identification, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Joint.Individual.Builder toBuilder()
-
validate
final Entity.Joint.Individual validate()
-
builder
final static Entity.Joint.Individual.Builder builder()
Returns a mutable builder for constructing an instance of Individual.
The following fields are required:
.address() .dateOfBirth() .identification() .name()
-
-
-
-