Package com.increase.api.models.entities
Class Entity.ThirdPartyVerification
-
- All Implemented Interfaces:
public final class Entity.ThirdPartyVerificationIf you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.ThirdPartyVerification.BuilderA builder for ThirdPartyVerification.
public final classEntity.ThirdPartyVerification.VendorThe vendor that was used to perform the verification.
-
Method Summary
Modifier and Type Method Description final Stringreference()The reference identifier for the third party verification. final Entity.ThirdPartyVerification.Vendorvendor()The vendor that was used to perform the verification. final JsonField<String>_reference()Returns the raw JSON value of reference. final JsonField<Entity.ThirdPartyVerification.Vendor>_vendor()Returns the raw JSON value of vendor. final Map<String, JsonValue>_additionalProperties()final Entity.ThirdPartyVerification.BuildertoBuilder()final Entity.ThirdPartyVerificationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.ThirdPartyVerification.Builderbuilder()Returns a mutable builder for constructing an instance of ThirdPartyVerification. -
-
Method Detail
-
vendor
final Entity.ThirdPartyVerification.Vendor vendor()
The vendor that was used to perform the verification.
-
_reference
final JsonField<String> _reference()
Returns the raw JSON value of reference.
Unlike reference, this method doesn't throw if the JSON field has an unexpected type.
-
_vendor
final JsonField<Entity.ThirdPartyVerification.Vendor> _vendor()
Returns the raw JSON value of vendor.
Unlike vendor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.ThirdPartyVerification.Builder toBuilder()
-
validate
final Entity.ThirdPartyVerification validate()
-
builder
final static Entity.ThirdPartyVerification.Builder builder()
Returns a mutable builder for constructing an instance of ThirdPartyVerification.
The following fields are required:
.reference() .vendor()
-
-
-
-