Package com.increase.api.models.entities
Class Entity.Validation.Issue.BeneficialOwnerIdentity
-
- All Implemented Interfaces:
public final class Entity.Validation.Issue.BeneficialOwnerIdentityDetails when the issue is with a beneficial owner's identity verification.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntity.Validation.Issue.BeneficialOwnerIdentity.BuilderA builder for BeneficialOwnerIdentity.
-
Method Summary
Modifier and Type Method Description final StringbeneficialOwnerId()The ID of the beneficial owner. final JsonField<String>_beneficialOwnerId()Returns the raw JSON value of beneficialOwnerId. final Map<String, JsonValue>_additionalProperties()final Entity.Validation.Issue.BeneficialOwnerIdentity.BuildertoBuilder()final Entity.Validation.Issue.BeneficialOwnerIdentityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Entity.Validation.Issue.BeneficialOwnerIdentity.Builderbuilder()Returns a mutable builder for constructing an instance of BeneficialOwnerIdentity. -
-
Method Detail
-
beneficialOwnerId
final String beneficialOwnerId()
The ID of the beneficial owner.
-
_beneficialOwnerId
final JsonField<String> _beneficialOwnerId()
Returns the raw JSON value of beneficialOwnerId.
Unlike beneficialOwnerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Entity.Validation.Issue.BeneficialOwnerIdentity.Builder toBuilder()
-
validate
final Entity.Validation.Issue.BeneficialOwnerIdentity validate()
-
builder
final static Entity.Validation.Issue.BeneficialOwnerIdentity.Builder builder()
Returns a mutable builder for constructing an instance of BeneficialOwnerIdentity.
The following fields are required:
.beneficialOwnerId()
-
-
-
-