Package com.increase.api.models.entities
Class EntityCreateParams.Joint
-
- All Implemented Interfaces:
public final class EntityCreateParams.JointDetails of the joint entity to create. Required if
structureis equal tojoint.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Joint.BuilderA builder for Joint.
public final classEntityCreateParams.Joint.Individual
-
Method Summary
Modifier and Type Method Description final List<EntityCreateParams.Joint.Individual>individuals()The two individuals that share control of the entity. final JsonField<List<EntityCreateParams.Joint.Individual>>_individuals()Returns the raw JSON value of individuals. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Joint.BuildertoBuilder()final EntityCreateParams.Jointvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Joint.Builderbuilder()Returns a mutable builder for constructing an instance of Joint. -
-
Method Detail
-
individuals
final List<EntityCreateParams.Joint.Individual> individuals()
The two individuals that share control of the entity.
-
_individuals
final JsonField<List<EntityCreateParams.Joint.Individual>> _individuals()
Returns the raw JSON value of individuals.
Unlike individuals, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Joint.Builder toBuilder()
-
validate
final EntityCreateParams.Joint validate()
-
builder
final static EntityCreateParams.Joint.Builder builder()
Returns a mutable builder for constructing an instance of Joint.
The following fields are required:
.individuals()
-
-
-
-