Package com.increase.api.models.entities
Class EntityCreateParams.NaturalPerson.Identification.Passport
-
- All Implemented Interfaces:
public final class EntityCreateParams.NaturalPerson.Identification.PassportInformation about the passport used for identification. Required if
methodis equal topassport.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.NaturalPerson.Identification.Passport.BuilderA builder for Passport.
-
Method Summary
Modifier and Type Method Description final Stringcountry()The two-character ISO 3166-1 code representing the country that issued the passport (e.g. final LocalDateexpirationDate()The passport's expiration date in YYYY-MM-DD format. final StringfileId()The identifier of the File containing the passport. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<LocalDate>_expirationDate()Returns the raw JSON value of expirationDate. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.NaturalPerson.Identification.Passport.BuildertoBuilder()final EntityCreateParams.NaturalPerson.Identification.Passportvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.NaturalPerson.Identification.Passport.Builderbuilder()Returns a mutable builder for constructing an instance of Passport. -
-
Method Detail
-
country
final String country()
The two-character ISO 3166-1 code representing the country that issued the passport (e.g.,
US).
-
expirationDate
final LocalDate expirationDate()
The passport's expiration date in YYYY-MM-DD format.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_expirationDate
final JsonField<LocalDate> _expirationDate()
Returns the raw JSON value of expirationDate.
Unlike expirationDate, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.NaturalPerson.Identification.Passport.Builder toBuilder()
-
validate
final EntityCreateParams.NaturalPerson.Identification.Passport validate()
-
builder
final static EntityCreateParams.NaturalPerson.Identification.Passport.Builder builder()
Returns a mutable builder for constructing an instance of Passport.
The following fields are required:
.country() .expirationDate() .fileId()
-
-
-
-