Package com.increase.api.models.entities
Class EntityCreateParams.SupplementalDocument
-
- All Implemented Interfaces:
public final class EntityCreateParams.SupplementalDocument
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.SupplementalDocument.BuilderA builder for SupplementalDocument.
-
Method Summary
Modifier and Type Method Description final StringfileId()The identifier of the File containing the document. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.SupplementalDocument.BuildertoBuilder()final EntityCreateParams.SupplementalDocumentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.SupplementalDocument.Builderbuilder()Returns a mutable builder for constructing an instance of SupplementalDocument. -
-
Method Detail
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.SupplementalDocument.Builder toBuilder()
-
validate
final EntityCreateParams.SupplementalDocument validate()
-
builder
final static EntityCreateParams.SupplementalDocument.Builder builder()
Returns a mutable builder for constructing an instance of SupplementalDocument.
The following fields are required:
.fileId()
-
-
-
-