Class EntityCreateParams.ThirdPartyVerification

  • All Implemented Interfaces:

    
    public final class EntityCreateParams.ThirdPartyVerification
    
                        

    If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.