Package com.increase.api.models.entities
Class EntityCreateParams.Trust.Trustee
-
- All Implemented Interfaces:
public final class EntityCreateParams.Trust.Trustee
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityCreateParams.Trust.Trustee.BuilderA builder for Trustee.
public final classEntityCreateParams.Trust.Trustee.StructureThe structure of the trustee.
public final classEntityCreateParams.Trust.Trustee.IndividualDetails of the individual trustee. Within the trustee object, this is required if
structureis equal toindividual.
-
Method Summary
Modifier and Type Method Description final EntityCreateParams.Trust.Trustee.Structurestructure()The structure of the trustee. final Optional<EntityCreateParams.Trust.Trustee.Individual>individual()Details of the individual trustee. final JsonField<EntityCreateParams.Trust.Trustee.Structure>_structure()Returns the raw JSON value of structure. final JsonField<EntityCreateParams.Trust.Trustee.Individual>_individual()Returns the raw JSON value of individual. final Map<String, JsonValue>_additionalProperties()final EntityCreateParams.Trust.Trustee.BuildertoBuilder()final EntityCreateParams.Trust.Trusteevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityCreateParams.Trust.Trustee.Builderbuilder()Returns a mutable builder for constructing an instance of Trustee. -
-
Method Detail
-
structure
final EntityCreateParams.Trust.Trustee.Structure structure()
The structure of the trustee.
-
individual
final Optional<EntityCreateParams.Trust.Trustee.Individual> individual()
Details of the individual trustee. Within the trustee object, this is required if
structureis equal toindividual.
-
_structure
final JsonField<EntityCreateParams.Trust.Trustee.Structure> _structure()
Returns the raw JSON value of structure.
Unlike structure, this method doesn't throw if the JSON field has an unexpected type.
-
_individual
final JsonField<EntityCreateParams.Trust.Trustee.Individual> _individual()
Returns the raw JSON value of individual.
Unlike individual, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityCreateParams.Trust.Trustee.Builder toBuilder()
-
validate
final EntityCreateParams.Trust.Trustee validate()
-
builder
final static EntityCreateParams.Trust.Trustee.Builder builder()
Returns a mutable builder for constructing an instance of Trustee.
The following fields are required:
.structure()
-
-
-
-