Package com.increase.api.models.entities
Class EntityListPage
-
- All Implemented Interfaces:
public final class EntityListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityListPage.BuilderA builder for EntityListPage.
public final classEntityListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Entity>data()Delegates to EntityListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to EntityListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<EntityListParams>getNextPageParams()final Optional<EntityListPage>getNextPage()final EntityListPage.AutoPagerautoPager()final EntityListParamsparams()The parameters that were used to request this page. final EntityListPageResponseresponse()The response that this page was parsed from. final EntityListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityListPage.Builderbuilder()Returns a mutable builder for constructing an instance of EntityListPage. -
-
Method Detail
-
data
final List<Entity> data()
Delegates to EntityListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to EntityListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<EntityListParams> getNextPageParams()
-
getNextPage
final Optional<EntityListPage> getNextPage()
-
autoPager
final EntityListPage.AutoPager autoPager()
-
params
final EntityListParams params()
The parameters that were used to request this page.
-
response
final EntityListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final EntityListPage.Builder toBuilder()
-
builder
final static EntityListPage.Builder builder()
Returns a mutable builder for constructing an instance of EntityListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-