Class EntityUpdateIndustryCodeParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityUpdateIndustryCodeParams implements Params
Update the industry code for a corporate Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateIndustryCodeParams.BuilderA builder for EntityUpdateIndustryCodeParams.
public final classEntityUpdateIndustryCodeParams.Body
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to update. final StringindustryCode()The North American Industry Classification System (NAICS) code for the corporation's primary line of business. final JsonField<String>_industryCode()Returns the raw JSON value of industryCode. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final EntityUpdateIndustryCodeParams.BuildertoBuilder()final EntityUpdateIndustryCodeParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateIndustryCodeParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityUpdateIndustryCodeParams. -
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to update. This endpoint only accepts
corporationentities.
-
industryCode
final String industryCode()
The North American Industry Classification System (NAICS) code for the corporation's primary line of business. This is a number, like
5132forSoftware Publishers. A full list of classification codes is available here.
-
_industryCode
final JsonField<String> _industryCode()
Returns the raw JSON value of industryCode.
Unlike industryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final EntityUpdateIndustryCodeParams.Builder toBuilder()
-
_body
final EntityUpdateIndustryCodeParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EntityUpdateIndustryCodeParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityUpdateIndustryCodeParams.
The following fields are required:
.entityId() .industryCode()
-
-
-
-