Class EntityUpdateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EntityUpdateParams implements Params
Update an Entity
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.BuilderA builder for EntityUpdateParams.
public final classEntityUpdateParams.Bodypublic final classEntityUpdateParams.RiskRatingAn assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
public final classEntityUpdateParams.ThirdPartyVerificationA reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
Method Summary
Modifier and Type Method Description final Optional<String>entityId()The entity identifier. final Optional<EntityUpdateParams.RiskRating>riskRating()An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering. final Optional<EntityUpdateParams.ThirdPartyVerification>thirdPartyVerification()A reference to data stored in a third-party verification service. final JsonField<EntityUpdateParams.RiskRating>_riskRating()Returns the raw JSON value of riskRating. final JsonField<EntityUpdateParams.ThirdPartyVerification>_thirdPartyVerification()Returns the raw JSON value of thirdPartyVerification. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EntityUpdateParams.BuildertoBuilder()final EntityUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParamsnone()final static EntityUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EntityUpdateParams. -
-
Method Detail
-
riskRating
final Optional<EntityUpdateParams.RiskRating> riskRating()
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
thirdPartyVerification
final Optional<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
_riskRating
final JsonField<EntityUpdateParams.RiskRating> _riskRating()
Returns the raw JSON value of riskRating.
Unlike riskRating, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdPartyVerification
final JsonField<EntityUpdateParams.ThirdPartyVerification> _thirdPartyVerification()
Returns the raw JSON value of thirdPartyVerification.
Unlike thirdPartyVerification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EntityUpdateParams.Builder toBuilder()
-
_body
final EntityUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static EntityUpdateParams none()
-
builder
final static EntityUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of EntityUpdateParams.
-
-
-
-