Class EntityUpdateParams.Body
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<EntityUpdateParams.Corporation>corporation()Details of the corporation entity to update. final Optional<OffsetDateTime>detailsConfirmedAt()When your user last confirmed the Entity's details. final Optional<EntityUpdateParams.GovernmentAuthority>governmentAuthority()Details of the government authority entity to update. final Optional<EntityUpdateParams.NaturalPerson>naturalPerson()Details of the natural person entity to update. final Optional<EntityUpdateParams.RiskRating>riskRating()An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering. final Optional<EntityUpdateParams.ThirdPartyVerification>thirdPartyVerification()If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service. final Optional<EntityUpdateParams.Trust>trust()Details of the trust entity to update. final JsonField<EntityUpdateParams.Corporation>_corporation()Returns the raw JSON value of corporation. final JsonField<OffsetDateTime>_detailsConfirmedAt()Returns the raw JSON value of detailsConfirmedAt. final JsonField<EntityUpdateParams.GovernmentAuthority>_governmentAuthority()Returns the raw JSON value of governmentAuthority. final JsonField<EntityUpdateParams.NaturalPerson>_naturalPerson()Returns the raw JSON value of naturalPerson. final JsonField<EntityUpdateParams.RiskRating>_riskRating()Returns the raw JSON value of riskRating. final JsonField<EntityUpdateParams.ThirdPartyVerification>_thirdPartyVerification()Returns the raw JSON value of thirdPartyVerification. final JsonField<EntityUpdateParams.Trust>_trust()Returns the raw JSON value of trust. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.Body.BuildertoBuilder()final EntityUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
corporation
final Optional<EntityUpdateParams.Corporation> corporation()
Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
-
detailsConfirmedAt
final Optional<OffsetDateTime> detailsConfirmedAt()
When your user last confirmed the Entity's details. Depending on your program, you may be required to affirmatively confirm details with your users on an annual basis.
-
governmentAuthority
final Optional<EntityUpdateParams.GovernmentAuthority> governmentAuthority()
Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
-
naturalPerson
final Optional<EntityUpdateParams.NaturalPerson> naturalPerson()
Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
riskRating
final Optional<EntityUpdateParams.RiskRating> riskRating()
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
thirdPartyVerification
final Optional<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification()
If you are using a third-party service for identity verification, you can use this field to associate this Entity with the identifier that represents them in that service.
-
trust
final Optional<EntityUpdateParams.Trust> trust()
Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
_corporation
final JsonField<EntityUpdateParams.Corporation> _corporation()
Returns the raw JSON value of corporation.
Unlike corporation, this method doesn't throw if the JSON field has an unexpected type.
-
_detailsConfirmedAt
final JsonField<OffsetDateTime> _detailsConfirmedAt()
Returns the raw JSON value of detailsConfirmedAt.
Unlike detailsConfirmedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentAuthority
final JsonField<EntityUpdateParams.GovernmentAuthority> _governmentAuthority()
Returns the raw JSON value of governmentAuthority.
Unlike governmentAuthority, this method doesn't throw if the JSON field has an unexpected type.
-
_naturalPerson
final JsonField<EntityUpdateParams.NaturalPerson> _naturalPerson()
Returns the raw JSON value of naturalPerson.
Unlike naturalPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_riskRating
final JsonField<EntityUpdateParams.RiskRating> _riskRating()
Returns the raw JSON value of riskRating.
Unlike riskRating, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdPartyVerification
final JsonField<EntityUpdateParams.ThirdPartyVerification> _thirdPartyVerification()
Returns the raw JSON value of thirdPartyVerification.
Unlike thirdPartyVerification, this method doesn't throw if the JSON field has an unexpected type.
-
_trust
final JsonField<EntityUpdateParams.Trust> _trust()
Returns the raw JSON value of trust.
Unlike trust, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.Body.Builder toBuilder()
-
validate
final EntityUpdateParams.Body validate()
-
builder
final static EntityUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-