Class EntityUpdateParams.Body
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
corporation
final Optional<EntityUpdateParams.Corporation> corporation()
Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
-
governmentAuthority
final Optional<EntityUpdateParams.GovernmentAuthority> governmentAuthority()
Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
-
naturalPerson
final Optional<EntityUpdateParams.NaturalPerson> naturalPerson()
Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
riskRating
final Optional<EntityUpdateParams.RiskRating> riskRating()
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
thirdPartyVerification
final Optional<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification()
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
trust
final Optional<EntityUpdateParams.Trust> trust()
Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
_corporation
final JsonField<EntityUpdateParams.Corporation> _corporation()
Returns the raw JSON value of corporation.
Unlike corporation, this method doesn't throw if the JSON field has an unexpected type.
-
_governmentAuthority
final JsonField<EntityUpdateParams.GovernmentAuthority> _governmentAuthority()
Returns the raw JSON value of governmentAuthority.
Unlike governmentAuthority, this method doesn't throw if the JSON field has an unexpected type.
-
_naturalPerson
final JsonField<EntityUpdateParams.NaturalPerson> _naturalPerson()
Returns the raw JSON value of naturalPerson.
Unlike naturalPerson, this method doesn't throw if the JSON field has an unexpected type.
-
_riskRating
final JsonField<EntityUpdateParams.RiskRating> _riskRating()
Returns the raw JSON value of riskRating.
Unlike riskRating, this method doesn't throw if the JSON field has an unexpected type.
-
_thirdPartyVerification
final JsonField<EntityUpdateParams.ThirdPartyVerification> _thirdPartyVerification()
Returns the raw JSON value of thirdPartyVerification.
Unlike thirdPartyVerification, this method doesn't throw if the JSON field has an unexpected type.
-
_trust
final JsonField<EntityUpdateParams.Trust> _trust()
Returns the raw JSON value of trust.
Unlike trust, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.Body.Builder toBuilder()
-
validate
final EntityUpdateParams.Body validate()
-
builder
final static EntityUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-