Class EntityUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
corporation
final EntityUpdateParams.Body.Builder corporation(EntityUpdateParams.Corporation corporation)
Details of the corporation entity to update. If you specify this parameter and the entity is not a corporation, the request will fail.
-
corporation
final EntityUpdateParams.Body.Builder corporation(JsonField<EntityUpdateParams.Corporation> corporation)
Sets Builder.corporation to an arbitrary JSON value.
You should usually call Builder.corporation with a well-typed Corporation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
governmentAuthority
final EntityUpdateParams.Body.Builder governmentAuthority(EntityUpdateParams.GovernmentAuthority governmentAuthority)
Details of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
-
governmentAuthority
final EntityUpdateParams.Body.Builder governmentAuthority(JsonField<EntityUpdateParams.GovernmentAuthority> governmentAuthority)
Sets Builder.governmentAuthority to an arbitrary JSON value.
You should usually call Builder.governmentAuthority with a well-typed GovernmentAuthority value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
naturalPerson
final EntityUpdateParams.Body.Builder naturalPerson(EntityUpdateParams.NaturalPerson naturalPerson)
Details of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
naturalPerson
final EntityUpdateParams.Body.Builder naturalPerson(JsonField<EntityUpdateParams.NaturalPerson> naturalPerson)
Sets Builder.naturalPerson to an arbitrary JSON value.
You should usually call Builder.naturalPerson with a well-typed NaturalPerson value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
riskRating
final EntityUpdateParams.Body.Builder riskRating(EntityUpdateParams.RiskRating riskRating)
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
riskRating
final EntityUpdateParams.Body.Builder riskRating(JsonField<EntityUpdateParams.RiskRating> riskRating)
Sets Builder.riskRating to an arbitrary JSON value.
You should usually call Builder.riskRating with a well-typed RiskRating value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
thirdPartyVerification
final EntityUpdateParams.Body.Builder thirdPartyVerification(EntityUpdateParams.ThirdPartyVerification thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
thirdPartyVerification
final EntityUpdateParams.Body.Builder thirdPartyVerification(JsonField<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification)
Sets Builder.thirdPartyVerification to an arbitrary JSON value.
You should usually call Builder.thirdPartyVerification with a well-typed ThirdPartyVerification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trust
final EntityUpdateParams.Body.Builder trust(EntityUpdateParams.Trust trust)
Details of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
trust
final EntityUpdateParams.Body.Builder trust(JsonField<EntityUpdateParams.Trust> trust)
Sets Builder.trust to an arbitrary JSON value.
You should usually call Builder.trust with a well-typed Trust value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-