Class EntityUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class EntityUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
riskRating
final EntityUpdateParams.Body.Builder riskRating(EntityUpdateParams.RiskRating riskRating)
An assessment of the entity’s potential risk of involvement in financial crimes, such as money laundering.
-
riskRating
final EntityUpdateParams.Body.Builder riskRating(JsonField<EntityUpdateParams.RiskRating> riskRating)
Sets Builder.riskRating to an arbitrary JSON value.
You should usually call Builder.riskRating with a well-typed RiskRating value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
thirdPartyVerification
final EntityUpdateParams.Body.Builder thirdPartyVerification(EntityUpdateParams.ThirdPartyVerification thirdPartyVerification)
A reference to data stored in a third-party verification service. Your integration may or may not use this field.
-
thirdPartyVerification
final EntityUpdateParams.Body.Builder thirdPartyVerification(JsonField<EntityUpdateParams.ThirdPartyVerification> thirdPartyVerification)
Sets Builder.thirdPartyVerification to an arbitrary JSON value.
You should usually call Builder.thirdPartyVerification with a well-typed ThirdPartyVerification value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final EntityUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final EntityUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final EntityUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final EntityUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final EntityUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final EntityUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-