Package com.increase.api.models.entities
Class EntityUpdateParams.GovernmentAuthority
-
- All Implemented Interfaces:
public final class EntityUpdateParams.GovernmentAuthorityDetails of the government authority entity to update. If you specify this parameter and the entity is not a government authority, the request will fail.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.GovernmentAuthority.BuilderA builder for GovernmentAuthority.
public final classEntityUpdateParams.GovernmentAuthority.AddressThe entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
Method Summary
Modifier and Type Method Description final Optional<EntityUpdateParams.GovernmentAuthority.Address>address()The entity's physical address. final Optional<String>name()The legal name of the government authority. final JsonField<EntityUpdateParams.GovernmentAuthority.Address>_address()Returns the raw JSON value of address. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.GovernmentAuthority.BuildertoBuilder()final EntityUpdateParams.GovernmentAuthorityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.GovernmentAuthority.Builderbuilder()Returns a mutable builder for constructing an instance of GovernmentAuthority. -
-
Method Detail
-
address
final Optional<EntityUpdateParams.GovernmentAuthority.Address> address()
The entity's physical address. Mail receiving locations like PO Boxes and PMB's are disallowed.
-
_address
final JsonField<EntityUpdateParams.GovernmentAuthority.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.GovernmentAuthority.Builder toBuilder()
-
validate
final EntityUpdateParams.GovernmentAuthority validate()
-
builder
final static EntityUpdateParams.GovernmentAuthority.Builder builder()
Returns a mutable builder for constructing an instance of GovernmentAuthority.
-
-
-
-