Package com.increase.api.models.entities
Class EntityUpdateParams.NaturalPerson
-
- All Implemented Interfaces:
public final class EntityUpdateParams.NaturalPersonDetails of the natural person entity to update. If you specify this parameter and the entity is not a natural person, the request will fail.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.NaturalPerson.BuilderA builder for NaturalPerson.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The legal name of the natural person. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.NaturalPerson.BuildertoBuilder()final EntityUpdateParams.NaturalPersonvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.NaturalPerson.Builderbuilder()Returns a mutable builder for constructing an instance of NaturalPerson. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.NaturalPerson.Builder toBuilder()
-
validate
final EntityUpdateParams.NaturalPerson validate()
-
builder
final static EntityUpdateParams.NaturalPerson.Builder builder()
Returns a mutable builder for constructing an instance of NaturalPerson.
-
-
-
-