Package com.increase.api.models.entities
Class EntityUpdateParams.Trust
-
- All Implemented Interfaces:
public final class EntityUpdateParams.TrustDetails of the trust entity to update. If you specify this parameter and the entity is not a trust, the request will fail.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityUpdateParams.Trust.BuilderA builder for Trust.
-
Method Summary
Modifier and Type Method Description final Optional<String>name()The legal name of the trust. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final EntityUpdateParams.Trust.BuildertoBuilder()final EntityUpdateParams.Trustvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EntityUpdateParams.Trust.Builderbuilder()Returns a mutable builder for constructing an instance of Trust. -
-
Method Detail
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EntityUpdateParams.Trust.Builder toBuilder()
-
validate
final EntityUpdateParams.Trust validate()
-
builder
final static EntityUpdateParams.Trust.Builder builder()
Returns a mutable builder for constructing an instance of Trust.
-
-
-
-