Class EventSubscriptionCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class EventSubscriptionCreateParams implements Params
Create an Event Subscription
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionCreateParams.BuilderA builder for EventSubscriptionCreateParams.
public final classEventSubscriptionCreateParams.Bodypublic final classEventSubscriptionCreateParams.SelectedEventCategoryIf specified, this subscription will only receive webhooks for Events with the specified
category.
-
Method Summary
Modifier and Type Method Description final Stringurl()The URL you'd like us to send webhooks to. final Optional<String>oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection. final Optional<EventSubscriptionCreateParams.SelectedEventCategory>selectedEventCategory()If specified, this subscription will only receive webhooks for Events with the specified category.final Optional<String>sharedSecret()The key that will be used to sign webhooks. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_oauthConnectionId()Returns the raw JSON value of oauthConnectionId. final JsonField<EventSubscriptionCreateParams.SelectedEventCategory>_selectedEventCategory()Returns the raw JSON value of selectedEventCategory. final JsonField<String>_sharedSecret()Returns the raw JSON value of sharedSecret. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final EventSubscriptionCreateParams.BuildertoBuilder()final EventSubscriptionCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of EventSubscriptionCreateParams. -
-
Method Detail
-
oauthConnectionId
final Optional<String> oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
selectedEventCategory
final Optional<EventSubscriptionCreateParams.SelectedEventCategory> selectedEventCategory()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
sharedSecret
final Optional<String> sharedSecret()
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthConnectionId
final JsonField<String> _oauthConnectionId()
Returns the raw JSON value of oauthConnectionId.
Unlike oauthConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_selectedEventCategory
final JsonField<EventSubscriptionCreateParams.SelectedEventCategory> _selectedEventCategory()
Returns the raw JSON value of selectedEventCategory.
Unlike selectedEventCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_sharedSecret
final JsonField<String> _sharedSecret()
Returns the raw JSON value of sharedSecret.
Unlike sharedSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final EventSubscriptionCreateParams.Builder toBuilder()
-
_body
final EventSubscriptionCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static EventSubscriptionCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of EventSubscriptionCreateParams.
The following fields are required:
.url()
-
-
-
-