Class EventSubscriptionCreateParams.Body
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringurl()The URL you'd like us to send webhooks to. final Optional<String>oauthConnectionId()If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection. final Optional<EventSubscriptionCreateParams.SelectedEventCategory>selectedEventCategory()If specified, this subscription will only receive webhooks for Events with the specified category.final Optional<String>sharedSecret()The key that will be used to sign webhooks. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_oauthConnectionId()Returns the raw JSON value of oauthConnectionId. final JsonField<EventSubscriptionCreateParams.SelectedEventCategory>_selectedEventCategory()Returns the raw JSON value of selectedEventCategory. final JsonField<String>_sharedSecret()Returns the raw JSON value of sharedSecret. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionCreateParams.Body.BuildertoBuilder()final EventSubscriptionCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
oauthConnectionId
final Optional<String> oauthConnectionId()
If specified, this subscription will only receive webhooks for Events associated with the specified OAuth Connection.
-
selectedEventCategory
final Optional<EventSubscriptionCreateParams.SelectedEventCategory> selectedEventCategory()
If specified, this subscription will only receive webhooks for Events with the specified
category.
-
sharedSecret
final Optional<String> sharedSecret()
The key that will be used to sign webhooks. If no value is passed, a random string will be used as default.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_oauthConnectionId
final JsonField<String> _oauthConnectionId()
Returns the raw JSON value of oauthConnectionId.
Unlike oauthConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_selectedEventCategory
final JsonField<EventSubscriptionCreateParams.SelectedEventCategory> _selectedEventCategory()
Returns the raw JSON value of selectedEventCategory.
Unlike selectedEventCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_sharedSecret
final JsonField<String> _sharedSecret()
Returns the raw JSON value of sharedSecret.
Unlike sharedSecret, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionCreateParams.Body.Builder toBuilder()
-
validate
final EventSubscriptionCreateParams.Body validate()
-
builder
final static EventSubscriptionCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.url()
-
-
-
-