Class EventSubscriptionCreateParams.SelectedEventCategory
-
- All Implemented Interfaces:
public final class EventSubscriptionCreateParams.SelectedEventCategory
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionCreateParams.SelectedEventCategory.BuilderA builder for SelectedEventCategory.
public final classEventSubscriptionCreateParams.SelectedEventCategory.EventCategoryThe category of the Event to subscribe to.
-
Method Summary
Modifier and Type Method Description final EventSubscriptionCreateParams.SelectedEventCategory.EventCategoryeventCategory()The category of the Event to subscribe to. final JsonField<EventSubscriptionCreateParams.SelectedEventCategory.EventCategory>_eventCategory()Returns the raw JSON value of eventCategory. final Map<String, JsonValue>_additionalProperties()final EventSubscriptionCreateParams.SelectedEventCategory.BuildertoBuilder()final EventSubscriptionCreateParams.SelectedEventCategoryvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EventSubscriptionCreateParams.SelectedEventCategory.Builderbuilder()Returns a mutable builder for constructing an instance of SelectedEventCategory. -
-
Method Detail
-
eventCategory
final EventSubscriptionCreateParams.SelectedEventCategory.EventCategory eventCategory()
The category of the Event to subscribe to.
-
_eventCategory
final JsonField<EventSubscriptionCreateParams.SelectedEventCategory.EventCategory> _eventCategory()
Returns the raw JSON value of eventCategory.
Unlike eventCategory, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EventSubscriptionCreateParams.SelectedEventCategory.Builder toBuilder()
-
validate
final EventSubscriptionCreateParams.SelectedEventCategory validate()
-
builder
final static EventSubscriptionCreateParams.SelectedEventCategory.Builder builder()
Returns a mutable builder for constructing an instance of SelectedEventCategory.
The following fields are required:
.eventCategory()
-
-
-
-