Class Export
-
- All Implemented Interfaces:
public final class ExportExports are generated files. Some exports can contain a lot of data, like a CSV of your transactions. Others can be a single document, like a tax form. Since they can take a while, they are generated asynchronously. We send a webhook when they are ready. For more information, please read our Exports documentation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.BuilderA builder for Export.
public final classExport.CategoryThe category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
public final classExport.StatusThe status of the Export.
public final classExport.TypeA constant representing the object's type. For this resource it will always be
export.
-
Method Summary
Modifier and Type Method Description final Stringid()The Export identifier. final Export.Categorycategory()The category of the Export. final OffsetDateTimecreatedAt()The time the Export was created. final Optional<String>fileDownloadUrl()A URL at which the Export's file can be downloaded. final Optional<String>fileId()The File containing the contents of the Export. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Export.Statusstatus()The status of the Export. final Export.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Export.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_fileDownloadUrl()Returns the raw JSON value of fileDownloadUrl. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<Export.Status>_status()Returns the raw JSON value of status. final JsonField<Export.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Export.BuildertoBuilder()final Exportvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.Builderbuilder()Returns a mutable builder for constructing an instance of Export. -
-
Method Detail
-
category
final Export.Category category()
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
createdAt
final OffsetDateTime createdAt()
The time the Export was created.
-
fileDownloadUrl
final Optional<String> fileDownloadUrl()
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileId
final Optional<String> fileId()
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
status
final Export.Status status()
The status of the Export.
-
type
final Export.Type type()
A constant representing the object's type. For this resource it will always be
export.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<Export.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_fileDownloadUrl
final JsonField<String> _fileDownloadUrl()
Returns the raw JSON value of fileDownloadUrl.
Unlike fileDownloadUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<Export.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Export.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.Builder toBuilder()
-
builder
final static Export.Builder builder()
Returns a mutable builder for constructing an instance of Export.
The following fields are required:
.id() .category() .createdAt() .fileDownloadUrl() .fileId() .idempotencyKey() .status() .type()
-
-
-
-