Package com.increase.api.models.exports
Class Export.AccountStatementOfx
-
- All Implemented Interfaces:
public final class Export.AccountStatementOfxDetails of the account statement OFX export. This field will be present when the
categoryis equal toaccount_statement_ofx.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.AccountStatementOfx.BuilderA builder for AccountStatementOfx.
public final classExport.AccountStatementOfx.CreatedAtFilter transactions by their created date.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account to create a statement for. final Optional<Export.AccountStatementOfx.CreatedAt>createdAt()Filter transactions by their created date. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Export.AccountStatementOfx.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final Export.AccountStatementOfx.BuildertoBuilder()final Export.AccountStatementOfxvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.AccountStatementOfx.Builderbuilder()Returns a mutable builder for constructing an instance of AccountStatementOfx. -
-
Method Detail
-
createdAt
final Optional<Export.AccountStatementOfx.CreatedAt> createdAt()
Filter transactions by their created date.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Export.AccountStatementOfx.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.AccountStatementOfx.Builder toBuilder()
-
validate
final Export.AccountStatementOfx validate()
-
builder
final static Export.AccountStatementOfx.Builder builder()
Returns a mutable builder for constructing an instance of AccountStatementOfx.
The following fields are required:
.accountId() .createdAt()
-
-
-
-