Package com.increase.api.models.exports
Class Export.AccountVerificationLetter
-
- All Implemented Interfaces:
public final class Export.AccountVerificationLetterDetails of the account verification letter export. This field will be present when the
categoryis equal toaccount_verification_letter.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.AccountVerificationLetter.BuilderA builder for AccountVerificationLetter.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number to create a letter for. final Optional<LocalDate>balanceDate()The date of the balance to include in the letter. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<LocalDate>_balanceDate()Returns the raw JSON value of balanceDate. final Map<String, JsonValue>_additionalProperties()final Export.AccountVerificationLetter.BuildertoBuilder()final Export.AccountVerificationLettervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.AccountVerificationLetter.Builderbuilder()Returns a mutable builder for constructing an instance of AccountVerificationLetter. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to create a letter for.
-
balanceDate
final Optional<LocalDate> balanceDate()
The date of the balance to include in the letter.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_balanceDate
final JsonField<LocalDate> _balanceDate()
Returns the raw JSON value of balanceDate.
Unlike balanceDate, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.AccountVerificationLetter.Builder toBuilder()
-
validate
final Export.AccountVerificationLetter validate()
-
builder
final static Export.AccountVerificationLetter.Builder builder()
Returns a mutable builder for constructing an instance of AccountVerificationLetter.
The following fields are required:
.accountNumberId() .balanceDate()
-
-
-
-