Class Export.Builder
-
- All Implemented Interfaces:
public final class Export.BuilderA builder for Export.
-
-
Method Summary
Modifier and Type Method Description final Export.Builderid(String id)The Export identifier. final Export.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Export.BuilderaccountStatementBai2(Export.AccountStatementBai2 accountStatementBai2)Details of the account statement BAI2 export. final Export.BuilderaccountStatementBai2(Optional<Export.AccountStatementBai2> accountStatementBai2)Alias for calling Builder.accountStatementBai2 with accountStatementBai2.orElse(null).final Export.BuilderaccountStatementBai2(JsonField<Export.AccountStatementBai2> accountStatementBai2)Sets Builder.accountStatementBai2 to an arbitrary JSON value. final Export.BuilderaccountStatementOfx(Export.AccountStatementOfx accountStatementOfx)Details of the account statement OFX export. final Export.BuilderaccountStatementOfx(Optional<Export.AccountStatementOfx> accountStatementOfx)Alias for calling Builder.accountStatementOfx with accountStatementOfx.orElse(null).final Export.BuilderaccountStatementOfx(JsonField<Export.AccountStatementOfx> accountStatementOfx)Sets Builder.accountStatementOfx to an arbitrary JSON value. final Export.BuilderaccountVerificationLetter(Export.AccountVerificationLetter accountVerificationLetter)Details of the account verification letter export. final Export.BuilderaccountVerificationLetter(Optional<Export.AccountVerificationLetter> accountVerificationLetter)Alias for calling Builder.accountVerificationLetter with accountVerificationLetter.orElse(null).final Export.BuilderaccountVerificationLetter(JsonField<Export.AccountVerificationLetter> accountVerificationLetter)Sets Builder.accountVerificationLetter to an arbitrary JSON value. final Export.BuilderbalanceCsv(Export.BalanceCsv balanceCsv)Details of the balance CSV export. final Export.BuilderbalanceCsv(Optional<Export.BalanceCsv> balanceCsv)Alias for calling Builder.balanceCsv with balanceCsv.orElse(null).final Export.BuilderbalanceCsv(JsonField<Export.BalanceCsv> balanceCsv)Sets Builder.balanceCsv to an arbitrary JSON value. final Export.BuilderbookkeepingAccountBalanceCsv(Export.BookkeepingAccountBalanceCsv bookkeepingAccountBalanceCsv)Details of the bookkeeping account balance CSV export. final Export.BuilderbookkeepingAccountBalanceCsv(Optional<Export.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv)Alias for calling Builder.bookkeepingAccountBalanceCsv with bookkeepingAccountBalanceCsv.orElse(null).final Export.BuilderbookkeepingAccountBalanceCsv(JsonField<Export.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv)Sets Builder.bookkeepingAccountBalanceCsv to an arbitrary JSON value. final Export.Buildercategory(Export.Category category)The category of the Export. final Export.Buildercategory(JsonField<Export.Category> category)Sets Builder.category to an arbitrary JSON value. final Export.BuildercreatedAt(OffsetDateTime createdAt)The time the Export was created. final Export.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Export.BuilderdashboardTableCsv(Export.DashboardTableCsv dashboardTableCsv)Details of the dashboard table CSV export. final Export.BuilderdashboardTableCsv(Optional<Export.DashboardTableCsv> dashboardTableCsv)Alias for calling Builder.dashboardTableCsv with dashboardTableCsv.orElse(null).final Export.BuilderdashboardTableCsv(JsonField<Export.DashboardTableCsv> dashboardTableCsv)Sets Builder.dashboardTableCsv to an arbitrary JSON value. final Export.BuilderentityCsv(Export.EntityCsv entityCsv)Details of the entity CSV export. final Export.BuilderentityCsv(Optional<Export.EntityCsv> entityCsv)Alias for calling Builder.entityCsv with entityCsv.orElse(null).final Export.BuilderentityCsv(JsonField<Export.EntityCsv> entityCsv)Sets Builder.entityCsv to an arbitrary JSON value. final Export.BuilderfileDownloadUrl(String fileDownloadUrl)A URL at which the Export's file can be downloaded. final Export.BuilderfileDownloadUrl(Optional<String> fileDownloadUrl)Alias for calling Builder.fileDownloadUrl with fileDownloadUrl.orElse(null).final Export.BuilderfileDownloadUrl(JsonField<String> fileDownloadUrl)Sets Builder.fileDownloadUrl to an arbitrary JSON value. final Export.BuilderfileId(String fileId)The File containing the contents of the Export. final Export.BuilderfileId(Optional<String> fileId)Alias for calling Builder.fileId with fileId.orElse(null).final Export.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final Export.Builderform1099Int(Export.Form1099Int form1099Int)Details of the Form 1099-INT export. final Export.Builderform1099Int(Optional<Export.Form1099Int> form1099Int)Alias for calling Builder.form1099Int with form1099Int.orElse(null).final Export.Builderform1099Int(JsonField<Export.Form1099Int> form1099Int)Sets Builder.form1099Int to an arbitrary JSON value. final Export.Builderform1099Misc(Export.Form1099Misc form1099Misc)Details of the Form 1099-MISC export. final Export.Builderform1099Misc(Optional<Export.Form1099Misc> form1099Misc)Alias for calling Builder.form1099Misc with form1099Misc.orElse(null).final Export.Builderform1099Misc(JsonField<Export.Form1099Misc> form1099Misc)Sets Builder.form1099Misc to an arbitrary JSON value. final Export.BuilderfundingInstructions(Export.FundingInstructions fundingInstructions)Details of the funding instructions export. final Export.BuilderfundingInstructions(Optional<Export.FundingInstructions> fundingInstructions)Alias for calling Builder.fundingInstructions with fundingInstructions.orElse(null).final Export.BuilderfundingInstructions(JsonField<Export.FundingInstructions> fundingInstructions)Sets Builder.fundingInstructions to an arbitrary JSON value. final Export.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Export.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final Export.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final Export.Builderstatus(Export.Status status)The status of the Export. final Export.Builderstatus(JsonField<Export.Status> status)Sets Builder.status to an arbitrary JSON value. final Export.BuildertransactionCsv(Export.TransactionCsv transactionCsv)Details of the transaction CSV export. final Export.BuildertransactionCsv(Optional<Export.TransactionCsv> transactionCsv)Alias for calling Builder.transactionCsv with transactionCsv.orElse(null).final Export.BuildertransactionCsv(JsonField<Export.TransactionCsv> transactionCsv)Sets Builder.transactionCsv to an arbitrary JSON value. final Export.Buildertype(Export.Type type)A constant representing the object's type. final Export.Buildertype(JsonField<Export.Type> type)Sets Builder.type to an arbitrary JSON value. final Export.BuildervendorCsv(Export.VendorCsv vendorCsv)Details of the vendor CSV export. final Export.BuildervendorCsv(Optional<Export.VendorCsv> vendorCsv)Alias for calling Builder.vendorCsv with vendorCsv.orElse(null).final Export.BuildervendorCsv(JsonField<Export.VendorCsv> vendorCsv)Sets Builder.vendorCsv to an arbitrary JSON value. final Export.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Export.BuilderputAdditionalProperty(String key, JsonValue value)final Export.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Export.BuilderremoveAdditionalProperty(String key)final Export.BuilderremoveAllAdditionalProperties(Set<String> keys)final Exportbuild()Returns an immutable instance of Export. -
-
Method Detail
-
id
final Export.Builder id(String id)
The Export identifier.
-
id
final Export.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountStatementBai2
final Export.Builder accountStatementBai2(Export.AccountStatementBai2 accountStatementBai2)
Details of the account statement BAI2 export. This field will be present when the
categoryis equal toaccount_statement_bai2.
-
accountStatementBai2
final Export.Builder accountStatementBai2(Optional<Export.AccountStatementBai2> accountStatementBai2)
Alias for calling Builder.accountStatementBai2 with
accountStatementBai2.orElse(null).
-
accountStatementBai2
final Export.Builder accountStatementBai2(JsonField<Export.AccountStatementBai2> accountStatementBai2)
Sets Builder.accountStatementBai2 to an arbitrary JSON value.
You should usually call Builder.accountStatementBai2 with a well-typed AccountStatementBai2 value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountStatementOfx
final Export.Builder accountStatementOfx(Export.AccountStatementOfx accountStatementOfx)
Details of the account statement OFX export. This field will be present when the
categoryis equal toaccount_statement_ofx.
-
accountStatementOfx
final Export.Builder accountStatementOfx(Optional<Export.AccountStatementOfx> accountStatementOfx)
Alias for calling Builder.accountStatementOfx with
accountStatementOfx.orElse(null).
-
accountStatementOfx
final Export.Builder accountStatementOfx(JsonField<Export.AccountStatementOfx> accountStatementOfx)
Sets Builder.accountStatementOfx to an arbitrary JSON value.
You should usually call Builder.accountStatementOfx with a well-typed AccountStatementOfx value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountVerificationLetter
final Export.Builder accountVerificationLetter(Export.AccountVerificationLetter accountVerificationLetter)
Details of the account verification letter export. This field will be present when the
categoryis equal toaccount_verification_letter.
-
accountVerificationLetter
final Export.Builder accountVerificationLetter(Optional<Export.AccountVerificationLetter> accountVerificationLetter)
Alias for calling Builder.accountVerificationLetter with
accountVerificationLetter.orElse(null).
-
accountVerificationLetter
final Export.Builder accountVerificationLetter(JsonField<Export.AccountVerificationLetter> accountVerificationLetter)
Sets Builder.accountVerificationLetter to an arbitrary JSON value.
You should usually call Builder.accountVerificationLetter with a well-typed AccountVerificationLetter value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
balanceCsv
final Export.Builder balanceCsv(Export.BalanceCsv balanceCsv)
Details of the balance CSV export. This field will be present when the
categoryis equal tobalance_csv.
-
balanceCsv
final Export.Builder balanceCsv(Optional<Export.BalanceCsv> balanceCsv)
Alias for calling Builder.balanceCsv with
balanceCsv.orElse(null).
-
balanceCsv
final Export.Builder balanceCsv(JsonField<Export.BalanceCsv> balanceCsv)
Sets Builder.balanceCsv to an arbitrary JSON value.
You should usually call Builder.balanceCsv with a well-typed BalanceCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bookkeepingAccountBalanceCsv
final Export.Builder bookkeepingAccountBalanceCsv(Export.BookkeepingAccountBalanceCsv bookkeepingAccountBalanceCsv)
Details of the bookkeeping account balance CSV export. This field will be present when the
categoryis equal tobookkeeping_account_balance_csv.
-
bookkeepingAccountBalanceCsv
final Export.Builder bookkeepingAccountBalanceCsv(Optional<Export.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv)
Alias for calling Builder.bookkeepingAccountBalanceCsv with
bookkeepingAccountBalanceCsv.orElse(null).
-
bookkeepingAccountBalanceCsv
final Export.Builder bookkeepingAccountBalanceCsv(JsonField<Export.BookkeepingAccountBalanceCsv> bookkeepingAccountBalanceCsv)
Sets Builder.bookkeepingAccountBalanceCsv to an arbitrary JSON value.
You should usually call Builder.bookkeepingAccountBalanceCsv with a well-typed BookkeepingAccountBalanceCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Export.Builder category(Export.Category category)
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
category
final Export.Builder category(JsonField<Export.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Export.Builder createdAt(OffsetDateTime createdAt)
The time the Export was created.
-
createdAt
final Export.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dashboardTableCsv
final Export.Builder dashboardTableCsv(Export.DashboardTableCsv dashboardTableCsv)
Details of the dashboard table CSV export. This field will be present when the
categoryis equal todashboard_table_csv.
-
dashboardTableCsv
final Export.Builder dashboardTableCsv(Optional<Export.DashboardTableCsv> dashboardTableCsv)
Alias for calling Builder.dashboardTableCsv with
dashboardTableCsv.orElse(null).
-
dashboardTableCsv
final Export.Builder dashboardTableCsv(JsonField<Export.DashboardTableCsv> dashboardTableCsv)
Sets Builder.dashboardTableCsv to an arbitrary JSON value.
You should usually call Builder.dashboardTableCsv with a well-typed DashboardTableCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
entityCsv
final Export.Builder entityCsv(Export.EntityCsv entityCsv)
Details of the entity CSV export. This field will be present when the
categoryis equal toentity_csv.
-
entityCsv
final Export.Builder entityCsv(Optional<Export.EntityCsv> entityCsv)
Alias for calling Builder.entityCsv with
entityCsv.orElse(null).
-
entityCsv
final Export.Builder entityCsv(JsonField<Export.EntityCsv> entityCsv)
Sets Builder.entityCsv to an arbitrary JSON value.
You should usually call Builder.entityCsv with a well-typed EntityCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(String fileDownloadUrl)
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(Optional<String> fileDownloadUrl)
Alias for calling Builder.fileDownloadUrl with
fileDownloadUrl.orElse(null).
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(JsonField<String> fileDownloadUrl)
Sets Builder.fileDownloadUrl to an arbitrary JSON value.
You should usually call Builder.fileDownloadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final Export.Builder fileId(String fileId)
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
fileId
final Export.Builder fileId(Optional<String> fileId)
Alias for calling Builder.fileId with
fileId.orElse(null).
-
fileId
final Export.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
form1099Int
final Export.Builder form1099Int(Export.Form1099Int form1099Int)
Details of the Form 1099-INT export. This field will be present when the
categoryis equal toform_1099_int.
-
form1099Int
final Export.Builder form1099Int(Optional<Export.Form1099Int> form1099Int)
Alias for calling Builder.form1099Int with
form1099Int.orElse(null).
-
form1099Int
final Export.Builder form1099Int(JsonField<Export.Form1099Int> form1099Int)
Sets Builder.form1099Int to an arbitrary JSON value.
You should usually call Builder.form1099Int with a well-typed Form1099Int value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
form1099Misc
final Export.Builder form1099Misc(Export.Form1099Misc form1099Misc)
Details of the Form 1099-MISC export. This field will be present when the
categoryis equal toform_1099_misc.
-
form1099Misc
final Export.Builder form1099Misc(Optional<Export.Form1099Misc> form1099Misc)
Alias for calling Builder.form1099Misc with
form1099Misc.orElse(null).
-
form1099Misc
final Export.Builder form1099Misc(JsonField<Export.Form1099Misc> form1099Misc)
Sets Builder.form1099Misc to an arbitrary JSON value.
You should usually call Builder.form1099Misc with a well-typed Form1099Misc value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fundingInstructions
final Export.Builder fundingInstructions(Export.FundingInstructions fundingInstructions)
Details of the funding instructions export. This field will be present when the
categoryis equal tofunding_instructions.
-
fundingInstructions
final Export.Builder fundingInstructions(Optional<Export.FundingInstructions> fundingInstructions)
Alias for calling Builder.fundingInstructions with
fundingInstructions.orElse(null).
-
fundingInstructions
final Export.Builder fundingInstructions(JsonField<Export.FundingInstructions> fundingInstructions)
Sets Builder.fundingInstructions to an arbitrary JSON value.
You should usually call Builder.fundingInstructions with a well-typed FundingInstructions value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final Export.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Export.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final Export.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Export.Builder status(Export.Status status)
The status of the Export.
-
status
final Export.Builder status(JsonField<Export.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionCsv
final Export.Builder transactionCsv(Export.TransactionCsv transactionCsv)
Details of the transaction CSV export. This field will be present when the
categoryis equal totransaction_csv.
-
transactionCsv
final Export.Builder transactionCsv(Optional<Export.TransactionCsv> transactionCsv)
Alias for calling Builder.transactionCsv with
transactionCsv.orElse(null).
-
transactionCsv
final Export.Builder transactionCsv(JsonField<Export.TransactionCsv> transactionCsv)
Sets Builder.transactionCsv to an arbitrary JSON value.
You should usually call Builder.transactionCsv with a well-typed TransactionCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Export.Builder type(Export.Type type)
A constant representing the object's type. For this resource it will always be
export.
-
type
final Export.Builder type(JsonField<Export.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vendorCsv
final Export.Builder vendorCsv(Export.VendorCsv vendorCsv)
Details of the vendor CSV export. This field will be present when the
categoryis equal tovendor_csv.
-
vendorCsv
final Export.Builder vendorCsv(Optional<Export.VendorCsv> vendorCsv)
Alias for calling Builder.vendorCsv with
vendorCsv.orElse(null).
-
vendorCsv
final Export.Builder vendorCsv(JsonField<Export.VendorCsv> vendorCsv)
Sets Builder.vendorCsv to an arbitrary JSON value.
You should usually call Builder.vendorCsv with a well-typed VendorCsv value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Export.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Export build()
Returns an immutable instance of Export.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountStatementBai2() .accountStatementOfx() .accountVerificationLetter() .balanceCsv() .bookkeepingAccountBalanceCsv() .category() .createdAt() .dashboardTableCsv() .entityCsv() .fileDownloadUrl() .fileId() .form1099Int() .form1099Misc() .fundingInstructions() .idempotencyKey() .status() .transactionCsv() .type() .vendorCsv()
-
-
-
-