Class Export.Builder
-
- All Implemented Interfaces:
public final class Export.BuilderA builder for Export.
-
-
Method Summary
Modifier and Type Method Description final Export.Builderid(String id)The Export identifier. final Export.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Export.Buildercategory(Export.Category category)The category of the Export. final Export.Buildercategory(JsonField<Export.Category> category)Sets Builder.category to an arbitrary JSON value. final Export.BuildercreatedAt(OffsetDateTime createdAt)The time the Export was created. final Export.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Export.BuilderfileDownloadUrl(String fileDownloadUrl)A URL at which the Export's file can be downloaded. final Export.BuilderfileDownloadUrl(Optional<String> fileDownloadUrl)Alias for calling Builder.fileDownloadUrl with fileDownloadUrl.orElse(null).final Export.BuilderfileDownloadUrl(JsonField<String> fileDownloadUrl)Sets Builder.fileDownloadUrl to an arbitrary JSON value. final Export.BuilderfileId(String fileId)The File containing the contents of the Export. final Export.BuilderfileId(Optional<String> fileId)Alias for calling Builder.fileId with fileId.orElse(null).final Export.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final Export.BuilderidempotencyKey(String idempotencyKey)The idempotency key you chose for this object. final Export.BuilderidempotencyKey(Optional<String> idempotencyKey)Alias for calling Builder.idempotencyKey with idempotencyKey.orElse(null).final Export.BuilderidempotencyKey(JsonField<String> idempotencyKey)Sets Builder.idempotencyKey to an arbitrary JSON value. final Export.Builderstatus(Export.Status status)The status of the Export. final Export.Builderstatus(JsonField<Export.Status> status)Sets Builder.status to an arbitrary JSON value. final Export.Buildertype(Export.Type type)A constant representing the object's type. final Export.Buildertype(JsonField<Export.Type> type)Sets Builder.type to an arbitrary JSON value. final Export.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Export.BuilderputAdditionalProperty(String key, JsonValue value)final Export.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Export.BuilderremoveAdditionalProperty(String key)final Export.BuilderremoveAllAdditionalProperties(Set<String> keys)final Exportbuild()Returns an immutable instance of Export. -
-
Method Detail
-
id
final Export.Builder id(String id)
The Export identifier.
-
id
final Export.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
category
final Export.Builder category(Export.Category category)
The category of the Export. We may add additional possible values for this enum over time; your application should be able to handle that gracefully.
-
category
final Export.Builder category(JsonField<Export.Category> category)
Sets Builder.category to an arbitrary JSON value.
You should usually call Builder.category with a well-typed Category value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Export.Builder createdAt(OffsetDateTime createdAt)
The time the Export was created.
-
createdAt
final Export.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(String fileDownloadUrl)
A URL at which the Export's file can be downloaded. This will be present when the Export's status transitions to
complete.
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(Optional<String> fileDownloadUrl)
Alias for calling Builder.fileDownloadUrl with
fileDownloadUrl.orElse(null).
-
fileDownloadUrl
final Export.Builder fileDownloadUrl(JsonField<String> fileDownloadUrl)
Sets Builder.fileDownloadUrl to an arbitrary JSON value.
You should usually call Builder.fileDownloadUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final Export.Builder fileId(String fileId)
The File containing the contents of the Export. This will be present when the Export's status transitions to
complete.
-
fileId
final Export.Builder fileId(Optional<String> fileId)
Alias for calling Builder.fileId with
fileId.orElse(null).
-
fileId
final Export.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final Export.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final Export.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final Export.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final Export.Builder status(Export.Status status)
The status of the Export.
-
status
final Export.Builder status(JsonField<Export.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Export.Builder type(Export.Type type)
A constant representing the object's type. For this resource it will always be
export.
-
type
final Export.Builder type(JsonField<Export.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Export.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Export.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Export.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Export.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Export.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-