Package com.increase.api.models.exports
Class Export.Form1099Misc
-
- All Implemented Interfaces:
public final class Export.Form1099MiscDetails of the Form 1099-MISC export. This field will be present when the
categoryis equal toform_1099_misc.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.Form1099Misc.BuilderA builder for Form1099Misc.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account the tax form is for. final Booleancorrected()Whether the tax form is a corrected form. final Longyear()The tax year for the tax form. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Boolean>_corrected()Returns the raw JSON value of corrected. final JsonField<Long>_year()Returns the raw JSON value of year. final Map<String, JsonValue>_additionalProperties()final Export.Form1099Misc.BuildertoBuilder()final Export.Form1099Miscvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.Form1099Misc.Builderbuilder()Returns a mutable builder for constructing an instance of Form1099Misc. -
-
Method Detail
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_corrected
final JsonField<Boolean> _corrected()
Returns the raw JSON value of corrected.
Unlike corrected, this method doesn't throw if the JSON field has an unexpected type.
-
_year
final JsonField<Long> _year()
Returns the raw JSON value of year.
Unlike year, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.Form1099Misc.Builder toBuilder()
-
validate
final Export.Form1099Misc validate()
-
builder
final static Export.Form1099Misc.Builder builder()
Returns a mutable builder for constructing an instance of Form1099Misc.
The following fields are required:
.accountId() .corrected() .year()
-
-
-
-