Package com.increase.api.models.exports
Class Export.TransactionCsv
-
- All Implemented Interfaces:
public final class Export.TransactionCsvDetails of the transaction CSV export. This field will be present when the
categoryis equal totransaction_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.TransactionCsv.BuilderA builder for TransactionCsv.
public final classExport.TransactionCsv.CreatedAtFilter transactions by their created date.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter results by Account. final Optional<Export.TransactionCsv.CreatedAt>createdAt()Filter transactions by their created date. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Export.TransactionCsv.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final Export.TransactionCsv.BuildertoBuilder()final Export.TransactionCsvvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.TransactionCsv.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionCsv. -
-
Method Detail
-
createdAt
final Optional<Export.TransactionCsv.CreatedAt> createdAt()
Filter transactions by their created date.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Export.TransactionCsv.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.TransactionCsv.Builder toBuilder()
-
validate
final Export.TransactionCsv validate()
-
builder
final static Export.TransactionCsv.Builder builder()
Returns a mutable builder for constructing an instance of TransactionCsv.
The following fields are required:
.accountId() .createdAt()
-
-
-
-