Package com.increase.api.models.exports
Class Export.TransactionCsv.CreatedAt
-
- All Implemented Interfaces:
public final class Export.TransactionCsv.CreatedAtFilter transactions by their created date.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.TransactionCsv.CreatedAt.BuilderA builder for CreatedAt.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>after()Filter transactions created after this time. final Optional<OffsetDateTime>before()Filter transactions created before this time. final JsonField<OffsetDateTime>_after()Returns the raw JSON value of after. final JsonField<OffsetDateTime>_before()Returns the raw JSON value of before. final Map<String, JsonValue>_additionalProperties()final Export.TransactionCsv.CreatedAt.BuildertoBuilder()final Export.TransactionCsv.CreatedAtvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.TransactionCsv.CreatedAt.Builderbuilder()Returns a mutable builder for constructing an instance of CreatedAt. -
-
Method Detail
-
after
final Optional<OffsetDateTime> after()
Filter transactions created after this time.
-
before
final Optional<OffsetDateTime> before()
Filter transactions created before this time.
-
_after
final JsonField<OffsetDateTime> _after()
Returns the raw JSON value of after.
Unlike after, this method doesn't throw if the JSON field has an unexpected type.
-
_before
final JsonField<OffsetDateTime> _before()
Returns the raw JSON value of before.
Unlike before, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.TransactionCsv.CreatedAt.Builder toBuilder()
-
validate
final Export.TransactionCsv.CreatedAt validate()
-
builder
final static Export.TransactionCsv.CreatedAt.Builder builder()
Returns a mutable builder for constructing an instance of CreatedAt.
The following fields are required:
.after() .before()
-
-
-
-