Package com.increase.api.models.exports
Class Export.VoidedCheck
-
- All Implemented Interfaces:
public final class Export.VoidedCheckDetails of the voided check export. This field will be present when the
categoryis equal tovoided_check.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExport.VoidedCheck.BuilderA builder for VoidedCheck.
public final classExport.VoidedCheck.Payer
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number for the voided check. final List<Export.VoidedCheck.Payer>payer()The payer information printed on the check. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<List<Export.VoidedCheck.Payer>>_payer()Returns the raw JSON value of payer. final Map<String, JsonValue>_additionalProperties()final Export.VoidedCheck.BuildertoBuilder()final Export.VoidedCheckvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Export.VoidedCheck.Builderbuilder()Returns a mutable builder for constructing an instance of VoidedCheck. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number for the voided check.
-
payer
final List<Export.VoidedCheck.Payer> payer()
The payer information printed on the check.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_payer
final JsonField<List<Export.VoidedCheck.Payer>> _payer()
Returns the raw JSON value of payer.
Unlike payer, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Export.VoidedCheck.Builder toBuilder()
-
validate
final Export.VoidedCheck validate()
-
builder
final static Export.VoidedCheck.Builder builder()
Returns a mutable builder for constructing an instance of VoidedCheck.
The following fields are required:
.accountNumberId() .payer()
-
-
-
-