Package com.increase.api.models.exports
Class ExportCreateParams.TransactionCsv
-
- All Implemented Interfaces:
public final class ExportCreateParams.TransactionCsvOptions for the created export. Required if
categoryis equal totransaction_csv.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.TransactionCsv.BuilderA builder for TransactionCsv.
public final classExportCreateParams.TransactionCsv.CreatedAtFilter results by time range on the
created_atattribute.
-
Method Summary
Modifier and Type Method Description final Optional<String>accountId()Filter exported Transactions to the specified Account. final Optional<ExportCreateParams.TransactionCsv.CreatedAt>createdAt()Filter results by time range on the created_atattribute.final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<ExportCreateParams.TransactionCsv.CreatedAt>_createdAt()Returns the raw JSON value of createdAt. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.TransactionCsv.BuildertoBuilder()final ExportCreateParams.TransactionCsvvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.TransactionCsv.Builderbuilder()Returns a mutable builder for constructing an instance of TransactionCsv. -
-
Method Detail
-
createdAt
final Optional<ExportCreateParams.TransactionCsv.CreatedAt> createdAt()
Filter results by time range on the
created_atattribute.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<ExportCreateParams.TransactionCsv.CreatedAt> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.TransactionCsv.Builder toBuilder()
-
validate
final ExportCreateParams.TransactionCsv validate()
-
builder
final static ExportCreateParams.TransactionCsv.Builder builder()
Returns a mutable builder for constructing an instance of TransactionCsv.
-
-
-
-