Class ExportCreateParams.TransactionCsv.CreatedAt
-
- All Implemented Interfaces:
public final class ExportCreateParams.TransactionCsv.CreatedAtFilter results by time range on the
created_atattribute.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.TransactionCsv.CreatedAt.BuilderA builder for CreatedAt.
-
Method Summary
-
-
Method Detail
-
after
final Optional<OffsetDateTime> after()
Return results after this ISO 8601 timestamp.
-
before
final Optional<OffsetDateTime> before()
Return results before this ISO 8601 timestamp.
-
onOrAfter
final Optional<OffsetDateTime> onOrAfter()
Return results on or after this ISO 8601 timestamp.
-
onOrBefore
final Optional<OffsetDateTime> onOrBefore()
Return results on or before this ISO 8601 timestamp.
-
_after
final JsonField<OffsetDateTime> _after()
Returns the raw JSON value of after.
Unlike after, this method doesn't throw if the JSON field has an unexpected type.
-
_before
final JsonField<OffsetDateTime> _before()
Returns the raw JSON value of before.
Unlike before, this method doesn't throw if the JSON field has an unexpected type.
-
_onOrAfter
final JsonField<OffsetDateTime> _onOrAfter()
Returns the raw JSON value of onOrAfter.
Unlike onOrAfter, this method doesn't throw if the JSON field has an unexpected type.
-
_onOrBefore
final JsonField<OffsetDateTime> _onOrBefore()
Returns the raw JSON value of onOrBefore.
Unlike onOrBefore, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.TransactionCsv.CreatedAt.Builder toBuilder()
-
validate
final ExportCreateParams.TransactionCsv.CreatedAt validate()
-
builder
final static ExportCreateParams.TransactionCsv.CreatedAt.Builder builder()
Returns a mutable builder for constructing an instance of CreatedAt.
-
-
-
-