Package com.increase.api.models.exports
Class ExportCreateParams.VoidedCheck.Payer
-
- All Implemented Interfaces:
public final class ExportCreateParams.VoidedCheck.Payer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.VoidedCheck.Payer.BuilderA builder for Payer.
-
Method Summary
Modifier and Type Method Description final Stringline()The contents of the line. final JsonField<String>_line()Returns the raw JSON value of line. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.VoidedCheck.Payer.BuildertoBuilder()final ExportCreateParams.VoidedCheck.Payervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.VoidedCheck.Payer.Builderbuilder()Returns a mutable builder for constructing an instance of Payer. -
-
Method Detail
-
_line
final JsonField<String> _line()
Returns the raw JSON value of line.
Unlike line, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.VoidedCheck.Payer.Builder toBuilder()
-
validate
final ExportCreateParams.VoidedCheck.Payer validate()
-
builder
final static ExportCreateParams.VoidedCheck.Payer.Builder builder()
Returns a mutable builder for constructing an instance of Payer.
The following fields are required:
.line()
-
-
-
-