Class ExternalAccountListPage
-
- All Implemented Interfaces:
public final class ExternalAccountListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountListPage.BuilderA builder for ExternalAccountListPage.
public final classExternalAccountListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<ExternalAccount>data()Delegates to ExternalAccountListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ExternalAccountListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<ExternalAccountListParams>getNextPageParams()final Optional<ExternalAccountListPage>getNextPage()final ExternalAccountListPage.AutoPagerautoPager()final ExternalAccountListParamsparams()The parameters that were used to request this page. final ExternalAccountListPageResponseresponse()The response that this page was parsed from. final ExternalAccountListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountListPage.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccountListPage. -
-
Method Detail
-
data
final List<ExternalAccount> data()
Delegates to ExternalAccountListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ExternalAccountListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ExternalAccountListParams> getNextPageParams()
-
getNextPage
final Optional<ExternalAccountListPage> getNextPage()
-
autoPager
final ExternalAccountListPage.AutoPager autoPager()
-
params
final ExternalAccountListParams params()
The parameters that were used to request this page.
-
response
final ExternalAccountListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ExternalAccountListPage.Builder toBuilder()
-
builder
final static ExternalAccountListPage.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccountListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-