Class ExternalAccountListPageResponse
-
- All Implemented Interfaces:
public final class ExternalAccountListPageResponseA list of External Account objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountListPageResponse.BuilderA builder for ExternalAccountListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<ExternalAccount>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<ExternalAccount>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final ExternalAccountListPageResponse.BuildertoBuilder()final ExternalAccountListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExternalAccountListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ExternalAccountListPageResponse. -
-
Method Detail
-
data
final List<ExternalAccount> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<ExternalAccount>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalAccountListPageResponse.Builder toBuilder()
-
validate
final ExternalAccountListPageResponse validate()
-
builder
final static ExternalAccountListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of ExternalAccountListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-