Class ExternalAccountUpdateParams.Body
-
- All Implemented Interfaces:
public final class ExternalAccountUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExternalAccountUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
accountHolder
final Optional<ExternalAccountUpdateParams.AccountHolder> accountHolder()
The type of entity that owns the External Account.
-
description
final Optional<String> description()
The description you choose to give the external account.
-
funding
final Optional<ExternalAccountUpdateParams.Funding> funding()
The funding type of the External Account.
-
status
final Optional<ExternalAccountUpdateParams.Status> status()
The status of the External Account.
-
_accountHolder
final JsonField<ExternalAccountUpdateParams.AccountHolder> _accountHolder()
Returns the raw JSON value of accountHolder.
Unlike accountHolder, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_funding
final JsonField<ExternalAccountUpdateParams.Funding> _funding()
Returns the raw JSON value of funding.
Unlike funding, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ExternalAccountUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExternalAccountUpdateParams.Body.Builder toBuilder()
-
validate
final ExternalAccountUpdateParams.Body validate()
-
builder
final static ExternalAccountUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-