Class FileLinkCreateParams.Body
-
- All Implemented Interfaces:
public final class FileLinkCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileLinkCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringfileId()The File to create a File Link for. final Optional<OffsetDateTime>expiresAt()The time at which the File Link will expire. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<OffsetDateTime>_expiresAt()Returns the raw JSON value of expiresAt. final Map<String, JsonValue>_additionalProperties()final FileLinkCreateParams.Body.BuildertoBuilder()final FileLinkCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileLinkCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
expiresAt
final Optional<OffsetDateTime> expiresAt()
The time at which the File Link will expire. The default is 1 hour from the time of the request. The maximum is 1 day from the time of the request.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAt
final JsonField<OffsetDateTime> _expiresAt()
Returns the raw JSON value of expiresAt.
Unlike expiresAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileLinkCreateParams.Body.Builder toBuilder()
-
validate
final FileLinkCreateParams.Body validate()
-
builder
final static FileLinkCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.fileId()
-
-
-
-