Class File
-
- All Implemented Interfaces:
public final class FileFiles are objects that represent a file hosted on Increase's servers. The file may have been uploaded by you (for example, when uploading a check image) or it may have been created by Increase (for example, an autogenerated statement PDF). If you need to download a File, create a File Link.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFile.BuilderA builder for File.
public final classFile.DirectionWhether the File was generated by Increase or by you and sent to Increase.
public final classFile.PurposeWhat the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classFile.TypeA constant representing the object's type. For this resource it will always be
file.
-
Method Summary
Modifier and Type Method Description final Stringid()The File's identifier. final OffsetDateTimecreatedAt()The time the File was created. final Optional<String>description()A description of the File. final File.Directiondirection()Whether the File was generated by Increase or by you and sent to Increase. final Optional<String>filename()The filename that was provided upon upload or generated by Increase. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringmimeType()The MIME type of the file. final File.Purposepurpose()What the File will be used for. final File.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<File.Direction>_direction()Returns the raw JSON value of direction. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_mimeType()Returns the raw JSON value of mimeType. final JsonField<File.Purpose>_purpose()Returns the raw JSON value of purpose. final JsonField<File.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final File.BuildertoBuilder()final Filevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static File.Builderbuilder()Returns a mutable builder for constructing an instance of File. -
-
Method Detail
-
createdAt
final OffsetDateTime createdAt()
The time the File was created.
-
description
final Optional<String> description()
A description of the File.
-
direction
final File.Direction direction()
Whether the File was generated by Increase or by you and sent to Increase.
-
filename
final Optional<String> filename()
The filename that was provided upon upload or generated by Increase.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
purpose
final File.Purpose purpose()
What the File will be used for. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
type
final File.Type type()
A constant representing the object's type. For this resource it will always be
file.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<File.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_mimeType
final JsonField<String> _mimeType()
Returns the raw JSON value of mimeType.
Unlike mimeType, this method doesn't throw if the JSON field has an unexpected type.
-
_purpose
final JsonField<File.Purpose> _purpose()
Returns the raw JSON value of purpose.
Unlike purpose, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<File.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final File.Builder toBuilder()
-
builder
final static File.Builder builder()
Returns a mutable builder for constructing an instance of File.
The following fields are required:
.id() .createdAt() .description() .direction() .filename() .idempotencyKey() .mimeType() .purpose() .type()
-
-
-
-