Package com.increase.api.models.files
Class FileCreateParams.Body
-
- All Implemented Interfaces:
public final class FileCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final InputStreamfile()The file contents. final FileCreateParams.Purposepurpose()What the File will be used for in Increase's systems. final Optional<String>description()The description you choose to give the File. final MultipartField<InputStream>_file()Returns the raw multipart value of file. final MultipartField<FileCreateParams.Purpose>_purpose()Returns the raw multipart value of purpose. final MultipartField<String>_description()Returns the raw multipart value of description. final Map<String, JsonValue>_additionalProperties()final FileCreateParams.Body.BuildertoBuilder()final FileCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
file
final InputStream file()
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
purpose
final FileCreateParams.Purpose purpose()
What the File will be used for in Increase's systems.
-
description
final Optional<String> description()
The description you choose to give the File.
-
_file
final MultipartField<InputStream> _file()
Returns the raw multipart value of file.
Unlike file, this method doesn't throw if the multipart field has an unexpected type.
-
_purpose
final MultipartField<FileCreateParams.Purpose> _purpose()
Returns the raw multipart value of purpose.
Unlike purpose, this method doesn't throw if the multipart field has an unexpected type.
-
_description
final MultipartField<String> _description()
Returns the raw multipart value of description.
Unlike description, this method doesn't throw if the multipart field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileCreateParams.Body.Builder toBuilder()
-
validate
final FileCreateParams.Body validate()
-
builder
final static FileCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.file() .purpose()
-
-
-
-