Class FileCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class FileCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
Modifier and Type Method Description final FileCreateParams.Body.Builderfile(InputStream file)The file contents. final FileCreateParams.Body.Builderfile(MultipartField<InputStream> file)The file contents. final FileCreateParams.Body.Builderfile(ByteArray file)The file contents. final FileCreateParams.Body.Builderfile(Path file)The file contents. final FileCreateParams.Body.Builderpurpose(FileCreateParams.Purpose purpose)What the File will be used for in Increase's systems. final FileCreateParams.Body.Builderpurpose(MultipartField<FileCreateParams.Purpose> purpose)What the File will be used for in Increase's systems. final FileCreateParams.Body.Builderdescription(String description)The description you choose to give the File. final FileCreateParams.Body.Builderdescription(MultipartField<String> description)The description you choose to give the File. final FileCreateParams.Bodybuild()Returns an immutable instance of Body. -
-
Method Detail
-
file
final FileCreateParams.Body.Builder file(InputStream file)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
file
final FileCreateParams.Body.Builder file(MultipartField<InputStream> file)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
file
final FileCreateParams.Body.Builder file(ByteArray file)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
file
final FileCreateParams.Body.Builder file(Path file)
The file contents. This should follow the specifications of RFC 7578 which defines file transfers for the multipart/form-data protocol.
-
purpose
final FileCreateParams.Body.Builder purpose(FileCreateParams.Purpose purpose)
What the File will be used for in Increase's systems.
-
purpose
final FileCreateParams.Body.Builder purpose(MultipartField<FileCreateParams.Purpose> purpose)
What the File will be used for in Increase's systems.
-
description
final FileCreateParams.Body.Builder description(String description)
The description you choose to give the File.
-
description
final FileCreateParams.Body.Builder description(MultipartField<String> description)
The description you choose to give the File.
-
build
final FileCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.file() .purpose()
-
-
-
-