Class Group

  • All Implemented Interfaces:

    
    public final class Group
    
                        

    Groups represent organizations using Increase. You can retrieve information about your own organization via the API. More commonly, OAuth platforms can retrieve information about the organizations that have granted them access. Learn more about OAuth here.