Class Group.Builder
-
- All Implemented Interfaces:
public final class Group.BuilderA builder for Group.
-
-
Method Summary
Modifier and Type Method Description final Group.Builderid(String id)The Group identifier. final Group.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final Group.BuilderachDebitStatus(Group.AchDebitStatus achDebitStatus)If the Group is allowed to create ACH debits. final Group.BuilderachDebitStatus(JsonField<Group.AchDebitStatus> achDebitStatus)Sets Builder.achDebitStatus to an arbitrary JSON value. final Group.BuilderactivationStatus(Group.ActivationStatus activationStatus)If the Group is activated or not. final Group.BuilderactivationStatus(JsonField<Group.ActivationStatus> activationStatus)Sets Builder.activationStatus to an arbitrary JSON value. final Group.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 time at which the Group was created. final Group.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final Group.Buildertype(Group.Type type)A constant representing the object's type. final Group.Buildertype(JsonField<Group.Type> type)Sets Builder.type to an arbitrary JSON value. final Group.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Group.BuilderputAdditionalProperty(String key, JsonValue value)final Group.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Group.BuilderremoveAdditionalProperty(String key)final Group.BuilderremoveAllAdditionalProperties(Set<String> keys)final Groupbuild()Returns an immutable instance of Group. -
-
Method Detail
-
id
final Group.Builder id(String id)
The Group identifier.
-
id
final Group.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
achDebitStatus
final Group.Builder achDebitStatus(Group.AchDebitStatus achDebitStatus)
If the Group is allowed to create ACH debits.
-
achDebitStatus
final Group.Builder achDebitStatus(JsonField<Group.AchDebitStatus> achDebitStatus)
Sets Builder.achDebitStatus to an arbitrary JSON value.
You should usually call Builder.achDebitStatus with a well-typed AchDebitStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
activationStatus
final Group.Builder activationStatus(Group.ActivationStatus activationStatus)
If the Group is activated or not.
-
activationStatus
final Group.Builder activationStatus(JsonField<Group.ActivationStatus> activationStatus)
Sets Builder.activationStatus to an arbitrary JSON value.
You should usually call Builder.activationStatus with a well-typed ActivationStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Group.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 time at which the Group was created.
-
createdAt
final Group.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final Group.Builder type(Group.Type type)
A constant representing the object's type. For this resource it will always be
group.
-
type
final Group.Builder type(JsonField<Group.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Group.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Group.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Group.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Group.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Group.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-