Class InboundMailItem.Check
-
- All Implemented Interfaces:
public final class InboundMailItem.CheckInbound Mail Item Checks represent the checks in an Inbound Mail Item.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItem.Check.BuilderA builder for Check.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the check. final Optional<String>backFileId()The identifier for the File containing the back of the check. final Optional<String>frontFileId()The identifier for the File containing the front of the check. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_backFileId()Returns the raw JSON value of backFileId. final JsonField<String>_frontFileId()Returns the raw JSON value of frontFileId. final Map<String, JsonValue>_additionalProperties()final InboundMailItem.Check.BuildertoBuilder()final InboundMailItem.Checkvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItem.Check.Builderbuilder()Returns a mutable builder for constructing an instance of Check. -
-
Method Detail
-
backFileId
final Optional<String> backFileId()
The identifier for the File containing the back of the check.
-
frontFileId
final Optional<String> frontFileId()
The identifier for the File containing the front of the check.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_backFileId
final JsonField<String> _backFileId()
Returns the raw JSON value of backFileId.
Unlike backFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontFileId
final JsonField<String> _frontFileId()
Returns the raw JSON value of frontFileId.
Unlike frontFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundMailItem.Check.Builder toBuilder()
-
validate
final InboundMailItem.Check validate()
-
builder
final static InboundMailItem.Check.Builder builder()
Returns a mutable builder for constructing an instance of Check.
The following fields are required:
.amount() .backFileId() .frontFileId()
-
-
-
-