Enum InboundMailItem.RejectionReason.Value
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum InboundMailItem.RejectionReason.Value extends Enum<InboundMailItem.RejectionReason.Value>
An enum containing RejectionReason's known values, as well as an _UNKNOWN member.
An instance of RejectionReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<InboundMailItem.RejectionReason.Value>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description NO_MATCHING_LOCKBOXThe mail item does not match any lockbox.
NO_CHECKThe mail item does not contain a check.
LOCKBOX_NOT_ACTIVEThe Lockbox or its associated Account is not active.
_UNKNOWNAn enum member indicating that RejectionReason was instantiated with an unknown value.
-
Method Summary
Modifier and Type Method Description final InboundMailItem.RejectionReason.ValuevalueOf(String value)Returns the enum constant of this type with the specified name. final Array<InboundMailItem.RejectionReason.Value>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<InboundMailItem.RejectionReason.Value>getEntries()An enum containing RejectionReason's known values, as well as an _UNKNOWN member. -
-
Method Detail
-
valueOf
final InboundMailItem.RejectionReason.Value valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<InboundMailItem.RejectionReason.Value> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<InboundMailItem.RejectionReason.Value> getEntries()
An enum containing RejectionReason's known values, as well as an _UNKNOWN member.
An instance of RejectionReason can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
-
-
-