Class InboundMailItemListPage
-
- All Implemented Interfaces:
public final class InboundMailItemListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemListPage.BuilderA builder for InboundMailItemListPage.
public final classInboundMailItemListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<InboundMailItem>data()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<InboundMailItemListParams>getNextPageParams()final Optional<InboundMailItemListPage>getNextPage()final InboundMailItemListPage.AutoPagerautoPager()final InboundMailItemListParamsparams()The parameters that were used to request this page. final InboundMailItemListPageResponseresponse()The response that this page was parsed from. final InboundMailItemListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemListPage.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemListPage. -
-
Method Detail
-
data
final List<InboundMailItem> data()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<InboundMailItemListParams> getNextPageParams()
-
getNextPage
final Optional<InboundMailItemListPage> getNextPage()
-
autoPager
final InboundMailItemListPage.AutoPager autoPager()
-
params
final InboundMailItemListParams params()
The parameters that were used to request this page.
-
response
final InboundMailItemListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundMailItemListPage.Builder toBuilder()
-
builder
final static InboundMailItemListPage.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-