Class InboundMailItemListPageAsync
-
- All Implemented Interfaces:
public final class InboundMailItemListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemListPageAsync.BuilderA builder for InboundMailItemListPageAsync.
public final classInboundMailItemListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<InboundMailItem>data()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to InboundMailItemListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<InboundMailItemListParams>getNextPageParams()final CompletableFuture<Optional<InboundMailItemListPageAsync>>getNextPage()final InboundMailItemListPageAsync.AutoPagerautoPager()final InboundMailItemListParamsparams()The parameters that were used to request this page. final InboundMailItemListPageResponseresponse()The response that this page was parsed from. final InboundMailItemListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemListPageAsync. -
-
Method Detail
-
data
final List<InboundMailItem> data()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to InboundMailItemListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<InboundMailItemListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<InboundMailItemListPageAsync>> getNextPage()
-
autoPager
final InboundMailItemListPageAsync.AutoPager autoPager()
-
params
final InboundMailItemListParams params()
The parameters that were used to request this page.
-
response
final InboundMailItemListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final InboundMailItemListPageAsync.Builder toBuilder()
-
builder
final static InboundMailItemListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-