Class InboundMailItemListPageResponse
-
- All Implemented Interfaces:
public final class InboundMailItemListPageResponseA list of Inbound Mail Item objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemListPageResponse.BuilderA builder for InboundMailItemListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<InboundMailItem>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<InboundMailItem>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final InboundMailItemListPageResponse.BuildertoBuilder()final InboundMailItemListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemListPageResponse. -
-
Method Detail
-
data
final List<InboundMailItem> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list. Pass this as the
cursorparameter to retrieve the next page of results. If there are no more results, the value will benull.
-
_data
final JsonField<List<InboundMailItem>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundMailItemListPageResponse.Builder toBuilder()
-
validate
final InboundMailItemListPageResponse validate()
-
builder
final static InboundMailItemListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-