Class InboundWireDrawdownRequest
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestInbound wire drawdown requests are requests from someone else to send them a wire. For more information, see our /documentation/wire-drawdown-requests.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequest.BuilderA builder for InboundWireDrawdownRequest.
public final classInboundWireDrawdownRequest.TypeA constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Wire drawdown request identifier. final Longamount()The amount being requested in cents. final StringbeneficiaryAccountNumber()The drawdown request's beneficiary's account number. final Optional<String>beneficiaryAddressLine1()Line 1 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryAddressLine2()Line 2 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryAddressLine3()Line 3 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryName()The drawdown request's beneficiary's name. final StringbeneficiaryRoutingNumber()The drawdown request's beneficiary's routing number. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound wire drawdown requested was created. final Stringcurrency()The ISO 4217 code for the amount being requested. final Optional<String>messageToRecipient()A message from the drawdown request's originator. final Optional<String>originatorAccountNumber()The drawdown request's originator's account number. final Optional<String>originatorAddressLine1()Line 1 of the drawdown request's originator's address. final Optional<String>originatorAddressLine2()Line 2 of the drawdown request's originator's address. final Optional<String>originatorAddressLine3()Line 3 of the drawdown request's originator's address. final Optional<String>originatorName()The drawdown request's originator's name. final StringoriginatorRoutingNumber()The drawdown request's originator's routing number. final Optional<String>originatorToBeneficiaryInformationLine1()Line 1 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine2()Line 2 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine3()Line 3 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine4()Line 4 of the information conveyed from the originator of the message to the beneficiary. final StringrecipientAccountNumberId()The Account Number from which the recipient of this request is being requested to send funds. final InboundWireDrawdownRequest.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_beneficiaryAccountNumber()Returns the raw JSON value of beneficiaryAccountNumber. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<String>_beneficiaryRoutingNumber()Returns the raw JSON value of beneficiaryRoutingNumber. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_originatorAccountNumber()Returns the raw JSON value of originatorAccountNumber. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_originatorToBeneficiaryInformationLine1()Returns the raw JSON value of originatorToBeneficiaryInformationLine1. final JsonField<String>_originatorToBeneficiaryInformationLine2()Returns the raw JSON value of originatorToBeneficiaryInformationLine2. final JsonField<String>_originatorToBeneficiaryInformationLine3()Returns the raw JSON value of originatorToBeneficiaryInformationLine3. final JsonField<String>_originatorToBeneficiaryInformationLine4()Returns the raw JSON value of originatorToBeneficiaryInformationLine4. final JsonField<String>_recipientAccountNumberId()Returns the raw JSON value of recipientAccountNumberId. final JsonField<InboundWireDrawdownRequest.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final InboundWireDrawdownRequest.BuildertoBuilder()final InboundWireDrawdownRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequest.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireDrawdownRequest. -
-
Method Detail
-
beneficiaryAccountNumber
final String beneficiaryAccountNumber()
The drawdown request's beneficiary's account number.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryName
final Optional<String> beneficiaryName()
The drawdown request's beneficiary's name.
-
beneficiaryRoutingNumber
final String beneficiaryRoutingNumber()
The drawdown request's beneficiary's routing number.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound wire drawdown requested was created.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
messageToRecipient
final Optional<String> messageToRecipient()
A message from the drawdown request's originator.
-
originatorAccountNumber
final Optional<String> originatorAccountNumber()
The drawdown request's originator's account number.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
Line 3 of the drawdown request's originator's address.
-
originatorName
final Optional<String> originatorName()
The drawdown request's originator's name.
-
originatorRoutingNumber
final String originatorRoutingNumber()
The drawdown request's originator's routing number.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
recipientAccountNumberId
final String recipientAccountNumberId()
The Account Number from which the recipient of this request is being requested to send funds.
-
type
final InboundWireDrawdownRequest.Type type()
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAccountNumber
final JsonField<String> _beneficiaryAccountNumber()
Returns the raw JSON value of beneficiaryAccountNumber.
Unlike beneficiaryAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryRoutingNumber
final JsonField<String> _beneficiaryRoutingNumber()
Returns the raw JSON value of beneficiaryRoutingNumber.
Unlike beneficiaryRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAccountNumber
final JsonField<String> _originatorAccountNumber()
Returns the raw JSON value of originatorAccountNumber.
Unlike originatorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
Returns the raw JSON value of originatorToBeneficiaryInformationLine1.
Unlike originatorToBeneficiaryInformationLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
Returns the raw JSON value of originatorToBeneficiaryInformationLine2.
Unlike originatorToBeneficiaryInformationLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
Returns the raw JSON value of originatorToBeneficiaryInformationLine3.
Unlike originatorToBeneficiaryInformationLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
Returns the raw JSON value of originatorToBeneficiaryInformationLine4.
Unlike originatorToBeneficiaryInformationLine4, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAccountNumberId
final JsonField<String> _recipientAccountNumberId()
Returns the raw JSON value of recipientAccountNumberId.
Unlike recipientAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundWireDrawdownRequest.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundWireDrawdownRequest.Builder toBuilder()
-
validate
final InboundWireDrawdownRequest validate()
-
builder
final static InboundWireDrawdownRequest.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequest.
The following fields are required:
.id() .amount() .beneficiaryAccountNumber() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .beneficiaryRoutingNumber() .createdAt() .currency() .messageToRecipient() .originatorAccountNumber() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .originatorRoutingNumber() .originatorToBeneficiaryInformationLine1() .originatorToBeneficiaryInformationLine2() .originatorToBeneficiaryInformationLine3() .originatorToBeneficiaryInformationLine4() .recipientAccountNumberId() .type()
-
-
-
-