Class InboundWireDrawdownRequest.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequest.BuilderA builder for InboundWireDrawdownRequest.
-
-
Method Summary
-
-
Method Detail
-
id
final InboundWireDrawdownRequest.Builder id(String id)
The Wire drawdown request identifier.
-
id
final InboundWireDrawdownRequest.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireDrawdownRequest.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final InboundWireDrawdownRequest.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequest.Builder beneficiaryAccountNumber(String beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequest.Builder beneficiaryAccountNumber(JsonField<String> beneficiaryAccountNumber)
Sets Builder.beneficiaryAccountNumber to an arbitrary JSON value.
You should usually call Builder.beneficiaryAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
Alias for calling Builder.beneficiaryAddressLine1 with
beneficiaryAddressLine1.orElse(null).
-
beneficiaryAddressLine1
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
Alias for calling Builder.beneficiaryAddressLine2 with
beneficiaryAddressLine2.orElse(null).
-
beneficiaryAddressLine2
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
Alias for calling Builder.beneficiaryAddressLine3 with
beneficiaryAddressLine3.orElse(null).
-
beneficiaryAddressLine3
final InboundWireDrawdownRequest.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final InboundWireDrawdownRequest.Builder beneficiaryName(String beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryName
final InboundWireDrawdownRequest.Builder beneficiaryName(Optional<String> beneficiaryName)
Alias for calling Builder.beneficiaryName with
beneficiaryName.orElse(null).
-
beneficiaryName
final InboundWireDrawdownRequest.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequest.Builder beneficiaryRoutingNumber(String beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequest.Builder beneficiaryRoutingNumber(JsonField<String> beneficiaryRoutingNumber)
Sets Builder.beneficiaryRoutingNumber to an arbitrary JSON value.
You should usually call Builder.beneficiaryRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InboundWireDrawdownRequest.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound wire drawdown requested was created.
-
createdAt
final InboundWireDrawdownRequest.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InboundWireDrawdownRequest.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final InboundWireDrawdownRequest.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final InboundWireDrawdownRequest.Builder messageToRecipient(String messageToRecipient)
A message from the drawdown request's originator.
-
messageToRecipient
final InboundWireDrawdownRequest.Builder messageToRecipient(Optional<String> messageToRecipient)
Alias for calling Builder.messageToRecipient with
messageToRecipient.orElse(null).
-
messageToRecipient
final InboundWireDrawdownRequest.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAccountNumber
final InboundWireDrawdownRequest.Builder originatorAccountNumber(String originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorAccountNumber
final InboundWireDrawdownRequest.Builder originatorAccountNumber(JsonField<String> originatorAccountNumber)
Sets Builder.originatorAccountNumber to an arbitrary JSON value.
You should usually call Builder.originatorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final InboundWireDrawdownRequest.Builder originatorAddressLine1(String originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine1
final InboundWireDrawdownRequest.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
Alias for calling Builder.originatorAddressLine1 with
originatorAddressLine1.orElse(null).
-
originatorAddressLine1
final InboundWireDrawdownRequest.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final InboundWireDrawdownRequest.Builder originatorAddressLine2(String originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine2
final InboundWireDrawdownRequest.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
Alias for calling Builder.originatorAddressLine2 with
originatorAddressLine2.orElse(null).
-
originatorAddressLine2
final InboundWireDrawdownRequest.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final InboundWireDrawdownRequest.Builder originatorAddressLine3(String originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorAddressLine3
final InboundWireDrawdownRequest.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
Alias for calling Builder.originatorAddressLine3 with
originatorAddressLine3.orElse(null).
-
originatorAddressLine3
final InboundWireDrawdownRequest.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final InboundWireDrawdownRequest.Builder originatorName(String originatorName)
The drawdown request's originator's name.
-
originatorName
final InboundWireDrawdownRequest.Builder originatorName(Optional<String> originatorName)
Alias for calling Builder.originatorName with
originatorName.orElse(null).
-
originatorName
final InboundWireDrawdownRequest.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final InboundWireDrawdownRequest.Builder originatorRoutingNumber(String originatorRoutingNumber)
The drawdown request's originator's routing number.
-
originatorRoutingNumber
final InboundWireDrawdownRequest.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)
Alias for calling Builder.originatorToBeneficiaryInformationLine1 with
originatorToBeneficiaryInformationLine1.orElse(null).
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)
Alias for calling Builder.originatorToBeneficiaryInformationLine2 with
originatorToBeneficiaryInformationLine2.orElse(null).
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)
Alias for calling Builder.originatorToBeneficiaryInformationLine3 with
originatorToBeneficiaryInformationLine3.orElse(null).
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)
Alias for calling Builder.originatorToBeneficiaryInformationLine4 with
originatorToBeneficiaryInformationLine4.orElse(null).
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequest.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumberId
final InboundWireDrawdownRequest.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number from which the recipient of this request is being requested to send funds.
-
recipientAccountNumberId
final InboundWireDrawdownRequest.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
Sets Builder.recipientAccountNumberId to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundWireDrawdownRequest.Builder type(InboundWireDrawdownRequest.Type type)
A constant representing the object's type. For this resource it will always be
inbound_wire_drawdown_request.
-
type
final InboundWireDrawdownRequest.Builder type(JsonField<InboundWireDrawdownRequest.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireDrawdownRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireDrawdownRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireDrawdownRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireDrawdownRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireDrawdownRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireDrawdownRequest build()
Returns an immutable instance of InboundWireDrawdownRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .amount() .beneficiaryAccountNumber() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .beneficiaryRoutingNumber() .createdAt() .currency() .messageToRecipient() .originatorAccountNumber() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .originatorRoutingNumber() .originatorToBeneficiaryInformationLine1() .originatorToBeneficiaryInformationLine2() .originatorToBeneficiaryInformationLine3() .originatorToBeneficiaryInformationLine4() .recipientAccountNumberId() .type()
-
-
-
-