Class InboundWireTransfer
-
- All Implemented Interfaces:
public final class InboundWireTransferAn Inbound Wire Transfer is a wire transfer initiated outside of Increase to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransfer.BuilderA builder for InboundWireTransfer.
public final classInboundWireTransfer.ReversalInformation about the reversal of the inbound wire transfer if it has been reversed.
public final classInboundWireTransfer.StatusThe status of the transfer.
public final classInboundWireTransfer.TypeA constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The inbound wire transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumberId()The identifier of the Account Number to which this transfer was sent. final Longamount()The amount in USD cents. final Optional<String>beneficiaryAddressLine1()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine2()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine3()A free-form address field set by the sender. final Optional<String>beneficiaryName()A name set by the sender. final Optional<String>beneficiaryReference()A free-form reference string set by the sender, to help identify the transfer. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the inbound wire transfer was created. final Stringdescription()An Increase-constructed description of the transfer. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>originatorAddressLine1()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine2()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine3()The address of the wire originator, set by the sending bank. final Optional<String>originatorName()The originator of the wire, set by the sending bank. final Optional<String>originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>originatorToBeneficiaryInformation()An Increase-created concatenation of the Originator-to-Beneficiary lines. final Optional<String>originatorToBeneficiaryInformationLine1()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine2()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine3()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine4()A free-form message set by the wire originator. final Optional<InboundWireTransfer.Reversal>reversal()Information about the reversal of the inbound wire transfer if it has been reversed. final Optional<String>senderReference()The sending bank's reference number for the wire transfer. final InboundWireTransfer.Statusstatus()The status of the transfer. final InboundWireTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<String>_beneficiaryReference()Returns the raw JSON value of beneficiaryReference. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_originatorToBeneficiaryInformation()Returns the raw JSON value of originatorToBeneficiaryInformation. final JsonField<String>_originatorToBeneficiaryInformationLine1()Returns the raw JSON value of originatorToBeneficiaryInformationLine1. final JsonField<String>_originatorToBeneficiaryInformationLine2()Returns the raw JSON value of originatorToBeneficiaryInformationLine2. final JsonField<String>_originatorToBeneficiaryInformationLine3()Returns the raw JSON value of originatorToBeneficiaryInformationLine3. final JsonField<String>_originatorToBeneficiaryInformationLine4()Returns the raw JSON value of originatorToBeneficiaryInformationLine4. final JsonField<InboundWireTransfer.Reversal>_reversal()Returns the raw JSON value of reversal. final JsonField<String>_senderReference()Returns the raw JSON value of senderReference. final JsonField<InboundWireTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<InboundWireTransfer.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final InboundWireTransfer.BuildertoBuilder()final InboundWireTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransfer. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number to which this transfer was sent.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
A free-form address field set by the sender.
-
beneficiaryName
final Optional<String> beneficiaryName()
A name set by the sender.
-
beneficiaryReference
final Optional<String> beneficiaryReference()
A free-form reference string set by the sender, to help identify the transfer.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the inbound wire transfer was created.
-
description
final String description()
An Increase-constructed description of the transfer.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The address of the wire originator, set by the sending bank.
-
originatorName
final Optional<String> originatorName()
The originator of the wire, set by the sending bank.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final Optional<String> originatorToBeneficiaryInformation()
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
A free-form message set by the wire originator.
-
reversal
final Optional<InboundWireTransfer.Reversal> reversal()
Information about the reversal of the inbound wire transfer if it has been reversed.
-
senderReference
final Optional<String> senderReference()
The sending bank's reference number for the wire transfer.
-
status
final InboundWireTransfer.Status status()
The status of the transfer.
-
type
final InboundWireTransfer.Type type()
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryReference
final JsonField<String> _beneficiaryReference()
Returns the raw JSON value of beneficiaryReference.
Unlike beneficiaryReference, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformation
final JsonField<String> _originatorToBeneficiaryInformation()
Returns the raw JSON value of originatorToBeneficiaryInformation.
Unlike originatorToBeneficiaryInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
Returns the raw JSON value of originatorToBeneficiaryInformationLine1.
Unlike originatorToBeneficiaryInformationLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
Returns the raw JSON value of originatorToBeneficiaryInformationLine2.
Unlike originatorToBeneficiaryInformationLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
Returns the raw JSON value of originatorToBeneficiaryInformationLine3.
Unlike originatorToBeneficiaryInformationLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
Returns the raw JSON value of originatorToBeneficiaryInformationLine4.
Unlike originatorToBeneficiaryInformationLine4, this method doesn't throw if the JSON field has an unexpected type.
-
_reversal
final JsonField<InboundWireTransfer.Reversal> _reversal()
Returns the raw JSON value of reversal.
Unlike reversal, this method doesn't throw if the JSON field has an unexpected type.
-
_senderReference
final JsonField<String> _senderReference()
Returns the raw JSON value of senderReference.
Unlike senderReference, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InboundWireTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<InboundWireTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundWireTransfer.Builder toBuilder()
-
validate
final InboundWireTransfer validate()
-
builder
final static InboundWireTransfer.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransfer.
The following fields are required:
.id() .accountId() .accountNumberId() .amount() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .beneficiaryReference() .createdAt() .description() .inputMessageAccountabilityData() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .originatorRoutingNumber() .originatorToBeneficiaryInformation() .originatorToBeneficiaryInformationLine1() .originatorToBeneficiaryInformationLine2() .originatorToBeneficiaryInformationLine3() .originatorToBeneficiaryInformationLine4() .reversal() .senderReference() .status() .type()
-
-
-
-