Class InboundWireTransfer.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
-
Method Summary
Modifier and Type Method Description final InboundWireTransfer.Builderid(String id)The inbound wire transfer's identifier. final InboundWireTransfer.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final InboundWireTransfer.BuilderaccountId(String accountId)The Account to which the transfer belongs. final InboundWireTransfer.BuilderaccountId(JsonField<String> accountId)Sets Builder.accountId to an arbitrary JSON value. final InboundWireTransfer.BuilderaccountNumberId(String accountNumberId)The identifier of the Account Number to which this transfer was sent. final InboundWireTransfer.BuilderaccountNumberId(JsonField<String> accountNumberId)Sets Builder.accountNumberId to an arbitrary JSON value. final InboundWireTransfer.Builderamount(Long amount)The amount in USD cents. final InboundWireTransfer.Builderamount(JsonField<Long> amount)Sets Builder.amount to an arbitrary JSON value. final InboundWireTransfer.BuilderbeneficiaryAddressLine1(String beneficiaryAddressLine1)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)Alias for calling Builder.beneficiaryAddressLine1 with beneficiaryAddressLine1.orElse(null).final InboundWireTransfer.BuilderbeneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value. final InboundWireTransfer.BuilderbeneficiaryAddressLine2(String beneficiaryAddressLine2)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)Alias for calling Builder.beneficiaryAddressLine2 with beneficiaryAddressLine2.orElse(null).final InboundWireTransfer.BuilderbeneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value. final InboundWireTransfer.BuilderbeneficiaryAddressLine3(String beneficiaryAddressLine3)A free-form address field set by the sender. final InboundWireTransfer.BuilderbeneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)Alias for calling Builder.beneficiaryAddressLine3 with beneficiaryAddressLine3.orElse(null).final InboundWireTransfer.BuilderbeneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value. final InboundWireTransfer.BuilderbeneficiaryName(String beneficiaryName)A name set by the sender. final InboundWireTransfer.BuilderbeneficiaryName(Optional<String> beneficiaryName)Alias for calling Builder.beneficiaryName with beneficiaryName.orElse(null).final InboundWireTransfer.BuilderbeneficiaryName(JsonField<String> beneficiaryName)Sets Builder.beneficiaryName to an arbitrary JSON value. final InboundWireTransfer.BuilderbeneficiaryReference(String beneficiaryReference)A free-form reference string set by the sender, to help identify the transfer. final InboundWireTransfer.BuilderbeneficiaryReference(Optional<String> beneficiaryReference)Alias for calling Builder.beneficiaryReference with beneficiaryReference.orElse(null).final InboundWireTransfer.BuilderbeneficiaryReference(JsonField<String> beneficiaryReference)Sets Builder.beneficiaryReference to an arbitrary JSON value. final InboundWireTransfer.BuildercreatedAt(OffsetDateTime createdAt)The ISO 8601 date and time at which the inbound wire transfer was created. final InboundWireTransfer.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final InboundWireTransfer.Builderdescription(String description)An Increase-constructed description of the transfer. final InboundWireTransfer.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final InboundWireTransfer.BuilderinputMessageAccountabilityData(String inputMessageAccountabilityData)A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final InboundWireTransfer.BuilderinputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)Alias for calling Builder.inputMessageAccountabilityData with inputMessageAccountabilityData.orElse(null).final InboundWireTransfer.BuilderinputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorAddressLine1(String originatorAddressLine1)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine1(Optional<String> originatorAddressLine1)Alias for calling Builder.originatorAddressLine1 with originatorAddressLine1.orElse(null).final InboundWireTransfer.BuilderoriginatorAddressLine1(JsonField<String> originatorAddressLine1)Sets Builder.originatorAddressLine1 to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorAddressLine2(String originatorAddressLine2)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine2(Optional<String> originatorAddressLine2)Alias for calling Builder.originatorAddressLine2 with originatorAddressLine2.orElse(null).final InboundWireTransfer.BuilderoriginatorAddressLine2(JsonField<String> originatorAddressLine2)Sets Builder.originatorAddressLine2 to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorAddressLine3(String originatorAddressLine3)The address of the wire originator, set by the sending bank. final InboundWireTransfer.BuilderoriginatorAddressLine3(Optional<String> originatorAddressLine3)Alias for calling Builder.originatorAddressLine3 with originatorAddressLine3.orElse(null).final InboundWireTransfer.BuilderoriginatorAddressLine3(JsonField<String> originatorAddressLine3)Sets Builder.originatorAddressLine3 to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorName(String originatorName)The originator of the wire, set by the sending bank. final InboundWireTransfer.BuilderoriginatorName(Optional<String> originatorName)Alias for calling Builder.originatorName with originatorName.orElse(null).final InboundWireTransfer.BuilderoriginatorName(JsonField<String> originatorName)Sets Builder.originatorName to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorRoutingNumber(String originatorRoutingNumber)The American Banking Association (ABA) routing number of the bank originating the transfer. final InboundWireTransfer.BuilderoriginatorRoutingNumber(Optional<String> originatorRoutingNumber)Alias for calling Builder.originatorRoutingNumber with originatorRoutingNumber.orElse(null).final InboundWireTransfer.BuilderoriginatorRoutingNumber(JsonField<String> originatorRoutingNumber)Sets Builder.originatorRoutingNumber to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)An Increase-created concatenation of the Originator-to-Beneficiary lines. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)Alias for calling Builder.originatorToBeneficiaryInformation with originatorToBeneficiaryInformation.orElse(null).final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)Sets Builder.originatorToBeneficiaryInformation to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)Alias for calling Builder.originatorToBeneficiaryInformationLine1 with originatorToBeneficiaryInformationLine1.orElse(null).final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)Alias for calling Builder.originatorToBeneficiaryInformationLine2 with originatorToBeneficiaryInformationLine2.orElse(null).final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)Alias for calling Builder.originatorToBeneficiaryInformationLine3 with originatorToBeneficiaryInformationLine3.orElse(null).final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)A free-form message set by the wire originator. final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)Alias for calling Builder.originatorToBeneficiaryInformationLine4 with originatorToBeneficiaryInformationLine4.orElse(null).final InboundWireTransfer.BuilderoriginatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value. final InboundWireTransfer.Builderreversal(InboundWireTransfer.Reversal reversal)Information about the reversal of the inbound wire transfer if it has been reversed. final InboundWireTransfer.Builderreversal(Optional<InboundWireTransfer.Reversal> reversal)Alias for calling Builder.reversal with reversal.orElse(null).final InboundWireTransfer.Builderreversal(JsonField<InboundWireTransfer.Reversal> reversal)Sets Builder.reversal to an arbitrary JSON value. final InboundWireTransfer.BuildersenderReference(String senderReference)The sending bank's reference number for the wire transfer. final InboundWireTransfer.BuildersenderReference(Optional<String> senderReference)Alias for calling Builder.senderReference with senderReference.orElse(null).final InboundWireTransfer.BuildersenderReference(JsonField<String> senderReference)Sets Builder.senderReference to an arbitrary JSON value. final InboundWireTransfer.Builderstatus(InboundWireTransfer.Status status)The status of the transfer. final InboundWireTransfer.Builderstatus(JsonField<InboundWireTransfer.Status> status)Sets Builder.status to an arbitrary JSON value. final InboundWireTransfer.Buildertype(InboundWireTransfer.Type type)A constant representing the object's type. final InboundWireTransfer.Buildertype(JsonField<InboundWireTransfer.Type> type)Sets Builder.type to an arbitrary JSON value. final InboundWireTransfer.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final InboundWireTransfer.BuilderputAdditionalProperty(String key, JsonValue value)final InboundWireTransfer.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final InboundWireTransfer.BuilderremoveAdditionalProperty(String key)final InboundWireTransfer.BuilderremoveAllAdditionalProperties(Set<String> keys)final InboundWireTransferbuild()Returns an immutable instance of InboundWireTransfer. -
-
Method Detail
-
id
final InboundWireTransfer.Builder id(String id)
The inbound wire transfer's identifier.
-
id
final InboundWireTransfer.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountId
final InboundWireTransfer.Builder accountId(String accountId)
The Account to which the transfer belongs.
-
accountId
final InboundWireTransfer.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumberId
final InboundWireTransfer.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number to which this transfer was sent.
-
accountNumberId
final InboundWireTransfer.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireTransfer.Builder amount(Long amount)
The amount in USD cents.
-
amount
final InboundWireTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final InboundWireTransfer.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine1
final InboundWireTransfer.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
Alias for calling Builder.beneficiaryAddressLine1 with
beneficiaryAddressLine1.orElse(null).
-
beneficiaryAddressLine1
final InboundWireTransfer.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final InboundWireTransfer.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final InboundWireTransfer.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
Alias for calling Builder.beneficiaryAddressLine2 with
beneficiaryAddressLine2.orElse(null).
-
beneficiaryAddressLine2
final InboundWireTransfer.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final InboundWireTransfer.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final InboundWireTransfer.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
Alias for calling Builder.beneficiaryAddressLine3 with
beneficiaryAddressLine3.orElse(null).
-
beneficiaryAddressLine3
final InboundWireTransfer.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final InboundWireTransfer.Builder beneficiaryName(String beneficiaryName)
A name set by the sender.
-
beneficiaryName
final InboundWireTransfer.Builder beneficiaryName(Optional<String> beneficiaryName)
Alias for calling Builder.beneficiaryName with
beneficiaryName.orElse(null).
-
beneficiaryName
final InboundWireTransfer.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryReference
final InboundWireTransfer.Builder beneficiaryReference(String beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
beneficiaryReference
final InboundWireTransfer.Builder beneficiaryReference(Optional<String> beneficiaryReference)
Alias for calling Builder.beneficiaryReference with
beneficiaryReference.orElse(null).
-
beneficiaryReference
final InboundWireTransfer.Builder beneficiaryReference(JsonField<String> beneficiaryReference)
Sets Builder.beneficiaryReference to an arbitrary JSON value.
You should usually call Builder.beneficiaryReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final InboundWireTransfer.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the inbound wire transfer was created.
-
createdAt
final InboundWireTransfer.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final InboundWireTransfer.Builder description(String description)
An Increase-constructed description of the transfer.
-
description
final InboundWireTransfer.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)
Alias for calling Builder.inputMessageAccountabilityData with
inputMessageAccountabilityData.orElse(null).
-
inputMessageAccountabilityData
final InboundWireTransfer.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.inputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final InboundWireTransfer.Builder originatorAddressLine1(String originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine1
final InboundWireTransfer.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
Alias for calling Builder.originatorAddressLine1 with
originatorAddressLine1.orElse(null).
-
originatorAddressLine1
final InboundWireTransfer.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final InboundWireTransfer.Builder originatorAddressLine2(String originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final InboundWireTransfer.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
Alias for calling Builder.originatorAddressLine2 with
originatorAddressLine2.orElse(null).
-
originatorAddressLine2
final InboundWireTransfer.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final InboundWireTransfer.Builder originatorAddressLine3(String originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final InboundWireTransfer.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
Alias for calling Builder.originatorAddressLine3 with
originatorAddressLine3.orElse(null).
-
originatorAddressLine3
final InboundWireTransfer.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final InboundWireTransfer.Builder originatorName(String originatorName)
The originator of the wire, set by the sending bank.
-
originatorName
final InboundWireTransfer.Builder originatorName(Optional<String> originatorName)
Alias for calling Builder.originatorName with
originatorName.orElse(null).
-
originatorName
final InboundWireTransfer.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final InboundWireTransfer.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final InboundWireTransfer.Builder originatorRoutingNumber(Optional<String> originatorRoutingNumber)
Alias for calling Builder.originatorRoutingNumber with
originatorRoutingNumber.orElse(null).
-
originatorRoutingNumber
final InboundWireTransfer.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformation
final InboundWireTransfer.Builder originatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformation
final InboundWireTransfer.Builder originatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)
Alias for calling Builder.originatorToBeneficiaryInformation with
originatorToBeneficiaryInformation.orElse(null).
-
originatorToBeneficiaryInformation
final InboundWireTransfer.Builder originatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)
Sets Builder.originatorToBeneficiaryInformation to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)
Alias for calling Builder.originatorToBeneficiaryInformationLine1 with
originatorToBeneficiaryInformationLine1.orElse(null).
-
originatorToBeneficiaryInformationLine1
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)
Alias for calling Builder.originatorToBeneficiaryInformationLine2 with
originatorToBeneficiaryInformationLine2.orElse(null).
-
originatorToBeneficiaryInformationLine2
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)
Alias for calling Builder.originatorToBeneficiaryInformationLine3 with
originatorToBeneficiaryInformationLine3.orElse(null).
-
originatorToBeneficiaryInformationLine3
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)
Alias for calling Builder.originatorToBeneficiaryInformationLine4 with
originatorToBeneficiaryInformationLine4.orElse(null).
-
originatorToBeneficiaryInformationLine4
final InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
reversal
final InboundWireTransfer.Builder reversal(InboundWireTransfer.Reversal reversal)
Information about the reversal of the inbound wire transfer if it has been reversed.
-
reversal
final InboundWireTransfer.Builder reversal(Optional<InboundWireTransfer.Reversal> reversal)
Alias for calling Builder.reversal with
reversal.orElse(null).
-
reversal
final InboundWireTransfer.Builder reversal(JsonField<InboundWireTransfer.Reversal> reversal)
Sets Builder.reversal to an arbitrary JSON value.
You should usually call Builder.reversal with a well-typed Reversal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderReference
final InboundWireTransfer.Builder senderReference(String senderReference)
The sending bank's reference number for the wire transfer.
-
senderReference
final InboundWireTransfer.Builder senderReference(Optional<String> senderReference)
Alias for calling Builder.senderReference with
senderReference.orElse(null).
-
senderReference
final InboundWireTransfer.Builder senderReference(JsonField<String> senderReference)
Sets Builder.senderReference to an arbitrary JSON value.
You should usually call Builder.senderReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final InboundWireTransfer.Builder status(InboundWireTransfer.Status status)
The status of the transfer.
-
status
final InboundWireTransfer.Builder status(JsonField<InboundWireTransfer.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final InboundWireTransfer.Builder type(InboundWireTransfer.Type type)
A constant representing the object's type. For this resource it will always be
inbound_wire_transfer.
-
type
final InboundWireTransfer.Builder type(JsonField<InboundWireTransfer.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireTransfer build()
Returns an immutable instance of InboundWireTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountId() .accountNumberId() .amount() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .beneficiaryReference() .createdAt() .description() .inputMessageAccountabilityData() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .originatorRoutingNumber() .originatorToBeneficiaryInformation() .originatorToBeneficiaryInformationLine1() .originatorToBeneficiaryInformationLine2() .originatorToBeneficiaryInformationLine3() .originatorToBeneficiaryInformationLine4() .reversal() .senderReference() .status() .type()
-
-
-
-