Class IntrafiExclusionCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class IntrafiExclusionCreateParams implements Params
Create an IntraFi Exclusion
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiExclusionCreateParams.BuilderA builder for IntrafiExclusionCreateParams.
public final classIntrafiExclusionCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringbankName()The name of the financial institution to be excluded. final StringentityId()The identifier of the Entity whose deposits will be excluded. final JsonField<String>_bankName()Returns the raw JSON value of bankName. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final IntrafiExclusionCreateParams.BuildertoBuilder()final IntrafiExclusionCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static IntrafiExclusionCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of IntrafiExclusionCreateParams. -
-
Method Detail
-
_bankName
final JsonField<String> _bankName()
Returns the raw JSON value of bankName.
Unlike bankName, this method doesn't throw if the JSON field has an unexpected type.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final IntrafiExclusionCreateParams.Builder toBuilder()
-
_body
final IntrafiExclusionCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static IntrafiExclusionCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of IntrafiExclusionCreateParams.
The following fields are required:
.bankName() .entityId()
-
-
-
-