Class LockboxRecipientUpdateParams.Body
-
- All Implemented Interfaces:
public final class LockboxRecipientUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxRecipientUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The description you choose for the Lockbox Recipient. final Optional<String>recipientName()The name of the Lockbox Recipient. final Optional<LockboxRecipientUpdateParams.Status>status()The status of the Lockbox Recipient. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<LockboxRecipientUpdateParams.Status>_status()Returns the raw JSON value of status. final Map<String, JsonValue>_additionalProperties()final LockboxRecipientUpdateParams.Body.BuildertoBuilder()final LockboxRecipientUpdateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static LockboxRecipientUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
The description you choose for the Lockbox Recipient.
-
recipientName
final Optional<String> recipientName()
The name of the Lockbox Recipient.
-
status
final Optional<LockboxRecipientUpdateParams.Status> status()
The status of the Lockbox Recipient.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<LockboxRecipientUpdateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final LockboxRecipientUpdateParams.Body.Builder toBuilder()
-
validate
final LockboxRecipientUpdateParams.Body validate()
-
builder
final static LockboxRecipientUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-