Class OAuthApplication

  • All Implemented Interfaces:

    
    public final class OAuthApplication
    
                        

    An OAuth Application lets you build an application for others to use with their Increase data. You can create an OAuth Application via the Dashboard and read information about it with the API. Learn more about OAuth here.