Class OAuthApplicationListPage
-
- All Implemented Interfaces:
public final class OAuthApplicationListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationListPage.BuilderA builder for OAuthApplicationListPage.
public final classOAuthApplicationListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<OAuthApplication>data()Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<OAuthApplicationListParams>getNextPageParams()final Optional<OAuthApplicationListPage>getNextPage()final OAuthApplicationListPage.AutoPagerautoPager()final OAuthApplicationListParamsparams()The parameters that were used to request this page. final OAuthApplicationListPageResponseresponse()The response that this page was parsed from. final OAuthApplicationListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplicationListPage.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplicationListPage. -
-
Method Detail
-
data
final List<OAuthApplication> data()
Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to OAuthApplicationListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<OAuthApplicationListParams> getNextPageParams()
-
getNextPage
final Optional<OAuthApplicationListPage> getNextPage()
-
autoPager
final OAuthApplicationListPage.AutoPager autoPager()
-
params
final OAuthApplicationListParams params()
The parameters that were used to request this page.
-
response
final OAuthApplicationListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final OAuthApplicationListPage.Builder toBuilder()
-
builder
final static OAuthApplicationListPage.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplicationListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-