Class OAuthApplicationListPageResponse
-
- All Implemented Interfaces:
public final class OAuthApplicationListPageResponseA list of OAuth Application objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationListPageResponse.BuilderA builder for OAuthApplicationListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<OAuthApplication>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<OAuthApplication>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final OAuthApplicationListPageResponse.BuildertoBuilder()final OAuthApplicationListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthApplicationListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthApplicationListPageResponse. -
-
Method Detail
-
data
final List<OAuthApplication> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<OAuthApplication>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OAuthApplicationListPageResponse.Builder toBuilder()
-
validate
final OAuthApplicationListPageResponse validate()
-
builder
final static OAuthApplicationListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of OAuthApplicationListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-