Class OAuthToken
-
- All Implemented Interfaces:
public final class OAuthTokenA token that is returned to your application when a user completes the OAuth flow and may be used to authenticate requests. Learn more about OAuth /documentation/oauth.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthToken.BuilderA builder for OAuthToken.
public final classOAuthToken.TokenTypeThe type of OAuth token.
public final classOAuthToken.TypeA constant representing the object's type. For this resource it will always be
oauth_token.
-
Method Summary
Modifier and Type Method Description final StringaccessToken()You may use this token in place of an API key to make OAuth requests on a user's behalf. final StringgroupId()The Group's identifier. final OAuthToken.TokenTypetokenType()The type of OAuth token. final OAuthToken.Typetype()A constant representing the object's type. final JsonField<String>_accessToken()Returns the raw JSON value of accessToken. final JsonField<String>_groupId()Returns the raw JSON value of groupId. final JsonField<OAuthToken.TokenType>_tokenType()Returns the raw JSON value of tokenType. final JsonField<OAuthToken.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final OAuthToken.BuildertoBuilder()final OAuthTokenvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OAuthToken.Builderbuilder()Returns a mutable builder for constructing an instance of OAuthToken. -
-
Method Detail
-
accessToken
final String accessToken()
You may use this token in place of an API key to make OAuth requests on a user's behalf.
-
groupId
final String groupId()
The Group's identifier. A Group is the top-level organization in Increase.
-
tokenType
final OAuthToken.TokenType tokenType()
The type of OAuth token.
-
type
final OAuthToken.Type type()
A constant representing the object's type. For this resource it will always be
oauth_token.
-
_accessToken
final JsonField<String> _accessToken()
Returns the raw JSON value of accessToken.
Unlike accessToken, this method doesn't throw if the JSON field has an unexpected type.
-
_groupId
final JsonField<String> _groupId()
Returns the raw JSON value of groupId.
Unlike groupId, this method doesn't throw if the JSON field has an unexpected type.
-
_tokenType
final JsonField<OAuthToken.TokenType> _tokenType()
Returns the raw JSON value of tokenType.
Unlike tokenType, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<OAuthToken.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OAuthToken.Builder toBuilder()
-
validate
final OAuthToken validate()
-
builder
final static OAuthToken.Builder builder()
Returns a mutable builder for constructing an instance of OAuthToken.
The following fields are required:
.accessToken() .groupId() .tokenType() .type()
-
-
-
-