Class PendingTransaction.Source
-
- All Implemented Interfaces:
public final class PendingTransaction.SourceThis is an object giving more details on the network-level event that caused the Pending Transaction. For example, for a card transaction this lists the merchant's industry and location.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.BuilderA builder for Source.
public final classPendingTransaction.Source.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classPendingTransaction.Source.AccountTransferInstructionAn Account Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_instruction.public final classPendingTransaction.Source.AchTransferInstructionAn ACH Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_instruction.public final classPendingTransaction.Source.BlockchainOfframpTransferA Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They're automatically created when funds land in a Blockchain Address.public final classPendingTransaction.Source.BlockchainOnrampTransferInstructionA Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_instruction.public final classPendingTransaction.Source.CardAuthorizationA Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.public final classPendingTransaction.Source.CardPushTransferInstructionA Card Push Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_instruction.public final classPendingTransaction.Source.CheckDepositInstructionA Check Deposit Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_instruction.public final classPendingTransaction.Source.CheckTransferInstructionA Check Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_instruction.public final classPendingTransaction.Source.FednowTransferInstructionA FedNow Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_instruction.public final classPendingTransaction.Source.InboundFundsHoldAn Inbound Funds Hold object. This field will be present in the JSON response if and only if
categoryis equal toinbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.public final classPendingTransaction.Source.InboundWireTransferReversalAn Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.public final classPendingTransaction.Source.OtherIf the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.public final classPendingTransaction.Source.RealTimePaymentsTransferInstructionA Real-Time Payments Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_instruction.public final classPendingTransaction.Source.SwiftTransferInstructionA Swift Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_instruction.public final classPendingTransaction.Source.UserInitiatedHoldAn User Initiated Hold object. This field will be present in the JSON response if and only if
categoryis equal touser_initiated_hold. Created when a user initiates a hold on funds in their account.public final classPendingTransaction.Source.WireTransferInstructionA Wire Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_instruction.
-
Method Summary
-
-
Method Detail
-
category
final PendingTransaction.Source.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
accountTransferInstruction
final Optional<PendingTransaction.Source.AccountTransferInstruction> accountTransferInstruction()
An Account Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_instruction.
-
achTransferInstruction
final Optional<PendingTransaction.Source.AchTransferInstruction> achTransferInstruction()
An ACH Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_instruction.
-
blockchainOfframpTransfer
final Optional<PendingTransaction.Source.BlockchainOfframpTransfer> blockchainOfframpTransfer()
A Blockchain Off-Ramp Transfer object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer. Blockchain Off-Ramp Transfers move funds from a Blockchain Address to an Account. They're automatically created when funds land in a Blockchain Address.
-
blockchainOnrampTransferInstruction
final Optional<PendingTransaction.Source.BlockchainOnrampTransferInstruction> blockchainOnrampTransferInstruction()
A Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_instruction.
-
cardAuthorization
final Optional<PendingTransaction.Source.CardAuthorization> cardAuthorization()
A Card Authorization object. This field will be present in the JSON response if and only if
categoryis equal tocard_authorization. Card Authorizations are temporary holds placed on a customer's funds with the intent to later clear a transaction.
-
cardPushTransferInstruction
final Optional<PendingTransaction.Source.CardPushTransferInstruction> cardPushTransferInstruction()
A Card Push Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_instruction.
-
checkDepositInstruction
final Optional<PendingTransaction.Source.CheckDepositInstruction> checkDepositInstruction()
A Check Deposit Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_instruction.
-
checkTransferInstruction
final Optional<PendingTransaction.Source.CheckTransferInstruction> checkTransferInstruction()
A Check Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_instruction.
-
fednowTransferInstruction
final Optional<PendingTransaction.Source.FednowTransferInstruction> fednowTransferInstruction()
A FedNow Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_instruction.
-
inboundFundsHold
final Optional<PendingTransaction.Source.InboundFundsHold> inboundFundsHold()
An Inbound Funds Hold object. This field will be present in the JSON response if and only if
categoryis equal toinbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
-
inboundWireTransferReversal
final Optional<PendingTransaction.Source.InboundWireTransferReversal> inboundWireTransferReversal()
An Inbound Wire Transfer Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal is created when Increase has received a wire and the User requests that it be reversed.
-
other
final Optional<PendingTransaction.Source.Other> other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
realTimePaymentsTransferInstruction
final Optional<PendingTransaction.Source.RealTimePaymentsTransferInstruction> realTimePaymentsTransferInstruction()
A Real-Time Payments Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_instruction.
-
swiftTransferInstruction
final Optional<PendingTransaction.Source.SwiftTransferInstruction> swiftTransferInstruction()
A Swift Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_instruction.
-
userInitiatedHold
final Optional<PendingTransaction.Source.UserInitiatedHold> userInitiatedHold()
An User Initiated Hold object. This field will be present in the JSON response if and only if
categoryis equal touser_initiated_hold. Created when a user initiates a hold on funds in their account.
-
wireTransferInstruction
final Optional<PendingTransaction.Source.WireTransferInstruction> wireTransferInstruction()
A Wire Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_instruction.
-
_category
final JsonField<PendingTransaction.Source.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_accountTransferInstruction
final JsonField<PendingTransaction.Source.AccountTransferInstruction> _accountTransferInstruction()
Returns the raw JSON value of accountTransferInstruction.
Unlike accountTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_achTransferInstruction
final JsonField<PendingTransaction.Source.AchTransferInstruction> _achTransferInstruction()
Returns the raw JSON value of achTransferInstruction.
Unlike achTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_blockchainOfframpTransfer
final JsonField<PendingTransaction.Source.BlockchainOfframpTransfer> _blockchainOfframpTransfer()
Returns the raw JSON value of blockchainOfframpTransfer.
Unlike blockchainOfframpTransfer, this method doesn't throw if the JSON field has an unexpected type.
-
_blockchainOnrampTransferInstruction
final JsonField<PendingTransaction.Source.BlockchainOnrampTransferInstruction> _blockchainOnrampTransferInstruction()
Returns the raw JSON value of blockchainOnrampTransferInstruction.
Unlike blockchainOnrampTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorization
final JsonField<PendingTransaction.Source.CardAuthorization> _cardAuthorization()
Returns the raw JSON value of cardAuthorization.
Unlike cardAuthorization, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPushTransferInstruction
final JsonField<PendingTransaction.Source.CardPushTransferInstruction> _cardPushTransferInstruction()
Returns the raw JSON value of cardPushTransferInstruction.
Unlike cardPushTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositInstruction
final JsonField<PendingTransaction.Source.CheckDepositInstruction> _checkDepositInstruction()
Returns the raw JSON value of checkDepositInstruction.
Unlike checkDepositInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_checkTransferInstruction
final JsonField<PendingTransaction.Source.CheckTransferInstruction> _checkTransferInstruction()
Returns the raw JSON value of checkTransferInstruction.
Unlike checkTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_fednowTransferInstruction
final JsonField<PendingTransaction.Source.FednowTransferInstruction> _fednowTransferInstruction()
Returns the raw JSON value of fednowTransferInstruction.
Unlike fednowTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundFundsHold
final JsonField<PendingTransaction.Source.InboundFundsHold> _inboundFundsHold()
Returns the raw JSON value of inboundFundsHold.
Unlike inboundFundsHold, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireTransferReversal
final JsonField<PendingTransaction.Source.InboundWireTransferReversal> _inboundWireTransferReversal()
Returns the raw JSON value of inboundWireTransferReversal.
Unlike inboundWireTransferReversal, this method doesn't throw if the JSON field has an unexpected type.
-
_other
final JsonField<PendingTransaction.Source.Other> _other()
Returns the raw JSON value of other.
Unlike other, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimePaymentsTransferInstruction
final JsonField<PendingTransaction.Source.RealTimePaymentsTransferInstruction> _realTimePaymentsTransferInstruction()
Returns the raw JSON value of realTimePaymentsTransferInstruction.
Unlike realTimePaymentsTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_swiftTransferInstruction
final JsonField<PendingTransaction.Source.SwiftTransferInstruction> _swiftTransferInstruction()
Returns the raw JSON value of swiftTransferInstruction.
Unlike swiftTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_userInitiatedHold
final JsonField<PendingTransaction.Source.UserInitiatedHold> _userInitiatedHold()
Returns the raw JSON value of userInitiatedHold.
Unlike userInitiatedHold, this method doesn't throw if the JSON field has an unexpected type.
-
_wireTransferInstruction
final JsonField<PendingTransaction.Source.WireTransferInstruction> _wireTransferInstruction()
Returns the raw JSON value of wireTransferInstruction.
Unlike wireTransferInstruction, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.Builder toBuilder()
-
validate
final PendingTransaction.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PendingTransaction.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
The following fields are required:
.category()
-
-
-
-