Class PendingTransaction.Source.BlockchainOnrampTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.BlockchainOnrampTransferInstructionA Blockchain On-Ramp Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.BlockchainOnrampTransferInstruction.BuilderA builder for BlockchainOnrampTransferInstruction.
-
Method Summary
-
-
Method Detail
-
destinationBlockchainAddress
final String destinationBlockchainAddress()
The blockchain address the funds are being sent to.
-
transferId
final String transferId()
The identifier of the Blockchain On-Ramp Transfer that led to this Pending Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationBlockchainAddress
final JsonField<String> _destinationBlockchainAddress()
Returns the raw JSON value of destinationBlockchainAddress.
Unlike destinationBlockchainAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.BlockchainOnrampTransferInstruction validate()
-
builder
final static PendingTransaction.Source.BlockchainOnrampTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOnrampTransferInstruction.
The following fields are required:
.amount() .destinationBlockchainAddress() .transferId()
-
-
-
-