Class PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CardAuthorization.NetworkDetails.VisaFields specific to the
visanetwork.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.BuilderA builder for Visa.
public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.ElectronicCommerceIndicatorFor electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.PointOfServiceEntryModeThe method used to enter the cardholder's primary account number and card expiration date.
public final classPendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.StandInProcessingReasonOnly present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.
-
Method Summary
-
-
Method Detail
-
electronicCommerceIndicator
final Optional<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.ElectronicCommerceIndicator> electronicCommerceIndicator()
For electronic commerce transactions, this identifies the level of security used in obtaining the customer's payment credential. For mail or telephone order transactions, identifies the type of mail or telephone order.
-
pointOfServiceEntryMode
final Optional<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.PointOfServiceEntryMode> pointOfServiceEntryMode()
The method used to enter the cardholder's primary account number and card expiration date.
-
standInProcessingReason
final Optional<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.StandInProcessingReason> standInProcessingReason()
Only present when
actioner: network. Describes why a card authorization was approved or declined by Visa through stand-in processing.
-
_electronicCommerceIndicator
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.ElectronicCommerceIndicator> _electronicCommerceIndicator()
Returns the raw JSON value of electronicCommerceIndicator.
Unlike electronicCommerceIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_pointOfServiceEntryMode
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.PointOfServiceEntryMode> _pointOfServiceEntryMode()
Returns the raw JSON value of pointOfServiceEntryMode.
Unlike pointOfServiceEntryMode, this method doesn't throw if the JSON field has an unexpected type.
-
_standInProcessingReason
final JsonField<PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.StandInProcessingReason> _standInProcessingReason()
Returns the raw JSON value of standInProcessingReason.
Unlike standInProcessingReason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa validate()
-
builder
final static PendingTransaction.Source.CardAuthorization.NetworkDetails.Visa.Builder builder()
Returns a mutable builder for constructing an instance of Visa.
The following fields are required:
.electronicCommerceIndicator() .pointOfServiceEntryMode() .standInProcessingReason()
-
-
-
-