Class PendingTransaction.Source.CheckDepositInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.CheckDepositInstructionA Check Deposit Instruction object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.CheckDepositInstruction.BuilderA builder for CheckDepositInstruction.
public final classPendingTransaction.Source.CheckDepositInstruction.CurrencyThe ISO 4217 code for the transaction's currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The pending amount in USD cents. final Optional<String>backImageFileId()The identifier of the File containing the image of the back of the check that was deposited. final Optional<String>checkDepositId()The identifier of the Check Deposit. final PendingTransaction.Source.CheckDepositInstruction.Currencycurrency()The ISO 4217 code for the transaction's currency. final StringfrontImageFileId()The identifier of the File containing the image of the front of the check that was deposited. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_checkDepositId()Returns the raw JSON value of checkDepositId. final JsonField<PendingTransaction.Source.CheckDepositInstruction.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.CheckDepositInstruction.BuildertoBuilder()final PendingTransaction.Source.CheckDepositInstructionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.CheckDepositInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of CheckDepositInstruction. -
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the File containing the image of the back of the check that was deposited.
-
checkDepositId
final Optional<String> checkDepositId()
The identifier of the Check Deposit.
-
currency
final PendingTransaction.Source.CheckDepositInstruction.Currency currency()
The ISO 4217 code for the transaction's currency.
-
frontImageFileId
final String frontImageFileId()
The identifier of the File containing the image of the front of the check that was deposited.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositId
final JsonField<String> _checkDepositId()
Returns the raw JSON value of checkDepositId.
Unlike checkDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<PendingTransaction.Source.CheckDepositInstruction.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.CheckDepositInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.CheckDepositInstruction validate()
-
builder
final static PendingTransaction.Source.CheckDepositInstruction.Builder builder()
Returns a mutable builder for constructing an instance of CheckDepositInstruction.
The following fields are required:
.amount() .backImageFileId() .checkDepositId() .currency() .frontImageFileId()
-
-
-
-