Class PendingTransaction.Source.FednowTransferInstruction
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.FednowTransferInstructionA FedNow Transfer Instruction object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_instruction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.FednowTransferInstruction.BuilderA builder for FednowTransferInstruction.
-
Method Summary
Modifier and Type Method Description final StringtransferId()The identifier of the FedNow Transfer that led to this Pending Transaction. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final PendingTransaction.Source.FednowTransferInstruction.BuildertoBuilder()final PendingTransaction.Source.FednowTransferInstructionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransaction.Source.FednowTransferInstruction.Builderbuilder()Returns a mutable builder for constructing an instance of FednowTransferInstruction. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the FedNow Transfer that led to this Pending Transaction.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.FednowTransferInstruction.Builder toBuilder()
-
validate
final PendingTransaction.Source.FednowTransferInstruction validate()
-
builder
final static PendingTransaction.Source.FednowTransferInstruction.Builder builder()
Returns a mutable builder for constructing an instance of FednowTransferInstruction.
The following fields are required:
.transferId()
-
-
-
-