Class PendingTransaction.Source.InboundFundsHold
-
- All Implemented Interfaces:
public final class PendingTransaction.Source.InboundFundsHoldAn Inbound Funds Hold object. This field will be present in the JSON response if and only if
categoryis equal toinbound_funds_hold. We hold funds for certain transaction types to account for return windows where funds might still be clawed back by the sending institution.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransaction.Source.InboundFundsHold.BuilderA builder for InboundFundsHold.
public final classPendingTransaction.Source.InboundFundsHold.CurrencyThe ISO 4217 code for the hold's currency.
public final classPendingTransaction.Source.InboundFundsHold.StatusThe status of the hold.
public final classPendingTransaction.Source.InboundFundsHold.TypeA constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
Method Summary
-
-
Method Detail
-
amount
final Long amount()
The held amount in the minor unit of the account's currency. For dollars, for example, this is cents.
-
automaticallyReleasesAt
final OffsetDateTime automaticallyReleasesAt()
When the hold will be released automatically. Certain conditions may cause it to be released before this time.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 time at which the hold was created.
-
currency
final PendingTransaction.Source.InboundFundsHold.Currency currency()
The ISO 4217 code for the hold's currency.
-
heldTransactionId
final Optional<String> heldTransactionId()
The ID of the Transaction for which funds were held.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID of the Pending Transaction representing the held funds.
-
releasedAt
final Optional<OffsetDateTime> releasedAt()
When the hold was released (if it has been released).
-
status
final PendingTransaction.Source.InboundFundsHold.Status status()
The status of the hold.
-
type
final PendingTransaction.Source.InboundFundsHold.Type type()
A constant representing the object's type. For this resource it will always be
inbound_funds_hold.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_automaticallyReleasesAt
final JsonField<OffsetDateTime> _automaticallyReleasesAt()
Returns the raw JSON value of automaticallyReleasesAt.
Unlike automaticallyReleasesAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<PendingTransaction.Source.InboundFundsHold.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_heldTransactionId
final JsonField<String> _heldTransactionId()
Returns the raw JSON value of heldTransactionId.
Unlike heldTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_releasedAt
final JsonField<OffsetDateTime> _releasedAt()
Returns the raw JSON value of releasedAt.
Unlike releasedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<PendingTransaction.Source.InboundFundsHold.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<PendingTransaction.Source.InboundFundsHold.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransaction.Source.InboundFundsHold.Builder toBuilder()
-
validate
final PendingTransaction.Source.InboundFundsHold validate()
-
builder
final static PendingTransaction.Source.InboundFundsHold.Builder builder()
Returns a mutable builder for constructing an instance of InboundFundsHold.
The following fields are required:
.amount() .automaticallyReleasesAt() .createdAt() .currency() .heldTransactionId() .pendingTransactionId() .releasedAt() .status() .type()
-
-
-
-