Class PendingTransactionCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PendingTransactionCreateParams implements Params
Creates a pending transaction on an account. This can be useful to hold funds for an external payment or known future transaction outside of Increase. The resulting Pending Transaction will have a
categoryofuser_initiated_holdand can be released via the API to unlock the held funds.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionCreateParams.BuilderA builder for PendingTransactionCreateParams.
public final classPendingTransactionCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account to place the hold on. final Longamount()The amount to hold in the minor unit of the account's currency. final Optional<String>description()The description you choose to give the hold. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PendingTransactionCreateParams.BuildertoBuilder()final PendingTransactionCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransactionCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of PendingTransactionCreateParams. -
-
Method Detail
-
amount
final Long amount()
The amount to hold in the minor unit of the account's currency. For dollars, for example, this is cents. This should be a negative amount - to hold $1.00 from the account, you would pass -100.
-
description
final Optional<String> description()
The description you choose to give the hold.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PendingTransactionCreateParams.Builder toBuilder()
-
_body
final PendingTransactionCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PendingTransactionCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of PendingTransactionCreateParams.
The following fields are required:
.accountId() .amount()
-
-
-
-