Class PendingTransactionCreateParams.Body
-
- All Implemented Interfaces:
public final class PendingTransactionCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The Account to place the hold on. final Longamount()The amount to hold in the minor unit of the account's currency. final Optional<String>description()The description you choose to give the hold. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_description()Returns the raw JSON value of description. final Map<String, JsonValue>_additionalProperties()final PendingTransactionCreateParams.Body.BuildertoBuilder()final PendingTransactionCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransactionCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
amount
final Long amount()
The amount to hold in the minor unit of the account's currency. For dollars, for example, this is cents. This should be a negative amount - to hold $1.00 from the account, you would pass -100.
-
description
final Optional<String> description()
The description you choose to give the hold.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PendingTransactionCreateParams.Body.Builder toBuilder()
-
validate
final PendingTransactionCreateParams.Body validate()
-
builder
final static PendingTransactionCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount()
-
-
-
-