Class PendingTransactionListPageAsync
-
- All Implemented Interfaces:
public final class PendingTransactionListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPendingTransactionListPageAsync.BuilderA builder for PendingTransactionListPageAsync.
public final classPendingTransactionListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<PendingTransaction>data()Delegates to PendingTransactionListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PendingTransactionListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<PendingTransactionListParams>getNextPageParams()final CompletableFuture<Optional<PendingTransactionListPageAsync>>getNextPage()final PendingTransactionListPageAsync.AutoPagerautoPager()final PendingTransactionListParamsparams()The parameters that were used to request this page. final PendingTransactionListPageResponseresponse()The response that this page was parsed from. final PendingTransactionListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PendingTransactionListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of PendingTransactionListPageAsync. -
-
Method Detail
-
data
final List<PendingTransaction> data()
Delegates to PendingTransactionListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PendingTransactionListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<PendingTransactionListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<PendingTransactionListPageAsync>> getNextPage()
-
autoPager
final PendingTransactionListPageAsync.AutoPager autoPager()
-
params
final PendingTransactionListParams params()
The parameters that were used to request this page.
-
response
final PendingTransactionListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PendingTransactionListPageAsync.Builder toBuilder()
-
builder
final static PendingTransactionListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of PendingTransactionListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-