Class PhysicalCardProfile.Builder
-
- All Implemented Interfaces:
public final class PhysicalCardProfile.BuilderA builder for PhysicalCardProfile.
-
-
Method Summary
-
-
Method Detail
-
id
final PhysicalCardProfile.Builder id(String id)
The Card Profile identifier.
-
id
final PhysicalCardProfile.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
backImageFileId
final PhysicalCardProfile.Builder backImageFileId(String backImageFileId)
The identifier of the File containing the physical card's back image.
-
backImageFileId
final PhysicalCardProfile.Builder backImageFileId(Optional<String> backImageFileId)
Alias for calling Builder.backImageFileId with
backImageFileId.orElse(null).
-
backImageFileId
final PhysicalCardProfile.Builder backImageFileId(JsonField<String> backImageFileId)
Sets Builder.backImageFileId to an arbitrary JSON value.
You should usually call Builder.backImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
carrierImageFileId
final PhysicalCardProfile.Builder carrierImageFileId(String carrierImageFileId)
The identifier of the File containing the physical card's carrier image.
-
carrierImageFileId
final PhysicalCardProfile.Builder carrierImageFileId(Optional<String> carrierImageFileId)
Alias for calling Builder.carrierImageFileId with
carrierImageFileId.orElse(null).
-
carrierImageFileId
final PhysicalCardProfile.Builder carrierImageFileId(JsonField<String> carrierImageFileId)
Sets Builder.carrierImageFileId to an arbitrary JSON value.
You should usually call Builder.carrierImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contactPhone
final PhysicalCardProfile.Builder contactPhone(String contactPhone)
A phone number the user can contact to receive support for their card.
-
contactPhone
final PhysicalCardProfile.Builder contactPhone(Optional<String> contactPhone)
Alias for calling Builder.contactPhone with
contactPhone.orElse(null).
-
contactPhone
final PhysicalCardProfile.Builder contactPhone(JsonField<String> contactPhone)
Sets Builder.contactPhone to an arbitrary JSON value.
You should usually call Builder.contactPhone with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final PhysicalCardProfile.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the Card Dispute was created.
-
createdAt
final PhysicalCardProfile.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
creator
final PhysicalCardProfile.Builder creator(PhysicalCardProfile.Creator creator)
The creator of this Physical Card Profile.
-
creator
final PhysicalCardProfile.Builder creator(JsonField<PhysicalCardProfile.Creator> creator)
Sets Builder.creator to an arbitrary JSON value.
You should usually call Builder.creator with a well-typed Creator value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final PhysicalCardProfile.Builder description(String description)
A description you can use to identify the Physical Card Profile.
-
description
final PhysicalCardProfile.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
frontImageFileId
final PhysicalCardProfile.Builder frontImageFileId(String frontImageFileId)
The identifier of the File containing the physical card's front image.
-
frontImageFileId
final PhysicalCardProfile.Builder frontImageFileId(Optional<String> frontImageFileId)
Alias for calling Builder.frontImageFileId with
frontImageFileId.orElse(null).
-
frontImageFileId
final PhysicalCardProfile.Builder frontImageFileId(JsonField<String> frontImageFileId)
Sets Builder.frontImageFileId to an arbitrary JSON value.
You should usually call Builder.frontImageFileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final PhysicalCardProfile.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final PhysicalCardProfile.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final PhysicalCardProfile.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isDefault
final PhysicalCardProfile.Builder isDefault(Boolean isDefault)
Whether this Physical Card Profile is the default for all cards in its Increase group.
-
isDefault
final PhysicalCardProfile.Builder isDefault(JsonField<Boolean> isDefault)
Sets Builder.isDefault to an arbitrary JSON value.
You should usually call Builder.isDefault with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final PhysicalCardProfile.Builder status(PhysicalCardProfile.Status status)
The status of the Physical Card Profile.
-
status
final PhysicalCardProfile.Builder status(JsonField<PhysicalCardProfile.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final PhysicalCardProfile.Builder type(PhysicalCardProfile.Type type)
A constant representing the object's type. For this resource it will always be
physical_card_profile.
-
type
final PhysicalCardProfile.Builder type(JsonField<PhysicalCardProfile.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final PhysicalCardProfile.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final PhysicalCardProfile.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final PhysicalCardProfile.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final PhysicalCardProfile.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final PhysicalCardProfile.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final PhysicalCardProfile build()
Returns an immutable instance of PhysicalCardProfile.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .backImageFileId() .carrierImageFileId() .contactPhone() .createdAt() .creator() .description() .frontImageFileId() .idempotencyKey() .isDefault() .status() .type()
-
-
-
-