Class PhysicalCardProfileCloneParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardProfileCloneParams implements Params
Clone a Physical Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCloneParams.BuilderA builder for PhysicalCardProfileCloneParams.
public final classPhysicalCardProfileCloneParams.Bodypublic final classPhysicalCardProfileCloneParams.FrontTextText printed on the front of the card. Reach out to [email protected] for more information.
-
Method Summary
Modifier and Type Method Description final StringphysicalCardProfileId()The identifier of the Physical Card Profile to clone. final Optional<String>carrierImageFileId()The identifier of the File containing the physical card's carrier image. final Optional<String>contactPhone()A phone number the user can contact to receive support for their card. final Optional<String>description()A description you can use to identify the Card Profile. final Optional<String>frontImageFileId()The identifier of the File containing the physical card's front image. final Optional<PhysicalCardProfileCloneParams.FrontText>frontText()Text printed on the front of the card. final JsonField<String>_carrierImageFileId()Returns the raw JSON value of carrierImageFileId. final JsonField<String>_contactPhone()Returns the raw JSON value of contactPhone. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<PhysicalCardProfileCloneParams.FrontText>_frontText()Returns the raw JSON value of frontText. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final PhysicalCardProfileCloneParams.BuildertoBuilder()final PhysicalCardProfileCloneParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCloneParams.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardProfileCloneParams. -
-
Method Detail
-
physicalCardProfileId
final String physicalCardProfileId()
The identifier of the Physical Card Profile to clone.
-
carrierImageFileId
final Optional<String> carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final Optional<String> contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final Optional<String> description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the File containing the physical card's front image.
-
frontText
final Optional<PhysicalCardProfileCloneParams.FrontText> frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
Returns the raw JSON value of carrierImageFileId.
Unlike carrierImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_contactPhone
final JsonField<String> _contactPhone()
Returns the raw JSON value of contactPhone.
Unlike contactPhone, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_frontText
final JsonField<PhysicalCardProfileCloneParams.FrontText> _frontText()
Returns the raw JSON value of frontText.
Unlike frontText, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final PhysicalCardProfileCloneParams.Builder toBuilder()
-
_body
final PhysicalCardProfileCloneParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PhysicalCardProfileCloneParams.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardProfileCloneParams.
The following fields are required:
.physicalCardProfileId()
-
-
-
-