Class PhysicalCardProfileCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class PhysicalCardProfileCreateParams implements Params
Create a Physical Card Profile
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileCreateParams.BuilderA builder for PhysicalCardProfileCreateParams.
public final classPhysicalCardProfileCreateParams.Bodypublic final classPhysicalCardProfileCreateParams.BackColorThe color of the text on the back of the card. Defaults to "black".
public final classPhysicalCardProfileCreateParams.FrontColorThe color of the design on the front of the card. Defaults to "black".
public final classPhysicalCardProfileCreateParams.FrontTextText printed on the front of the card. Reach out to [email protected] for more information.
-
Method Summary
Modifier and Type Method Description final StringcarrierImageFileId()The identifier of the File containing the physical card's carrier image. final StringcontactPhone()A phone number the user can contact to receive support for their card. final Stringdescription()A description you can use to identify the Card Profile. final StringfrontImageFileId()The identifier of the File containing the physical card's front image. final StringprogramId()The identifier for the Program that this Physical Card Profile falls under. final Optional<PhysicalCardProfileCreateParams.BackColor>backColor()The color of the text on the back of the card. final Optional<String>cardStockReference()A reference ID provided by the fulfillment provider for the card stock used. final Optional<String>carrierStockReference()A reference ID provided by the fulfillment provider for the carrier stock used. final Optional<PhysicalCardProfileCreateParams.FrontColor>frontColor()The color of the design on the front of the card. final Optional<PhysicalCardProfileCreateParams.FrontText>frontText()Text printed on the front of the card. final JsonField<String>_carrierImageFileId()Returns the raw JSON value of carrierImageFileId. final JsonField<String>_contactPhone()Returns the raw JSON value of contactPhone. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_programId()Returns the raw JSON value of programId. final JsonField<PhysicalCardProfileCreateParams.BackColor>_backColor()Returns the raw JSON value of backColor. final JsonField<String>_cardStockReference()Returns the raw JSON value of cardStockReference. final JsonField<String>_carrierStockReference()Returns the raw JSON value of carrierStockReference. final JsonField<PhysicalCardProfileCreateParams.FrontColor>_frontColor()Returns the raw JSON value of frontColor. final JsonField<PhysicalCardProfileCreateParams.FrontText>_frontText()Returns the raw JSON value of frontText. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final PhysicalCardProfileCreateParams.BuildertoBuilder()final PhysicalCardProfileCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardProfileCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardProfileCreateParams. -
-
Method Detail
-
carrierImageFileId
final String carrierImageFileId()
The identifier of the File containing the physical card's carrier image.
-
contactPhone
final String contactPhone()
A phone number the user can contact to receive support for their card.
-
description
final String description()
A description you can use to identify the Card Profile.
-
frontImageFileId
final String frontImageFileId()
The identifier of the File containing the physical card's front image.
-
programId
final String programId()
The identifier for the Program that this Physical Card Profile falls under.
-
backColor
final Optional<PhysicalCardProfileCreateParams.BackColor> backColor()
The color of the text on the back of the card. Defaults to "black".
-
cardStockReference
final Optional<String> cardStockReference()
A reference ID provided by the fulfillment provider for the card stock used. Only used if you've ordered card stock separately.
-
carrierStockReference
final Optional<String> carrierStockReference()
A reference ID provided by the fulfillment provider for the carrier stock used. Only used if you've ordered carrier stock separately.
-
frontColor
final Optional<PhysicalCardProfileCreateParams.FrontColor> frontColor()
The color of the design on the front of the card. Defaults to "black".
-
frontText
final Optional<PhysicalCardProfileCreateParams.FrontText> frontText()
Text printed on the front of the card. Reach out to [email protected] for more information.
-
_carrierImageFileId
final JsonField<String> _carrierImageFileId()
Returns the raw JSON value of carrierImageFileId.
Unlike carrierImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_contactPhone
final JsonField<String> _contactPhone()
Returns the raw JSON value of contactPhone.
Unlike contactPhone, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_programId
final JsonField<String> _programId()
Returns the raw JSON value of programId.
Unlike programId, this method doesn't throw if the JSON field has an unexpected type.
-
_backColor
final JsonField<PhysicalCardProfileCreateParams.BackColor> _backColor()
Returns the raw JSON value of backColor.
Unlike backColor, this method doesn't throw if the JSON field has an unexpected type.
-
_cardStockReference
final JsonField<String> _cardStockReference()
Returns the raw JSON value of cardStockReference.
Unlike cardStockReference, this method doesn't throw if the JSON field has an unexpected type.
-
_carrierStockReference
final JsonField<String> _carrierStockReference()
Returns the raw JSON value of carrierStockReference.
Unlike carrierStockReference, this method doesn't throw if the JSON field has an unexpected type.
-
_frontColor
final JsonField<PhysicalCardProfileCreateParams.FrontColor> _frontColor()
Returns the raw JSON value of frontColor.
Unlike frontColor, this method doesn't throw if the JSON field has an unexpected type.
-
_frontText
final JsonField<PhysicalCardProfileCreateParams.FrontText> _frontText()
Returns the raw JSON value of frontText.
Unlike frontText, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final PhysicalCardProfileCreateParams.Builder toBuilder()
-
_body
final PhysicalCardProfileCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static PhysicalCardProfileCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardProfileCreateParams.
The following fields are required:
.carrierImageFileId() .contactPhone() .description() .frontImageFileId() .programId()
-
-
-
-