Class PhysicalCard.Cardholder
-
- All Implemented Interfaces:
public final class PhysicalCard.CardholderDetails about the cardholder, as it appears on the printed card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.Cardholder.BuilderA builder for Cardholder.
-
Method Summary
Modifier and Type Method Description final StringfirstName()The cardholder's first name. final StringlastName()The cardholder's last name. final JsonField<String>_firstName()Returns the raw JSON value of firstName. final JsonField<String>_lastName()Returns the raw JSON value of lastName. final Map<String, JsonValue>_additionalProperties()final PhysicalCard.Cardholder.BuildertoBuilder()final PhysicalCard.Cardholdervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCard.Cardholder.Builderbuilder()Returns a mutable builder for constructing an instance of Cardholder. -
-
Method Detail
-
_firstName
final JsonField<String> _firstName()
Returns the raw JSON value of firstName.
Unlike firstName, this method doesn't throw if the JSON field has an unexpected type.
-
_lastName
final JsonField<String> _lastName()
Returns the raw JSON value of lastName.
Unlike lastName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCard.Cardholder.Builder toBuilder()
-
validate
final PhysicalCard.Cardholder validate()
-
builder
final static PhysicalCard.Cardholder.Builder builder()
Returns a mutable builder for constructing an instance of Cardholder.
The following fields are required:
.firstName() .lastName()
-
-
-
-