Class PhysicalCard.Shipment
-
- All Implemented Interfaces:
public final class PhysicalCard.ShipmentThe details used to ship this physical card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.Shipment.BuilderA builder for Shipment.
public final classPhysicalCard.Shipment.AddressThe location to where the card's packing label is addressed.
public final classPhysicalCard.Shipment.MethodThe shipping method.
public final classPhysicalCard.Shipment.StatusThe status of this shipment.
public final classPhysicalCard.Shipment.TrackingTracking details for the shipment.
-
Method Summary
-
-
Method Detail
-
address
final PhysicalCard.Shipment.Address address()
The location to where the card's packing label is addressed.
-
method
final PhysicalCard.Shipment.Method method()
The shipping method.
-
status
final PhysicalCard.Shipment.Status status()
The status of this shipment.
-
tracking
final Optional<PhysicalCard.Shipment.Tracking> tracking()
Tracking details for the shipment.
-
_address
final JsonField<PhysicalCard.Shipment.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<PhysicalCard.Shipment.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<PhysicalCard.Shipment.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_tracking
final JsonField<PhysicalCard.Shipment.Tracking> _tracking()
Returns the raw JSON value of tracking.
Unlike tracking, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCard.Shipment.Builder toBuilder()
-
validate
final PhysicalCard.Shipment validate()
-
builder
final static PhysicalCard.Shipment.Builder builder()
Returns a mutable builder for constructing an instance of Shipment.
The following fields are required:
.address() .method() .status() .tracking()
-
-
-
-