Class PhysicalCard.Shipment.Tracking
-
- All Implemented Interfaces:
public final class PhysicalCard.Shipment.TrackingTracking details for the shipment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCard.Shipment.Tracking.BuilderA builder for Tracking.
public final classPhysicalCard.Shipment.Tracking.Update
-
Method Summary
Modifier and Type Method Description final Stringnumber()The tracking number. final Optional<String>returnNumber()For returned shipments, the tracking number of the return shipment. final Optional<String>returnReason()For returned shipments, this describes why the package was returned. final OffsetDateTimeshippedAt()The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier. final List<PhysicalCard.Shipment.Tracking.Update>updates()Tracking updates relating to the physical card's delivery. final JsonField<String>_number()Returns the raw JSON value of number. final JsonField<String>_returnNumber()Returns the raw JSON value of returnNumber. final JsonField<String>_returnReason()Returns the raw JSON value of returnReason. final JsonField<OffsetDateTime>_shippedAt()Returns the raw JSON value of shippedAt. final JsonField<List<PhysicalCard.Shipment.Tracking.Update>>_updates()Returns the raw JSON value of updates. final Map<String, JsonValue>_additionalProperties()final PhysicalCard.Shipment.Tracking.BuildertoBuilder()final PhysicalCard.Shipment.Trackingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCard.Shipment.Tracking.Builderbuilder()Returns a mutable builder for constructing an instance of Tracking. -
-
Method Detail
-
returnNumber
final Optional<String> returnNumber()
For returned shipments, the tracking number of the return shipment.
-
returnReason
final Optional<String> returnReason()
For returned shipments, this describes why the package was returned.
-
shippedAt
final OffsetDateTime shippedAt()
The ISO 8601 date and time at which the fulfillment provider marked the card as ready for pick-up by the shipment carrier.
-
updates
final List<PhysicalCard.Shipment.Tracking.Update> updates()
Tracking updates relating to the physical card's delivery.
-
_number
final JsonField<String> _number()
Returns the raw JSON value of number.
Unlike number, this method doesn't throw if the JSON field has an unexpected type.
-
_returnNumber
final JsonField<String> _returnNumber()
Returns the raw JSON value of returnNumber.
Unlike returnNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_returnReason
final JsonField<String> _returnReason()
Returns the raw JSON value of returnReason.
Unlike returnReason, this method doesn't throw if the JSON field has an unexpected type.
-
_shippedAt
final JsonField<OffsetDateTime> _shippedAt()
Returns the raw JSON value of shippedAt.
Unlike shippedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_updates
final JsonField<List<PhysicalCard.Shipment.Tracking.Update>> _updates()
Returns the raw JSON value of updates.
Unlike updates, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCard.Shipment.Tracking.Builder toBuilder()
-
validate
final PhysicalCard.Shipment.Tracking validate()
-
builder
final static PhysicalCard.Shipment.Tracking.Builder builder()
Returns a mutable builder for constructing an instance of Tracking.
The following fields are required:
.number() .returnNumber() .returnReason() .shippedAt() .updates()
-
-
-
-