Class PhysicalCardCreateParams.Shipment
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.ShipmentThe details used to ship this physical card.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Shipment.BuilderA builder for Shipment.
public final classPhysicalCardCreateParams.Shipment.AddressThe address to where the card should be shipped.
public final classPhysicalCardCreateParams.Shipment.MethodThe shipping method to use.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Shipment.Addressaddress()The address to where the card should be shipped. final PhysicalCardCreateParams.Shipment.Methodmethod()The shipping method to use. final JsonField<PhysicalCardCreateParams.Shipment.Address>_address()Returns the raw JSON value of address. final JsonField<PhysicalCardCreateParams.Shipment.Method>_method()Returns the raw JSON value of method. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Shipment.BuildertoBuilder()final PhysicalCardCreateParams.Shipmentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Shipment.Builderbuilder()Returns a mutable builder for constructing an instance of Shipment. -
-
Method Detail
-
address
final PhysicalCardCreateParams.Shipment.Address address()
The address to where the card should be shipped.
-
method
final PhysicalCardCreateParams.Shipment.Method method()
The shipping method to use.
-
_address
final JsonField<PhysicalCardCreateParams.Shipment.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_method
final JsonField<PhysicalCardCreateParams.Shipment.Method> _method()
Returns the raw JSON value of method.
Unlike method, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardCreateParams.Shipment.Builder toBuilder()
-
validate
final PhysicalCardCreateParams.Shipment validate()
-
builder
final static PhysicalCardCreateParams.Shipment.Builder builder()
Returns a mutable builder for constructing an instance of Shipment.
The following fields are required:
.address() .method()
-
-
-
-