Class PhysicalCardListPage
-
- All Implemented Interfaces:
public final class PhysicalCardListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardListPage.BuilderA builder for PhysicalCardListPage.
public final classPhysicalCardListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<PhysicalCard>data()Delegates to PhysicalCardListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PhysicalCardListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<PhysicalCardListParams>getNextPageParams()final Optional<PhysicalCardListPage>getNextPage()final PhysicalCardListPage.AutoPagerautoPager()final PhysicalCardListParamsparams()The parameters that were used to request this page. final PhysicalCardListPageResponseresponse()The response that this page was parsed from. final PhysicalCardListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardListPage.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardListPage. -
-
Method Detail
-
data
final List<PhysicalCard> data()
Delegates to PhysicalCardListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PhysicalCardListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<PhysicalCardListParams> getNextPageParams()
-
getNextPage
final Optional<PhysicalCardListPage> getNextPage()
-
autoPager
final PhysicalCardListPage.AutoPager autoPager()
-
params
final PhysicalCardListParams params()
The parameters that were used to request this page.
-
response
final PhysicalCardListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PhysicalCardListPage.Builder toBuilder()
-
builder
final static PhysicalCardListPage.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-