Class PhysicalCardListPageAsync
-
- All Implemented Interfaces:
public final class PhysicalCardListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardListPageAsync.BuilderA builder for PhysicalCardListPageAsync.
public final classPhysicalCardListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<PhysicalCard>data()Delegates to PhysicalCardListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to PhysicalCardListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<PhysicalCardListParams>getNextPageParams()final CompletableFuture<Optional<PhysicalCardListPageAsync>>getNextPage()final PhysicalCardListPageAsync.AutoPagerautoPager()final PhysicalCardListParamsparams()The parameters that were used to request this page. final PhysicalCardListPageResponseresponse()The response that this page was parsed from. final PhysicalCardListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of PhysicalCardListPageAsync. -
-
Method Detail
-
data
final List<PhysicalCard> data()
Delegates to PhysicalCardListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to PhysicalCardListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<PhysicalCardListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<PhysicalCardListPageAsync>> getNextPage()
-
autoPager
final PhysicalCardListPageAsync.AutoPager autoPager()
-
params
final PhysicalCardListParams params()
The parameters that were used to request this page.
-
response
final PhysicalCardListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final PhysicalCardListPageAsync.Builder toBuilder()
-
builder
final static PhysicalCardListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of PhysicalCardListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-