Package com.increase.api.models.programs
Class Program.Lending
-
- All Implemented Interfaces:
public final class Program.LendingThe lending details for the program.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgram.Lending.BuilderA builder for Lending.
-
Method Summary
Modifier and Type Method Description final LongmaximumExtendableCredit()The maximum extendable credit of the program. final JsonField<Long>_maximumExtendableCredit()Returns the raw JSON value of maximumExtendableCredit. final Map<String, JsonValue>_additionalProperties()final Program.Lending.BuildertoBuilder()final Program.Lendingvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Program.Lending.Builderbuilder()Returns a mutable builder for constructing an instance of Lending. -
-
Method Detail
-
maximumExtendableCredit
final Long maximumExtendableCredit()
The maximum extendable credit of the program.
-
_maximumExtendableCredit
final JsonField<Long> _maximumExtendableCredit()
Returns the raw JSON value of maximumExtendableCredit.
Unlike maximumExtendableCredit, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Program.Lending.Builder toBuilder()
-
validate
final Program.Lending validate()
-
builder
final static Program.Lending.Builder builder()
Returns a mutable builder for constructing an instance of Lending.
The following fields are required:
.maximumExtendableCredit()
-
-
-
-