Package com.increase.api.models.programs
Class ProgramListPage
-
- All Implemented Interfaces:
public final class ProgramListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramListPage.BuilderA builder for ProgramListPage.
public final classProgramListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Program>data()Delegates to ProgramListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ProgramListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<ProgramListParams>getNextPageParams()final Optional<ProgramListPage>getNextPage()final ProgramListPage.AutoPagerautoPager()final ProgramListParamsparams()The parameters that were used to request this page. final ProgramListPageResponseresponse()The response that this page was parsed from. final ProgramListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramListPage.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramListPage. -
-
Method Detail
-
data
final List<Program> data()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ProgramListParams> getNextPageParams()
-
getNextPage
final Optional<ProgramListPage> getNextPage()
-
autoPager
final ProgramListPage.AutoPager autoPager()
-
params
final ProgramListParams params()
The parameters that were used to request this page.
-
response
final ProgramListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ProgramListPage.Builder toBuilder()
-
builder
final static ProgramListPage.Builder builder()
Returns a mutable builder for constructing an instance of ProgramListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-