Package com.increase.api.models.programs
Class ProgramListPageAsync
-
- All Implemented Interfaces:
public final class ProgramListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramListPageAsync.BuilderA builder for ProgramListPageAsync.
public final classProgramListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<Program>data()Delegates to ProgramListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to ProgramListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<ProgramListParams>getNextPageParams()final CompletableFuture<Optional<ProgramListPageAsync>>getNextPage()final ProgramListPageAsync.AutoPagerautoPager()final ProgramListParamsparams()The parameters that were used to request this page. final ProgramListPageResponseresponse()The response that this page was parsed from. final ProgramListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProgramListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of ProgramListPageAsync. -
-
Method Detail
-
data
final List<Program> data()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to ProgramListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<ProgramListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<ProgramListPageAsync>> getNextPage()
-
autoPager
final ProgramListPageAsync.AutoPager autoPager()
-
params
final ProgramListParams params()
The parameters that were used to request this page.
-
response
final ProgramListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final ProgramListPageAsync.Builder toBuilder()
-
builder
final static ProgramListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of ProgramListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-