Class RealTimeDecision
-
- All Implemented Interfaces:
public final class RealTimeDecisionReal Time Decisions are created when your application needs to take action in real-time to some event such as a card authorization. For more information, see our Real-Time Decisions guide.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.BuilderA builder for RealTimeDecision.
public final classRealTimeDecision.CardAuthenticationFields related to a 3DS authentication attempt.
public final classRealTimeDecision.CardAuthenticationChallengeFields related to a 3DS authentication attempt.
public final classRealTimeDecision.CardAuthorizationFields related to a card authorization.
public final classRealTimeDecision.CategoryThe category of the Real-Time Decision.
public final classRealTimeDecision.DigitalWalletAuthenticationFields related to a digital wallet authentication attempt.
public final classRealTimeDecision.DigitalWalletTokenFields related to a digital wallet token provisioning attempt.
public final classRealTimeDecision.StatusThe status of the Real-Time Decision.
public final classRealTimeDecision.TypeA constant representing the object's type. For this resource it will always be
real_time_decision.
-
Method Summary
-
-
Method Detail
-
cardAuthentication
final Optional<RealTimeDecision.CardAuthentication> cardAuthentication()
Fields related to a 3DS authentication attempt.
-
cardAuthenticationChallenge
final Optional<RealTimeDecision.CardAuthenticationChallenge> cardAuthenticationChallenge()
Fields related to a 3DS authentication attempt.
-
cardAuthorization
final Optional<RealTimeDecision.CardAuthorization> cardAuthorization()
Fields related to a card authorization.
-
category
final RealTimeDecision.Category category()
The category of the Real-Time Decision.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the Real-Time Decision was created.
-
digitalWalletAuthentication
final Optional<RealTimeDecision.DigitalWalletAuthentication> digitalWalletAuthentication()
Fields related to a digital wallet authentication attempt.
-
digitalWalletToken
final Optional<RealTimeDecision.DigitalWalletToken> digitalWalletToken()
Fields related to a digital wallet token provisioning attempt.
-
status
final RealTimeDecision.Status status()
The status of the Real-Time Decision.
-
timeoutAt
final OffsetDateTime timeoutAt()
The ISO 8601 date and time at which your application can no longer respond to the Real-Time Decision.
-
type
final RealTimeDecision.Type type()
A constant representing the object's type. For this resource it will always be
real_time_decision.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthentication
final JsonField<RealTimeDecision.CardAuthentication> _cardAuthentication()
Returns the raw JSON value of cardAuthentication.
Unlike cardAuthentication, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthenticationChallenge
final JsonField<RealTimeDecision.CardAuthenticationChallenge> _cardAuthenticationChallenge()
Returns the raw JSON value of cardAuthenticationChallenge.
Unlike cardAuthenticationChallenge, this method doesn't throw if the JSON field has an unexpected type.
-
_cardAuthorization
final JsonField<RealTimeDecision.CardAuthorization> _cardAuthorization()
Returns the raw JSON value of cardAuthorization.
Unlike cardAuthorization, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<RealTimeDecision.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletAuthentication
final JsonField<RealTimeDecision.DigitalWalletAuthentication> _digitalWalletAuthentication()
Returns the raw JSON value of digitalWalletAuthentication.
Unlike digitalWalletAuthentication, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletToken
final JsonField<RealTimeDecision.DigitalWalletToken> _digitalWalletToken()
Returns the raw JSON value of digitalWalletToken.
Unlike digitalWalletToken, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<RealTimeDecision.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_timeoutAt
final JsonField<OffsetDateTime> _timeoutAt()
Returns the raw JSON value of timeoutAt.
Unlike timeoutAt, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RealTimeDecision.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.Builder toBuilder()
-
validate
final RealTimeDecision validate()
-
builder
final static RealTimeDecision.Builder builder()
Returns a mutable builder for constructing an instance of RealTimeDecision.
The following fields are required:
.id() .cardAuthentication() .cardAuthenticationChallenge() .cardAuthorization() .category() .createdAt() .digitalWalletAuthentication() .digitalWalletToken() .status() .timeoutAt() .type()
-
-
-
-