Class RealTimeDecision.CardAuthentication
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthenticationFields related to a 3DS authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.CardAuthentication.BuilderA builder for CardAuthentication.
public final classRealTimeDecision.CardAuthentication.DecisionWhether or not the authentication attempt was approved.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier of the Account the card belongs to. final StringcardId()The identifier of the Card that is being tokenized. final Optional<RealTimeDecision.CardAuthentication.Decision>decision()Whether or not the authentication attempt was approved. final StringupcomingCardPaymentId()The identifier of the Card Payment this authentication attempt will belong to. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<RealTimeDecision.CardAuthentication.Decision>_decision()Returns the raw JSON value of decision. final JsonField<String>_upcomingCardPaymentId()Returns the raw JSON value of upcomingCardPaymentId. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.CardAuthentication.BuildertoBuilder()final RealTimeDecision.CardAuthenticationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.CardAuthentication.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthentication. -
-
Method Detail
-
decision
final Optional<RealTimeDecision.CardAuthentication.Decision> decision()
Whether or not the authentication attempt was approved.
-
upcomingCardPaymentId
final String upcomingCardPaymentId()
The identifier of the Card Payment this authentication attempt will belong to. Available in the API once the card authentication has completed.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_decision
final JsonField<RealTimeDecision.CardAuthentication.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_upcomingCardPaymentId
final JsonField<String> _upcomingCardPaymentId()
Returns the raw JSON value of upcomingCardPaymentId.
Unlike upcomingCardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.CardAuthentication.Builder toBuilder()
-
validate
final RealTimeDecision.CardAuthentication validate()
-
builder
final static RealTimeDecision.CardAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthentication.
The following fields are required:
.accountId() .cardId() .decision() .upcomingCardPaymentId()
-
-
-
-