Class RealTimeDecision.CardAuthentication.Builder
-
- All Implemented Interfaces:
public final class RealTimeDecision.CardAuthentication.BuilderA builder for CardAuthentication.
-
-
Method Summary
-
-
Method Detail
-
accountId
final RealTimeDecision.CardAuthentication.Builder accountId(String accountId)
The identifier of the Account the card belongs to.
-
accountId
final RealTimeDecision.CardAuthentication.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cardId
final RealTimeDecision.CardAuthentication.Builder cardId(String cardId)
The identifier of the Card that is being tokenized.
-
cardId
final RealTimeDecision.CardAuthentication.Builder cardId(JsonField<String> cardId)
Sets Builder.cardId to an arbitrary JSON value.
You should usually call Builder.cardId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
decision
final RealTimeDecision.CardAuthentication.Builder decision(RealTimeDecision.CardAuthentication.Decision decision)
Whether or not the authentication attempt was approved.
-
decision
final RealTimeDecision.CardAuthentication.Builder decision(Optional<RealTimeDecision.CardAuthentication.Decision> decision)
Alias for calling Builder.decision with
decision.orElse(null).
-
decision
final RealTimeDecision.CardAuthentication.Builder decision(JsonField<RealTimeDecision.CardAuthentication.Decision> decision)
Sets Builder.decision to an arbitrary JSON value.
You should usually call Builder.decision with a well-typed Decision value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
upcomingCardPaymentId
final RealTimeDecision.CardAuthentication.Builder upcomingCardPaymentId(String upcomingCardPaymentId)
The identifier of the Card Payment this authentication attempt will belong to. Available in the API once the card authentication has completed.
-
upcomingCardPaymentId
final RealTimeDecision.CardAuthentication.Builder upcomingCardPaymentId(JsonField<String> upcomingCardPaymentId)
Sets Builder.upcomingCardPaymentId to an arbitrary JSON value.
You should usually call Builder.upcomingCardPaymentId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealTimeDecision.CardAuthentication.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealTimeDecision.CardAuthentication.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealTimeDecision.CardAuthentication.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealTimeDecision.CardAuthentication.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealTimeDecision.CardAuthentication.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealTimeDecision.CardAuthentication build()
Returns an immutable instance of CardAuthentication.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .cardId() .decision() .upcomingCardPaymentId()
-
-
-
-