Class RealTimeDecision.DigitalWalletAuthentication
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletAuthenticationFields related to a digital wallet authentication attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.DigitalWalletAuthentication.BuilderA builder for DigitalWalletAuthentication.
public final classRealTimeDecision.DigitalWalletAuthentication.ChannelThe channel to send the card user their one-time passcode.
public final classRealTimeDecision.DigitalWalletAuthentication.DigitalWalletThe digital wallet app being used.
public final classRealTimeDecision.DigitalWalletAuthentication.ResultWhether your application successfully delivered the one-time passcode.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card that is being tokenized. final RealTimeDecision.DigitalWalletAuthentication.Channelchannel()The channel to send the card user their one-time passcode. final RealTimeDecision.DigitalWalletAuthentication.DigitalWalletdigitalWallet()The digital wallet app being used. final Optional<String>email()The email to send the one-time passcode to if channelis equal toemail.final StringoneTimePasscode()The one-time passcode to send the card user. final Optional<String>phone()The phone number to send the one-time passcode to if channelis equal tosms.final Optional<RealTimeDecision.DigitalWalletAuthentication.Result>result()Whether your application successfully delivered the one-time passcode. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<RealTimeDecision.DigitalWalletAuthentication.Channel>_channel()Returns the raw JSON value of channel. final JsonField<RealTimeDecision.DigitalWalletAuthentication.DigitalWallet>_digitalWallet()Returns the raw JSON value of digitalWallet. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<String>_oneTimePasscode()Returns the raw JSON value of oneTimePasscode. final JsonField<String>_phone()Returns the raw JSON value of phone. final JsonField<RealTimeDecision.DigitalWalletAuthentication.Result>_result()Returns the raw JSON value of result. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.DigitalWalletAuthentication.BuildertoBuilder()final RealTimeDecision.DigitalWalletAuthenticationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.DigitalWalletAuthentication.Builderbuilder()Returns a mutable builder for constructing an instance of DigitalWalletAuthentication. -
-
Method Detail
-
channel
final RealTimeDecision.DigitalWalletAuthentication.Channel channel()
The channel to send the card user their one-time passcode.
-
digitalWallet
final RealTimeDecision.DigitalWalletAuthentication.DigitalWallet digitalWallet()
The digital wallet app being used.
-
email
final Optional<String> email()
The email to send the one-time passcode to if
channelis equal toemail.
-
oneTimePasscode
final String oneTimePasscode()
The one-time passcode to send the card user.
-
phone
final Optional<String> phone()
The phone number to send the one-time passcode to if
channelis equal tosms.
-
result
final Optional<RealTimeDecision.DigitalWalletAuthentication.Result> result()
Whether your application successfully delivered the one-time passcode.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_channel
final JsonField<RealTimeDecision.DigitalWalletAuthentication.Channel> _channel()
Returns the raw JSON value of channel.
Unlike channel, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<RealTimeDecision.DigitalWalletAuthentication.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_oneTimePasscode
final JsonField<String> _oneTimePasscode()
Returns the raw JSON value of oneTimePasscode.
Unlike oneTimePasscode, this method doesn't throw if the JSON field has an unexpected type.
-
_phone
final JsonField<String> _phone()
Returns the raw JSON value of phone.
Unlike phone, this method doesn't throw if the JSON field has an unexpected type.
-
_result
final JsonField<RealTimeDecision.DigitalWalletAuthentication.Result> _result()
Returns the raw JSON value of result.
Unlike result, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.DigitalWalletAuthentication.Builder toBuilder()
-
validate
final RealTimeDecision.DigitalWalletAuthentication validate()
-
builder
final static RealTimeDecision.DigitalWalletAuthentication.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletAuthentication.
The following fields are required:
.cardId() .channel() .digitalWallet() .email() .oneTimePasscode() .phone() .result()
-
-
-
-