Class RealTimeDecision.DigitalWalletToken
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletTokenFields related to a digital wallet token provisioning attempt.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.DigitalWalletToken.BuilderA builder for DigitalWalletToken.
public final classRealTimeDecision.DigitalWalletToken.DecisionWhether or not the provisioning request was approved. This will be null until the real time decision is responded to.
public final classRealTimeDecision.DigitalWalletToken.DeviceDevice that is being used to provision the digital wallet token.
public final classRealTimeDecision.DigitalWalletToken.DigitalWalletThe digital wallet app being used.
-
Method Summary
-
-
Method Detail
-
decision
final Optional<RealTimeDecision.DigitalWalletToken.Decision> decision()
Whether or not the provisioning request was approved. This will be null until the real time decision is responded to.
-
device
final RealTimeDecision.DigitalWalletToken.Device device()
Device that is being used to provision the digital wallet token.
-
digitalWallet
final RealTimeDecision.DigitalWalletToken.DigitalWallet digitalWallet()
The digital wallet app being used.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_decision
final JsonField<RealTimeDecision.DigitalWalletToken.Decision> _decision()
Returns the raw JSON value of decision.
Unlike decision, this method doesn't throw if the JSON field has an unexpected type.
-
_device
final JsonField<RealTimeDecision.DigitalWalletToken.Device> _device()
Returns the raw JSON value of device.
Unlike device, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWallet
final JsonField<RealTimeDecision.DigitalWalletToken.DigitalWallet> _digitalWallet()
Returns the raw JSON value of digitalWallet.
Unlike digitalWallet, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.DigitalWalletToken.Builder toBuilder()
-
validate
final RealTimeDecision.DigitalWalletToken validate()
-
builder
final static RealTimeDecision.DigitalWalletToken.Builder builder()
Returns a mutable builder for constructing an instance of DigitalWalletToken.
The following fields are required:
.cardId() .decision() .device() .digitalWallet()
-
-
-
-