Class RealTimeDecision.DigitalWalletToken.Device
-
- All Implemented Interfaces:
public final class RealTimeDecision.DigitalWalletToken.DeviceDevice that is being used to provision the digital wallet token.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecision.DigitalWalletToken.Device.BuilderA builder for Device.
-
Method Summary
Modifier and Type Method Description final Optional<String>identifier()ID assigned to the device by the digital wallet provider. final JsonField<String>_identifier()Returns the raw JSON value of identifier. final Map<String, JsonValue>_additionalProperties()final RealTimeDecision.DigitalWalletToken.Device.BuildertoBuilder()final RealTimeDecision.DigitalWalletToken.Devicevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimeDecision.DigitalWalletToken.Device.Builderbuilder()Returns a mutable builder for constructing an instance of Device. -
-
Method Detail
-
identifier
final Optional<String> identifier()
ID assigned to the device by the digital wallet provider.
-
_identifier
final JsonField<String> _identifier()
Returns the raw JSON value of identifier.
Unlike identifier, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealTimeDecision.DigitalWalletToken.Device.Builder toBuilder()
-
validate
final RealTimeDecision.DigitalWalletToken.Device validate()
-
builder
final static RealTimeDecision.DigitalWalletToken.Device.Builder builder()
Returns a mutable builder for constructing an instance of Device.
The following fields are required:
.identifier()
-
-
-
-