Class RealTimePaymentsTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class RealTimePaymentsTransferCreateParams implements Params
Create a Real-Time Payments Transfer
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferCreateParams.BuilderA builder for RealTimePaymentsTransferCreateParams.
public final classRealTimePaymentsTransferCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringcreditorName()The name of the transfer's recipient. final StringremittanceInformation()Unstructured information that will show on the recipient's bank statement. final StringsourceAccountNumberId()The identifier of the Account Number from which to send the transfer. final Optional<String>debtorName()The name of the transfer's sender. final Optional<String>destinationAccountNumber()The destination account number. final Optional<String>destinationRoutingNumber()The destination American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>ultimateCreditorName()The name of the ultimate recipient of the transfer. final Optional<String>ultimateDebtorName()The name of the ultimate sender of the transfer. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_remittanceInformation()Returns the raw JSON value of remittanceInformation. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_destinationAccountNumber()Returns the raw JSON value of destinationAccountNumber. final JsonField<String>_destinationRoutingNumber()Returns the raw JSON value of destinationRoutingNumber. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_ultimateCreditorName()Returns the raw JSON value of ultimateCreditorName. final JsonField<String>_ultimateDebtorName()Returns the raw JSON value of ultimateDebtorName. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final RealTimePaymentsTransferCreateParams.BuildertoBuilder()final RealTimePaymentsTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealTimePaymentsTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of RealTimePaymentsTransferCreateParams. -
-
Method Detail
-
amount
final Long amount()
The transfer amount in USD cents. For Real-Time Payments transfers, must be positive.
-
creditorName
final String creditorName()
The name of the transfer's recipient.
-
remittanceInformation
final String remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
sourceAccountNumberId
final String sourceAccountNumberId()
The identifier of the Account Number from which to send the transfer.
-
debtorName
final Optional<String> debtorName()
The name of the transfer's sender. If not provided, defaults to the name of the account's entity.
-
destinationAccountNumber
final Optional<String> destinationAccountNumber()
The destination account number.
-
destinationRoutingNumber
final Optional<String> destinationRoutingNumber()
The destination American Bankers' Association (ABA) Routing Transit Number (RTN).
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
destination_account_numberanddestination_routing_numbermust be absent.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
ultimateCreditorName
final Optional<String> ultimateCreditorName()
The name of the ultimate recipient of the transfer. Set this if the creditor is an intermediary receiving the payment for someone else.
-
ultimateDebtorName
final Optional<String> ultimateDebtorName()
The name of the ultimate sender of the transfer. Set this if the funds are being sent on behalf of someone who is not the account holder at Increase.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Returns the raw JSON value of remittanceInformation.
Unlike remittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountNumber
final JsonField<String> _destinationAccountNumber()
Returns the raw JSON value of destinationAccountNumber.
Unlike destinationAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationRoutingNumber
final JsonField<String> _destinationRoutingNumber()
Returns the raw JSON value of destinationRoutingNumber.
Unlike destinationRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_ultimateCreditorName
final JsonField<String> _ultimateCreditorName()
Returns the raw JSON value of ultimateCreditorName.
Unlike ultimateCreditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_ultimateDebtorName
final JsonField<String> _ultimateDebtorName()
Returns the raw JSON value of ultimateDebtorName.
Unlike ultimateDebtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final RealTimePaymentsTransferCreateParams.Builder toBuilder()
-
_body
final RealTimePaymentsTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static RealTimePaymentsTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of RealTimePaymentsTransferCreateParams.
The following fields are required:
.amount() .creditorName() .remittanceInformation() .sourceAccountNumberId()
-
-
-
-