Class RoutingNumberListPageAsync
-
- All Implemented Interfaces:
public final class RoutingNumberListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberListPageAsync.BuilderA builder for RoutingNumberListPageAsync.
public final classRoutingNumberListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<RoutingNumberListResponse>data()Delegates to RoutingNumberListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to RoutingNumberListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<RoutingNumberListParams>getNextPageParams()final CompletableFuture<Optional<RoutingNumberListPageAsync>>getNextPage()final RoutingNumberListPageAsync.AutoPagerautoPager()final RoutingNumberListParamsparams()The parameters that were used to request this page. final RoutingNumberListPageResponseresponse()The response that this page was parsed from. final RoutingNumberListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RoutingNumberListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of RoutingNumberListPageAsync. -
-
Method Detail
-
data
final List<RoutingNumberListResponse> data()
Delegates to RoutingNumberListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to RoutingNumberListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<RoutingNumberListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<RoutingNumberListPageAsync>> getNextPage()
-
autoPager
final RoutingNumberListPageAsync.AutoPager autoPager()
-
params
final RoutingNumberListParams params()
The parameters that were used to request this page.
-
response
final RoutingNumberListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final RoutingNumberListPageAsync.Builder toBuilder()
-
builder
final static RoutingNumberListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of RoutingNumberListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-