Class RoutingNumberListPageAsync
-
- All Implemented Interfaces:
public final class RoutingNumberListPageAsyncYou can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. Since routing numbers uniquely identify a bank, this will always return 0 or 1 entry. In Sandbox, the only valid routing number for this method is 110000000.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberListPageAsync.Responsepublic final classRoutingNumberListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final RoutingNumberListPageAsync.Responseresponse()final List<RoutingNumberListResponse>data()final Optional<String>nextCursor()Booleanequals(Object other)IntegerhashCode()StringtoString()final BooleanhasNextPage()final Optional<RoutingNumberListParams>getNextPageParams()final CompletableFuture<Optional<RoutingNumberListPageAsync>>getNextPage()final RoutingNumberListPageAsync.AutoPagerautoPager()final static RoutingNumberListPageAsyncof(RoutingNumberServiceAsync routingNumbersService, RoutingNumberListParams params, RoutingNumberListPageAsync.Response response)-
-
Method Detail
-
response
final RoutingNumberListPageAsync.Response response()
-
data
final List<RoutingNumberListResponse> data()
-
nextCursor
final Optional<String> nextCursor()
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<RoutingNumberListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<RoutingNumberListPageAsync>> getNextPage()
-
autoPager
final RoutingNumberListPageAsync.AutoPager autoPager()
-
of
final static RoutingNumberListPageAsync of(RoutingNumberServiceAsync routingNumbersService, RoutingNumberListParams params, RoutingNumberListPageAsync.Response response)
-
-
-
-