Class RoutingNumberListResponse
-
- All Implemented Interfaces:
public final class RoutingNumberListResponseRouting numbers are used to identify your bank in a financial transaction.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberListResponse.BuilderA builder for RoutingNumberListResponse.
public final classRoutingNumberListResponse.AchTransfersThis routing number's support for ACH Transfers.
public final classRoutingNumberListResponse.RealTimePaymentsTransfersThis routing number's support for Real-Time Payments Transfers.
public final classRoutingNumberListResponse.TypeA constant representing the object's type. For this resource it will always be
routing_number.public final classRoutingNumberListResponse.WireTransfersThis routing number's support for Wire Transfers.
-
Method Summary
-
-
Method Detail
-
achTransfers
final RoutingNumberListResponse.AchTransfers achTransfers()
This routing number's support for ACH Transfers.
-
realTimePaymentsTransfers
final RoutingNumberListResponse.RealTimePaymentsTransfers realTimePaymentsTransfers()
This routing number's support for Real-Time Payments Transfers.
-
routingNumber
final String routingNumber()
The nine digit routing number identifier.
-
type
final RoutingNumberListResponse.Type type()
A constant representing the object's type. For this resource it will always be
routing_number.
-
wireTransfers
final RoutingNumberListResponse.WireTransfers wireTransfers()
This routing number's support for Wire Transfers.
-
_achTransfers
final JsonField<RoutingNumberListResponse.AchTransfers> _achTransfers()
Returns the raw JSON value of achTransfers.
Unlike achTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimePaymentsTransfers
final JsonField<RoutingNumberListResponse.RealTimePaymentsTransfers> _realTimePaymentsTransfers()
Returns the raw JSON value of realTimePaymentsTransfers.
Unlike realTimePaymentsTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<RoutingNumberListResponse.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_wireTransfers
final JsonField<RoutingNumberListResponse.WireTransfers> _wireTransfers()
Returns the raw JSON value of wireTransfers.
Unlike wireTransfers, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RoutingNumberListResponse.Builder toBuilder()
-
validate
final RoutingNumberListResponse validate()
-
builder
final static RoutingNumberListResponse.Builder builder()
Returns a mutable builder for constructing an instance of RoutingNumberListResponse.
The following fields are required:
.achTransfers() .name() .realTimePaymentsTransfers() .routingNumber() .type() .wireTransfers()
-
-
-
-