Class CardAuthenticationCreateParams.Body
-
- All Implemented Interfaces:
public final class CardAuthenticationCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthenticationCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to be authorized. final Optional<CardAuthenticationCreateParams.Category>category()The category of the card authentication attempt. final Optional<CardAuthenticationCreateParams.DeviceChannel>deviceChannel()The device channel of the card authentication attempt. final Optional<String>merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final Optional<String>merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCountry()The country the merchant resides in. final Optional<String>merchantName()The name of the merchant final Optional<Long>purchaseAmount()The purchase amount in cents. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<CardAuthenticationCreateParams.Category>_category()Returns the raw JSON value of category. final JsonField<CardAuthenticationCreateParams.DeviceChannel>_deviceChannel()Returns the raw JSON value of deviceChannel. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantName()Returns the raw JSON value of merchantName. final JsonField<Long>_purchaseAmount()Returns the raw JSON value of purchaseAmount. final Map<String, JsonValue>_additionalProperties()final CardAuthenticationCreateParams.Body.BuildertoBuilder()final CardAuthenticationCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthenticationCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
category
final Optional<CardAuthenticationCreateParams.Category> category()
The category of the card authentication attempt.
-
deviceChannel
final Optional<CardAuthenticationCreateParams.DeviceChannel> deviceChannel()
The device channel of the card authentication attempt.
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Optional<String> merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantName
final Optional<String> merchantName()
The name of the merchant
-
purchaseAmount
final Optional<Long> purchaseAmount()
The purchase amount in cents.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_category
final JsonField<CardAuthenticationCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_deviceChannel
final JsonField<CardAuthenticationCreateParams.DeviceChannel> _deviceChannel()
Returns the raw JSON value of deviceChannel.
Unlike deviceChannel, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantName
final JsonField<String> _merchantName()
Returns the raw JSON value of merchantName.
Unlike merchantName, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseAmount
final JsonField<Long> _purchaseAmount()
Returns the raw JSON value of purchaseAmount.
Unlike purchaseAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardAuthenticationCreateParams.Body.Builder toBuilder()
-
validate
final CardAuthenticationCreateParams.Body validate()
-
builder
final static CardAuthenticationCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.cardId()
-
-
-
-