Class CardAuthorizationCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardAuthorizationCreateParams implements Params
Simulates a purchase authorization on a #cards. Depending on the balance available to the card and the
amountsubmitted, the authorization activity will result in a #pending-transactions of typecard_authorizationor a #declined-transactions of typecard_decline. You can pass either a Card id or a #digital-wallet-tokens id to simulate the two different ways purchases can be made.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationCreateParams.BuilderA builder for CardAuthorizationCreateParams.
public final classCardAuthorizationCreateParams.Bodypublic final classCardAuthorizationCreateParams.DeclineReasonForces a card decline with a specific reason. No real time decision will be sent.
public final classCardAuthorizationCreateParams.DirectionThe direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
public final classCardAuthorizationCreateParams.NetworkDetailsFields specific to a given card network.
-
Method Summary
Modifier and Type Method Description final Longamount()The authorization amount in cents. final Optional<String>authenticatedCardPaymentId()The identifier of a Card Payment with a card_authenticationif you want to simulate an authenticated authorization.final Optional<String>cardId()The identifier of the Card to be authorized. final Optional<CardAuthorizationCreateParams.DeclineReason>declineReason()Forces a card decline with a specific reason. final Optional<String>digitalWalletTokenId()The identifier of the Digital Wallet Token to be authorized. final Optional<CardAuthorizationCreateParams.Direction>direction()The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder. final Optional<String>eventSubscriptionId()The identifier of the Event Subscription to use. final Optional<String>merchantAcceptorId()The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with. final Optional<String>merchantCategoryCode()The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with. final Optional<String>merchantCity()The city the merchant resides in. final Optional<String>merchantCountry()The country the merchant resides in. final Optional<String>merchantDescriptor()The merchant descriptor of the merchant the card is transacting with. final Optional<String>merchantState()The state the merchant resides in. final Optional<CardAuthorizationCreateParams.NetworkDetails>networkDetails()Fields specific to a given card network. final Optional<Long>networkRiskScore()The risk score generated by the card network. final Optional<String>physicalCardId()The identifier of the Physical Card to be authorized. final Optional<String>terminalId()The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_authenticatedCardPaymentId()Returns the raw JSON value of authenticatedCardPaymentId. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<CardAuthorizationCreateParams.DeclineReason>_declineReason()Returns the raw JSON value of declineReason. final JsonField<String>_digitalWalletTokenId()Returns the raw JSON value of digitalWalletTokenId. final JsonField<CardAuthorizationCreateParams.Direction>_direction()Returns the raw JSON value of direction. final JsonField<String>_eventSubscriptionId()Returns the raw JSON value of eventSubscriptionId. final JsonField<String>_merchantAcceptorId()Returns the raw JSON value of merchantAcceptorId. final JsonField<String>_merchantCategoryCode()Returns the raw JSON value of merchantCategoryCode. final JsonField<String>_merchantCity()Returns the raw JSON value of merchantCity. final JsonField<String>_merchantCountry()Returns the raw JSON value of merchantCountry. final JsonField<String>_merchantDescriptor()Returns the raw JSON value of merchantDescriptor. final JsonField<String>_merchantState()Returns the raw JSON value of merchantState. final JsonField<CardAuthorizationCreateParams.NetworkDetails>_networkDetails()Returns the raw JSON value of networkDetails. final JsonField<Long>_networkRiskScore()Returns the raw JSON value of networkRiskScore. final JsonField<String>_physicalCardId()Returns the raw JSON value of physicalCardId. final JsonField<String>_terminalId()Returns the raw JSON value of terminalId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()final QueryParams_additionalQueryParams()final CardAuthorizationCreateParams.BuildertoBuilder()final CardAuthorizationCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardAuthorizationCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardAuthorizationCreateParams. -
-
Method Detail
-
authenticatedCardPaymentId
final Optional<String> authenticatedCardPaymentId()
The identifier of a Card Payment with a
card_authenticationif you want to simulate an authenticated authorization.
-
declineReason
final Optional<CardAuthorizationCreateParams.DeclineReason> declineReason()
Forces a card decline with a specific reason. No real time decision will be sent.
-
digitalWalletTokenId
final Optional<String> digitalWalletTokenId()
The identifier of the Digital Wallet Token to be authorized.
-
direction
final Optional<CardAuthorizationCreateParams.Direction> direction()
The direction describes the direction the funds will move, either from the cardholder to the merchant or from the merchant to the cardholder.
-
eventSubscriptionId
final Optional<String> eventSubscriptionId()
The identifier of the Event Subscription to use. If provided, will override the default real time event subscription. Because you can only create one real time decision event subscription, you can use this field to route events to any specified event subscription for testing purposes.
-
merchantAcceptorId
final Optional<String> merchantAcceptorId()
The merchant identifier (commonly abbreviated as MID) of the merchant the card is transacting with.
-
merchantCategoryCode
final Optional<String> merchantCategoryCode()
The Merchant Category Code (commonly abbreviated as MCC) of the merchant the card is transacting with.
-
merchantCity
final Optional<String> merchantCity()
The city the merchant resides in.
-
merchantCountry
final Optional<String> merchantCountry()
The country the merchant resides in.
-
merchantDescriptor
final Optional<String> merchantDescriptor()
The merchant descriptor of the merchant the card is transacting with.
-
merchantState
final Optional<String> merchantState()
The state the merchant resides in.
-
networkDetails
final Optional<CardAuthorizationCreateParams.NetworkDetails> networkDetails()
Fields specific to a given card network.
-
networkRiskScore
final Optional<Long> networkRiskScore()
The risk score generated by the card network. For Visa this is the Visa Advanced Authorization risk score, from 0 to 99, where 99 is the riskiest.
-
physicalCardId
final Optional<String> physicalCardId()
The identifier of the Physical Card to be authorized.
-
terminalId
final Optional<String> terminalId()
The terminal identifier (commonly abbreviated as TID) of the terminal the card is transacting with.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_authenticatedCardPaymentId
final JsonField<String> _authenticatedCardPaymentId()
Returns the raw JSON value of authenticatedCardPaymentId.
Unlike authenticatedCardPaymentId, this method doesn't throw if the JSON field has an unexpected type.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_declineReason
final JsonField<CardAuthorizationCreateParams.DeclineReason> _declineReason()
Returns the raw JSON value of declineReason.
Unlike declineReason, this method doesn't throw if the JSON field has an unexpected type.
-
_digitalWalletTokenId
final JsonField<String> _digitalWalletTokenId()
Returns the raw JSON value of digitalWalletTokenId.
Unlike digitalWalletTokenId, this method doesn't throw if the JSON field has an unexpected type.
-
_direction
final JsonField<CardAuthorizationCreateParams.Direction> _direction()
Returns the raw JSON value of direction.
Unlike direction, this method doesn't throw if the JSON field has an unexpected type.
-
_eventSubscriptionId
final JsonField<String> _eventSubscriptionId()
Returns the raw JSON value of eventSubscriptionId.
Unlike eventSubscriptionId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantAcceptorId
final JsonField<String> _merchantAcceptorId()
Returns the raw JSON value of merchantAcceptorId.
Unlike merchantAcceptorId, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCategoryCode
final JsonField<String> _merchantCategoryCode()
Returns the raw JSON value of merchantCategoryCode.
Unlike merchantCategoryCode, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCity
final JsonField<String> _merchantCity()
Returns the raw JSON value of merchantCity.
Unlike merchantCity, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantCountry
final JsonField<String> _merchantCountry()
Returns the raw JSON value of merchantCountry.
Unlike merchantCountry, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantDescriptor
final JsonField<String> _merchantDescriptor()
Returns the raw JSON value of merchantDescriptor.
Unlike merchantDescriptor, this method doesn't throw if the JSON field has an unexpected type.
-
_merchantState
final JsonField<String> _merchantState()
Returns the raw JSON value of merchantState.
Unlike merchantState, this method doesn't throw if the JSON field has an unexpected type.
-
_networkDetails
final JsonField<CardAuthorizationCreateParams.NetworkDetails> _networkDetails()
Returns the raw JSON value of networkDetails.
Unlike networkDetails, this method doesn't throw if the JSON field has an unexpected type.
-
_networkRiskScore
final JsonField<Long> _networkRiskScore()
Returns the raw JSON value of networkRiskScore.
Unlike networkRiskScore, this method doesn't throw if the JSON field has an unexpected type.
-
_physicalCardId
final JsonField<String> _physicalCardId()
Returns the raw JSON value of physicalCardId.
Unlike physicalCardId, this method doesn't throw if the JSON field has an unexpected type.
-
_terminalId
final JsonField<String> _terminalId()
Returns the raw JSON value of terminalId.
Unlike terminalId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
-
toBuilder
final CardAuthorizationCreateParams.Builder toBuilder()
-
_body
final CardAuthorizationCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardAuthorizationCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardAuthorizationCreateParams.
The following fields are required:
.amount()
-
-
-
-