Class CardRefundCreateParams.Body
-
- All Implemented Interfaces:
public final class CardRefundCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRefundCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<Long>amount()The refund amount in cents. final Optional<String>pendingTransactionId()The identifier of the Pending Transaction for the refund authorization. final Optional<String>transactionId()The identifier for the Transaction to refund. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final CardRefundCreateParams.Body.BuildertoBuilder()final CardRefundCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRefundCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
amount
final Optional<Long> amount()
The refund amount in cents. Pulled off the
pending_transactionor thetransactionif not provided.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The identifier of the Pending Transaction for the refund authorization. If this is provided,
transactionmust not be provided as a refund with a refund authorized can not be linked to a regular transaction.
-
transactionId
final Optional<String> transactionId()
The identifier for the Transaction to refund. The Transaction's source must have a category of card_settlement.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardRefundCreateParams.Body.Builder toBuilder()
-
validate
final CardRefundCreateParams.Body validate()
-
builder
final static CardRefundCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-