Class CardRefundCreateParams.Body
-
- All Implemented Interfaces:
public final class CardRefundCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardRefundCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringtransactionId()The identifier for the Transaction to refund. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final Map<String, JsonValue>_additionalProperties()final CardRefundCreateParams.Body.BuildertoBuilder()final CardRefundCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardRefundCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
transactionId
final String transactionId()
The identifier for the Transaction to refund. The Transaction's source must have a category of card_settlement.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CardRefundCreateParams.Body.Builder toBuilder()
-
validate
final CardRefundCreateParams.Body validate()
-
builder
final static CardRefundCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.transactionId()
-
-
-
-