Class CardSettlementCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardSettlementCreateParams implements Params
Simulates the settlement of an authorization by a card acquirer. After a card authorization is created, the merchant will eventually send a settlement. This simulates that event, which may occur many days after the purchase in production. The amount settled can be different from the amount originally authorized, for example, when adding a tip to a restaurant bill.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSettlementCreateParams.BuilderA builder for CardSettlementCreateParams.
public final classCardSettlementCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringcardId()The identifier of the Card to create a settlement on. final StringpendingTransactionId()The identifier of the Pending Transaction for the Card Authorization you wish to settle. final Optional<Long>amount()The amount to be settled. final JsonField<String>_cardId()Returns the raw JSON value of cardId. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardSettlementCreateParams.BuildertoBuilder()final CardSettlementCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardSettlementCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardSettlementCreateParams. -
-
Method Detail
-
pendingTransactionId
final String pendingTransactionId()
The identifier of the Pending Transaction for the Card Authorization you wish to settle.
-
amount
final Optional<Long> amount()
The amount to be settled. This defaults to the amount of the Pending Transaction being settled.
-
_cardId
final JsonField<String> _cardId()
Returns the raw JSON value of cardId.
Unlike cardId, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardSettlementCreateParams.Builder toBuilder()
-
_body
final CardSettlementCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CardSettlementCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardSettlementCreateParams.
The following fields are required:
.cardId() .pendingTransactionId()
-
-
-
-