Class CardTokenCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class CardTokenCreateParams implements Params
Simulates tokenizing a card in the sandbox environment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardTokenCreateParams.BuilderA builder for CardTokenCreateParams.
public final classCardTokenCreateParams.Bodypublic final classCardTokenCreateParams.Capability
-
Method Summary
Modifier and Type Method Description final Optional<List<CardTokenCreateParams.Capability>>capabilities()The capabilities of the outbound card token. final Optional<LocalDate>expiration()The expiration date of the card. final Optional<String>last4()The last 4 digits of the card number. final Optional<String>prefix()The prefix of the card number, usually the first 8 digits. final Optional<Long>primaryAccountNumberLength()The total length of the card number, including prefix and last4. final JsonField<List<CardTokenCreateParams.Capability>>_capabilities()Returns the raw JSON value of capabilities. final JsonField<LocalDate>_expiration()Returns the raw JSON value of expiration. final JsonField<String>_last4()Returns the raw JSON value of last4. final JsonField<String>_prefix()Returns the raw JSON value of prefix. final JsonField<Long>_primaryAccountNumberLength()Returns the raw JSON value of primaryAccountNumberLength. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CardTokenCreateParams.BuildertoBuilder()final CardTokenCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CardTokenCreateParamsnone()final static CardTokenCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CardTokenCreateParams. -
-
Method Detail
-
capabilities
final Optional<List<CardTokenCreateParams.Capability>> capabilities()
The capabilities of the outbound card token.
-
expiration
final Optional<LocalDate> expiration()
The expiration date of the card.
-
primaryAccountNumberLength
final Optional<Long> primaryAccountNumberLength()
The total length of the card number, including prefix and last4.
-
_capabilities
final JsonField<List<CardTokenCreateParams.Capability>> _capabilities()
Returns the raw JSON value of capabilities.
Unlike capabilities, this method doesn't throw if the JSON field has an unexpected type.
-
_expiration
final JsonField<LocalDate> _expiration()
Returns the raw JSON value of expiration.
Unlike expiration, this method doesn't throw if the JSON field has an unexpected type.
-
_last4
final JsonField<String> _last4()
Returns the raw JSON value of last4.
Unlike last4, this method doesn't throw if the JSON field has an unexpected type.
-
_prefix
final JsonField<String> _prefix()
Returns the raw JSON value of prefix.
Unlike prefix, this method doesn't throw if the JSON field has an unexpected type.
-
_primaryAccountNumberLength
final JsonField<Long> _primaryAccountNumberLength()
Returns the raw JSON value of primaryAccountNumberLength.
Unlike primaryAccountNumberLength, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CardTokenCreateParams.Builder toBuilder()
-
_body
final CardTokenCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CardTokenCreateParams none()
-
builder
final static CardTokenCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CardTokenCreateParams.
-
-
-
-