Class CheckDepositSubmitParams.Scan
-
- All Implemented Interfaces:
public final class CheckDepositSubmitParams.ScanIf set, the simulation will use these values for the check's scanned MICR data.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckDepositSubmitParams.Scan.BuilderA builder for Scan.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The account number to be returned in the check deposit's scan data. final StringroutingNumber()The routing number to be returned in the check deposit's scan data. final Optional<String>auxiliaryOnUs()The auxiliary on-us data to be returned in the check deposit's scan data. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_auxiliaryOnUs()Returns the raw JSON value of auxiliaryOnUs. final Map<String, JsonValue>_additionalProperties()final CheckDepositSubmitParams.Scan.BuildertoBuilder()final CheckDepositSubmitParams.Scanvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CheckDepositSubmitParams.Scan.Builderbuilder()Returns a mutable builder for constructing an instance of Scan. -
-
Method Detail
-
accountNumber
final String accountNumber()
The account number to be returned in the check deposit's scan data.
-
routingNumber
final String routingNumber()
The routing number to be returned in the check deposit's scan data.
-
auxiliaryOnUs
final Optional<String> auxiliaryOnUs()
The auxiliary on-us data to be returned in the check deposit's scan data.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_auxiliaryOnUs
final JsonField<String> _auxiliaryOnUs()
Returns the raw JSON value of auxiliaryOnUs.
Unlike auxiliaryOnUs, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CheckDepositSubmitParams.Scan.Builder toBuilder()
-
validate
final CheckDepositSubmitParams.Scan validate()
-
builder
final static CheckDepositSubmitParams.Scan.Builder builder()
Returns a mutable builder for constructing an instance of Scan.
The following fields are required:
.accountNumber() .routingNumber()
-
-
-
-