Class ExportCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class ExportCreateParams implements Params
Many exports are created by you via POST /exports or in the Dashboard. Some exports are created automatically by Increase. For example, tax documents are published once a year. In sandbox, you can trigger the arrival of an export that would normally only be created automatically via this simulation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.BuilderA builder for ExportCreateParams.
public final classExportCreateParams.Bodypublic final classExportCreateParams.CategoryThe type of Export to create.
public final classExportCreateParams.Form1099IntOptions for the created export. Required if
categoryis equal toform_1099_int.
-
Method Summary
Modifier and Type Method Description final ExportCreateParams.Categorycategory()The type of Export to create. final Optional<ExportCreateParams.Form1099Int>form1099Int()Options for the created export. final JsonField<ExportCreateParams.Category>_category()Returns the raw JSON value of category. final JsonField<ExportCreateParams.Form1099Int>_form1099Int()Returns the raw JSON value of form1099Int. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final ExportCreateParams.BuildertoBuilder()final ExportCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of ExportCreateParams. -
-
Method Detail
-
category
final ExportCreateParams.Category category()
The type of Export to create.
-
form1099Int
final Optional<ExportCreateParams.Form1099Int> form1099Int()
Options for the created export. Required if
categoryis equal toform_1099_int.
-
_category
final JsonField<ExportCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_form1099Int
final JsonField<ExportCreateParams.Form1099Int> _form1099Int()
Returns the raw JSON value of form1099Int.
Unlike form1099Int, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final ExportCreateParams.Builder toBuilder()
-
_body
final ExportCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static ExportCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of ExportCreateParams.
The following fields are required:
.category()
-
-
-
-