Class ExportCreateParams.Body
-
- All Implemented Interfaces:
public final class ExportCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final ExportCreateParams.Categorycategory()The type of Export to create. final Optional<ExportCreateParams.Form1099Int>form1099Int()Options for the created export. final JsonField<ExportCreateParams.Category>_category()Returns the raw JSON value of category. final JsonField<ExportCreateParams.Form1099Int>_form1099Int()Returns the raw JSON value of form1099Int. final Map<String, JsonValue>_additionalProperties()final ExportCreateParams.Body.BuildertoBuilder()final ExportCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExportCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
category
final ExportCreateParams.Category category()
The type of Export to create.
-
form1099Int
final Optional<ExportCreateParams.Form1099Int> form1099Int()
Options for the created export. Required if
categoryis equal toform_1099_int.
-
_category
final JsonField<ExportCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_form1099Int
final JsonField<ExportCreateParams.Form1099Int> _form1099Int()
Returns the raw JSON value of form1099Int.
Unlike form1099Int, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExportCreateParams.Body.Builder toBuilder()
-
validate
final ExportCreateParams.Body validate()
-
builder
final static ExportCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.category()
-
-
-
-