Class InboundCheckDepositCreateParams.Body
-
- All Implemented Interfaces:
public final class InboundCheckDepositCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the Inbound Check Deposit will be against. final Longamount()The check amount in cents. final StringcheckNumber()The check number on the check to be deposited. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_checkNumber()Returns the raw JSON value of checkNumber. final Map<String, JsonValue>_additionalProperties()final InboundCheckDepositCreateParams.Body.BuildertoBuilder()final InboundCheckDepositCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundCheckDepositCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the Inbound Check Deposit will be against.
-
checkNumber
final String checkNumber()
The check number on the check to be deposited.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_checkNumber
final JsonField<String> _checkNumber()
Returns the raw JSON value of checkNumber.
Unlike checkNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundCheckDepositCreateParams.Body.Builder toBuilder()
-
validate
final InboundCheckDepositCreateParams.Body validate()
-
builder
final static InboundCheckDepositCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountNumberId() .amount() .checkNumber()
-
-
-
-