Class InboundMailItemCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundMailItemCreateParams implements Params
Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemCreateParams.BuilderA builder for InboundMailItemCreateParams.
public final classInboundMailItemCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the check to be simulated, in cents. final StringlockboxId()The identifier of the Lockbox to simulate inbound mail to. final Optional<String>contentsFileId()The file containing the PDF contents. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_lockboxId()Returns the raw JSON value of lockboxId. final JsonField<String>_contentsFileId()Returns the raw JSON value of contentsFileId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundMailItemCreateParams.BuildertoBuilder()final InboundMailItemCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundMailItemCreateParams. -
-
Method Detail
-
contentsFileId
final Optional<String> contentsFileId()
The file containing the PDF contents. If not present, a default check image file will be used.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxId
final JsonField<String> _lockboxId()
Returns the raw JSON value of lockboxId.
Unlike lockboxId, this method doesn't throw if the JSON field has an unexpected type.
-
_contentsFileId
final JsonField<String> _contentsFileId()
Returns the raw JSON value of contentsFileId.
Unlike contentsFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundMailItemCreateParams.Builder toBuilder()
-
_body
final InboundMailItemCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundMailItemCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundMailItemCreateParams.
The following fields are required:
.amount() .lockboxId()
-
-
-
-