Class InboundMailItemCreateParams.Body
-
- All Implemented Interfaces:
public final class InboundMailItemCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount of the check to be simulated, in cents. final StringlockboxId()The identifier of the Lockbox to simulate inbound mail to. final Optional<String>contentsFileId()The file containing the PDF contents. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_lockboxId()Returns the raw JSON value of lockboxId. final JsonField<String>_contentsFileId()Returns the raw JSON value of contentsFileId. final Map<String, JsonValue>_additionalProperties()final InboundMailItemCreateParams.Body.BuildertoBuilder()final InboundMailItemCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundMailItemCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
contentsFileId
final Optional<String> contentsFileId()
The file containing the PDF contents. If not present, a default check image file will be used.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_lockboxId
final JsonField<String> _lockboxId()
Returns the raw JSON value of lockboxId.
Unlike lockboxId, this method doesn't throw if the JSON field has an unexpected type.
-
_contentsFileId
final JsonField<String> _contentsFileId()
Returns the raw JSON value of contentsFileId.
Unlike contentsFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InboundMailItemCreateParams.Body.Builder toBuilder()
-
validate
final InboundMailItemCreateParams.Body validate()
-
builder
final static InboundMailItemCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.amount() .lockboxId()
-
-
-
-