Class InboundWireDrawdownRequestCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundWireDrawdownRequestCreateParams implements Params
Simulates receiving an #inbound-wire-drawdown-requests.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestCreateParams.BuilderA builder for InboundWireDrawdownRequestCreateParams.
public final classInboundWireDrawdownRequestCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Longamount()The amount being requested in cents. final StringbeneficiaryAccountNumber()The drawdown request's beneficiary's account number. final StringbeneficiaryRoutingNumber()The drawdown request's beneficiary's routing number. final Stringcurrency()The ISO 4217 code for the amount being requested. final StringmessageToRecipient()A message from the drawdown request's originator. final StringoriginatorAccountNumber()The drawdown request's originator's account number. final StringoriginatorRoutingNumber()The drawdown request's originator's routing number. final StringrecipientAccountNumberId()The Account Number to which the recipient of this request is being requested to send funds from. final Optional<String>beneficiaryAddressLine1()Line 1 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryAddressLine2()Line 2 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryAddressLine3()Line 3 of the drawdown request's beneficiary's address. final Optional<String>beneficiaryName()The drawdown request's beneficiary's name. final Optional<String>originatorAddressLine1()Line 1 of the drawdown request's originator's address. final Optional<String>originatorAddressLine2()Line 2 of the drawdown request's originator's address. final Optional<String>originatorAddressLine3()Line 3 of the drawdown request's originator's address. final Optional<String>originatorName()The drawdown request's originator's name. final Optional<String>originatorToBeneficiaryInformationLine1()Line 1 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine2()Line 2 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine3()Line 3 of the information conveyed from the originator of the message to the beneficiary. final Optional<String>originatorToBeneficiaryInformationLine4()Line 4 of the information conveyed from the originator of the message to the beneficiary. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_beneficiaryAccountNumber()Returns the raw JSON value of beneficiaryAccountNumber. final JsonField<String>_beneficiaryRoutingNumber()Returns the raw JSON value of beneficiaryRoutingNumber. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_originatorAccountNumber()Returns the raw JSON value of originatorAccountNumber. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_recipientAccountNumberId()Returns the raw JSON value of recipientAccountNumberId. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_originatorToBeneficiaryInformationLine1()Returns the raw JSON value of originatorToBeneficiaryInformationLine1. final JsonField<String>_originatorToBeneficiaryInformationLine2()Returns the raw JSON value of originatorToBeneficiaryInformationLine2. final JsonField<String>_originatorToBeneficiaryInformationLine3()Returns the raw JSON value of originatorToBeneficiaryInformationLine3. final JsonField<String>_originatorToBeneficiaryInformationLine4()Returns the raw JSON value of originatorToBeneficiaryInformationLine4. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundWireDrawdownRequestCreateParams.BuildertoBuilder()final InboundWireDrawdownRequestCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireDrawdownRequestCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestCreateParams. -
-
Method Detail
-
beneficiaryAccountNumber
final String beneficiaryAccountNumber()
The drawdown request's beneficiary's account number.
-
beneficiaryRoutingNumber
final String beneficiaryRoutingNumber()
The drawdown request's beneficiary's routing number.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
messageToRecipient
final String messageToRecipient()
A message from the drawdown request's originator.
-
originatorAccountNumber
final String originatorAccountNumber()
The drawdown request's originator's account number.
-
originatorRoutingNumber
final String originatorRoutingNumber()
The drawdown request's originator's routing number.
-
recipientAccountNumberId
final String recipientAccountNumberId()
The Account Number to which the recipient of this request is being requested to send funds from.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryName
final Optional<String> beneficiaryName()
The drawdown request's beneficiary's name.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
Line 3 of the drawdown request's originator's address.
-
originatorName
final Optional<String> originatorName()
The drawdown request's originator's name.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAccountNumber
final JsonField<String> _beneficiaryAccountNumber()
Returns the raw JSON value of beneficiaryAccountNumber.
Unlike beneficiaryAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryRoutingNumber
final JsonField<String> _beneficiaryRoutingNumber()
Returns the raw JSON value of beneficiaryRoutingNumber.
Unlike beneficiaryRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAccountNumber
final JsonField<String> _originatorAccountNumber()
Returns the raw JSON value of originatorAccountNumber.
Unlike originatorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAccountNumberId
final JsonField<String> _recipientAccountNumberId()
Returns the raw JSON value of recipientAccountNumberId.
Unlike recipientAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
Returns the raw JSON value of originatorToBeneficiaryInformationLine1.
Unlike originatorToBeneficiaryInformationLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
Returns the raw JSON value of originatorToBeneficiaryInformationLine2.
Unlike originatorToBeneficiaryInformationLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
Returns the raw JSON value of originatorToBeneficiaryInformationLine3.
Unlike originatorToBeneficiaryInformationLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
Returns the raw JSON value of originatorToBeneficiaryInformationLine4.
Unlike originatorToBeneficiaryInformationLine4, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundWireDrawdownRequestCreateParams.Builder toBuilder()
-
_body
final InboundWireDrawdownRequestCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundWireDrawdownRequestCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireDrawdownRequestCreateParams.
The following fields are required:
.amount() .beneficiaryAccountNumber() .beneficiaryRoutingNumber() .currency() .messageToRecipient() .originatorAccountNumber() .originatorRoutingNumber() .recipientAccountNumberId()
-
-
-
-