Class InboundWireDrawdownRequestCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
amount
final InboundWireDrawdownRequestCreateParams.Body.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final InboundWireDrawdownRequestCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAccountNumber(String beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAccountNumber(JsonField<String> beneficiaryAccountNumber)
Sets Builder.beneficiaryAccountNumber to an arbitrary JSON value.
You should usually call Builder.beneficiaryAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryRoutingNumber(String beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryRoutingNumber(JsonField<String> beneficiaryRoutingNumber)
Sets Builder.beneficiaryRoutingNumber to an arbitrary JSON value.
You should usually call Builder.beneficiaryRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InboundWireDrawdownRequestCreateParams.Body.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final InboundWireDrawdownRequestCreateParams.Body.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final InboundWireDrawdownRequestCreateParams.Body.Builder messageToRecipient(String messageToRecipient)
A message from the drawdown request's originator.
-
messageToRecipient
final InboundWireDrawdownRequestCreateParams.Body.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAccountNumber(String originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorAccountNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAccountNumber(JsonField<String> originatorAccountNumber)
Sets Builder.originatorAccountNumber to an arbitrary JSON value.
You should usually call Builder.originatorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorRoutingNumber(String originatorRoutingNumber)
The drawdown request's originator's routing number.
-
originatorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumberId
final InboundWireDrawdownRequestCreateParams.Body.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number to which the recipient of this request is being requested to send funds from.
-
recipientAccountNumberId
final InboundWireDrawdownRequestCreateParams.Body.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
Sets Builder.recipientAccountNumberId to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryName(String beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryName
final InboundWireDrawdownRequestCreateParams.Body.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorAddressLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorName(String originatorName)
The drawdown request's originator's name.
-
originatorName
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequestCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireDrawdownRequestCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireDrawdownRequestCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireDrawdownRequestCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireDrawdownRequestCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireDrawdownRequestCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireDrawdownRequestCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .beneficiaryAccountNumber() .beneficiaryRoutingNumber() .currency() .messageToRecipient() .originatorAccountNumber() .originatorRoutingNumber() .recipientAccountNumberId()
-
-
-
-