Class InboundWireDrawdownRequestCreateParams.Builder
-
- All Implemented Interfaces:
public final class InboundWireDrawdownRequestCreateParams.BuilderA builder for InboundWireDrawdownRequestCreateParams.
-
-
Method Summary
-
-
Method Detail
-
body
final InboundWireDrawdownRequestCreateParams.Builder body(InboundWireDrawdownRequestCreateParams.Body body)
Sets the entire request body.
This is generally only useful if you are already constructing the body separately. Otherwise, it's more convenient to use the top-level setters instead:
-
amount
final InboundWireDrawdownRequestCreateParams.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final InboundWireDrawdownRequestCreateParams.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAccountNumber(String beneficiaryAccountNumber)
The drawdown request's beneficiary's account number.
-
beneficiaryAccountNumber
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAccountNumber(JsonField<String> beneficiaryAccountNumber)
Sets Builder.beneficiaryAccountNumber to an arbitrary JSON value.
You should usually call Builder.beneficiaryAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryRoutingNumber(String beneficiaryRoutingNumber)
The drawdown request's beneficiary's routing number.
-
beneficiaryRoutingNumber
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryRoutingNumber(JsonField<String> beneficiaryRoutingNumber)
Sets Builder.beneficiaryRoutingNumber to an arbitrary JSON value.
You should usually call Builder.beneficiaryRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final InboundWireDrawdownRequestCreateParams.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final InboundWireDrawdownRequestCreateParams.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final InboundWireDrawdownRequestCreateParams.Builder messageToRecipient(String messageToRecipient)
A message from the drawdown request's originator.
-
messageToRecipient
final InboundWireDrawdownRequestCreateParams.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAccountNumber
final InboundWireDrawdownRequestCreateParams.Builder originatorAccountNumber(String originatorAccountNumber)
The drawdown request's originator's account number.
-
originatorAccountNumber
final InboundWireDrawdownRequestCreateParams.Builder originatorAccountNumber(JsonField<String> originatorAccountNumber)
Sets Builder.originatorAccountNumber to an arbitrary JSON value.
You should usually call Builder.originatorAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Builder originatorRoutingNumber(String originatorRoutingNumber)
The drawdown request's originator's routing number.
-
originatorRoutingNumber
final InboundWireDrawdownRequestCreateParams.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumberId
final InboundWireDrawdownRequestCreateParams.Builder recipientAccountNumberId(String recipientAccountNumberId)
The Account Number to which the recipient of this request is being requested to send funds from.
-
recipientAccountNumberId
final InboundWireDrawdownRequestCreateParams.Builder recipientAccountNumberId(JsonField<String> recipientAccountNumberId)
Sets Builder.recipientAccountNumberId to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
Line 1 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine1
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
Line 2 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine2
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
Line 3 of the drawdown request's beneficiary's address.
-
beneficiaryAddressLine3
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryName(String beneficiaryName)
The drawdown request's beneficiary's name.
-
beneficiaryName
final InboundWireDrawdownRequestCreateParams.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final InboundWireDrawdownRequestCreateParams.Builder originatorAddressLine1(String originatorAddressLine1)
Line 1 of the drawdown request's originator's address.
-
originatorAddressLine1
final InboundWireDrawdownRequestCreateParams.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final InboundWireDrawdownRequestCreateParams.Builder originatorAddressLine2(String originatorAddressLine2)
Line 2 of the drawdown request's originator's address.
-
originatorAddressLine2
final InboundWireDrawdownRequestCreateParams.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final InboundWireDrawdownRequestCreateParams.Builder originatorAddressLine3(String originatorAddressLine3)
Line 3 of the drawdown request's originator's address.
-
originatorAddressLine3
final InboundWireDrawdownRequestCreateParams.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final InboundWireDrawdownRequestCreateParams.Builder originatorName(String originatorName)
The drawdown request's originator's name.
-
originatorName
final InboundWireDrawdownRequestCreateParams.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
Line 1 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine1
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
Line 2 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine2
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
Line 3 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine3
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
Line 4 of the information conveyed from the originator of the message to the beneficiary.
-
originatorToBeneficiaryInformationLine4
final InboundWireDrawdownRequestCreateParams.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalBodyProperties
final InboundWireDrawdownRequestCreateParams.Builder additionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
putAdditionalBodyProperty
final InboundWireDrawdownRequestCreateParams.Builder putAdditionalBodyProperty(String key, JsonValue value)
-
putAllAdditionalBodyProperties
final InboundWireDrawdownRequestCreateParams.Builder putAllAdditionalBodyProperties(Map<String, JsonValue> additionalBodyProperties)
-
removeAdditionalBodyProperty
final InboundWireDrawdownRequestCreateParams.Builder removeAdditionalBodyProperty(String key)
-
removeAllAdditionalBodyProperties
final InboundWireDrawdownRequestCreateParams.Builder removeAllAdditionalBodyProperties(Set<String> keys)
-
additionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder additionalHeaders(Headers additionalHeaders)
-
additionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder additionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
putAdditionalHeader
final InboundWireDrawdownRequestCreateParams.Builder putAdditionalHeader(String name, String value)
-
putAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder putAdditionalHeaders(String name, Iterable<String> values)
-
putAllAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder putAllAdditionalHeaders(Headers additionalHeaders)
-
putAllAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder putAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
replaceAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder replaceAdditionalHeaders(String name, String value)
-
replaceAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder replaceAdditionalHeaders(String name, Iterable<String> values)
-
replaceAllAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder replaceAllAdditionalHeaders(Headers additionalHeaders)
-
replaceAllAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder replaceAllAdditionalHeaders(Map<String, Iterable<String>> additionalHeaders)
-
removeAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder removeAdditionalHeaders(String name)
-
removeAllAdditionalHeaders
final InboundWireDrawdownRequestCreateParams.Builder removeAllAdditionalHeaders(Set<String> names)
-
additionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder additionalQueryParams(QueryParams additionalQueryParams)
-
additionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder additionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
putAdditionalQueryParam
final InboundWireDrawdownRequestCreateParams.Builder putAdditionalQueryParam(String key, String value)
-
putAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder putAdditionalQueryParams(String key, Iterable<String> values)
-
putAllAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder putAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
putAllAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder putAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
replaceAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder replaceAdditionalQueryParams(String key, String value)
-
replaceAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder replaceAdditionalQueryParams(String key, Iterable<String> values)
-
replaceAllAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder replaceAllAdditionalQueryParams(QueryParams additionalQueryParams)
-
replaceAllAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder replaceAllAdditionalQueryParams(Map<String, Iterable<String>> additionalQueryParams)
-
removeAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder removeAdditionalQueryParams(String key)
-
removeAllAdditionalQueryParams
final InboundWireDrawdownRequestCreateParams.Builder removeAllAdditionalQueryParams(Set<String> keys)
-
build
final InboundWireDrawdownRequestCreateParams build()
Returns an immutable instance of InboundWireDrawdownRequestCreateParams.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .beneficiaryAccountNumber() .beneficiaryRoutingNumber() .currency() .messageToRecipient() .originatorAccountNumber() .originatorRoutingNumber() .recipientAccountNumberId()
-
-
-
-