Class InboundWireTransferCreateParams
-
- All Implemented Interfaces:
-
com.increase.api.core.Params
public final class InboundWireTransferCreateParams implements Params
Simulates an #inbound-wire-transfers to your account.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferCreateParams.BuilderA builder for InboundWireTransferCreateParams.
public final classInboundWireTransferCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The identifier of the Account Number the inbound Wire Transfer is for. final Longamount()The transfer amount in cents. final Optional<String>beneficiaryAddressLine1()The sending bank will set beneficiary_address_line1 in production. final Optional<String>beneficiaryAddressLine2()The sending bank will set beneficiary_address_line2 in production. final Optional<String>beneficiaryAddressLine3()The sending bank will set beneficiary_address_line3 in production. final Optional<String>beneficiaryName()The sending bank will set beneficiary_name in production. final Optional<String>beneficiaryReference()The sending bank will set beneficiary_reference in production. final Optional<String>originatorAddressLine1()The sending bank will set originator_address_line1 in production. final Optional<String>originatorAddressLine2()The sending bank will set originator_address_line2 in production. final Optional<String>originatorAddressLine3()The sending bank will set originator_address_line3 in production. final Optional<String>originatorName()The sending bank will set originator_name in production. final Optional<String>originatorRoutingNumber()The sending bank will set originator_routing_number in production. final Optional<String>originatorToBeneficiaryInformationLine1()The sending bank will set originator_to_beneficiary_information_line1 in production. final Optional<String>originatorToBeneficiaryInformationLine2()The sending bank will set originator_to_beneficiary_information_line2 in production. final Optional<String>originatorToBeneficiaryInformationLine3()The sending bank will set originator_to_beneficiary_information_line3 in production. final Optional<String>originatorToBeneficiaryInformationLine4()The sending bank will set originator_to_beneficiary_information_line4 in production. final Optional<String>senderReference()The sending bank will set sender_reference in production. final Optional<String>wireDrawdownRequestId()The identifier of a Wire Drawdown Request the inbound Wire Transfer is fulfilling. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<String>_beneficiaryReference()Returns the raw JSON value of beneficiaryReference. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_originatorToBeneficiaryInformationLine1()Returns the raw JSON value of originatorToBeneficiaryInformationLine1. final JsonField<String>_originatorToBeneficiaryInformationLine2()Returns the raw JSON value of originatorToBeneficiaryInformationLine2. final JsonField<String>_originatorToBeneficiaryInformationLine3()Returns the raw JSON value of originatorToBeneficiaryInformationLine3. final JsonField<String>_originatorToBeneficiaryInformationLine4()Returns the raw JSON value of originatorToBeneficiaryInformationLine4. final JsonField<String>_senderReference()Returns the raw JSON value of senderReference. final JsonField<String>_wireDrawdownRequestId()Returns the raw JSON value of wireDrawdownRequestId. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InboundWireTransferCreateParams.BuildertoBuilder()final InboundWireTransferCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InboundWireTransferCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransferCreateParams. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The identifier of the Account Number the inbound Wire Transfer is for.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
The sending bank will set beneficiary_address_line1 in production. You can simulate any value here.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
The sending bank will set beneficiary_address_line2 in production. You can simulate any value here.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
The sending bank will set beneficiary_address_line3 in production. You can simulate any value here.
-
beneficiaryName
final Optional<String> beneficiaryName()
The sending bank will set beneficiary_name in production. You can simulate any value here.
-
beneficiaryReference
final Optional<String> beneficiaryReference()
The sending bank will set beneficiary_reference in production. You can simulate any value here.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The sending bank will set originator_address_line1 in production. You can simulate any value here.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The sending bank will set originator_address_line2 in production. You can simulate any value here.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The sending bank will set originator_address_line3 in production. You can simulate any value here.
-
originatorName
final Optional<String> originatorName()
The sending bank will set originator_name in production. You can simulate any value here.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The sending bank will set originator_routing_number in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
The sending bank will set originator_to_beneficiary_information_line1 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
The sending bank will set originator_to_beneficiary_information_line2 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
The sending bank will set originator_to_beneficiary_information_line3 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
The sending bank will set originator_to_beneficiary_information_line4 in production. You can simulate any value here.
-
senderReference
final Optional<String> senderReference()
The sending bank will set sender_reference in production. You can simulate any value here.
-
wireDrawdownRequestId
final Optional<String> wireDrawdownRequestId()
The identifier of a Wire Drawdown Request the inbound Wire Transfer is fulfilling.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryReference
final JsonField<String> _beneficiaryReference()
Returns the raw JSON value of beneficiaryReference.
Unlike beneficiaryReference, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
Returns the raw JSON value of originatorToBeneficiaryInformationLine1.
Unlike originatorToBeneficiaryInformationLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
Returns the raw JSON value of originatorToBeneficiaryInformationLine2.
Unlike originatorToBeneficiaryInformationLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
Returns the raw JSON value of originatorToBeneficiaryInformationLine3.
Unlike originatorToBeneficiaryInformationLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
Returns the raw JSON value of originatorToBeneficiaryInformationLine4.
Unlike originatorToBeneficiaryInformationLine4, this method doesn't throw if the JSON field has an unexpected type.
-
_senderReference
final JsonField<String> _senderReference()
Returns the raw JSON value of senderReference.
Unlike senderReference, this method doesn't throw if the JSON field has an unexpected type.
-
_wireDrawdownRequestId
final JsonField<String> _wireDrawdownRequestId()
Returns the raw JSON value of wireDrawdownRequestId.
Unlike wireDrawdownRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InboundWireTransferCreateParams.Builder toBuilder()
-
_body
final InboundWireTransferCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InboundWireTransferCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransferCreateParams.
The following fields are required:
.accountNumberId() .amount()
-
-
-
-