Class InboundWireTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class InboundWireTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final InboundWireTransferCreateParams.Body.Builder accountNumberId(String accountNumberId)
The identifier of the Account Number the inbound Wire Transfer is for.
-
accountNumberId
final InboundWireTransferCreateParams.Body.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final InboundWireTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in cents. Must be positive.
-
amount
final InboundWireTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final InboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
The sending bank will set beneficiary_address_line1 in production. You can simulate any value here.
-
beneficiaryAddressLine1
final InboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final InboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
The sending bank will set beneficiary_address_line2 in production. You can simulate any value here.
-
beneficiaryAddressLine2
final InboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final InboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
The sending bank will set beneficiary_address_line3 in production. You can simulate any value here.
-
beneficiaryAddressLine3
final InboundWireTransferCreateParams.Body.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final InboundWireTransferCreateParams.Body.Builder beneficiaryName(String beneficiaryName)
The sending bank will set beneficiary_name in production. You can simulate any value here.
-
beneficiaryName
final InboundWireTransferCreateParams.Body.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryReference
final InboundWireTransferCreateParams.Body.Builder beneficiaryReference(String beneficiaryReference)
The sending bank will set beneficiary_reference in production. You can simulate any value here.
-
beneficiaryReference
final InboundWireTransferCreateParams.Body.Builder beneficiaryReference(JsonField<String> beneficiaryReference)
Sets Builder.beneficiaryReference to an arbitrary JSON value.
You should usually call Builder.beneficiaryReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final InboundWireTransferCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
The sending bank will set originator_address_line1 in production. You can simulate any value here.
-
originatorAddressLine1
final InboundWireTransferCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final InboundWireTransferCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
The sending bank will set originator_address_line2 in production. You can simulate any value here.
-
originatorAddressLine2
final InboundWireTransferCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final InboundWireTransferCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
The sending bank will set originator_address_line3 in production. You can simulate any value here.
-
originatorAddressLine3
final InboundWireTransferCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final InboundWireTransferCreateParams.Body.Builder originatorName(String originatorName)
The sending bank will set originator_name in production. You can simulate any value here.
-
originatorName
final InboundWireTransferCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final InboundWireTransferCreateParams.Body.Builder originatorRoutingNumber(String originatorRoutingNumber)
The sending bank will set originator_routing_number in production. You can simulate any value here.
-
originatorRoutingNumber
final InboundWireTransferCreateParams.Body.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
The sending bank will set originator_to_beneficiary_information_line1 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine1
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
The sending bank will set originator_to_beneficiary_information_line2 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine2
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
The sending bank will set originator_to_beneficiary_information_line3 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine3
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
The sending bank will set originator_to_beneficiary_information_line4 in production. You can simulate any value here.
-
originatorToBeneficiaryInformationLine4
final InboundWireTransferCreateParams.Body.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderReference
final InboundWireTransferCreateParams.Body.Builder senderReference(String senderReference)
The sending bank will set sender_reference in production. You can simulate any value here.
-
senderReference
final InboundWireTransferCreateParams.Body.Builder senderReference(JsonField<String> senderReference)
Sets Builder.senderReference to an arbitrary JSON value.
You should usually call Builder.senderReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final InboundWireTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final InboundWireTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final InboundWireTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final InboundWireTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final InboundWireTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final InboundWireTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .amount()
-
-
-
-