Class PhysicalCardCreateParams.Body
-
- All Implemented Interfaces:
public final class PhysicalCardCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final PhysicalCardCreateParams.Categorycategory()The type of tracking event. final Optional<OffsetDateTime>carrierEstimatedDeliveryAt()The ISO 8601 date and time when the carrier expects the card to be delivered. final Optional<String>city()The city where the event took place. final Optional<String>postalCode()The postal code where the event took place. final Optional<String>state()The state where the event took place. final JsonField<PhysicalCardCreateParams.Category>_category()Returns the raw JSON value of category. final JsonField<OffsetDateTime>_carrierEstimatedDeliveryAt()Returns the raw JSON value of carrierEstimatedDeliveryAt. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final PhysicalCardCreateParams.Body.BuildertoBuilder()final PhysicalCardCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PhysicalCardCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
category
final PhysicalCardCreateParams.Category category()
The type of tracking event.
-
carrierEstimatedDeliveryAt
final Optional<OffsetDateTime> carrierEstimatedDeliveryAt()
The ISO 8601 date and time when the carrier expects the card to be delivered.
-
postalCode
final Optional<String> postalCode()
The postal code where the event took place.
-
_category
final JsonField<PhysicalCardCreateParams.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_carrierEstimatedDeliveryAt
final JsonField<OffsetDateTime> _carrierEstimatedDeliveryAt()
Returns the raw JSON value of carrierEstimatedDeliveryAt.
Unlike carrierEstimatedDeliveryAt, this method doesn't throw if the JSON field has an unexpected type.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PhysicalCardCreateParams.Body.Builder toBuilder()
-
validate
final PhysicalCardCreateParams.Body validate()
-
builder
final static PhysicalCardCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.category()
-
-
-
-