Class SupplementalDocumentCreateParams.Body
-
- All Implemented Interfaces:
public final class SupplementalDocumentCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringentityId()The identifier of the Entity to associate with the supplemental document. final StringfileId()The identifier of the File containing the document. final JsonField<String>_entityId()Returns the raw JSON value of entityId. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final SupplementalDocumentCreateParams.Body.BuildertoBuilder()final SupplementalDocumentCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
entityId
final String entityId()
The identifier of the Entity to associate with the supplemental document.
-
_entityId
final JsonField<String> _entityId()
Returns the raw JSON value of entityId.
Unlike entityId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SupplementalDocumentCreateParams.Body.Builder toBuilder()
-
validate
final SupplementalDocumentCreateParams.Body validate()
-
builder
final static SupplementalDocumentCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.entityId() .fileId()
-
-
-
-