Class SupplementalDocumentListPage
-
- All Implemented Interfaces:
public final class SupplementalDocumentListPage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentListPage.BuilderA builder for SupplementalDocumentListPage.
public final classSupplementalDocumentListPage.AutoPager
-
Method Summary
Modifier and Type Method Description final List<EntitySupplementalDocument>data()Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<SupplementalDocumentListParams>getNextPageParams()final Optional<SupplementalDocumentListPage>getNextPage()final SupplementalDocumentListPage.AutoPagerautoPager()final SupplementalDocumentListParamsparams()The parameters that were used to request this page. final SupplementalDocumentListPageResponseresponse()The response that this page was parsed from. final SupplementalDocumentListPage.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupplementalDocumentListPage.Builderbuilder()Returns a mutable builder for constructing an instance of SupplementalDocumentListPage. -
-
Method Detail
-
data
final List<EntitySupplementalDocument> data()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<SupplementalDocumentListParams> getNextPageParams()
-
getNextPage
final Optional<SupplementalDocumentListPage> getNextPage()
-
autoPager
final SupplementalDocumentListPage.AutoPager autoPager()
-
params
final SupplementalDocumentListParams params()
The parameters that were used to request this page.
-
response
final SupplementalDocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final SupplementalDocumentListPage.Builder toBuilder()
-
builder
final static SupplementalDocumentListPage.Builder builder()
Returns a mutable builder for constructing an instance of SupplementalDocumentListPage.
The following fields are required:
.service() .params() .response()
-
-
-
-