Class SupplementalDocumentListPageAsync
-
- All Implemented Interfaces:
public final class SupplementalDocumentListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentListPageAsync.BuilderA builder for SupplementalDocumentListPageAsync.
public final classSupplementalDocumentListPageAsync.AutoPager
-
Method Summary
-
-
Method Detail
-
data
final List<EntitySupplementalDocument> data()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to SupplementalDocumentListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<SupplementalDocumentListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<SupplementalDocumentListPageAsync>> getNextPage()
-
autoPager
final SupplementalDocumentListPageAsync.AutoPager autoPager()
-
params
final SupplementalDocumentListParams params()
The parameters that were used to request this page.
-
response
final SupplementalDocumentListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final SupplementalDocumentListPageAsync.Builder toBuilder()
-
builder
final static SupplementalDocumentListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of SupplementalDocumentListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-