Class Transaction.Source
-
- All Implemented Interfaces:
public final class Transaction.SourceThis is an object giving more details on the network-level event that caused the Transaction. Note that for backwards compatibility reasons, additional undocumented keys may appear in this object. These should be treated as deprecated and will be removed in the future.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.BuilderA builder for Source.
public final classTransaction.Source.CategoryThe type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
public final classTransaction.Source.AccountRevenuePaymentAn Account Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal toaccount_revenue_payment. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.public final classTransaction.Source.AccountTransferIntentionAn Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.public final classTransaction.Source.AchTransferIntentionAn ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.public final classTransaction.Source.AchTransferRejectionAn ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.public final classTransaction.Source.AchTransferReturnAn ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.public final classTransaction.Source.BlockchainOfframpTransferSettlementA Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_settlement.public final classTransaction.Source.BlockchainOnrampTransferIntentionA Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_intention.public final classTransaction.Source.CardDisputeAcceptanceA Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.public final classTransaction.Source.CardDisputeFinancialA Card Dispute Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_financial. Financial event related to a Card Dispute.public final classTransaction.Source.CardDisputeLossA Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.public final classTransaction.Source.CardFinancialA Card Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_financial. Card Financials are card transactions that have cleared and settled. Unlike a Card Settlement, which clears a previous authorization, a Card Financial is authorized and cleared in a single message.public final classTransaction.Source.CardPushTransferAcceptanceA Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_acceptance. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.public final classTransaction.Source.CardRefundA Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.public final classTransaction.Source.CardRevenuePaymentA Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.public final classTransaction.Source.CardSettlementA Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.public final classTransaction.Source.CashbackPaymentA Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.public final classTransaction.Source.CheckDepositAcceptanceA Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.public final classTransaction.Source.CheckDepositReturnA Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.public final classTransaction.Source.CheckTransferDepositA Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.public final classTransaction.Source.FednowTransferAcknowledgementA FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_acknowledgement. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.public final classTransaction.Source.FeePaymentA Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.public final classTransaction.Source.InboundAchTransferAn Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundAchTransferReturnIntentionAn Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.public final classTransaction.Source.InboundCheckAdjustmentAn Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.public final classTransaction.Source.InboundCheckDepositReturnIntentionAn Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.public final classTransaction.Source.InboundFednowTransferConfirmationAn Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_confirmation. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundRealTimePaymentsTransferConfirmationAn Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundWireReversalAn Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.public final classTransaction.Source.InboundWireTransferAn Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.public final classTransaction.Source.InboundWireTransferReversalAn Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.public final classTransaction.Source.InterestPaymentAn Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.public final classTransaction.Source.InternalSourceAn Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.public final classTransaction.Source.OtherIf the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.public final classTransaction.Source.RealTimePaymentsTransferAcknowledgementA Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.public final classTransaction.Source.SampleFundsA Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.public final classTransaction.Source.SwiftTransferIntentionA Swift Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_intention. A Swift Transfer initiated via Increase.public final classTransaction.Source.SwiftTransferReturnA Swift Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_return. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.public final classTransaction.Source.WireTransferIntentionA Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
Method Summary
-
-
Method Detail
-
category
final Transaction.Source.Category category()
The type of the resource. We may add additional possible values for this enum over time; your application should be able to handle such additions gracefully.
-
accountRevenuePayment
final Optional<Transaction.Source.AccountRevenuePayment> accountRevenuePayment()
An Account Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal toaccount_revenue_payment. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.
-
accountTransferIntention
final Optional<Transaction.Source.AccountTransferIntention> accountTransferIntention()
An Account Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toaccount_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.
-
achTransferIntention
final Optional<Transaction.Source.AchTransferIntention> achTransferIntention()
An ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_intention. An ACH Transfer Intention is created from an ACH Transfer. It reflects the intention to move money into or out of an Increase account via the ACH network.
-
achTransferRejection
final Optional<Transaction.Source.AchTransferRejection> achTransferRejection()
An ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
achTransferReturn
final Optional<Transaction.Source.AchTransferReturn> achTransferReturn()
An ACH Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_return. An ACH Transfer Return is created when an ACH Transfer is returned by the receiving bank. It offsets the ACH Transfer Intention. ACH Transfer Returns usually occur within the first two business days after the transfer is initiated, but can occur much later.
-
blockchainOfframpTransferSettlement
final Optional<Transaction.Source.BlockchainOfframpTransferSettlement> blockchainOfframpTransferSettlement()
A Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_settlement.
-
blockchainOnrampTransferIntention
final Optional<Transaction.Source.BlockchainOnrampTransferIntention> blockchainOnrampTransferIntention()
A Blockchain On-Ramp Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_onramp_transfer_intention.
-
cardDisputeAcceptance
final Optional<Transaction.Source.CardDisputeAcceptance> cardDisputeAcceptance()
A Legacy Card Dispute Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_acceptance. Contains the details of a successful Card Dispute.
-
cardDisputeFinancial
final Optional<Transaction.Source.CardDisputeFinancial> cardDisputeFinancial()
A Card Dispute Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_financial. Financial event related to a Card Dispute.
-
cardDisputeLoss
final Optional<Transaction.Source.CardDisputeLoss> cardDisputeLoss()
A Legacy Card Dispute Loss object. This field will be present in the JSON response if and only if
categoryis equal tocard_dispute_loss. Contains the details of a lost Card Dispute.
-
cardFinancial
final Optional<Transaction.Source.CardFinancial> cardFinancial()
A Card Financial object. This field will be present in the JSON response if and only if
categoryis equal tocard_financial. Card Financials are card transactions that have cleared and settled. Unlike a Card Settlement, which clears a previous authorization, a Card Financial is authorized and cleared in a single message.
-
cardPushTransferAcceptance
final Optional<Transaction.Source.CardPushTransferAcceptance> cardPushTransferAcceptance()
A Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_acceptance. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.
-
cardRefund
final Optional<Transaction.Source.CardRefund> cardRefund()
A Card Refund object. This field will be present in the JSON response if and only if
categoryis equal tocard_refund. Card Refunds move money back to the cardholder. While they are usually connected to a Card Settlement, an acquirer can also refund money directly to a card without relation to a transaction.
-
cardRevenuePayment
final Optional<Transaction.Source.CardRevenuePayment> cardRevenuePayment()
A Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
cardSettlement
final Optional<Transaction.Source.CardSettlement> cardSettlement()
A Card Settlement object. This field will be present in the JSON response if and only if
categoryis equal tocard_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.
-
cashbackPayment
final Optional<Transaction.Source.CashbackPayment> cashbackPayment()
A Cashback Payment object. This field will be present in the JSON response if and only if
categoryis equal tocashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.
-
checkDepositAcceptance
final Optional<Transaction.Source.CheckDepositAcceptance> checkDepositAcceptance()
A Check Deposit Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_acceptance. A Check Deposit Acceptance is created when a Check Deposit is processed and its details confirmed. Check Deposits may be returned by the receiving bank, which will appear as a Check Deposit Return.
-
checkDepositReturn
final Optional<Transaction.Source.CheckDepositReturn> checkDepositReturn()
A Check Deposit Return object. This field will be present in the JSON response if and only if
categoryis equal tocheck_deposit_return. A Check Deposit Return is created when a Check Deposit is returned by the bank holding the account it was drawn against. Check Deposits may be returned for a variety of reasons, including insufficient funds or a mismatched account number. Usually, checks are returned within the first 7 days after the deposit is made.
-
checkTransferDeposit
final Optional<Transaction.Source.CheckTransferDeposit> checkTransferDeposit()
A Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
fednowTransferAcknowledgement
final Optional<Transaction.Source.FednowTransferAcknowledgement> fednowTransferAcknowledgement()
A FedNow Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal tofednow_transfer_acknowledgement. A FedNow Transfer Acknowledgement is created when a FedNow Transfer sent from Increase is acknowledged by the receiving bank.
-
feePayment
final Optional<Transaction.Source.FeePayment> feePayment()
A Fee Payment object. This field will be present in the JSON response if and only if
categoryis equal tofee_payment. A Fee Payment represents a payment made to Increase.
-
inboundAchTransfer
final Optional<Transaction.Source.InboundAchTransfer> inboundAchTransfer()
An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.
-
inboundAchTransferReturnIntention
final Optional<Transaction.Source.InboundAchTransferReturnIntention> inboundAchTransferReturnIntention()
An Inbound ACH Transfer Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_ach_transfer_return_intention. An Inbound ACH Transfer Return Intention is created when an ACH transfer is initiated at another bank and returned by Increase.
-
inboundCheckAdjustment
final Optional<Transaction.Source.InboundCheckAdjustment> inboundCheckAdjustment()
An Inbound Check Adjustment object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.
-
inboundCheckDepositReturnIntention
final Optional<Transaction.Source.InboundCheckDepositReturnIntention> inboundCheckDepositReturnIntention()
An Inbound Check Deposit Return Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_check_deposit_return_intention. An Inbound Check Deposit Return Intention is created when Increase receives an Inbound Check and the User requests that it be returned.
-
inboundFednowTransferConfirmation
final Optional<Transaction.Source.InboundFednowTransferConfirmation> inboundFednowTransferConfirmation()
An Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_confirmation. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.
-
inboundRealTimePaymentsTransferConfirmation
final Optional<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> inboundRealTimePaymentsTransferConfirmation()
An Inbound Real-Time Payments Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_real_time_payments_transfer_confirmation. An Inbound Real-Time Payments Transfer Confirmation is created when a Real-Time Payments transfer is initiated at another bank and received by Increase.
-
inboundWireReversal
final Optional<Transaction.Source.InboundWireReversal> inboundWireReversal()
An Inbound Wire Reversal object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_reversal. An Inbound Wire Reversal represents a reversal of a wire transfer that was initiated via Increase. The other bank is sending the money back. This most often happens when the original destination account details were incorrect.
-
inboundWireTransfer
final Optional<Transaction.Source.InboundWireTransfer> inboundWireTransfer()
An Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
inboundWireTransferReversal
final Optional<Transaction.Source.InboundWireTransferReversal> inboundWireTransferReversal()
An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.
-
interestPayment
final Optional<Transaction.Source.InterestPayment> interestPayment()
An Interest Payment object. This field will be present in the JSON response if and only if
categoryis equal tointerest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.
-
internalSource
final Optional<Transaction.Source.InternalSource> internalSource()
An Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
other
final Optional<Transaction.Source.Other> other()
If the category of this Transaction source is equal to
other, this field will contain an empty object, otherwise it will contain null.
-
realTimePaymentsTransferAcknowledgement
final Optional<Transaction.Source.RealTimePaymentsTransferAcknowledgement> realTimePaymentsTransferAcknowledgement()
A Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
sampleFunds
final Optional<Transaction.Source.SampleFunds> sampleFunds()
A Sample Funds object. This field will be present in the JSON response if and only if
categoryis equal tosample_funds. Sample funds for testing purposes.
-
swiftTransferIntention
final Optional<Transaction.Source.SwiftTransferIntention> swiftTransferIntention()
A Swift Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_intention. A Swift Transfer initiated via Increase.
-
swiftTransferReturn
final Optional<Transaction.Source.SwiftTransferReturn> swiftTransferReturn()
A Swift Transfer Return object. This field will be present in the JSON response if and only if
categoryis equal toswift_transfer_return. A Swift Transfer Return is created when a Swift Transfer is returned by the receiving bank.
-
wireTransferIntention
final Optional<Transaction.Source.WireTransferIntention> wireTransferIntention()
A Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
_category
final JsonField<Transaction.Source.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_accountRevenuePayment
final JsonField<Transaction.Source.AccountRevenuePayment> _accountRevenuePayment()
Returns the raw JSON value of accountRevenuePayment.
Unlike accountRevenuePayment, this method doesn't throw if the JSON field has an unexpected type.
-
_accountTransferIntention
final JsonField<Transaction.Source.AccountTransferIntention> _accountTransferIntention()
Returns the raw JSON value of accountTransferIntention.
Unlike accountTransferIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_achTransferIntention
final JsonField<Transaction.Source.AchTransferIntention> _achTransferIntention()
Returns the raw JSON value of achTransferIntention.
Unlike achTransferIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_achTransferRejection
final JsonField<Transaction.Source.AchTransferRejection> _achTransferRejection()
Returns the raw JSON value of achTransferRejection.
Unlike achTransferRejection, this method doesn't throw if the JSON field has an unexpected type.
-
_achTransferReturn
final JsonField<Transaction.Source.AchTransferReturn> _achTransferReturn()
Returns the raw JSON value of achTransferReturn.
Unlike achTransferReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_blockchainOfframpTransferSettlement
final JsonField<Transaction.Source.BlockchainOfframpTransferSettlement> _blockchainOfframpTransferSettlement()
Returns the raw JSON value of blockchainOfframpTransferSettlement.
Unlike blockchainOfframpTransferSettlement, this method doesn't throw if the JSON field has an unexpected type.
-
_blockchainOnrampTransferIntention
final JsonField<Transaction.Source.BlockchainOnrampTransferIntention> _blockchainOnrampTransferIntention()
Returns the raw JSON value of blockchainOnrampTransferIntention.
Unlike blockchainOnrampTransferIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDisputeAcceptance
final JsonField<Transaction.Source.CardDisputeAcceptance> _cardDisputeAcceptance()
Returns the raw JSON value of cardDisputeAcceptance.
Unlike cardDisputeAcceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDisputeFinancial
final JsonField<Transaction.Source.CardDisputeFinancial> _cardDisputeFinancial()
Returns the raw JSON value of cardDisputeFinancial.
Unlike cardDisputeFinancial, this method doesn't throw if the JSON field has an unexpected type.
-
_cardDisputeLoss
final JsonField<Transaction.Source.CardDisputeLoss> _cardDisputeLoss()
Returns the raw JSON value of cardDisputeLoss.
Unlike cardDisputeLoss, this method doesn't throw if the JSON field has an unexpected type.
-
_cardFinancial
final JsonField<Transaction.Source.CardFinancial> _cardFinancial()
Returns the raw JSON value of cardFinancial.
Unlike cardFinancial, this method doesn't throw if the JSON field has an unexpected type.
-
_cardPushTransferAcceptance
final JsonField<Transaction.Source.CardPushTransferAcceptance> _cardPushTransferAcceptance()
Returns the raw JSON value of cardPushTransferAcceptance.
Unlike cardPushTransferAcceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_cardRefund
final JsonField<Transaction.Source.CardRefund> _cardRefund()
Returns the raw JSON value of cardRefund.
Unlike cardRefund, this method doesn't throw if the JSON field has an unexpected type.
-
_cardRevenuePayment
final JsonField<Transaction.Source.CardRevenuePayment> _cardRevenuePayment()
Returns the raw JSON value of cardRevenuePayment.
Unlike cardRevenuePayment, this method doesn't throw if the JSON field has an unexpected type.
-
_cardSettlement
final JsonField<Transaction.Source.CardSettlement> _cardSettlement()
Returns the raw JSON value of cardSettlement.
Unlike cardSettlement, this method doesn't throw if the JSON field has an unexpected type.
-
_cashbackPayment
final JsonField<Transaction.Source.CashbackPayment> _cashbackPayment()
Returns the raw JSON value of cashbackPayment.
Unlike cashbackPayment, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositAcceptance
final JsonField<Transaction.Source.CheckDepositAcceptance> _checkDepositAcceptance()
Returns the raw JSON value of checkDepositAcceptance.
Unlike checkDepositAcceptance, this method doesn't throw if the JSON field has an unexpected type.
-
_checkDepositReturn
final JsonField<Transaction.Source.CheckDepositReturn> _checkDepositReturn()
Returns the raw JSON value of checkDepositReturn.
Unlike checkDepositReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_checkTransferDeposit
final JsonField<Transaction.Source.CheckTransferDeposit> _checkTransferDeposit()
Returns the raw JSON value of checkTransferDeposit.
Unlike checkTransferDeposit, this method doesn't throw if the JSON field has an unexpected type.
-
_fednowTransferAcknowledgement
final JsonField<Transaction.Source.FednowTransferAcknowledgement> _fednowTransferAcknowledgement()
Returns the raw JSON value of fednowTransferAcknowledgement.
Unlike fednowTransferAcknowledgement, this method doesn't throw if the JSON field has an unexpected type.
-
_feePayment
final JsonField<Transaction.Source.FeePayment> _feePayment()
Returns the raw JSON value of feePayment.
Unlike feePayment, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundAchTransfer
final JsonField<Transaction.Source.InboundAchTransfer> _inboundAchTransfer()
Returns the raw JSON value of inboundAchTransfer.
Unlike inboundAchTransfer, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundAchTransferReturnIntention
final JsonField<Transaction.Source.InboundAchTransferReturnIntention> _inboundAchTransferReturnIntention()
Returns the raw JSON value of inboundAchTransferReturnIntention.
Unlike inboundAchTransferReturnIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundCheckAdjustment
final JsonField<Transaction.Source.InboundCheckAdjustment> _inboundCheckAdjustment()
Returns the raw JSON value of inboundCheckAdjustment.
Unlike inboundCheckAdjustment, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundCheckDepositReturnIntention
final JsonField<Transaction.Source.InboundCheckDepositReturnIntention> _inboundCheckDepositReturnIntention()
Returns the raw JSON value of inboundCheckDepositReturnIntention.
Unlike inboundCheckDepositReturnIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundFednowTransferConfirmation
final JsonField<Transaction.Source.InboundFednowTransferConfirmation> _inboundFednowTransferConfirmation()
Returns the raw JSON value of inboundFednowTransferConfirmation.
Unlike inboundFednowTransferConfirmation, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundRealTimePaymentsTransferConfirmation
final JsonField<Transaction.Source.InboundRealTimePaymentsTransferConfirmation> _inboundRealTimePaymentsTransferConfirmation()
Returns the raw JSON value of inboundRealTimePaymentsTransferConfirmation.
Unlike inboundRealTimePaymentsTransferConfirmation, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireReversal
final JsonField<Transaction.Source.InboundWireReversal> _inboundWireReversal()
Returns the raw JSON value of inboundWireReversal.
Unlike inboundWireReversal, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireTransfer
final JsonField<Transaction.Source.InboundWireTransfer> _inboundWireTransfer()
Returns the raw JSON value of inboundWireTransfer.
Unlike inboundWireTransfer, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireTransferReversal
final JsonField<Transaction.Source.InboundWireTransferReversal> _inboundWireTransferReversal()
Returns the raw JSON value of inboundWireTransferReversal.
Unlike inboundWireTransferReversal, this method doesn't throw if the JSON field has an unexpected type.
-
_interestPayment
final JsonField<Transaction.Source.InterestPayment> _interestPayment()
Returns the raw JSON value of interestPayment.
Unlike interestPayment, this method doesn't throw if the JSON field has an unexpected type.
-
_internalSource
final JsonField<Transaction.Source.InternalSource> _internalSource()
Returns the raw JSON value of internalSource.
Unlike internalSource, this method doesn't throw if the JSON field has an unexpected type.
-
_other
final JsonField<Transaction.Source.Other> _other()
Returns the raw JSON value of other.
Unlike other, this method doesn't throw if the JSON field has an unexpected type.
-
_realTimePaymentsTransferAcknowledgement
final JsonField<Transaction.Source.RealTimePaymentsTransferAcknowledgement> _realTimePaymentsTransferAcknowledgement()
Returns the raw JSON value of realTimePaymentsTransferAcknowledgement.
Unlike realTimePaymentsTransferAcknowledgement, this method doesn't throw if the JSON field has an unexpected type.
-
_sampleFunds
final JsonField<Transaction.Source.SampleFunds> _sampleFunds()
Returns the raw JSON value of sampleFunds.
Unlike sampleFunds, this method doesn't throw if the JSON field has an unexpected type.
-
_swiftTransferIntention
final JsonField<Transaction.Source.SwiftTransferIntention> _swiftTransferIntention()
Returns the raw JSON value of swiftTransferIntention.
Unlike swiftTransferIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_swiftTransferReturn
final JsonField<Transaction.Source.SwiftTransferReturn> _swiftTransferReturn()
Returns the raw JSON value of swiftTransferReturn.
Unlike swiftTransferReturn, this method doesn't throw if the JSON field has an unexpected type.
-
_wireTransferIntention
final JsonField<Transaction.Source.WireTransferIntention> _wireTransferIntention()
Returns the raw JSON value of wireTransferIntention.
Unlike wireTransferIntention, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.Builder toBuilder()
-
validate
final Transaction.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
The following fields are required:
.category()
-
-
-
-