Class Transaction.Source.AccountRevenuePayment
-
- All Implemented Interfaces:
public final class Transaction.Source.AccountRevenuePaymentAn Account Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal toaccount_revenue_payment. An Account Revenue Payment represents a payment made to an account from the bank. Account revenue is a type of non-interest income.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.AccountRevenuePayment.BuilderA builder for AccountRevenuePayment.
-
Method Summary
Modifier and Type Method Description final StringaccruedOnAccountId()The account on which the account revenue was accrued. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid account revenue. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid account revenue. final JsonField<String>_accruedOnAccountId()Returns the raw JSON value of accruedOnAccountId. final JsonField<OffsetDateTime>_periodEnd()Returns the raw JSON value of periodEnd. final JsonField<OffsetDateTime>_periodStart()Returns the raw JSON value of periodStart. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.AccountRevenuePayment.BuildertoBuilder()final Transaction.Source.AccountRevenuePaymentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.AccountRevenuePayment.Builderbuilder()Returns a mutable builder for constructing an instance of AccountRevenuePayment. -
-
Method Detail
-
accruedOnAccountId
final String accruedOnAccountId()
The account on which the account revenue was accrued.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid account revenue.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid account revenue.
-
_accruedOnAccountId
final JsonField<String> _accruedOnAccountId()
Returns the raw JSON value of accruedOnAccountId.
Unlike accruedOnAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
Returns the raw JSON value of periodEnd.
Unlike periodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
Returns the raw JSON value of periodStart.
Unlike periodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.AccountRevenuePayment.Builder toBuilder()
-
validate
final Transaction.Source.AccountRevenuePayment validate()
-
builder
final static Transaction.Source.AccountRevenuePayment.Builder builder()
Returns a mutable builder for constructing an instance of AccountRevenuePayment.
The following fields are required:
.accruedOnAccountId() .periodEnd() .periodStart()
-
-
-
-