Class Transaction.Source.AccountTransferIntention

  • All Implemented Interfaces:

    
    public final class Transaction.Source.AccountTransferIntention
    
                        

    An Account Transfer Intention object. This field will be present in the JSON response if and only if category is equal to account_transfer_intention. Two Account Transfer Intentions are created from each Account Transfer. One decrements the source account, and the other increments the destination account.