Class Transaction.Source.AchTransferRejection
-
- All Implemented Interfaces:
public final class Transaction.Source.AchTransferRejectionAn ACH Transfer Rejection object. This field will be present in the JSON response if and only if
categoryis equal toach_transfer_rejection. An ACH Transfer Rejection is created when an ACH Transfer is rejected by Increase. It offsets the ACH Transfer Intention. These rejections are rare.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.AchTransferRejection.BuilderA builder for AchTransferRejection.
-
Method Summary
Modifier and Type Method Description final StringtransferId()The identifier of the ACH Transfer that led to this Transaction. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.AchTransferRejection.BuildertoBuilder()final Transaction.Source.AchTransferRejectionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.AchTransferRejection.Builderbuilder()Returns a mutable builder for constructing an instance of AchTransferRejection. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the ACH Transfer that led to this Transaction.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.AchTransferRejection.Builder toBuilder()
-
validate
final Transaction.Source.AchTransferRejection validate()
-
builder
final static Transaction.Source.AchTransferRejection.Builder builder()
Returns a mutable builder for constructing an instance of AchTransferRejection.
The following fields are required:
.transferId()
-
-
-
-