Class Transaction.Source.BlockchainOfframpTransferSettlement
-
- All Implemented Interfaces:
public final class Transaction.Source.BlockchainOfframpTransferSettlementA Blockchain Off-Ramp Transfer Settlement object. This field will be present in the JSON response if and only if
categoryis equal toblockchain_offramp_transfer_settlement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.BlockchainOfframpTransferSettlement.BuilderA builder for BlockchainOfframpTransferSettlement.
-
Method Summary
Modifier and Type Method Description final StringsourceBlockchainAddressId()The identifier of the Blockchain Address the funds were received at. final StringtransferId()The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction. final JsonField<String>_sourceBlockchainAddressId()Returns the raw JSON value of sourceBlockchainAddressId. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.BlockchainOfframpTransferSettlement.BuildertoBuilder()final Transaction.Source.BlockchainOfframpTransferSettlementvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.BlockchainOfframpTransferSettlement.Builderbuilder()Returns a mutable builder for constructing an instance of BlockchainOfframpTransferSettlement. -
-
Method Detail
-
sourceBlockchainAddressId
final String sourceBlockchainAddressId()
The identifier of the Blockchain Address the funds were received at.
-
transferId
final String transferId()
The identifier of the Blockchain Off-Ramp Transfer that led to this Transaction.
-
_sourceBlockchainAddressId
final JsonField<String> _sourceBlockchainAddressId()
Returns the raw JSON value of sourceBlockchainAddressId.
Unlike sourceBlockchainAddressId, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.BlockchainOfframpTransferSettlement.Builder toBuilder()
-
validate
final Transaction.Source.BlockchainOfframpTransferSettlement validate()
-
builder
final static Transaction.Source.BlockchainOfframpTransferSettlement.Builder builder()
Returns a mutable builder for constructing an instance of BlockchainOfframpTransferSettlement.
The following fields are required:
.sourceBlockchainAddressId() .transferId()
-
-
-
-