Class Transaction.Source.CardDisputeFinancial.Visa

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardDisputeFinancial.Visa
    
                        

    Information for events related to card dispute for card payments processed over Visa's network. This field will be present in the JSON response if and only if network is equal to visa.