Class Transaction.Source.CardDisputeFinancial.Visa
-
- All Implemented Interfaces:
public final class Transaction.Source.CardDisputeFinancial.VisaInformation for events related to card dispute for card payments processed over Visa's network. This field will be present in the JSON response if and only if
networkis equal tovisa.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardDisputeFinancial.Visa.BuilderA builder for Visa.
public final classTransaction.Source.CardDisputeFinancial.Visa.EventTypeThe type of card dispute financial event.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.CardDisputeFinancial.Visa.EventTypeeventType()The type of card dispute financial event. final JsonField<Transaction.Source.CardDisputeFinancial.Visa.EventType>_eventType()Returns the raw JSON value of eventType. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardDisputeFinancial.Visa.BuildertoBuilder()final Transaction.Source.CardDisputeFinancial.Visavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardDisputeFinancial.Visa.Builderbuilder()Returns a mutable builder for constructing an instance of Visa. -
-
Method Detail
-
eventType
final Transaction.Source.CardDisputeFinancial.Visa.EventType eventType()
The type of card dispute financial event.
-
_eventType
final JsonField<Transaction.Source.CardDisputeFinancial.Visa.EventType> _eventType()
Returns the raw JSON value of eventType.
Unlike eventType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardDisputeFinancial.Visa.Builder toBuilder()
-
validate
final Transaction.Source.CardDisputeFinancial.Visa validate()
-
builder
final static Transaction.Source.CardDisputeFinancial.Visa.Builder builder()
Returns a mutable builder for constructing an instance of Visa.
The following fields are required:
.eventType()
-
-
-
-