Class Transaction.Source.CardFinancial

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardFinancial
    
                        

    A Card Financial object. This field will be present in the JSON response if and only if category is equal to card_financial. Card Financials are temporary holds placed on a customer's funds with the intent to later clear a transaction.