Class Transaction.Source.CardFinancial.AdditionalAmounts

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardFinancial.AdditionalAmounts
    
                        

    Additional amounts associated with the card authorization, such as ATM surcharges fees. These are usually a subset of the amount field and are used to provide more detailed information about the transaction.