Class Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability
-
- All Implemented Interfaces:
-
com.increase.api.core.Enum
public final class Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability implements EnumThe capability of the terminal being used to read the card. Shows whether a terminal can e.g., accept chip cards or if it only supports magnetic stripe reads. This reflects the highest capability of the terminal — for example, a terminal that supports both chip and magnetic stripe will be identified as chip-capable.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumTransaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.KnownAn enum containing TerminalEntryCapability's known values.
public enumTransaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.ValueAn enum containing TerminalEntryCapability's known values, as well as an _UNKNOWN member.
An instance of TerminalEntryCapability can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityUNKNOWNpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityTERMINAL_NOT_USEDpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityMAGNETIC_STRIPEpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityBARCODEpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityOPTICAL_CHARACTER_RECOGNITIONpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityCHIP_OR_CONTACTLESSpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityCONTACTLESS_ONLYpublic final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityNO_CAPABILITY
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapabilityof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability validate()
-
of
final static Transaction.Source.CardFinancial.NetworkDetails.Visa.TerminalEntryCapability of(String value)
-
-
-
-