Class Transaction.Source.CardFinancial.Verification.CardholderName
-
- All Implemented Interfaces:
public final class Transaction.Source.CardFinancial.Verification.CardholderNameCardholder name provided in the authorization request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardFinancial.Verification.CardholderName.BuilderA builder for CardholderName.
-
Method Summary
-
-
Method Detail
-
providedFirstName
final Optional<String> providedFirstName()
The first name provided for verification in the authorization request.
-
providedLastName
final Optional<String> providedLastName()
The last name provided for verification in the authorization request.
-
providedMiddleName
final Optional<String> providedMiddleName()
The middle name provided for verification in the authorization request.
-
_providedFirstName
final JsonField<String> _providedFirstName()
Returns the raw JSON value of providedFirstName.
Unlike providedFirstName, this method doesn't throw if the JSON field has an unexpected type.
-
_providedLastName
final JsonField<String> _providedLastName()
Returns the raw JSON value of providedLastName.
Unlike providedLastName, this method doesn't throw if the JSON field has an unexpected type.
-
_providedMiddleName
final JsonField<String> _providedMiddleName()
Returns the raw JSON value of providedMiddleName.
Unlike providedMiddleName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final Transaction.Source.CardFinancial.Verification.CardholderName validate()
-
builder
final static Transaction.Source.CardFinancial.Verification.CardholderName.Builder builder()
Returns a mutable builder for constructing an instance of CardholderName.
The following fields are required:
.providedFirstName() .providedLastName() .providedMiddleName()
-
-
-
-