Class Transaction.Source.CardPushTransferAcceptance
-
- All Implemented Interfaces:
public final class Transaction.Source.CardPushTransferAcceptanceA Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tocard_push_transfer_acceptance. A Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardPushTransferAcceptance.BuilderA builder for CardPushTransferAcceptance.
-
Method Summary
Modifier and Type Method Description final LongsettlementAmount()The transfer amount in USD cents. final StringtransferId()The identifier of the Card Push Transfer that led to this Transaction. final JsonField<Long>_settlementAmount()Returns the raw JSON value of settlementAmount. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardPushTransferAcceptance.BuildertoBuilder()final Transaction.Source.CardPushTransferAcceptancevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardPushTransferAcceptance.Builderbuilder()Returns a mutable builder for constructing an instance of CardPushTransferAcceptance. -
-
Method Detail
-
settlementAmount
final Long settlementAmount()
The transfer amount in USD cents.
-
transferId
final String transferId()
The identifier of the Card Push Transfer that led to this Transaction.
-
_settlementAmount
final JsonField<Long> _settlementAmount()
Returns the raw JSON value of settlementAmount.
Unlike settlementAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardPushTransferAcceptance.Builder toBuilder()
-
validate
final Transaction.Source.CardPushTransferAcceptance validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Transaction.Source.CardPushTransferAcceptance.Builder builder()
Returns a mutable builder for constructing an instance of CardPushTransferAcceptance.
The following fields are required:
.settlementAmount() .transferId()
-
-
-
-