Class Transaction.Source.CardRefund.PurchaseDetails
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetailsAdditional details about the card purchase, such as tax and industry-specific fields.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.BuilderA builder for PurchaseDetails.
public final classTransaction.Source.CardRefund.PurchaseDetails.CarRentalFields specific to car rentals.
public final classTransaction.Source.CardRefund.PurchaseDetails.LodgingFields specific to lodging.
public final classTransaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormatThe format of the purchase identifier.
public final classTransaction.Source.CardRefund.PurchaseDetails.TravelFields specific to travel.
-
Method Summary
-
-
Method Detail
-
carRental
final Optional<Transaction.Source.CardRefund.PurchaseDetails.CarRental> carRental()
Fields specific to car rentals.
-
customerReferenceIdentifier
final Optional<String> customerReferenceIdentifier()
An identifier from the merchant for the customer or consumer.
-
localTaxAmount
final Optional<Long> localTaxAmount()
The state or provincial tax amount in minor units.
-
localTaxCurrency
final Optional<String> localTaxCurrency()
The ISO 4217 code for the local tax assessed.
-
lodging
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging> lodging()
Fields specific to lodging.
-
nationalTaxAmount
final Optional<Long> nationalTaxAmount()
The national tax amount in minor units.
-
nationalTaxCurrency
final Optional<String> nationalTaxCurrency()
The ISO 4217 code for the local tax assessed.
-
purchaseIdentifier
final Optional<String> purchaseIdentifier()
An identifier from the merchant for the purchase to the issuer and cardholder.
-
purchaseIdentifierFormat
final Optional<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat> purchaseIdentifierFormat()
The format of the purchase identifier.
-
travel
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel> travel()
Fields specific to travel.
-
_carRental
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.CarRental> _carRental()
Returns the raw JSON value of carRental.
Unlike carRental, this method doesn't throw if the JSON field has an unexpected type.
-
_customerReferenceIdentifier
final JsonField<String> _customerReferenceIdentifier()
Returns the raw JSON value of customerReferenceIdentifier.
Unlike customerReferenceIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_localTaxAmount
final JsonField<Long> _localTaxAmount()
Returns the raw JSON value of localTaxAmount.
Unlike localTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_localTaxCurrency
final JsonField<String> _localTaxCurrency()
Returns the raw JSON value of localTaxCurrency.
Unlike localTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_lodging
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging> _lodging()
Returns the raw JSON value of lodging.
Unlike lodging, this method doesn't throw if the JSON field has an unexpected type.
-
_nationalTaxAmount
final JsonField<Long> _nationalTaxAmount()
Returns the raw JSON value of nationalTaxAmount.
Unlike nationalTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_nationalTaxCurrency
final JsonField<String> _nationalTaxCurrency()
Returns the raw JSON value of nationalTaxCurrency.
Unlike nationalTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseIdentifier
final JsonField<String> _purchaseIdentifier()
Returns the raw JSON value of purchaseIdentifier.
Unlike purchaseIdentifier, this method doesn't throw if the JSON field has an unexpected type.
-
_purchaseIdentifierFormat
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.PurchaseIdentifierFormat> _purchaseIdentifierFormat()
Returns the raw JSON value of purchaseIdentifierFormat.
Unlike purchaseIdentifierFormat, this method doesn't throw if the JSON field has an unexpected type.
-
_travel
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel> _travel()
Returns the raw JSON value of travel.
Unlike travel, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails validate()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Builder builder()
Returns a mutable builder for constructing an instance of PurchaseDetails.
The following fields are required:
.carRental() .customerReferenceIdentifier() .localTaxAmount() .localTaxCurrency() .lodging() .nationalTaxAmount() .nationalTaxCurrency() .purchaseIdentifier() .purchaseIdentifierFormat() .travel()
-
-
-
-