Class Transaction.Source.CardRefund.PurchaseDetails.Lodging
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.LodgingFields specific to lodging.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.Lodging.BuilderA builder for Lodging.
public final classTransaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraChargesAdditional charges (phone, late check-out, etc.) being billed.
public final classTransaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicatorIndicator that the cardholder is being billed for a reserved room that was not actually used.
-
Method Summary
-
-
Method Detail
-
checkInDate
final Optional<LocalDate> checkInDate()
Date the customer checked in.
-
dailyRoomRateAmount
final Optional<Long> dailyRoomRateAmount()
Daily rate being charged for the room.
-
dailyRoomRateCurrency
final Optional<String> dailyRoomRateCurrency()
The ISO 4217 code for the daily room rate.
-
extraCharges
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges> extraCharges()
Additional charges (phone, late check-out, etc.) being billed.
-
folioCashAdvancesAmount
final Optional<Long> folioCashAdvancesAmount()
Folio cash advances for the room.
-
folioCashAdvancesCurrency
final Optional<String> folioCashAdvancesCurrency()
The ISO 4217 code for the folio cash advances.
-
foodBeverageChargesAmount
final Optional<Long> foodBeverageChargesAmount()
Food and beverage charges for the room.
-
foodBeverageChargesCurrency
final Optional<String> foodBeverageChargesCurrency()
The ISO 4217 code for the food and beverage charges.
-
noShowIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator> noShowIndicator()
Indicator that the cardholder is being billed for a reserved room that was not actually used.
-
prepaidExpensesAmount
final Optional<Long> prepaidExpensesAmount()
Prepaid expenses being charged for the room.
-
prepaidExpensesCurrency
final Optional<String> prepaidExpensesCurrency()
The ISO 4217 code for the prepaid expenses.
-
roomNights
final Optional<Long> roomNights()
Number of nights the room was rented.
-
totalRoomTaxAmount
final Optional<Long> totalRoomTaxAmount()
Total room tax being charged.
-
totalRoomTaxCurrency
final Optional<String> totalRoomTaxCurrency()
The ISO 4217 code for the total room tax.
-
totalTaxAmount
final Optional<Long> totalTaxAmount()
Total tax being charged for the room.
-
totalTaxCurrency
final Optional<String> totalTaxCurrency()
The ISO 4217 code for the total tax assessed.
-
_checkInDate
final JsonField<LocalDate> _checkInDate()
Returns the raw JSON value of checkInDate.
Unlike checkInDate, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyRoomRateAmount
final JsonField<Long> _dailyRoomRateAmount()
Returns the raw JSON value of dailyRoomRateAmount.
Unlike dailyRoomRateAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_dailyRoomRateCurrency
final JsonField<String> _dailyRoomRateCurrency()
Returns the raw JSON value of dailyRoomRateCurrency.
Unlike dailyRoomRateCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_extraCharges
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.ExtraCharges> _extraCharges()
Returns the raw JSON value of extraCharges.
Unlike extraCharges, this method doesn't throw if the JSON field has an unexpected type.
-
_folioCashAdvancesAmount
final JsonField<Long> _folioCashAdvancesAmount()
Returns the raw JSON value of folioCashAdvancesAmount.
Unlike folioCashAdvancesAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_folioCashAdvancesCurrency
final JsonField<String> _folioCashAdvancesCurrency()
Returns the raw JSON value of folioCashAdvancesCurrency.
Unlike folioCashAdvancesCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_foodBeverageChargesAmount
final JsonField<Long> _foodBeverageChargesAmount()
Returns the raw JSON value of foodBeverageChargesAmount.
Unlike foodBeverageChargesAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_foodBeverageChargesCurrency
final JsonField<String> _foodBeverageChargesCurrency()
Returns the raw JSON value of foodBeverageChargesCurrency.
Unlike foodBeverageChargesCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_noShowIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Lodging.NoShowIndicator> _noShowIndicator()
Returns the raw JSON value of noShowIndicator.
Unlike noShowIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_prepaidExpensesAmount
final JsonField<Long> _prepaidExpensesAmount()
Returns the raw JSON value of prepaidExpensesAmount.
Unlike prepaidExpensesAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_prepaidExpensesCurrency
final JsonField<String> _prepaidExpensesCurrency()
Returns the raw JSON value of prepaidExpensesCurrency.
Unlike prepaidExpensesCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_roomNights
final JsonField<Long> _roomNights()
Returns the raw JSON value of roomNights.
Unlike roomNights, this method doesn't throw if the JSON field has an unexpected type.
-
_totalRoomTaxAmount
final JsonField<Long> _totalRoomTaxAmount()
Returns the raw JSON value of totalRoomTaxAmount.
Unlike totalRoomTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_totalRoomTaxCurrency
final JsonField<String> _totalRoomTaxCurrency()
Returns the raw JSON value of totalRoomTaxCurrency.
Unlike totalRoomTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_totalTaxAmount
final JsonField<Long> _totalTaxAmount()
Returns the raw JSON value of totalTaxAmount.
Unlike totalTaxAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_totalTaxCurrency
final JsonField<String> _totalTaxCurrency()
Returns the raw JSON value of totalTaxCurrency.
Unlike totalTaxCurrency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.Lodging validate()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Lodging.Builder builder()
Returns a mutable builder for constructing an instance of Lodging.
The following fields are required:
.checkInDate() .dailyRoomRateAmount() .dailyRoomRateCurrency() .extraCharges() .folioCashAdvancesAmount() .folioCashAdvancesCurrency() .foodBeverageChargesAmount() .foodBeverageChargesCurrency() .noShowIndicator() .prepaidExpensesAmount() .prepaidExpensesCurrency() .roomNights() .totalRoomTaxAmount() .totalRoomTaxCurrency() .totalTaxAmount() .totalTaxCurrency()
-
-
-
-