Class Transaction.Source.CardRefund.PurchaseDetails.Travel
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRefund.PurchaseDetails.TravelFields specific to travel.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.BuilderA builder for Travel.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.AncillaryAncillary purchases in addition to the airfare.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.CreditReasonIndicatorIndicates the reason for a credit to the cardholder.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.RestrictedTicketIndicatorIndicates whether this ticket is non-refundable.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.TicketChangeIndicatorIndicates why a ticket was changed.
public final classTransaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg
-
Method Summary
-
-
Method Detail
-
ancillary
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary> ancillary()
Ancillary purchases in addition to the airfare.
-
computerizedReservationSystem
final Optional<String> computerizedReservationSystem()
Indicates the computerized reservation system used to book the ticket.
-
creditReasonIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.CreditReasonIndicator> creditReasonIndicator()
Indicates the reason for a credit to the cardholder.
-
departureDate
final Optional<LocalDate> departureDate()
Date of departure.
-
originationCityAirportCode
final Optional<String> originationCityAirportCode()
Code for the originating city or airport.
-
passengerName
final Optional<String> passengerName()
Name of the passenger.
-
restrictedTicketIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.RestrictedTicketIndicator> restrictedTicketIndicator()
Indicates whether this ticket is non-refundable.
-
ticketChangeIndicator
final Optional<Transaction.Source.CardRefund.PurchaseDetails.Travel.TicketChangeIndicator> ticketChangeIndicator()
Indicates why a ticket was changed.
-
ticketNumber
final Optional<String> ticketNumber()
Ticket number.
-
travelAgencyCode
final Optional<String> travelAgencyCode()
Code for the travel agency if the ticket was issued by a travel agency.
-
travelAgencyName
final Optional<String> travelAgencyName()
Name of the travel agency if the ticket was issued by a travel agency.
-
tripLegs
final Optional<List<Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg>> tripLegs()
Fields specific to each leg of the journey.
-
_ancillary
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.Ancillary> _ancillary()
Returns the raw JSON value of ancillary.
Unlike ancillary, this method doesn't throw if the JSON field has an unexpected type.
-
_computerizedReservationSystem
final JsonField<String> _computerizedReservationSystem()
Returns the raw JSON value of computerizedReservationSystem.
Unlike computerizedReservationSystem, this method doesn't throw if the JSON field has an unexpected type.
-
_creditReasonIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.CreditReasonIndicator> _creditReasonIndicator()
Returns the raw JSON value of creditReasonIndicator.
Unlike creditReasonIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_departureDate
final JsonField<LocalDate> _departureDate()
Returns the raw JSON value of departureDate.
Unlike departureDate, this method doesn't throw if the JSON field has an unexpected type.
-
_originationCityAirportCode
final JsonField<String> _originationCityAirportCode()
Returns the raw JSON value of originationCityAirportCode.
Unlike originationCityAirportCode, this method doesn't throw if the JSON field has an unexpected type.
-
_passengerName
final JsonField<String> _passengerName()
Returns the raw JSON value of passengerName.
Unlike passengerName, this method doesn't throw if the JSON field has an unexpected type.
-
_restrictedTicketIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.RestrictedTicketIndicator> _restrictedTicketIndicator()
Returns the raw JSON value of restrictedTicketIndicator.
Unlike restrictedTicketIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_ticketChangeIndicator
final JsonField<Transaction.Source.CardRefund.PurchaseDetails.Travel.TicketChangeIndicator> _ticketChangeIndicator()
Returns the raw JSON value of ticketChangeIndicator.
Unlike ticketChangeIndicator, this method doesn't throw if the JSON field has an unexpected type.
-
_ticketNumber
final JsonField<String> _ticketNumber()
Returns the raw JSON value of ticketNumber.
Unlike ticketNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_travelAgencyCode
final JsonField<String> _travelAgencyCode()
Returns the raw JSON value of travelAgencyCode.
Unlike travelAgencyCode, this method doesn't throw if the JSON field has an unexpected type.
-
_travelAgencyName
final JsonField<String> _travelAgencyName()
Returns the raw JSON value of travelAgencyName.
Unlike travelAgencyName, this method doesn't throw if the JSON field has an unexpected type.
-
_tripLegs
final JsonField<List<Transaction.Source.CardRefund.PurchaseDetails.Travel.TripLeg>> _tripLegs()
Returns the raw JSON value of tripLegs.
Unlike tripLegs, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRefund.PurchaseDetails.Travel.Builder toBuilder()
-
validate
final Transaction.Source.CardRefund.PurchaseDetails.Travel validate()
-
builder
final static Transaction.Source.CardRefund.PurchaseDetails.Travel.Builder builder()
Returns a mutable builder for constructing an instance of Travel.
The following fields are required:
.ancillary() .computerizedReservationSystem() .creditReasonIndicator() .departureDate() .originationCityAirportCode() .passengerName() .restrictedTicketIndicator() .ticketChangeIndicator() .ticketNumber() .travelAgencyCode() .travelAgencyName() .tripLegs()
-
-
-
-