Class Transaction.Source.CardRevenuePayment
-
- All Implemented Interfaces:
public final class Transaction.Source.CardRevenuePaymentA Card Revenue Payment object. This field will be present in the JSON response if and only if
categoryis equal tocard_revenue_payment. Card Revenue Payments reflect earnings from fees on card transactions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardRevenuePayment.BuilderA builder for CardRevenuePayment.
public final classTransaction.Source.CardRevenuePayment.CurrencyThe ISO 4217 code for the transaction currency.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in the minor unit of the transaction's currency. final Transaction.Source.CardRevenuePayment.Currencycurrency()The ISO 4217 code for the transaction currency. final OffsetDateTimeperiodEnd()The end of the period for which this transaction paid interest. final OffsetDateTimeperiodStart()The start of the period for which this transaction paid interest. final Optional<String>transactedOnAccountId()The account the card belonged to. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Transaction.Source.CardRevenuePayment.Currency>_currency()Returns the raw JSON value of currency. final JsonField<OffsetDateTime>_periodEnd()Returns the raw JSON value of periodEnd. final JsonField<OffsetDateTime>_periodStart()Returns the raw JSON value of periodStart. final JsonField<String>_transactedOnAccountId()Returns the raw JSON value of transactedOnAccountId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardRevenuePayment.BuildertoBuilder()final Transaction.Source.CardRevenuePaymentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardRevenuePayment.Builderbuilder()Returns a mutable builder for constructing an instance of CardRevenuePayment. -
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.CardRevenuePayment.Currency currency()
The ISO 4217 code for the transaction currency.
-
periodEnd
final OffsetDateTime periodEnd()
The end of the period for which this transaction paid interest.
-
periodStart
final OffsetDateTime periodStart()
The start of the period for which this transaction paid interest.
-
transactedOnAccountId
final Optional<String> transactedOnAccountId()
The account the card belonged to.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.CardRevenuePayment.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_periodEnd
final JsonField<OffsetDateTime> _periodEnd()
Returns the raw JSON value of periodEnd.
Unlike periodEnd, this method doesn't throw if the JSON field has an unexpected type.
-
_periodStart
final JsonField<OffsetDateTime> _periodStart()
Returns the raw JSON value of periodStart.
Unlike periodStart, this method doesn't throw if the JSON field has an unexpected type.
-
_transactedOnAccountId
final JsonField<String> _transactedOnAccountId()
Returns the raw JSON value of transactedOnAccountId.
Unlike transactedOnAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardRevenuePayment.Builder toBuilder()
-
validate
final Transaction.Source.CardRevenuePayment validate()
-
builder
final static Transaction.Source.CardRevenuePayment.Builder builder()
Returns a mutable builder for constructing an instance of CardRevenuePayment.
The following fields are required:
.amount() .currency() .periodEnd() .periodStart() .transactedOnAccountId()
-
-
-
-