Class Transaction.Source.CardSettlement

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CardSettlement
    
                        

    A Card Settlement object. This field will be present in the JSON response if and only if category is equal to card_settlement. Card Settlements are card transactions that have cleared and settled. While a settlement is usually preceded by an authorization, an acquirer can also directly clear a transaction without first authorizing it.