Class Transaction.Source.CardSettlement.Surcharge
-
- All Implemented Interfaces:
public final class Transaction.Source.CardSettlement.SurchargeSurcharge amount details, if applicable. The amount is positive if the surcharge is added to the overall transaction amount (surcharge), and negative if the surcharge is deducted from the overall transaction amount (discount).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CardSettlement.Surcharge.BuilderA builder for Surcharge.
-
Method Summary
Modifier and Type Method Description final Longamount()The surcharge amount in the minor unit of the transaction's settlement currency. final LongpresentmentAmount()The surcharge amount in the minor unit of the transaction's presentment currency. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<Long>_presentmentAmount()Returns the raw JSON value of presentmentAmount. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CardSettlement.Surcharge.BuildertoBuilder()final Transaction.Source.CardSettlement.Surchargevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CardSettlement.Surcharge.Builderbuilder()Returns a mutable builder for constructing an instance of Surcharge. -
-
Method Detail
-
amount
final Long amount()
The surcharge amount in the minor unit of the transaction's settlement currency.
-
presentmentAmount
final Long presentmentAmount()
The surcharge amount in the minor unit of the transaction's presentment currency.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_presentmentAmount
final JsonField<Long> _presentmentAmount()
Returns the raw JSON value of presentmentAmount.
Unlike presentmentAmount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CardSettlement.Surcharge.Builder toBuilder()
-
validate
final Transaction.Source.CardSettlement.Surcharge validate()
-
builder
final static Transaction.Source.CardSettlement.Surcharge.Builder builder()
Returns a mutable builder for constructing an instance of Surcharge.
The following fields are required:
.amount() .presentmentAmount()
-
-
-
-