Class Transaction.Source.CashbackPayment

  • All Implemented Interfaces:

    
    public final class Transaction.Source.CashbackPayment
    
                        

    A Cashback Payment object. This field will be present in the JSON response if and only if category is equal to cashback_payment. A Cashback Payment represents the cashback paid to a cardholder for a given period. Cashback is usually paid monthly for the prior month's transactions.