Class Transaction.Source.CheckTransferDeposit
-
- All Implemented Interfaces:
public final class Transaction.Source.CheckTransferDepositA Check Transfer Deposit object. This field will be present in the JSON response if and only if
categoryis equal tocheck_transfer_deposit. An Inbound Check is a check drawn on an Increase account that has been deposited by an external bank account. These types of checks are not pre-registered.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.CheckTransferDeposit.BuilderA builder for CheckTransferDeposit.
public final classTransaction.Source.CheckTransferDeposit.TypeA constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
Method Summary
Modifier and Type Method Description final Optional<String>backImageFileId()The identifier of the API File object containing an image of the back of the deposited check. final Optional<String>bankOfFirstDepositRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. final OffsetDateTimedepositedAt()When the check was deposited. final Optional<String>frontImageFileId()The identifier of the API File object containing an image of the front of the deposited check. final Optional<String>inboundCheckDepositId()The identifier of the Inbound Check Deposit object associated with this transaction. final Optional<String>transactionId()The identifier of the Transaction object created when the check was deposited. final Optional<String>transferId()The identifier of the Check Transfer object that was deposited. final Transaction.Source.CheckTransferDeposit.Typetype()A constant representing the object's type. final JsonField<String>_backImageFileId()Returns the raw JSON value of backImageFileId. final JsonField<String>_bankOfFirstDepositRoutingNumber()Returns the raw JSON value of bankOfFirstDepositRoutingNumber. final JsonField<OffsetDateTime>_depositedAt()Returns the raw JSON value of depositedAt. final JsonField<String>_frontImageFileId()Returns the raw JSON value of frontImageFileId. final JsonField<String>_inboundCheckDepositId()Returns the raw JSON value of inboundCheckDepositId. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final JsonField<Transaction.Source.CheckTransferDeposit.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.CheckTransferDeposit.BuildertoBuilder()final Transaction.Source.CheckTransferDepositvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.CheckTransferDeposit.Builderbuilder()Returns a mutable builder for constructing an instance of CheckTransferDeposit. -
-
Method Detail
-
backImageFileId
final Optional<String> backImageFileId()
The identifier of the API File object containing an image of the back of the deposited check.
-
bankOfFirstDepositRoutingNumber
final Optional<String> bankOfFirstDepositRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the bank depositing this check. In some rare cases, this is not transmitted via Check21 and the value will be null.
-
depositedAt
final OffsetDateTime depositedAt()
When the check was deposited.
-
frontImageFileId
final Optional<String> frontImageFileId()
The identifier of the API File object containing an image of the front of the deposited check.
-
inboundCheckDepositId
final Optional<String> inboundCheckDepositId()
The identifier of the Inbound Check Deposit object associated with this transaction.
-
transactionId
final Optional<String> transactionId()
The identifier of the Transaction object created when the check was deposited.
-
transferId
final Optional<String> transferId()
The identifier of the Check Transfer object that was deposited.
-
type
final Transaction.Source.CheckTransferDeposit.Type type()
A constant representing the object's type. For this resource it will always be
check_transfer_deposit.
-
_backImageFileId
final JsonField<String> _backImageFileId()
Returns the raw JSON value of backImageFileId.
Unlike backImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_bankOfFirstDepositRoutingNumber
final JsonField<String> _bankOfFirstDepositRoutingNumber()
Returns the raw JSON value of bankOfFirstDepositRoutingNumber.
Unlike bankOfFirstDepositRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_depositedAt
final JsonField<OffsetDateTime> _depositedAt()
Returns the raw JSON value of depositedAt.
Unlike depositedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_frontImageFileId
final JsonField<String> _frontImageFileId()
Returns the raw JSON value of frontImageFileId.
Unlike frontImageFileId, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundCheckDepositId
final JsonField<String> _inboundCheckDepositId()
Returns the raw JSON value of inboundCheckDepositId.
Unlike inboundCheckDepositId, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Transaction.Source.CheckTransferDeposit.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.CheckTransferDeposit.Builder toBuilder()
-
validate
final Transaction.Source.CheckTransferDeposit validate()
-
builder
final static Transaction.Source.CheckTransferDeposit.Builder builder()
Returns a mutable builder for constructing an instance of CheckTransferDeposit.
The following fields are required:
.backImageFileId() .bankOfFirstDepositRoutingNumber() .depositedAt() .frontImageFileId() .inboundCheckDepositId() .transactionId() .transferId() .type()
-
-
-
-