Class Transaction.Source.InboundAchTransfer

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InboundAchTransfer
    
                        

    An Inbound ACH Transfer Intention object. This field will be present in the JSON response if and only if category is equal to inbound_ach_transfer. An Inbound ACH Transfer Intention is created when an ACH transfer is initiated at another bank and received by Increase.