Class Transaction.Source.InboundAchTransfer.Addenda
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.AddendaAdditional information sent from the originator.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundAchTransfer.Addenda.BuilderA builder for Addenda.
public final classTransaction.Source.InboundAchTransfer.Addenda.CategoryThe type of addendum.
public final classTransaction.Source.InboundAchTransfer.Addenda.FreeformUnstructured
payment_related_informationpassed through by the originator.
-
Method Summary
Modifier and Type Method Description final Transaction.Source.InboundAchTransfer.Addenda.Categorycategory()The type of addendum. final Optional<Transaction.Source.InboundAchTransfer.Addenda.Freeform>freeform()Unstructured payment_related_informationpassed through by the originator.final JsonField<Transaction.Source.InboundAchTransfer.Addenda.Category>_category()Returns the raw JSON value of category. final JsonField<Transaction.Source.InboundAchTransfer.Addenda.Freeform>_freeform()Returns the raw JSON value of freeform. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundAchTransfer.Addenda.BuildertoBuilder()final Transaction.Source.InboundAchTransfer.Addendavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundAchTransfer.Addenda.Builderbuilder()Returns a mutable builder for constructing an instance of Addenda. -
-
Method Detail
-
category
final Transaction.Source.InboundAchTransfer.Addenda.Category category()
The type of addendum.
-
freeform
final Optional<Transaction.Source.InboundAchTransfer.Addenda.Freeform> freeform()
Unstructured
payment_related_informationpassed through by the originator.
-
_category
final JsonField<Transaction.Source.InboundAchTransfer.Addenda.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_freeform
final JsonField<Transaction.Source.InboundAchTransfer.Addenda.Freeform> _freeform()
Returns the raw JSON value of freeform.
Unlike freeform, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundAchTransfer.Addenda.Builder toBuilder()
-
validate
final Transaction.Source.InboundAchTransfer.Addenda validate()
-
builder
final static Transaction.Source.InboundAchTransfer.Addenda.Builder builder()
Returns a mutable builder for constructing an instance of Addenda.
The following fields are required:
.category() .freeform()
-
-
-
-