Class Transaction.Source.InboundAchTransfer.Addenda.Freeform
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundAchTransfer.Addenda.FreeformUnstructured
payment_related_informationpassed through by the originator.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundAchTransfer.Addenda.Freeform.BuilderA builder for Freeform.
public final classTransaction.Source.InboundAchTransfer.Addenda.Freeform.Entry
-
Method Summary
Modifier and Type Method Description final List<Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry>entries()Each entry represents an addendum received from the originator. final JsonField<List<Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry>>_entries()Returns the raw JSON value of entries. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundAchTransfer.Addenda.Freeform.BuildertoBuilder()final Transaction.Source.InboundAchTransfer.Addenda.Freeformvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundAchTransfer.Addenda.Freeform.Builderbuilder()Returns a mutable builder for constructing an instance of Freeform. -
-
Method Detail
-
entries
final List<Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry> entries()
Each entry represents an addendum received from the originator.
-
_entries
final JsonField<List<Transaction.Source.InboundAchTransfer.Addenda.Freeform.Entry>> _entries()
Returns the raw JSON value of entries.
Unlike entries, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundAchTransfer.Addenda.Freeform.Builder toBuilder()
-
validate
final Transaction.Source.InboundAchTransfer.Addenda.Freeform validate()
-
builder
final static Transaction.Source.InboundAchTransfer.Addenda.Freeform.Builder builder()
Returns a mutable builder for constructing an instance of Freeform.
The following fields are required:
.entries()
-
-
-
-