Class Transaction.Source.InboundCheckAdjustment

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InboundCheckAdjustment
    
                        

    An Inbound Check Adjustment object. This field will be present in the JSON response if and only if category is equal to inbound_check_adjustment. An Inbound Check Adjustment is created when Increase receives an adjustment for a check or return deposited through Check21.