Class Transaction.Source.InboundFednowTransferConfirmation
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundFednowTransferConfirmationAn Inbound FedNow Transfer Confirmation object. This field will be present in the JSON response if and only if
categoryis equal toinbound_fednow_transfer_confirmation. An Inbound FedNow Transfer Confirmation is created when a FedNow transfer is initiated at another bank and received by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundFednowTransferConfirmation.BuilderA builder for InboundFednowTransferConfirmation.
-
Method Summary
Modifier and Type Method Description final StringtransferId()The identifier of the FedNow Transfer that led to this Transaction. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundFednowTransferConfirmation.BuildertoBuilder()final Transaction.Source.InboundFednowTransferConfirmationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundFednowTransferConfirmation.Builderbuilder()Returns a mutable builder for constructing an instance of InboundFednowTransferConfirmation. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the FedNow Transfer that led to this Transaction.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundFednowTransferConfirmation.Builder toBuilder()
-
validate
final Transaction.Source.InboundFednowTransferConfirmation validate()
-
builder
final static Transaction.Source.InboundFednowTransferConfirmation.Builder builder()
Returns a mutable builder for constructing an instance of InboundFednowTransferConfirmation.
The following fields are required:
.transferId()
-
-
-
-