Class Transaction.Source.InboundWireReversal.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireReversal.BuilderA builder for InboundWireReversal.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.InboundWireReversal.Builder amount(Long amount)
The amount that was reversed in USD cents.
-
amount
final Transaction.Source.InboundWireReversal.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final Transaction.Source.InboundWireReversal.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the reversal was created.
-
createdAt
final Transaction.Source.InboundWireReversal.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Transaction.Source.InboundWireReversal.Builder description(String description)
The description on the reversal message from Fedwire, set by the reversing bank.
-
description
final Transaction.Source.InboundWireReversal.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
financialInstitutionToFinancialInstitutionInformation
final Transaction.Source.InboundWireReversal.Builder financialInstitutionToFinancialInstitutionInformation(String financialInstitutionToFinancialInstitutionInformation)
Additional financial institution information included in the wire reversal.
-
financialInstitutionToFinancialInstitutionInformation
final Transaction.Source.InboundWireReversal.Builder financialInstitutionToFinancialInstitutionInformation(Optional<String> financialInstitutionToFinancialInstitutionInformation)
Alias for calling Builder.financialInstitutionToFinancialInstitutionInformation with
financialInstitutionToFinancialInstitutionInformation.orElse(null).
-
financialInstitutionToFinancialInstitutionInformation
final Transaction.Source.InboundWireReversal.Builder financialInstitutionToFinancialInstitutionInformation(JsonField<String> financialInstitutionToFinancialInstitutionInformation)
Sets Builder.financialInstitutionToFinancialInstitutionInformation to an arbitrary JSON value.
You should usually call Builder.financialInstitutionToFinancialInstitutionInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputCycleDate
final Transaction.Source.InboundWireReversal.Builder inputCycleDate(LocalDate inputCycleDate)
The Fedwire cycle date for the wire reversal. The "Fedwire day" begins at 9:00 PM Eastern Time on the evening before the
cycle date.
-
inputCycleDate
final Transaction.Source.InboundWireReversal.Builder inputCycleDate(JsonField<LocalDate> inputCycleDate)
Sets Builder.inputCycleDate to an arbitrary JSON value.
You should usually call Builder.inputCycleDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireReversal.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
The Fedwire transaction identifier.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireReversal.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.inputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputSequenceNumber
final Transaction.Source.InboundWireReversal.Builder inputSequenceNumber(String inputSequenceNumber)
The Fedwire sequence number.
-
inputSequenceNumber
final Transaction.Source.InboundWireReversal.Builder inputSequenceNumber(JsonField<String> inputSequenceNumber)
Sets Builder.inputSequenceNumber to an arbitrary JSON value.
You should usually call Builder.inputSequenceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputSource
final Transaction.Source.InboundWireReversal.Builder inputSource(String inputSource)
The Fedwire input source identifier.
-
inputSource
final Transaction.Source.InboundWireReversal.Builder inputSource(JsonField<String> inputSource)
Sets Builder.inputSource to an arbitrary JSON value.
You should usually call Builder.inputSource with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final Transaction.Source.InboundWireReversal.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final Transaction.Source.InboundWireReversal.Builder originatorRoutingNumber(Optional<String> originatorRoutingNumber)
Alias for calling Builder.originatorRoutingNumber with
originatorRoutingNumber.orElse(null).
-
originatorRoutingNumber
final Transaction.Source.InboundWireReversal.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireReversal.Builder originatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)
Additional information included in the wire reversal by the reversal originator.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireReversal.Builder originatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)
Alias for calling Builder.originatorToBeneficiaryInformation with
originatorToBeneficiaryInformation.orElse(null).
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireReversal.Builder originatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)
Sets Builder.originatorToBeneficiaryInformation to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousMessageInputCycleDate
final Transaction.Source.InboundWireReversal.Builder previousMessageInputCycleDate(LocalDate previousMessageInputCycleDate)
The Fedwire cycle date for the wire transfer that is being reversed by this message.
-
previousMessageInputCycleDate
final Transaction.Source.InboundWireReversal.Builder previousMessageInputCycleDate(JsonField<LocalDate> previousMessageInputCycleDate)
Sets Builder.previousMessageInputCycleDate to an arbitrary JSON value.
You should usually call Builder.previousMessageInputCycleDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousMessageInputMessageAccountabilityData
final Transaction.Source.InboundWireReversal.Builder previousMessageInputMessageAccountabilityData(String previousMessageInputMessageAccountabilityData)
The Fedwire transaction identifier for the wire transfer that was reversed.
-
previousMessageInputMessageAccountabilityData
final Transaction.Source.InboundWireReversal.Builder previousMessageInputMessageAccountabilityData(JsonField<String> previousMessageInputMessageAccountabilityData)
Sets Builder.previousMessageInputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.previousMessageInputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousMessageInputSequenceNumber
final Transaction.Source.InboundWireReversal.Builder previousMessageInputSequenceNumber(String previousMessageInputSequenceNumber)
The Fedwire sequence number for the wire transfer that was reversed.
-
previousMessageInputSequenceNumber
final Transaction.Source.InboundWireReversal.Builder previousMessageInputSequenceNumber(JsonField<String> previousMessageInputSequenceNumber)
Sets Builder.previousMessageInputSequenceNumber to an arbitrary JSON value.
You should usually call Builder.previousMessageInputSequenceNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
previousMessageInputSource
final Transaction.Source.InboundWireReversal.Builder previousMessageInputSource(String previousMessageInputSource)
The Fedwire input source identifier for the wire transfer that was reversed.
-
previousMessageInputSource
final Transaction.Source.InboundWireReversal.Builder previousMessageInputSource(JsonField<String> previousMessageInputSource)
Sets Builder.previousMessageInputSource to an arbitrary JSON value.
You should usually call Builder.previousMessageInputSource with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
receiverFinancialInstitutionInformation
final Transaction.Source.InboundWireReversal.Builder receiverFinancialInstitutionInformation(String receiverFinancialInstitutionInformation)
Information included in the wire reversal for the receiving financial institution.
-
receiverFinancialInstitutionInformation
final Transaction.Source.InboundWireReversal.Builder receiverFinancialInstitutionInformation(Optional<String> receiverFinancialInstitutionInformation)
Alias for calling Builder.receiverFinancialInstitutionInformation with
receiverFinancialInstitutionInformation.orElse(null).
-
receiverFinancialInstitutionInformation
final Transaction.Source.InboundWireReversal.Builder receiverFinancialInstitutionInformation(JsonField<String> receiverFinancialInstitutionInformation)
Sets Builder.receiverFinancialInstitutionInformation to an arbitrary JSON value.
You should usually call Builder.receiverFinancialInstitutionInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
senderReference
final Transaction.Source.InboundWireReversal.Builder senderReference(String senderReference)
The sending bank's reference number for the wire reversal.
-
senderReference
final Transaction.Source.InboundWireReversal.Builder senderReference(Optional<String> senderReference)
Alias for calling Builder.senderReference with
senderReference.orElse(null).
-
senderReference
final Transaction.Source.InboundWireReversal.Builder senderReference(JsonField<String> senderReference)
Sets Builder.senderReference to an arbitrary JSON value.
You should usually call Builder.senderReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transactionId
final Transaction.Source.InboundWireReversal.Builder transactionId(String transactionId)
The ID for the Transaction associated with the transfer reversal.
-
transactionId
final Transaction.Source.InboundWireReversal.Builder transactionId(JsonField<String> transactionId)
Sets Builder.transactionId to an arbitrary JSON value.
You should usually call Builder.transactionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
wireTransferId
final Transaction.Source.InboundWireReversal.Builder wireTransferId(String wireTransferId)
The ID for the Wire Transfer that is being reversed.
-
wireTransferId
final Transaction.Source.InboundWireReversal.Builder wireTransferId(JsonField<String> wireTransferId)
Sets Builder.wireTransferId to an arbitrary JSON value.
You should usually call Builder.wireTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundWireReversal.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundWireReversal.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundWireReversal.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundWireReversal.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundWireReversal.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundWireReversal build()
Returns an immutable instance of InboundWireReversal.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .createdAt() .description() .financialInstitutionToFinancialInstitutionInformation() .inputCycleDate() .inputMessageAccountabilityData() .inputSequenceNumber() .inputSource() .originatorRoutingNumber() .originatorToBeneficiaryInformation() .previousMessageInputCycleDate() .previousMessageInputMessageAccountabilityData() .previousMessageInputSequenceNumber() .previousMessageInputSource() .receiverFinancialInstitutionInformation() .senderReference() .transactionId() .wireTransferId()
-
-
-
-