Class Transaction.Source.InboundWireTransfer
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireTransferAn Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in USD cents. final Optional<String>creditorAddressLine1()A free-form address field set by the sender. final Optional<String>creditorAddressLine2()A free-form address field set by the sender. final Optional<String>creditorAddressLine3()A free-form address field set by the sender. final Optional<String>creditorName()A name set by the sender. final Optional<String>debtorAddressLine1()A free-form address field set by the sender. final Optional<String>debtorAddressLine2()A free-form address field set by the sender. final Optional<String>debtorAddressLine3()A free-form address field set by the sender. final Optional<String>debtorName()A name set by the sender. final Stringdescription()An Increase-constructed description of the transfer. final Optional<String>endToEndIdentification()A free-form reference string set by the sender, to help identify the transfer. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>instructingAgentRoutingNumber()The American Banking Association (ABA) routing number of the bank that sent the wire. final Optional<String>instructionIdentification()The sending bank's identifier for the wire transfer. final StringtransferId()The ID of the Inbound Wire Transfer object that resulted in this Transaction. final Optional<String>uniqueEndToEndTransactionReference()The Unique End-to-end Transaction Reference (UETR) of the transfer. final Optional<String>unstructuredRemittanceInformation()A free-form message set by the sender. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_creditorAddressLine1()Returns the raw JSON value of creditorAddressLine1. final JsonField<String>_creditorAddressLine2()Returns the raw JSON value of creditorAddressLine2. final JsonField<String>_creditorAddressLine3()Returns the raw JSON value of creditorAddressLine3. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<String>_debtorAddressLine1()Returns the raw JSON value of debtorAddressLine1. final JsonField<String>_debtorAddressLine2()Returns the raw JSON value of debtorAddressLine2. final JsonField<String>_debtorAddressLine3()Returns the raw JSON value of debtorAddressLine3. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_instructingAgentRoutingNumber()Returns the raw JSON value of instructingAgentRoutingNumber. final JsonField<String>_instructionIdentification()Returns the raw JSON value of instructionIdentification. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final JsonField<String>_uniqueEndToEndTransactionReference()Returns the raw JSON value of uniqueEndToEndTransactionReference. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundWireTransfer.BuildertoBuilder()final Transaction.Source.InboundWireTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundWireTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransfer. -
-
Method Detail
-
creditorAddressLine1
final Optional<String> creditorAddressLine1()
A free-form address field set by the sender.
-
creditorAddressLine2
final Optional<String> creditorAddressLine2()
A free-form address field set by the sender.
-
creditorAddressLine3
final Optional<String> creditorAddressLine3()
A free-form address field set by the sender.
-
creditorName
final Optional<String> creditorName()
A name set by the sender.
-
debtorAddressLine1
final Optional<String> debtorAddressLine1()
A free-form address field set by the sender.
-
debtorAddressLine2
final Optional<String> debtorAddressLine2()
A free-form address field set by the sender.
-
debtorAddressLine3
final Optional<String> debtorAddressLine3()
A free-form address field set by the sender.
-
debtorName
final Optional<String> debtorName()
A name set by the sender.
-
description
final String description()
An Increase-constructed description of the transfer.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender, to help identify the transfer.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
instructingAgentRoutingNumber
final Optional<String> instructingAgentRoutingNumber()
The American Banking Association (ABA) routing number of the bank that sent the wire.
-
instructionIdentification
final Optional<String> instructionIdentification()
The sending bank's identifier for the wire transfer.
-
transferId
final String transferId()
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
uniqueEndToEndTransactionReference
final Optional<String> uniqueEndToEndTransactionReference()
The Unique End-to-end Transaction Reference (UETR) of the transfer.
-
unstructuredRemittanceInformation
final Optional<String> unstructuredRemittanceInformation()
A free-form message set by the sender.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine1
final JsonField<String> _creditorAddressLine1()
Returns the raw JSON value of creditorAddressLine1.
Unlike creditorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine2
final JsonField<String> _creditorAddressLine2()
Returns the raw JSON value of creditorAddressLine2.
Unlike creditorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddressLine3
final JsonField<String> _creditorAddressLine3()
Returns the raw JSON value of creditorAddressLine3.
Unlike creditorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine1
final JsonField<String> _debtorAddressLine1()
Returns the raw JSON value of debtorAddressLine1.
Unlike debtorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine2
final JsonField<String> _debtorAddressLine2()
Returns the raw JSON value of debtorAddressLine2.
Unlike debtorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddressLine3
final JsonField<String> _debtorAddressLine3()
Returns the raw JSON value of debtorAddressLine3.
Unlike debtorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_instructingAgentRoutingNumber
final JsonField<String> _instructingAgentRoutingNumber()
Returns the raw JSON value of instructingAgentRoutingNumber.
Unlike instructingAgentRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_instructionIdentification
final JsonField<String> _instructionIdentification()
Returns the raw JSON value of instructionIdentification.
Unlike instructionIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_uniqueEndToEndTransactionReference
final JsonField<String> _uniqueEndToEndTransactionReference()
Returns the raw JSON value of uniqueEndToEndTransactionReference.
Unlike uniqueEndToEndTransactionReference, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundWireTransfer.Builder toBuilder()
-
validate
final Transaction.Source.InboundWireTransfer validate()
-
builder
final static Transaction.Source.InboundWireTransfer.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransfer.
The following fields are required:
.amount() .creditorAddressLine1() .creditorAddressLine2() .creditorAddressLine3() .creditorName() .debtorAddressLine1() .debtorAddressLine2() .debtorAddressLine3() .debtorName() .description() .endToEndIdentification() .inputMessageAccountabilityData() .instructingAgentRoutingNumber() .instructionIdentification() .transferId() .uniqueEndToEndTransactionReference() .unstructuredRemittanceInformation()
-
-
-
-