Class Transaction.Source.InboundWireTransfer
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireTransferAn Inbound Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal toinbound_wire_transfer. An Inbound Wire Transfer Intention is created when a wire transfer is initiated at another bank and received by Increase.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
Method Summary
Modifier and Type Method Description final Longamount()The amount in USD cents. final Optional<String>beneficiaryAddressLine1()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine2()A free-form address field set by the sender. final Optional<String>beneficiaryAddressLine3()A free-form address field set by the sender. final Optional<String>beneficiaryName()A name set by the sender. final Optional<String>beneficiaryReference()A free-form reference string set by the sender, to help identify the transfer. final Stringdescription()An Increase-constructed description of the transfer. final Optional<String>inputMessageAccountabilityData()A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. final Optional<String>originatorAddressLine1()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine2()The address of the wire originator, set by the sending bank. final Optional<String>originatorAddressLine3()The address of the wire originator, set by the sending bank. final Optional<String>originatorName()The originator of the wire, set by the sending bank. final Optional<String>originatorRoutingNumber()The American Banking Association (ABA) routing number of the bank originating the transfer. final Optional<String>originatorToBeneficiaryInformation()An Increase-created concatenation of the Originator-to-Beneficiary lines. final Optional<String>originatorToBeneficiaryInformationLine1()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine2()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine3()A free-form message set by the wire originator. final Optional<String>originatorToBeneficiaryInformationLine4()A free-form message set by the wire originator. final StringtransferId()The ID of the Inbound Wire Transfer object that resulted in this Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<String>_beneficiaryReference()Returns the raw JSON value of beneficiaryReference. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_inputMessageAccountabilityData()Returns the raw JSON value of inputMessageAccountabilityData. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_originatorRoutingNumber()Returns the raw JSON value of originatorRoutingNumber. final JsonField<String>_originatorToBeneficiaryInformation()Returns the raw JSON value of originatorToBeneficiaryInformation. final JsonField<String>_originatorToBeneficiaryInformationLine1()Returns the raw JSON value of originatorToBeneficiaryInformationLine1. final JsonField<String>_originatorToBeneficiaryInformationLine2()Returns the raw JSON value of originatorToBeneficiaryInformationLine2. final JsonField<String>_originatorToBeneficiaryInformationLine3()Returns the raw JSON value of originatorToBeneficiaryInformationLine3. final JsonField<String>_originatorToBeneficiaryInformationLine4()Returns the raw JSON value of originatorToBeneficiaryInformationLine4. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.InboundWireTransfer.BuildertoBuilder()final Transaction.Source.InboundWireTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.InboundWireTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of InboundWireTransfer. -
-
Method Detail
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
A free-form address field set by the sender.
-
beneficiaryName
final Optional<String> beneficiaryName()
A name set by the sender.
-
beneficiaryReference
final Optional<String> beneficiaryReference()
A free-form reference string set by the sender, to help identify the transfer.
-
description
final String description()
An Increase-constructed description of the transfer.
-
inputMessageAccountabilityData
final Optional<String> inputMessageAccountabilityData()
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The address of the wire originator, set by the sending bank.
-
originatorName
final Optional<String> originatorName()
The originator of the wire, set by the sending bank.
-
originatorRoutingNumber
final Optional<String> originatorRoutingNumber()
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorToBeneficiaryInformation
final Optional<String> originatorToBeneficiaryInformation()
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformationLine1
final Optional<String> originatorToBeneficiaryInformationLine1()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Optional<String> originatorToBeneficiaryInformationLine2()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Optional<String> originatorToBeneficiaryInformationLine3()
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Optional<String> originatorToBeneficiaryInformationLine4()
A free-form message set by the wire originator.
-
transferId
final String transferId()
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryReference
final JsonField<String> _beneficiaryReference()
Returns the raw JSON value of beneficiaryReference.
Unlike beneficiaryReference, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_inputMessageAccountabilityData
final JsonField<String> _inputMessageAccountabilityData()
Returns the raw JSON value of inputMessageAccountabilityData.
Unlike inputMessageAccountabilityData, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorRoutingNumber
final JsonField<String> _originatorRoutingNumber()
Returns the raw JSON value of originatorRoutingNumber.
Unlike originatorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformation
final JsonField<String> _originatorToBeneficiaryInformation()
Returns the raw JSON value of originatorToBeneficiaryInformation.
Unlike originatorToBeneficiaryInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine1
final JsonField<String> _originatorToBeneficiaryInformationLine1()
Returns the raw JSON value of originatorToBeneficiaryInformationLine1.
Unlike originatorToBeneficiaryInformationLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine2
final JsonField<String> _originatorToBeneficiaryInformationLine2()
Returns the raw JSON value of originatorToBeneficiaryInformationLine2.
Unlike originatorToBeneficiaryInformationLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine3
final JsonField<String> _originatorToBeneficiaryInformationLine3()
Returns the raw JSON value of originatorToBeneficiaryInformationLine3.
Unlike originatorToBeneficiaryInformationLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorToBeneficiaryInformationLine4
final JsonField<String> _originatorToBeneficiaryInformationLine4()
Returns the raw JSON value of originatorToBeneficiaryInformationLine4.
Unlike originatorToBeneficiaryInformationLine4, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InboundWireTransfer.Builder toBuilder()
-
validate
final Transaction.Source.InboundWireTransfer validate()
-
builder
final static Transaction.Source.InboundWireTransfer.Builder builder()
Returns a mutable builder for constructing an instance of InboundWireTransfer.
The following fields are required:
.amount() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .beneficiaryReference() .description() .inputMessageAccountabilityData() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .originatorRoutingNumber() .originatorToBeneficiaryInformation() .originatorToBeneficiaryInformationLine1() .originatorToBeneficiaryInformationLine2() .originatorToBeneficiaryInformationLine3() .originatorToBeneficiaryInformationLine4() .transferId()
-
-
-
-