Class Transaction.Source.InboundWireTransfer.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.InboundWireTransfer.BuilderA builder for InboundWireTransfer.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.InboundWireTransfer.Builder amount(Long amount)
The amount in USD cents.
-
amount
final Transaction.Source.InboundWireTransfer.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
A free-form address field set by the sender.
-
beneficiaryAddressLine1
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine1(Optional<String> beneficiaryAddressLine1)
Alias for calling Builder.beneficiaryAddressLine1 with
beneficiaryAddressLine1.orElse(null).
-
beneficiaryAddressLine1
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
A free-form address field set by the sender.
-
beneficiaryAddressLine2
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine2(Optional<String> beneficiaryAddressLine2)
Alias for calling Builder.beneficiaryAddressLine2 with
beneficiaryAddressLine2.orElse(null).
-
beneficiaryAddressLine2
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
A free-form address field set by the sender.
-
beneficiaryAddressLine3
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine3(Optional<String> beneficiaryAddressLine3)
Alias for calling Builder.beneficiaryAddressLine3 with
beneficiaryAddressLine3.orElse(null).
-
beneficiaryAddressLine3
final Transaction.Source.InboundWireTransfer.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final Transaction.Source.InboundWireTransfer.Builder beneficiaryName(String beneficiaryName)
A name set by the sender.
-
beneficiaryName
final Transaction.Source.InboundWireTransfer.Builder beneficiaryName(Optional<String> beneficiaryName)
Alias for calling Builder.beneficiaryName with
beneficiaryName.orElse(null).
-
beneficiaryName
final Transaction.Source.InboundWireTransfer.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryReference
final Transaction.Source.InboundWireTransfer.Builder beneficiaryReference(String beneficiaryReference)
A free-form reference string set by the sender, to help identify the transfer.
-
beneficiaryReference
final Transaction.Source.InboundWireTransfer.Builder beneficiaryReference(Optional<String> beneficiaryReference)
Alias for calling Builder.beneficiaryReference with
beneficiaryReference.orElse(null).
-
beneficiaryReference
final Transaction.Source.InboundWireTransfer.Builder beneficiaryReference(JsonField<String> beneficiaryReference)
Sets Builder.beneficiaryReference to an arbitrary JSON value.
You should usually call Builder.beneficiaryReference with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final Transaction.Source.InboundWireTransfer.Builder description(String description)
An Increase-constructed description of the transfer.
-
description
final Transaction.Source.InboundWireTransfer.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireTransfer.Builder inputMessageAccountabilityData(String inputMessageAccountabilityData)
A unique identifier available to the originating and receiving banks, commonly abbreviated as IMAD. It is created when the wire is submitted to the Fedwire service and is helpful when debugging wires with the originating bank.
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireTransfer.Builder inputMessageAccountabilityData(Optional<String> inputMessageAccountabilityData)
Alias for calling Builder.inputMessageAccountabilityData with
inputMessageAccountabilityData.orElse(null).
-
inputMessageAccountabilityData
final Transaction.Source.InboundWireTransfer.Builder inputMessageAccountabilityData(JsonField<String> inputMessageAccountabilityData)
Sets Builder.inputMessageAccountabilityData to an arbitrary JSON value.
You should usually call Builder.inputMessageAccountabilityData with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine1(String originatorAddressLine1)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine1
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
Alias for calling Builder.originatorAddressLine1 with
originatorAddressLine1.orElse(null).
-
originatorAddressLine1
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine2(String originatorAddressLine2)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine2
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
Alias for calling Builder.originatorAddressLine2 with
originatorAddressLine2.orElse(null).
-
originatorAddressLine2
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine3(String originatorAddressLine3)
The address of the wire originator, set by the sending bank.
-
originatorAddressLine3
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
Alias for calling Builder.originatorAddressLine3 with
originatorAddressLine3.orElse(null).
-
originatorAddressLine3
final Transaction.Source.InboundWireTransfer.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final Transaction.Source.InboundWireTransfer.Builder originatorName(String originatorName)
The originator of the wire, set by the sending bank.
-
originatorName
final Transaction.Source.InboundWireTransfer.Builder originatorName(Optional<String> originatorName)
Alias for calling Builder.originatorName with
originatorName.orElse(null).
-
originatorName
final Transaction.Source.InboundWireTransfer.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorRoutingNumber
final Transaction.Source.InboundWireTransfer.Builder originatorRoutingNumber(String originatorRoutingNumber)
The American Banking Association (ABA) routing number of the bank originating the transfer.
-
originatorRoutingNumber
final Transaction.Source.InboundWireTransfer.Builder originatorRoutingNumber(Optional<String> originatorRoutingNumber)
Alias for calling Builder.originatorRoutingNumber with
originatorRoutingNumber.orElse(null).
-
originatorRoutingNumber
final Transaction.Source.InboundWireTransfer.Builder originatorRoutingNumber(JsonField<String> originatorRoutingNumber)
Sets Builder.originatorRoutingNumber to an arbitrary JSON value.
You should usually call Builder.originatorRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformation(String originatorToBeneficiaryInformation)
An Increase-created concatenation of the Originator-to-Beneficiary lines.
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformation(Optional<String> originatorToBeneficiaryInformation)
Alias for calling Builder.originatorToBeneficiaryInformation with
originatorToBeneficiaryInformation.orElse(null).
-
originatorToBeneficiaryInformation
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformation(JsonField<String> originatorToBeneficiaryInformation)
Sets Builder.originatorToBeneficiaryInformation to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine1
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(String originatorToBeneficiaryInformationLine1)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine1
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(Optional<String> originatorToBeneficiaryInformationLine1)
Alias for calling Builder.originatorToBeneficiaryInformationLine1 with
originatorToBeneficiaryInformationLine1.orElse(null).
-
originatorToBeneficiaryInformationLine1
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine1(JsonField<String> originatorToBeneficiaryInformationLine1)
Sets Builder.originatorToBeneficiaryInformationLine1 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine2
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(String originatorToBeneficiaryInformationLine2)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine2
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(Optional<String> originatorToBeneficiaryInformationLine2)
Alias for calling Builder.originatorToBeneficiaryInformationLine2 with
originatorToBeneficiaryInformationLine2.orElse(null).
-
originatorToBeneficiaryInformationLine2
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine2(JsonField<String> originatorToBeneficiaryInformationLine2)
Sets Builder.originatorToBeneficiaryInformationLine2 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine3
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(String originatorToBeneficiaryInformationLine3)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine3
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(Optional<String> originatorToBeneficiaryInformationLine3)
Alias for calling Builder.originatorToBeneficiaryInformationLine3 with
originatorToBeneficiaryInformationLine3.orElse(null).
-
originatorToBeneficiaryInformationLine3
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine3(JsonField<String> originatorToBeneficiaryInformationLine3)
Sets Builder.originatorToBeneficiaryInformationLine3 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorToBeneficiaryInformationLine4
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(String originatorToBeneficiaryInformationLine4)
A free-form message set by the wire originator.
-
originatorToBeneficiaryInformationLine4
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(Optional<String> originatorToBeneficiaryInformationLine4)
Alias for calling Builder.originatorToBeneficiaryInformationLine4 with
originatorToBeneficiaryInformationLine4.orElse(null).
-
originatorToBeneficiaryInformationLine4
final Transaction.Source.InboundWireTransfer.Builder originatorToBeneficiaryInformationLine4(JsonField<String> originatorToBeneficiaryInformationLine4)
Sets Builder.originatorToBeneficiaryInformationLine4 to an arbitrary JSON value.
You should usually call Builder.originatorToBeneficiaryInformationLine4 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.InboundWireTransfer.Builder transferId(String transferId)
The ID of the Inbound Wire Transfer object that resulted in this Transaction.
-
transferId
final Transaction.Source.InboundWireTransfer.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.InboundWireTransfer.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.InboundWireTransfer.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.InboundWireTransfer.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.InboundWireTransfer.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.InboundWireTransfer.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.InboundWireTransfer build()
Returns an immutable instance of InboundWireTransfer.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .beneficiaryReference() .description() .inputMessageAccountabilityData() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .originatorRoutingNumber() .originatorToBeneficiaryInformation() .originatorToBeneficiaryInformationLine1() .originatorToBeneficiaryInformationLine2() .originatorToBeneficiaryInformationLine3() .originatorToBeneficiaryInformationLine4() .transferId()
-
-
-
-