Class Transaction.Source.InboundWireTransferReversal

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InboundWireTransferReversal
    
                        

    An Inbound Wire Transfer Reversal Intention object. This field will be present in the JSON response if and only if category is equal to inbound_wire_transfer_reversal. An Inbound Wire Transfer Reversal Intention is created when Increase has received a wire and the User requests that it be reversed.