Class Transaction.Source.InterestPayment

  • All Implemented Interfaces:

    
    public final class Transaction.Source.InterestPayment
    
                        

    An Interest Payment object. This field will be present in the JSON response if and only if category is equal to interest_payment. An Interest Payment represents a payment of interest on an account. Interest is usually paid monthly.