Class Transaction.Source.InternalSource
-
- All Implemented Interfaces:
public final class Transaction.Source.InternalSourceAn Internal Source object. This field will be present in the JSON response if and only if
categoryis equal tointernal_source. A transaction between the user and Increase. See thereasonattribute for more information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.InternalSource.BuilderA builder for InternalSource.
public final classTransaction.Source.InternalSource.CurrencyThe ISO 4217 code for the transaction currency.
public final classTransaction.Source.InternalSource.ReasonAn Internal Source is a transaction between you and Increase. This describes the reason for the transaction.
-
Method Summary
-
-
Method Detail
-
amount
final Long amount()
The amount in the minor unit of the transaction's currency. For dollars, for example, this is cents.
-
currency
final Transaction.Source.InternalSource.Currency currency()
The ISO 4217 code for the transaction currency.
-
reason
final Transaction.Source.InternalSource.Reason reason()
An Internal Source is a transaction between you and Increase. This describes the reason for the transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<Transaction.Source.InternalSource.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_reason
final JsonField<Transaction.Source.InternalSource.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.InternalSource.Builder toBuilder()
-
validate
final Transaction.Source.InternalSource validate()
-
builder
final static Transaction.Source.InternalSource.Builder builder()
Returns a mutable builder for constructing an instance of InternalSource.
The following fields are required:
.amount() .currency() .reason()
-
-
-
-