Class Transaction.Source.Other

  • All Implemented Interfaces:

    
    public final class Transaction.Source.Other
    
                        

    If the category of this Transaction source is equal to other, this field will contain an empty object, otherwise it will contain null.