Class Transaction.Source.OutboundCardPushTransferAcceptance
-
- All Implemented Interfaces:
public final class Transaction.Source.OutboundCardPushTransferAcceptanceAn Outbound Card Push Transfer Acceptance object. This field will be present in the JSON response if and only if
categoryis equal tooutbound_card_push_transfer_acceptance. An Outbound Card Push Transfer Acceptance is created when an Outbound Card Push Transfer sent from Increase is accepted by the receiving bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.OutboundCardPushTransferAcceptance.BuilderA builder for OutboundCardPushTransferAcceptance.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringtransferId()The identifier of the Outbound Card Push Transfer that led to this Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.OutboundCardPushTransferAcceptance.BuildertoBuilder()final Transaction.Source.OutboundCardPushTransferAcceptancevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.OutboundCardPushTransferAcceptance.Builderbuilder()Returns a mutable builder for constructing an instance of OutboundCardPushTransferAcceptance. -
-
Method Detail
-
transferId
final String transferId()
The identifier of the Outbound Card Push Transfer that led to this Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.OutboundCardPushTransferAcceptance.Builder toBuilder()
-
validate
final Transaction.Source.OutboundCardPushTransferAcceptance validate()
-
builder
final static Transaction.Source.OutboundCardPushTransferAcceptance.Builder builder()
Returns a mutable builder for constructing an instance of OutboundCardPushTransferAcceptance.
The following fields are required:
.amount() .transferId()
-
-
-
-