Class Transaction.Source.RealTimePaymentsTransferAcknowledgement
-
- All Implemented Interfaces:
public final class Transaction.Source.RealTimePaymentsTransferAcknowledgementA Real-Time Payments Transfer Acknowledgement object. This field will be present in the JSON response if and only if
categoryis equal toreal_time_payments_transfer_acknowledgement. A Real-Time Payments Transfer Acknowledgement is created when a Real-Time Payments Transfer sent from Increase is acknowledged by the receiving bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.RealTimePaymentsTransferAcknowledgement.BuilderA builder for RealTimePaymentsTransferAcknowledgement.
-
Method Summary
Modifier and Type Method Description final Longamount()The transfer amount in USD cents. final StringdestinationAccountNumber()The destination account number. final StringdestinationRoutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final StringremittanceInformation()Unstructured information that will show on the recipient's bank statement. final StringtransferId()The identifier of the Real-Time Payments Transfer that led to this Transaction. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_destinationAccountNumber()Returns the raw JSON value of destinationAccountNumber. final JsonField<String>_destinationRoutingNumber()Returns the raw JSON value of destinationRoutingNumber. final JsonField<String>_remittanceInformation()Returns the raw JSON value of remittanceInformation. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.RealTimePaymentsTransferAcknowledgement.BuildertoBuilder()final Transaction.Source.RealTimePaymentsTransferAcknowledgementvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builderbuilder()Returns a mutable builder for constructing an instance of RealTimePaymentsTransferAcknowledgement. -
-
Method Detail
-
destinationAccountNumber
final String destinationAccountNumber()
The destination account number.
-
destinationRoutingNumber
final String destinationRoutingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
remittanceInformation
final String remittanceInformation()
Unstructured information that will show on the recipient's bank statement.
-
transferId
final String transferId()
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationAccountNumber
final JsonField<String> _destinationAccountNumber()
Returns the raw JSON value of destinationAccountNumber.
Unlike destinationAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_destinationRoutingNumber
final JsonField<String> _destinationRoutingNumber()
Returns the raw JSON value of destinationRoutingNumber.
Unlike destinationRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_remittanceInformation
final JsonField<String> _remittanceInformation()
Returns the raw JSON value of remittanceInformation.
Unlike remittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder toBuilder()
-
validate
final Transaction.Source.RealTimePaymentsTransferAcknowledgement validate()
-
builder
final static Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder builder()
Returns a mutable builder for constructing an instance of RealTimePaymentsTransferAcknowledgement.
The following fields are required:
.amount() .destinationAccountNumber() .destinationRoutingNumber() .remittanceInformation() .transferId()
-
-
-
-