Class Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder
-
- All Implemented Interfaces:
public final class Transaction.Source.RealTimePaymentsTransferAcknowledgement.BuilderA builder for RealTimePaymentsTransferAcknowledgement.
-
-
Method Summary
-
-
Method Detail
-
amount
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationAccountNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder destinationAccountNumber(String destinationAccountNumber)
The destination account number.
-
destinationAccountNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder destinationAccountNumber(JsonField<String> destinationAccountNumber)
Sets Builder.destinationAccountNumber to an arbitrary JSON value.
You should usually call Builder.destinationAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
destinationRoutingNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder destinationRoutingNumber(String destinationRoutingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
destinationRoutingNumber
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder destinationRoutingNumber(JsonField<String> destinationRoutingNumber)
Sets Builder.destinationRoutingNumber to an arbitrary JSON value.
You should usually call Builder.destinationRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remittanceInformation
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder remittanceInformation(String remittanceInformation)
Unstructured information that will show on the recipient's bank statement.
-
remittanceInformation
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder remittanceInformation(JsonField<String> remittanceInformation)
Sets Builder.remittanceInformation to an arbitrary JSON value.
You should usually call Builder.remittanceInformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transferId
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder transferId(String transferId)
The identifier of the Real-Time Payments Transfer that led to this Transaction.
-
transferId
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder transferId(JsonField<String> transferId)
Sets Builder.transferId to an arbitrary JSON value.
You should usually call Builder.transferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transaction.Source.RealTimePaymentsTransferAcknowledgement.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transaction.Source.RealTimePaymentsTransferAcknowledgement build()
Returns an immutable instance of RealTimePaymentsTransferAcknowledgement.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.amount() .destinationAccountNumber() .destinationRoutingNumber() .remittanceInformation() .transferId()
-
-
-
-