Class Transaction.Source.WireTransferIntention
-
- All Implemented Interfaces:
public final class Transaction.Source.WireTransferIntentionA Wire Transfer Intention object. This field will be present in the JSON response if and only if
categoryis equal towire_transfer_intention. A Wire Transfer initiated via Increase and sent to a different bank.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTransaction.Source.WireTransferIntention.BuilderA builder for WireTransferIntention.
-
Method Summary
Modifier and Type Method Description final StringaccountNumber()The destination account number. final Longamount()The transfer amount in USD cents. final StringmessageToRecipient()The message that will show on the recipient's bank statement. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final StringtransferId()The identifier of the Wire Transfer that led to this Transaction. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_transferId()Returns the raw JSON value of transferId. final Map<String, JsonValue>_additionalProperties()final Transaction.Source.WireTransferIntention.BuildertoBuilder()final Transaction.Source.WireTransferIntentionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transaction.Source.WireTransferIntention.Builderbuilder()Returns a mutable builder for constructing an instance of WireTransferIntention. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
messageToRecipient
final String messageToRecipient()
The message that will show on the recipient's bank statement.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
transferId
final String transferId()
The identifier of the Wire Transfer that led to this Transaction.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_transferId
final JsonField<String> _transferId()
Returns the raw JSON value of transferId.
Unlike transferId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Transaction.Source.WireTransferIntention.Builder toBuilder()
-
validate
final Transaction.Source.WireTransferIntention validate()
-
builder
final static Transaction.Source.WireTransferIntention.Builder builder()
Returns a mutable builder for constructing an instance of WireTransferIntention.
The following fields are required:
.accountNumber() .amount() .messageToRecipient() .routingNumber() .transferId()
-
-
-
-