Class WireDrawdownRequest
-
- All Implemented Interfaces:
public final class WireDrawdownRequestWire drawdown requests enable you to request that someone else send you a wire. This feature is in beta; reach out to [email protected] to learn more.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequest.BuilderA builder for WireDrawdownRequest.
public final classWireDrawdownRequest.StatusThe lifecycle status of the drawdown request.
public final classWireDrawdownRequest.SubmissionAfter the drawdown request is submitted to Fedwire, this will contain supplemental details.
public final classWireDrawdownRequest.TypeA constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
Method Summary
Modifier and Type Method Description final Stringid()The Wire drawdown request identifier. final StringaccountNumberId()The Account Number to which the recipient of this request is being requested to send funds. final Longamount()The amount being requested in cents. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the wire drawdown request was created. final Stringcurrency()The ISO 4217 code for the amount being requested. final Optional<String>fulfillmentInboundWireTransferId()If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final StringmessageToRecipient()The message the recipient will see as part of the drawdown request. final Optional<String>originatorAddressLine1()The originator's address line 1. final Optional<String>originatorAddressLine2()The originator's address line 2. final Optional<String>originatorAddressLine3()The originator's address line 3. final Optional<String>originatorName()The originator's name. final StringrecipientAccountNumber()The drawdown request's recipient's account number. final Optional<String>recipientAddressLine1()Line 1 of the drawdown request's recipient's address. final Optional<String>recipientAddressLine2()Line 2 of the drawdown request's recipient's address. final Optional<String>recipientAddressLine3()Line 3 of the drawdown request's recipient's address. final Optional<String>recipientName()The drawdown request's recipient's name. final StringrecipientRoutingNumber()The drawdown request's recipient's routing number. final WireDrawdownRequest.Statusstatus()The lifecycle status of the drawdown request. final Optional<WireDrawdownRequest.Submission>submission()After the drawdown request is submitted to Fedwire, this will contain supplemental details. final WireDrawdownRequest.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_currency()Returns the raw JSON value of currency. final JsonField<String>_fulfillmentInboundWireTransferId()Returns the raw JSON value of fulfillmentInboundWireTransferId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_recipientAccountNumber()Returns the raw JSON value of recipientAccountNumber. final JsonField<String>_recipientAddressLine1()Returns the raw JSON value of recipientAddressLine1. final JsonField<String>_recipientAddressLine2()Returns the raw JSON value of recipientAddressLine2. final JsonField<String>_recipientAddressLine3()Returns the raw JSON value of recipientAddressLine3. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<String>_recipientRoutingNumber()Returns the raw JSON value of recipientRoutingNumber. final JsonField<WireDrawdownRequest.Status>_status()Returns the raw JSON value of status. final JsonField<WireDrawdownRequest.Submission>_submission()Returns the raw JSON value of submission. final JsonField<WireDrawdownRequest.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final WireDrawdownRequest.BuildertoBuilder()final WireDrawdownRequestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequest.Builderbuilder()Returns a mutable builder for constructing an instance of WireDrawdownRequest. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to which the recipient of this request is being requested to send funds.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the wire drawdown request was created.
-
currency
final String currency()
The ISO 4217 code for the amount being requested. Will always be "USD".
-
fulfillmentInboundWireTransferId
final Optional<String> fulfillmentInboundWireTransferId()
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
messageToRecipient
final String messageToRecipient()
The message the recipient will see as part of the drawdown request.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The originator's address line 1.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The originator's address line 2.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The originator's address line 3.
-
originatorName
final Optional<String> originatorName()
The originator's name.
-
recipientAccountNumber
final String recipientAccountNumber()
The drawdown request's recipient's account number.
-
recipientAddressLine1
final Optional<String> recipientAddressLine1()
Line 1 of the drawdown request's recipient's address.
-
recipientAddressLine2
final Optional<String> recipientAddressLine2()
Line 2 of the drawdown request's recipient's address.
-
recipientAddressLine3
final Optional<String> recipientAddressLine3()
Line 3 of the drawdown request's recipient's address.
-
recipientName
final Optional<String> recipientName()
The drawdown request's recipient's name.
-
recipientRoutingNumber
final String recipientRoutingNumber()
The drawdown request's recipient's routing number.
-
status
final WireDrawdownRequest.Status status()
The lifecycle status of the drawdown request.
-
submission
final Optional<WireDrawdownRequest.Submission> submission()
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
type
final WireDrawdownRequest.Type type()
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<String> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_fulfillmentInboundWireTransferId
final JsonField<String> _fulfillmentInboundWireTransferId()
Returns the raw JSON value of fulfillmentInboundWireTransferId.
Unlike fulfillmentInboundWireTransferId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAccountNumber
final JsonField<String> _recipientAccountNumber()
Returns the raw JSON value of recipientAccountNumber.
Unlike recipientAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine1
final JsonField<String> _recipientAddressLine1()
Returns the raw JSON value of recipientAddressLine1.
Unlike recipientAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine2
final JsonField<String> _recipientAddressLine2()
Returns the raw JSON value of recipientAddressLine2.
Unlike recipientAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine3
final JsonField<String> _recipientAddressLine3()
Returns the raw JSON value of recipientAddressLine3.
Unlike recipientAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientRoutingNumber
final JsonField<String> _recipientRoutingNumber()
Returns the raw JSON value of recipientRoutingNumber.
Unlike recipientRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<WireDrawdownRequest.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<WireDrawdownRequest.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WireDrawdownRequest.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireDrawdownRequest.Builder toBuilder()
-
validate
final WireDrawdownRequest validate()
-
builder
final static WireDrawdownRequest.Builder builder()
Returns a mutable builder for constructing an instance of WireDrawdownRequest.
The following fields are required:
.id() .accountNumberId() .amount() .createdAt() .currency() .fulfillmentInboundWireTransferId() .idempotencyKey() .messageToRecipient() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .recipientAccountNumber() .recipientAddressLine1() .recipientAddressLine2() .recipientAddressLine3() .recipientName() .recipientRoutingNumber() .status() .submission() .type()
-
-
-
-