Class WireDrawdownRequest.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequest.BuilderA builder for WireDrawdownRequest.
-
-
Method Summary
-
-
Method Detail
-
id
final WireDrawdownRequest.Builder id(String id)
The Wire drawdown request identifier.
-
id
final WireDrawdownRequest.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumberId
final WireDrawdownRequest.Builder accountNumberId(String accountNumberId)
The Account Number to which the recipient of this request is being requested to send funds.
-
accountNumberId
final WireDrawdownRequest.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireDrawdownRequest.Builder amount(Long amount)
The amount being requested in cents.
-
amount
final WireDrawdownRequest.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final WireDrawdownRequest.Builder createdAt(OffsetDateTime createdAt)
The ISO 8601 date and time at which the wire drawdown request was created.
-
createdAt
final WireDrawdownRequest.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
currency
final WireDrawdownRequest.Builder currency(String currency)
The ISO 4217 code for the amount being requested. Will always be "USD".
-
currency
final WireDrawdownRequest.Builder currency(JsonField<String> currency)
Sets Builder.currency to an arbitrary JSON value.
You should usually call Builder.currency with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fulfillmentInboundWireTransferId
final WireDrawdownRequest.Builder fulfillmentInboundWireTransferId(String fulfillmentInboundWireTransferId)
If the recipient fulfills the drawdown request by sending funds, then this will be the identifier of the corresponding Transaction.
-
fulfillmentInboundWireTransferId
final WireDrawdownRequest.Builder fulfillmentInboundWireTransferId(Optional<String> fulfillmentInboundWireTransferId)
Alias for calling Builder.fulfillmentInboundWireTransferId with
fulfillmentInboundWireTransferId.orElse(null).
-
fulfillmentInboundWireTransferId
final WireDrawdownRequest.Builder fulfillmentInboundWireTransferId(JsonField<String> fulfillmentInboundWireTransferId)
Sets Builder.fulfillmentInboundWireTransferId to an arbitrary JSON value.
You should usually call Builder.fulfillmentInboundWireTransferId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
idempotencyKey
final WireDrawdownRequest.Builder idempotencyKey(String idempotencyKey)
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
idempotencyKey
final WireDrawdownRequest.Builder idempotencyKey(Optional<String> idempotencyKey)
Alias for calling Builder.idempotencyKey with
idempotencyKey.orElse(null).
-
idempotencyKey
final WireDrawdownRequest.Builder idempotencyKey(JsonField<String> idempotencyKey)
Sets Builder.idempotencyKey to an arbitrary JSON value.
You should usually call Builder.idempotencyKey with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final WireDrawdownRequest.Builder messageToRecipient(String messageToRecipient)
The message the recipient will see as part of the drawdown request.
-
messageToRecipient
final WireDrawdownRequest.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final WireDrawdownRequest.Builder originatorAddressLine1(String originatorAddressLine1)
The originator's address line 1.
-
originatorAddressLine1
final WireDrawdownRequest.Builder originatorAddressLine1(Optional<String> originatorAddressLine1)
Alias for calling Builder.originatorAddressLine1 with
originatorAddressLine1.orElse(null).
-
originatorAddressLine1
final WireDrawdownRequest.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final WireDrawdownRequest.Builder originatorAddressLine2(String originatorAddressLine2)
The originator's address line 2.
-
originatorAddressLine2
final WireDrawdownRequest.Builder originatorAddressLine2(Optional<String> originatorAddressLine2)
Alias for calling Builder.originatorAddressLine2 with
originatorAddressLine2.orElse(null).
-
originatorAddressLine2
final WireDrawdownRequest.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final WireDrawdownRequest.Builder originatorAddressLine3(String originatorAddressLine3)
The originator's address line 3.
-
originatorAddressLine3
final WireDrawdownRequest.Builder originatorAddressLine3(Optional<String> originatorAddressLine3)
Alias for calling Builder.originatorAddressLine3 with
originatorAddressLine3.orElse(null).
-
originatorAddressLine3
final WireDrawdownRequest.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final WireDrawdownRequest.Builder originatorName(String originatorName)
The originator's name.
-
originatorName
final WireDrawdownRequest.Builder originatorName(Optional<String> originatorName)
Alias for calling Builder.originatorName with
originatorName.orElse(null).
-
originatorName
final WireDrawdownRequest.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumber
final WireDrawdownRequest.Builder recipientAccountNumber(String recipientAccountNumber)
The drawdown request's recipient's account number.
-
recipientAccountNumber
final WireDrawdownRequest.Builder recipientAccountNumber(JsonField<String> recipientAccountNumber)
Sets Builder.recipientAccountNumber to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine1
final WireDrawdownRequest.Builder recipientAddressLine1(String recipientAddressLine1)
Line 1 of the drawdown request's recipient's address.
-
recipientAddressLine1
final WireDrawdownRequest.Builder recipientAddressLine1(Optional<String> recipientAddressLine1)
Alias for calling Builder.recipientAddressLine1 with
recipientAddressLine1.orElse(null).
-
recipientAddressLine1
final WireDrawdownRequest.Builder recipientAddressLine1(JsonField<String> recipientAddressLine1)
Sets Builder.recipientAddressLine1 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine2
final WireDrawdownRequest.Builder recipientAddressLine2(String recipientAddressLine2)
Line 2 of the drawdown request's recipient's address.
-
recipientAddressLine2
final WireDrawdownRequest.Builder recipientAddressLine2(Optional<String> recipientAddressLine2)
Alias for calling Builder.recipientAddressLine2 with
recipientAddressLine2.orElse(null).
-
recipientAddressLine2
final WireDrawdownRequest.Builder recipientAddressLine2(JsonField<String> recipientAddressLine2)
Sets Builder.recipientAddressLine2 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine3
final WireDrawdownRequest.Builder recipientAddressLine3(String recipientAddressLine3)
Line 3 of the drawdown request's recipient's address.
-
recipientAddressLine3
final WireDrawdownRequest.Builder recipientAddressLine3(Optional<String> recipientAddressLine3)
Alias for calling Builder.recipientAddressLine3 with
recipientAddressLine3.orElse(null).
-
recipientAddressLine3
final WireDrawdownRequest.Builder recipientAddressLine3(JsonField<String> recipientAddressLine3)
Sets Builder.recipientAddressLine3 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final WireDrawdownRequest.Builder recipientName(String recipientName)
The drawdown request's recipient's name.
-
recipientName
final WireDrawdownRequest.Builder recipientName(Optional<String> recipientName)
Alias for calling Builder.recipientName with
recipientName.orElse(null).
-
recipientName
final WireDrawdownRequest.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientRoutingNumber
final WireDrawdownRequest.Builder recipientRoutingNumber(String recipientRoutingNumber)
The drawdown request's recipient's routing number.
-
recipientRoutingNumber
final WireDrawdownRequest.Builder recipientRoutingNumber(JsonField<String> recipientRoutingNumber)
Sets Builder.recipientRoutingNumber to an arbitrary JSON value.
You should usually call Builder.recipientRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
status
final WireDrawdownRequest.Builder status(WireDrawdownRequest.Status status)
The lifecycle status of the drawdown request.
-
status
final WireDrawdownRequest.Builder status(JsonField<WireDrawdownRequest.Status> status)
Sets Builder.status to an arbitrary JSON value.
You should usually call Builder.status with a well-typed Status value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
submission
final WireDrawdownRequest.Builder submission(WireDrawdownRequest.Submission submission)
After the drawdown request is submitted to Fedwire, this will contain supplemental details.
-
submission
final WireDrawdownRequest.Builder submission(Optional<WireDrawdownRequest.Submission> submission)
Alias for calling Builder.submission with
submission.orElse(null).
-
submission
final WireDrawdownRequest.Builder submission(JsonField<WireDrawdownRequest.Submission> submission)
Sets Builder.submission to an arbitrary JSON value.
You should usually call Builder.submission with a well-typed Submission value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final WireDrawdownRequest.Builder type(WireDrawdownRequest.Type type)
A constant representing the object's type. For this resource it will always be
wire_drawdown_request.
-
type
final WireDrawdownRequest.Builder type(JsonField<WireDrawdownRequest.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequest.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequest.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequest.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequest.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequest.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequest build()
Returns an immutable instance of WireDrawdownRequest.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .accountNumberId() .amount() .createdAt() .currency() .fulfillmentInboundWireTransferId() .idempotencyKey() .messageToRecipient() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .recipientAccountNumber() .recipientAddressLine1() .recipientAddressLine2() .recipientAddressLine3() .recipientName() .recipientRoutingNumber() .status() .submission() .type()
-
-
-
-