Class WireDrawdownRequestCreateParams.Body
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number to which the debtor should send funds. final Longamount()The amount requested from the debtor, in USD cents. final WireDrawdownRequestCreateParams.CreditorAddresscreditorAddress()The creditor's address. final StringcreditorName()The creditor's name. final WireDrawdownRequestCreateParams.DebtorAddressdebtorAddress()The debtor's address. final StringdebtorName()The debtor's name. final StringunstructuredRemittanceInformation()Remittance information the debtor will see as part of the request. final Optional<String>debtorAccountNumber()The debtor's account number. final Optional<String>debtorExternalAccountId()The ID of an External Account to initiate a transfer to. final Optional<String>debtorRoutingNumber()The debtor's routing number. final Optional<String>endToEndIdentification()A free-form reference string set by the sender mirrored back in the subsequent wire transfer. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<WireDrawdownRequestCreateParams.CreditorAddress>_creditorAddress()Returns the raw JSON value of creditorAddress. final JsonField<String>_creditorName()Returns the raw JSON value of creditorName. final JsonField<WireDrawdownRequestCreateParams.DebtorAddress>_debtorAddress()Returns the raw JSON value of debtorAddress. final JsonField<String>_debtorName()Returns the raw JSON value of debtorName. final JsonField<String>_unstructuredRemittanceInformation()Returns the raw JSON value of unstructuredRemittanceInformation. final JsonField<String>_debtorAccountNumber()Returns the raw JSON value of debtorAccountNumber. final JsonField<String>_debtorExternalAccountId()Returns the raw JSON value of debtorExternalAccountId. final JsonField<String>_debtorRoutingNumber()Returns the raw JSON value of debtorRoutingNumber. final JsonField<String>_endToEndIdentification()Returns the raw JSON value of endToEndIdentification. final Map<String, JsonValue>_additionalProperties()final WireDrawdownRequestCreateParams.Body.BuildertoBuilder()final WireDrawdownRequestCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to which the debtor should send funds.
-
creditorAddress
final WireDrawdownRequestCreateParams.CreditorAddress creditorAddress()
The creditor's address.
-
creditorName
final String creditorName()
The creditor's name.
-
debtorAddress
final WireDrawdownRequestCreateParams.DebtorAddress debtorAddress()
The debtor's address.
-
debtorName
final String debtorName()
The debtor's name.
-
unstructuredRemittanceInformation
final String unstructuredRemittanceInformation()
Remittance information the debtor will see as part of the request.
-
debtorAccountNumber
final Optional<String> debtorAccountNumber()
The debtor's account number.
-
debtorExternalAccountId
final Optional<String> debtorExternalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
debtor_account_numberanddebtor_routing_numbermust be absent.
-
debtorRoutingNumber
final Optional<String> debtorRoutingNumber()
The debtor's routing number.
-
endToEndIdentification
final Optional<String> endToEndIdentification()
A free-form reference string set by the sender mirrored back in the subsequent wire transfer.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorAddress
final JsonField<WireDrawdownRequestCreateParams.CreditorAddress> _creditorAddress()
Returns the raw JSON value of creditorAddress.
Unlike creditorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_creditorName
final JsonField<String> _creditorName()
Returns the raw JSON value of creditorName.
Unlike creditorName, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAddress
final JsonField<WireDrawdownRequestCreateParams.DebtorAddress> _debtorAddress()
Returns the raw JSON value of debtorAddress.
Unlike debtorAddress, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorName
final JsonField<String> _debtorName()
Returns the raw JSON value of debtorName.
Unlike debtorName, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructuredRemittanceInformation
final JsonField<String> _unstructuredRemittanceInformation()
Returns the raw JSON value of unstructuredRemittanceInformation.
Unlike unstructuredRemittanceInformation, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorAccountNumber
final JsonField<String> _debtorAccountNumber()
Returns the raw JSON value of debtorAccountNumber.
Unlike debtorAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorExternalAccountId
final JsonField<String> _debtorExternalAccountId()
Returns the raw JSON value of debtorExternalAccountId.
Unlike debtorExternalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_debtorRoutingNumber
final JsonField<String> _debtorRoutingNumber()
Returns the raw JSON value of debtorRoutingNumber.
Unlike debtorRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_endToEndIdentification
final JsonField<String> _endToEndIdentification()
Returns the raw JSON value of endToEndIdentification.
Unlike endToEndIdentification, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireDrawdownRequestCreateParams.Body.Builder toBuilder()
-
validate
final WireDrawdownRequestCreateParams.Body validate()
-
builder
final static WireDrawdownRequestCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountNumberId() .amount() .creditorAddress() .creditorName() .debtorAddress() .debtorName() .unstructuredRemittanceInformation()
-
-
-
-