Class WireDrawdownRequestCreateParams.Body
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountNumberId()The Account Number to which the recipient should send funds. final Longamount()The amount requested from the recipient, in USD cents. final StringmessageToRecipient()A message the recipient will see as part of the request. final StringrecipientAccountNumber()The drawdown request's recipient's account number. final StringrecipientName()The drawdown request's recipient's name. final StringrecipientRoutingNumber()The drawdown request's recipient's routing number. final Optional<String>originatorAddressLine1()The drawdown request originator's address line 1. final Optional<String>originatorAddressLine2()The drawdown request originator's address line 2. final Optional<String>originatorAddressLine3()The drawdown request originator's address line 3. final Optional<String>originatorName()The drawdown request originator's name. final Optional<String>recipientAddressLine1()Line 1 of the drawdown request's recipient's address. final Optional<String>recipientAddressLine2()Line 2 of the drawdown request's recipient's address. final Optional<String>recipientAddressLine3()Line 3 of the drawdown request's recipient's address. final JsonField<String>_accountNumberId()Returns the raw JSON value of accountNumberId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_recipientAccountNumber()Returns the raw JSON value of recipientAccountNumber. final JsonField<String>_recipientName()Returns the raw JSON value of recipientName. final JsonField<String>_recipientRoutingNumber()Returns the raw JSON value of recipientRoutingNumber. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_recipientAddressLine1()Returns the raw JSON value of recipientAddressLine1. final JsonField<String>_recipientAddressLine2()Returns the raw JSON value of recipientAddressLine2. final JsonField<String>_recipientAddressLine3()Returns the raw JSON value of recipientAddressLine3. final Map<String, JsonValue>_additionalProperties()final WireDrawdownRequestCreateParams.Body.BuildertoBuilder()final WireDrawdownRequestCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
accountNumberId
final String accountNumberId()
The Account Number to which the recipient should send funds.
-
messageToRecipient
final String messageToRecipient()
A message the recipient will see as part of the request.
-
recipientAccountNumber
final String recipientAccountNumber()
The drawdown request's recipient's account number.
-
recipientName
final String recipientName()
The drawdown request's recipient's name.
-
recipientRoutingNumber
final String recipientRoutingNumber()
The drawdown request's recipient's routing number.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The drawdown request originator's address line 1. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The drawdown request originator's address line 2. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The drawdown request originator's address line 3. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final Optional<String> originatorName()
The drawdown request originator's name. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
recipientAddressLine1
final Optional<String> recipientAddressLine1()
Line 1 of the drawdown request's recipient's address.
-
recipientAddressLine2
final Optional<String> recipientAddressLine2()
Line 2 of the drawdown request's recipient's address.
-
recipientAddressLine3
final Optional<String> recipientAddressLine3()
Line 3 of the drawdown request's recipient's address.
-
_accountNumberId
final JsonField<String> _accountNumberId()
Returns the raw JSON value of accountNumberId.
Unlike accountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAccountNumber
final JsonField<String> _recipientAccountNumber()
Returns the raw JSON value of recipientAccountNumber.
Unlike recipientAccountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientName
final JsonField<String> _recipientName()
Returns the raw JSON value of recipientName.
Unlike recipientName, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientRoutingNumber
final JsonField<String> _recipientRoutingNumber()
Returns the raw JSON value of recipientRoutingNumber.
Unlike recipientRoutingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine1
final JsonField<String> _recipientAddressLine1()
Returns the raw JSON value of recipientAddressLine1.
Unlike recipientAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine2
final JsonField<String> _recipientAddressLine2()
Returns the raw JSON value of recipientAddressLine2.
Unlike recipientAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_recipientAddressLine3
final JsonField<String> _recipientAddressLine3()
Returns the raw JSON value of recipientAddressLine3.
Unlike recipientAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireDrawdownRequestCreateParams.Body.Builder toBuilder()
-
validate
final WireDrawdownRequestCreateParams.Body validate()
-
builder
final static WireDrawdownRequestCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountNumberId() .amount() .messageToRecipient() .recipientAccountNumber() .recipientName() .recipientRoutingNumber()
-
-
-
-