Class WireDrawdownRequestCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountNumberId
final WireDrawdownRequestCreateParams.Body.Builder accountNumberId(String accountNumberId)
The Account Number to which the recipient should send funds.
-
accountNumberId
final WireDrawdownRequestCreateParams.Body.Builder accountNumberId(JsonField<String> accountNumberId)
Sets Builder.accountNumberId to an arbitrary JSON value.
You should usually call Builder.accountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireDrawdownRequestCreateParams.Body.Builder amount(Long amount)
The amount requested from the recipient, in USD cents.
-
amount
final WireDrawdownRequestCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
messageToRecipient
final WireDrawdownRequestCreateParams.Body.Builder messageToRecipient(String messageToRecipient)
A message the recipient will see as part of the request.
-
messageToRecipient
final WireDrawdownRequestCreateParams.Body.Builder messageToRecipient(JsonField<String> messageToRecipient)
Sets Builder.messageToRecipient to an arbitrary JSON value.
You should usually call Builder.messageToRecipient with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAccountNumber
final WireDrawdownRequestCreateParams.Body.Builder recipientAccountNumber(String recipientAccountNumber)
The drawdown request's recipient's account number.
-
recipientAccountNumber
final WireDrawdownRequestCreateParams.Body.Builder recipientAccountNumber(JsonField<String> recipientAccountNumber)
Sets Builder.recipientAccountNumber to an arbitrary JSON value.
You should usually call Builder.recipientAccountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientName
final WireDrawdownRequestCreateParams.Body.Builder recipientName(String recipientName)
The drawdown request's recipient's name.
-
recipientName
final WireDrawdownRequestCreateParams.Body.Builder recipientName(JsonField<String> recipientName)
Sets Builder.recipientName to an arbitrary JSON value.
You should usually call Builder.recipientName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientRoutingNumber
final WireDrawdownRequestCreateParams.Body.Builder recipientRoutingNumber(String recipientRoutingNumber)
The drawdown request's recipient's routing number.
-
recipientRoutingNumber
final WireDrawdownRequestCreateParams.Body.Builder recipientRoutingNumber(JsonField<String> recipientRoutingNumber)
Sets Builder.recipientRoutingNumber to an arbitrary JSON value.
You should usually call Builder.recipientRoutingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final WireDrawdownRequestCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
The drawdown request originator's address line 1. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine1
final WireDrawdownRequestCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final WireDrawdownRequestCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
The drawdown request originator's address line 2. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final WireDrawdownRequestCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final WireDrawdownRequestCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
The drawdown request originator's address line 3. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final WireDrawdownRequestCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final WireDrawdownRequestCreateParams.Body.Builder originatorName(String originatorName)
The drawdown request originator's name. This is only necessary if you're requesting a payment to a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final WireDrawdownRequestCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine1
final WireDrawdownRequestCreateParams.Body.Builder recipientAddressLine1(String recipientAddressLine1)
Line 1 of the drawdown request's recipient's address.
-
recipientAddressLine1
final WireDrawdownRequestCreateParams.Body.Builder recipientAddressLine1(JsonField<String> recipientAddressLine1)
Sets Builder.recipientAddressLine1 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine2
final WireDrawdownRequestCreateParams.Body.Builder recipientAddressLine2(String recipientAddressLine2)
Line 2 of the drawdown request's recipient's address.
-
recipientAddressLine2
final WireDrawdownRequestCreateParams.Body.Builder recipientAddressLine2(JsonField<String> recipientAddressLine2)
Sets Builder.recipientAddressLine2 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
recipientAddressLine3
final WireDrawdownRequestCreateParams.Body.Builder recipientAddressLine3(String recipientAddressLine3)
Line 3 of the drawdown request's recipient's address.
-
recipientAddressLine3
final WireDrawdownRequestCreateParams.Body.Builder recipientAddressLine3(JsonField<String> recipientAddressLine3)
Sets Builder.recipientAddressLine3 to an arbitrary JSON value.
You should usually call Builder.recipientAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireDrawdownRequestCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireDrawdownRequestCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireDrawdownRequestCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireDrawdownRequestCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireDrawdownRequestCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireDrawdownRequestCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountNumberId() .amount() .messageToRecipient() .recipientAccountNumber() .recipientName() .recipientRoutingNumber()
-
-
-
-