Class WireDrawdownRequestCreateParams.CreditorAddress
-
- All Implemented Interfaces:
public final class WireDrawdownRequestCreateParams.CreditorAddressThe creditor's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestCreateParams.CreditorAddress.BuilderA builder for CreditorAddress.
-
Method Summary
Modifier and Type Method Description final Stringcity()The city, district, town, or village of the address. final Stringcountry()The two-letter ISO 3166-1 alpha-2 code for the country of the address. final Stringline1()The first line of the address. final Optional<String>line2()The second line of the address. final Optional<String>postalCode()The ZIP code of the address. final Optional<String>state()The address state. final JsonField<String>_city()Returns the raw JSON value of city. final JsonField<String>_country()Returns the raw JSON value of country. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_postalCode()Returns the raw JSON value of postalCode. final JsonField<String>_state()Returns the raw JSON value of state. final Map<String, JsonValue>_additionalProperties()final WireDrawdownRequestCreateParams.CreditorAddress.BuildertoBuilder()final WireDrawdownRequestCreateParams.CreditorAddressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestCreateParams.CreditorAddress.Builderbuilder()Returns a mutable builder for constructing an instance of CreditorAddress. -
-
Method Detail
-
country
final String country()
The two-letter ISO 3166-1 alpha-2 code for the country of the address.
-
line1
final String line1()
The first line of the address. This is usually the street number and street.
-
line2
final Optional<String> line2()
The second line of the address. This might be the floor or room number.
-
postalCode
final Optional<String> postalCode()
The ZIP code of the address.
-
_city
final JsonField<String> _city()
Returns the raw JSON value of city.
Unlike city, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<String> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_postalCode
final JsonField<String> _postalCode()
Returns the raw JSON value of postalCode.
Unlike postalCode, this method doesn't throw if the JSON field has an unexpected type.
-
_state
final JsonField<String> _state()
Returns the raw JSON value of state.
Unlike state, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireDrawdownRequestCreateParams.CreditorAddress.Builder toBuilder()
-
validate
final WireDrawdownRequestCreateParams.CreditorAddress validate()
-
builder
final static WireDrawdownRequestCreateParams.CreditorAddress.Builder builder()
Returns a mutable builder for constructing an instance of CreditorAddress.
The following fields are required:
.city() .country() .line1()
-
-
-
-