Class WireDrawdownRequestListPageAsync
-
- All Implemented Interfaces:
public final class WireDrawdownRequestListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireDrawdownRequestListPageAsync.BuilderA builder for WireDrawdownRequestListPageAsync.
public final classWireDrawdownRequestListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<WireDrawdownRequest>data()Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<WireDrawdownRequestListParams>getNextPageParams()final CompletableFuture<Optional<WireDrawdownRequestListPageAsync>>getNextPage()final WireDrawdownRequestListPageAsync.AutoPagerautoPager()final WireDrawdownRequestListParamsparams()The parameters that were used to request this page. final WireDrawdownRequestListPageResponseresponse()The response that this page was parsed from. final WireDrawdownRequestListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireDrawdownRequestListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of WireDrawdownRequestListPageAsync. -
-
Method Detail
-
data
final List<WireDrawdownRequest> data()
Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to WireDrawdownRequestListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<WireDrawdownRequestListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<WireDrawdownRequestListPageAsync>> getNextPage()
-
autoPager
final WireDrawdownRequestListPageAsync.AutoPager autoPager()
-
params
final WireDrawdownRequestListParams params()
The parameters that were used to request this page.
-
response
final WireDrawdownRequestListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final WireDrawdownRequestListPageAsync.Builder toBuilder()
-
builder
final static WireDrawdownRequestListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of WireDrawdownRequestListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-