Class WireTransfer
-
- All Implemented Interfaces:
public final class WireTransferWire transfers move funds between your Increase account and any other account accessible by Fedwire.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.BuilderA builder for WireTransfer.
public final classWireTransfer.ApprovalIf your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
public final classWireTransfer.CancellationIf your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
public final classWireTransfer.CreatedByWhat object created the transfer, either via the API or the dashboard.
public final classWireTransfer.CurrencyThe ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.public final classWireTransfer.NetworkThe transfer's network.
public final classWireTransfer.ReversalIf your transfer is reversed, this will contain details of the reversal.
public final classWireTransfer.StatusThe lifecycle status of the transfer.
public final classWireTransfer.SubmissionAfter the transfer is submitted to Fedwire, this will contain supplemental details.
public final classWireTransfer.TypeA constant representing the object's type. For this resource it will always be
wire_transfer.
-
Method Summary
Modifier and Type Method Description final Stringid()The wire transfer's identifier. final StringaccountId()The Account to which the transfer belongs. final StringaccountNumber()The destination account number. final Longamount()The transfer amount in USD cents. final Optional<WireTransfer.Approval>approval()If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval. final Optional<String>beneficiaryAddressLine1()The beneficiary's address line 1. final Optional<String>beneficiaryAddressLine2()The beneficiary's address line 2. final Optional<String>beneficiaryAddressLine3()The beneficiary's address line 3. final Optional<String>beneficiaryName()The beneficiary's name. final Optional<WireTransfer.Cancellation>cancellation()If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation. final OffsetDateTimecreatedAt()The ISO 8601 date and time at which the transfer was created. final Optional<WireTransfer.CreatedBy>createdBy()What object created the transfer, either via the API or the dashboard. final WireTransfer.Currencycurrency()The ISO 4217 code for the transfer's currency. final Optional<String>externalAccountId()The identifier of the External Account the transfer was made to, if any. final Optional<String>idempotencyKey()The idempotency key you chose for this object. final Optional<String>inboundWireDrawdownRequestId()The ID of an Inbound Wire Drawdown Request in response to which this transfer was sent. final Optional<String>messageToRecipient()The message that will show on the recipient's bank statement. final WireTransfer.Networknetwork()The transfer's network. final Optional<String>originatorAddressLine1()The originator's address line 1. final Optional<String>originatorAddressLine2()The originator's address line 2. final Optional<String>originatorAddressLine3()The originator's address line 3. final Optional<String>originatorName()The originator's name. final Optional<String>pendingTransactionId()The ID for the pending transaction representing the transfer. final Optional<WireTransfer.Reversal>reversal()If your transfer is reversed, this will contain details of the reversal. final StringroutingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN). final Optional<String>sourceAccountNumberId()The Account Number that was passed to the wire's recipient. final WireTransfer.Statusstatus()The lifecycle status of the transfer. final Optional<WireTransfer.Submission>submission()After the transfer is submitted to Fedwire, this will contain supplemental details. final Optional<String>transactionId()The ID for the transaction funding the transfer. final WireTransfer.Typetype()A constant representing the object's type. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<WireTransfer.Approval>_approval()Returns the raw JSON value of approval. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<WireTransfer.Cancellation>_cancellation()Returns the raw JSON value of cancellation. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<WireTransfer.CreatedBy>_createdBy()Returns the raw JSON value of createdBy. final JsonField<WireTransfer.Currency>_currency()Returns the raw JSON value of currency. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<String>_idempotencyKey()Returns the raw JSON value of idempotencyKey. final JsonField<String>_inboundWireDrawdownRequestId()Returns the raw JSON value of inboundWireDrawdownRequestId. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<WireTransfer.Network>_network()Returns the raw JSON value of network. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<String>_pendingTransactionId()Returns the raw JSON value of pendingTransactionId. final JsonField<WireTransfer.Reversal>_reversal()Returns the raw JSON value of reversal. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final JsonField<WireTransfer.Status>_status()Returns the raw JSON value of status. final JsonField<WireTransfer.Submission>_submission()Returns the raw JSON value of submission. final JsonField<String>_transactionId()Returns the raw JSON value of transactionId. final JsonField<WireTransfer.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final WireTransfer.BuildertoBuilder()final WireTransfervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Builderbuilder()Returns a mutable builder for constructing an instance of WireTransfer. -
-
Method Detail
-
accountNumber
final String accountNumber()
The destination account number.
-
approval
final Optional<WireTransfer.Approval> approval()
If your account requires approvals for transfers and the transfer was approved, this will contain details of the approval.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
The beneficiary's address line 1.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
The beneficiary's address line 2.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
The beneficiary's address line 3.
-
beneficiaryName
final Optional<String> beneficiaryName()
The beneficiary's name.
-
cancellation
final Optional<WireTransfer.Cancellation> cancellation()
If your account requires approvals for transfers and the transfer was not approved, this will contain details of the cancellation.
-
createdAt
final OffsetDateTime createdAt()
The ISO 8601 date and time at which the transfer was created.
-
createdBy
final Optional<WireTransfer.CreatedBy> createdBy()
What object created the transfer, either via the API or the dashboard.
-
currency
final WireTransfer.Currency currency()
The ISO 4217 code for the transfer's currency. For wire transfers this is always equal to
usd.
-
externalAccountId
final Optional<String> externalAccountId()
The identifier of the External Account the transfer was made to, if any.
-
idempotencyKey
final Optional<String> idempotencyKey()
The idempotency key you chose for this object. This value is unique across Increase and is used to ensure that a request is only processed once. Learn more about idempotency.
-
inboundWireDrawdownRequestId
final Optional<String> inboundWireDrawdownRequestId()
The ID of an Inbound Wire Drawdown Request in response to which this transfer was sent.
-
messageToRecipient
final Optional<String> messageToRecipient()
The message that will show on the recipient's bank statement.
-
network
final WireTransfer.Network network()
The transfer's network.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The originator's address line 1.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The originator's address line 2.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The originator's address line 3.
-
originatorName
final Optional<String> originatorName()
The originator's name.
-
pendingTransactionId
final Optional<String> pendingTransactionId()
The ID for the pending transaction representing the transfer. A pending transaction is created when the transfer requires approval by someone else in your organization.
-
reversal
final Optional<WireTransfer.Reversal> reversal()
If your transfer is reversed, this will contain details of the reversal.
-
routingNumber
final String routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN).
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The Account Number that was passed to the wire's recipient.
-
status
final WireTransfer.Status status()
The lifecycle status of the transfer.
-
submission
final Optional<WireTransfer.Submission> submission()
After the transfer is submitted to Fedwire, this will contain supplemental details.
-
transactionId
final Optional<String> transactionId()
The ID for the transaction funding the transfer.
-
type
final WireTransfer.Type type()
A constant representing the object's type. For this resource it will always be
wire_transfer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_approval
final JsonField<WireTransfer.Approval> _approval()
Returns the raw JSON value of approval.
Unlike approval, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_cancellation
final JsonField<WireTransfer.Cancellation> _cancellation()
Returns the raw JSON value of cancellation.
Unlike cancellation, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<WireTransfer.CreatedBy> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_currency
final JsonField<WireTransfer.Currency> _currency()
Returns the raw JSON value of currency.
Unlike currency, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_idempotencyKey
final JsonField<String> _idempotencyKey()
Returns the raw JSON value of idempotencyKey.
Unlike idempotencyKey, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireDrawdownRequestId
final JsonField<String> _inboundWireDrawdownRequestId()
Returns the raw JSON value of inboundWireDrawdownRequestId.
Unlike inboundWireDrawdownRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_network
final JsonField<WireTransfer.Network> _network()
Returns the raw JSON value of network.
Unlike network, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingTransactionId
final JsonField<String> _pendingTransactionId()
Returns the raw JSON value of pendingTransactionId.
Unlike pendingTransactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_reversal
final JsonField<WireTransfer.Reversal> _reversal()
Returns the raw JSON value of reversal.
Unlike reversal, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<WireTransfer.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_submission
final JsonField<WireTransfer.Submission> _submission()
Returns the raw JSON value of submission.
Unlike submission, this method doesn't throw if the JSON field has an unexpected type.
-
_transactionId
final JsonField<String> _transactionId()
Returns the raw JSON value of transactionId.
Unlike transactionId, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<WireTransfer.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Builder toBuilder()
-
validate
final WireTransfer validate()
-
builder
final static WireTransfer.Builder builder()
Returns a mutable builder for constructing an instance of WireTransfer.
The following fields are required:
.id() .accountId() .accountNumber() .amount() .approval() .beneficiaryAddressLine1() .beneficiaryAddressLine2() .beneficiaryAddressLine3() .beneficiaryName() .cancellation() .createdAt() .createdBy() .currency() .externalAccountId() .idempotencyKey() .inboundWireDrawdownRequestId() .messageToRecipient() .network() .originatorAddressLine1() .originatorAddressLine2() .originatorAddressLine3() .originatorName() .pendingTransactionId() .reversal() .routingNumber() .sourceAccountNumberId() .status() .submission() .transactionId() .type()
-
-
-
-