Class WireTransfer.Debtor
-
- All Implemented Interfaces:
public final class WireTransfer.DebtorThe person or business whose funds are being transferred.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Debtor.BuilderA builder for Debtor.
public final classWireTransfer.Debtor.AddressThe person or business's address.
-
Method Summary
Modifier and Type Method Description final Optional<WireTransfer.Debtor.Address>address()The person or business's address. final Optional<String>name()The person or business's name. final JsonField<WireTransfer.Debtor.Address>_address()Returns the raw JSON value of address. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Debtor.BuildertoBuilder()final WireTransfer.Debtorvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Debtor.Builderbuilder()Returns a mutable builder for constructing an instance of Debtor. -
-
Method Detail
-
address
final Optional<WireTransfer.Debtor.Address> address()
The person or business's address.
-
_address
final JsonField<WireTransfer.Debtor.Address> _address()
Returns the raw JSON value of address.
Unlike address, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Debtor.Builder toBuilder()
-
validate
final WireTransfer.Debtor validate()
-
builder
final static WireTransfer.Debtor.Builder builder()
Returns a mutable builder for constructing an instance of Debtor.
The following fields are required:
.address() .name()
-
-
-
-