Class WireTransfer.Debtor.Address
-
- All Implemented Interfaces:
public final class WireTransfer.Debtor.AddressThe person or business's address.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Debtor.Address.BuilderA builder for Address.
public final classWireTransfer.Debtor.Address.UnstructuredUnstructured address lines.
-
Method Summary
Modifier and Type Method Description final Optional<WireTransfer.Debtor.Address.Unstructured>unstructured()Unstructured address lines. final JsonField<WireTransfer.Debtor.Address.Unstructured>_unstructured()Returns the raw JSON value of unstructured. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Debtor.Address.BuildertoBuilder()final WireTransfer.Debtor.Addressvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Debtor.Address.Builderbuilder()Returns a mutable builder for constructing an instance of Address. -
-
Method Detail
-
unstructured
final Optional<WireTransfer.Debtor.Address.Unstructured> unstructured()
Unstructured address lines.
-
_unstructured
final JsonField<WireTransfer.Debtor.Address.Unstructured> _unstructured()
Returns the raw JSON value of unstructured.
Unlike unstructured, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Debtor.Address.Builder toBuilder()
-
validate
final WireTransfer.Debtor.Address validate()
-
builder
final static WireTransfer.Debtor.Address.Builder builder()
Returns a mutable builder for constructing an instance of Address.
The following fields are required:
.unstructured()
-
-
-
-