Class WireTransfer.Debtor.Address.Unstructured
-
- All Implemented Interfaces:
public final class WireTransfer.Debtor.Address.UnstructuredUnstructured address lines.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Debtor.Address.Unstructured.BuilderA builder for Unstructured.
-
Method Summary
Modifier and Type Method Description final Optional<String>line1()The first line. final Optional<String>line2()The second line. final Optional<String>line3()The third line. final JsonField<String>_line1()Returns the raw JSON value of line1. final JsonField<String>_line2()Returns the raw JSON value of line2. final JsonField<String>_line3()Returns the raw JSON value of line3. final Map<String, JsonValue>_additionalProperties()final WireTransfer.Debtor.Address.Unstructured.BuildertoBuilder()final WireTransfer.Debtor.Address.Unstructuredvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransfer.Debtor.Address.Unstructured.Builderbuilder()Returns a mutable builder for constructing an instance of Unstructured. -
-
Method Detail
-
_line1
final JsonField<String> _line1()
Returns the raw JSON value of line1.
Unlike line1, this method doesn't throw if the JSON field has an unexpected type.
-
_line2
final JsonField<String> _line2()
Returns the raw JSON value of line2.
Unlike line2, this method doesn't throw if the JSON field has an unexpected type.
-
_line3
final JsonField<String> _line3()
Returns the raw JSON value of line3.
Unlike line3, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Debtor.Address.Unstructured.Builder toBuilder()
-
validate
final WireTransfer.Debtor.Address.Unstructured validate()
-
builder
final static WireTransfer.Debtor.Address.Unstructured.Builder builder()
Returns a mutable builder for constructing an instance of Unstructured.
The following fields are required:
.line1() .line2() .line3()
-
-
-
-