Class WireTransfer.Remittance
-
- All Implemented Interfaces:
public final class WireTransfer.RemittanceRemittance information sent with the wire transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransfer.Remittance.BuilderA builder for Remittance.
public final classWireTransfer.Remittance.CategoryThe type of remittance information being passed.
public final classWireTransfer.Remittance.TaxInternal Revenue Service (IRS) tax repayment information. Required if
categoryis equal totax.public final classWireTransfer.Remittance.UnstructuredUnstructured remittance information. Required if
categoryis equal tounstructured.
-
Method Summary
-
-
Method Detail
-
category
final WireTransfer.Remittance.Category category()
The type of remittance information being passed.
-
tax
final Optional<WireTransfer.Remittance.Tax> tax()
Internal Revenue Service (IRS) tax repayment information. Required if
categoryis equal totax.
-
unstructured
final Optional<WireTransfer.Remittance.Unstructured> unstructured()
Unstructured remittance information. Required if
categoryis equal tounstructured.
-
_category
final JsonField<WireTransfer.Remittance.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_tax
final JsonField<WireTransfer.Remittance.Tax> _tax()
Returns the raw JSON value of tax.
Unlike tax, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructured
final JsonField<WireTransfer.Remittance.Unstructured> _unstructured()
Returns the raw JSON value of unstructured.
Unlike unstructured, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransfer.Remittance.Builder toBuilder()
-
validate
final WireTransfer.Remittance validate()
-
builder
final static WireTransfer.Remittance.Builder builder()
Returns a mutable builder for constructing an instance of Remittance.
The following fields are required:
.category()
-
-
-
-