Class WireTransferCreateParams.Body
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringaccountId()The identifier for the account that will send the transfer. final Longamount()The transfer amount in USD cents. final StringbeneficiaryName()The beneficiary's name. final StringmessageToRecipient()The message that will show on the recipient's bank statement. final Optional<String>accountNumber()The account number for the destination account. final Optional<String>beneficiaryAddressLine1()The beneficiary's address line 1. final Optional<String>beneficiaryAddressLine2()The beneficiary's address line 2. final Optional<String>beneficiaryAddressLine3()The beneficiary's address line 3. final Optional<String>externalAccountId()The ID of an External Account to initiate a transfer to. final Optional<String>inboundWireDrawdownRequestId()The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent. final Optional<String>originatorAddressLine1()The originator's address line 1. final Optional<String>originatorAddressLine2()The originator's address line 2. final Optional<String>originatorAddressLine3()The originator's address line 3. final Optional<String>originatorName()The originator's name. final Optional<Boolean>requireApproval()Whether the transfer requires explicit approval via the dashboard or API. final Optional<String>routingNumber()The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account. final Optional<String>sourceAccountNumberId()The ID of an Account Number that will be passed to the wire's recipient final JsonField<String>_accountId()Returns the raw JSON value of accountId. final JsonField<Long>_amount()Returns the raw JSON value of amount. final JsonField<String>_beneficiaryName()Returns the raw JSON value of beneficiaryName. final JsonField<String>_messageToRecipient()Returns the raw JSON value of messageToRecipient. final JsonField<String>_accountNumber()Returns the raw JSON value of accountNumber. final JsonField<String>_beneficiaryAddressLine1()Returns the raw JSON value of beneficiaryAddressLine1. final JsonField<String>_beneficiaryAddressLine2()Returns the raw JSON value of beneficiaryAddressLine2. final JsonField<String>_beneficiaryAddressLine3()Returns the raw JSON value of beneficiaryAddressLine3. final JsonField<String>_externalAccountId()Returns the raw JSON value of externalAccountId. final JsonField<String>_inboundWireDrawdownRequestId()Returns the raw JSON value of inboundWireDrawdownRequestId. final JsonField<String>_originatorAddressLine1()Returns the raw JSON value of originatorAddressLine1. final JsonField<String>_originatorAddressLine2()Returns the raw JSON value of originatorAddressLine2. final JsonField<String>_originatorAddressLine3()Returns the raw JSON value of originatorAddressLine3. final JsonField<String>_originatorName()Returns the raw JSON value of originatorName. final JsonField<Boolean>_requireApproval()Returns the raw JSON value of requireApproval. final JsonField<String>_routingNumber()Returns the raw JSON value of routingNumber. final JsonField<String>_sourceAccountNumberId()Returns the raw JSON value of sourceAccountNumberId. final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Body.BuildertoBuilder()final WireTransferCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
beneficiaryName
final String beneficiaryName()
The beneficiary's name.
-
messageToRecipient
final String messageToRecipient()
The message that will show on the recipient's bank statement.
-
accountNumber
final Optional<String> accountNumber()
The account number for the destination account.
-
beneficiaryAddressLine1
final Optional<String> beneficiaryAddressLine1()
The beneficiary's address line 1.
-
beneficiaryAddressLine2
final Optional<String> beneficiaryAddressLine2()
The beneficiary's address line 2.
-
beneficiaryAddressLine3
final Optional<String> beneficiaryAddressLine3()
The beneficiary's address line 3.
-
externalAccountId
final Optional<String> externalAccountId()
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
inboundWireDrawdownRequestId
final Optional<String> inboundWireDrawdownRequestId()
The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent.
-
originatorAddressLine1
final Optional<String> originatorAddressLine1()
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final Optional<String> originatorAddressLine2()
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final Optional<String> originatorAddressLine3()
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final Optional<String> originatorName()
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
requireApproval
final Optional<Boolean> requireApproval()
Whether the transfer requires explicit approval via the dashboard or API.
-
routingNumber
final Optional<String> routingNumber()
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
sourceAccountNumberId
final Optional<String> sourceAccountNumberId()
The ID of an Account Number that will be passed to the wire's recipient
-
_accountId
final JsonField<String> _accountId()
Returns the raw JSON value of accountId.
Unlike accountId, this method doesn't throw if the JSON field has an unexpected type.
-
_amount
final JsonField<Long> _amount()
Returns the raw JSON value of amount.
Unlike amount, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryName
final JsonField<String> _beneficiaryName()
Returns the raw JSON value of beneficiaryName.
Unlike beneficiaryName, this method doesn't throw if the JSON field has an unexpected type.
-
_messageToRecipient
final JsonField<String> _messageToRecipient()
Returns the raw JSON value of messageToRecipient.
Unlike messageToRecipient, this method doesn't throw if the JSON field has an unexpected type.
-
_accountNumber
final JsonField<String> _accountNumber()
Returns the raw JSON value of accountNumber.
Unlike accountNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine1
final JsonField<String> _beneficiaryAddressLine1()
Returns the raw JSON value of beneficiaryAddressLine1.
Unlike beneficiaryAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine2
final JsonField<String> _beneficiaryAddressLine2()
Returns the raw JSON value of beneficiaryAddressLine2.
Unlike beneficiaryAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_beneficiaryAddressLine3
final JsonField<String> _beneficiaryAddressLine3()
Returns the raw JSON value of beneficiaryAddressLine3.
Unlike beneficiaryAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_externalAccountId
final JsonField<String> _externalAccountId()
Returns the raw JSON value of externalAccountId.
Unlike externalAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_inboundWireDrawdownRequestId
final JsonField<String> _inboundWireDrawdownRequestId()
Returns the raw JSON value of inboundWireDrawdownRequestId.
Unlike inboundWireDrawdownRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine1
final JsonField<String> _originatorAddressLine1()
Returns the raw JSON value of originatorAddressLine1.
Unlike originatorAddressLine1, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine2
final JsonField<String> _originatorAddressLine2()
Returns the raw JSON value of originatorAddressLine2.
Unlike originatorAddressLine2, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorAddressLine3
final JsonField<String> _originatorAddressLine3()
Returns the raw JSON value of originatorAddressLine3.
Unlike originatorAddressLine3, this method doesn't throw if the JSON field has an unexpected type.
-
_originatorName
final JsonField<String> _originatorName()
Returns the raw JSON value of originatorName.
Unlike originatorName, this method doesn't throw if the JSON field has an unexpected type.
-
_requireApproval
final JsonField<Boolean> _requireApproval()
Returns the raw JSON value of requireApproval.
Unlike requireApproval, this method doesn't throw if the JSON field has an unexpected type.
-
_routingNumber
final JsonField<String> _routingNumber()
Returns the raw JSON value of routingNumber.
Unlike routingNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceAccountNumberId
final JsonField<String> _sourceAccountNumberId()
Returns the raw JSON value of sourceAccountNumberId.
Unlike sourceAccountNumberId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Body.Builder toBuilder()
-
validate
final WireTransferCreateParams.Body validate()
-
builder
final static WireTransferCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.accountId() .amount() .beneficiaryName() .messageToRecipient()
-
-
-
-