Class WireTransferCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
accountId
final WireTransferCreateParams.Body.Builder accountId(String accountId)
The identifier for the account that will send the transfer.
-
accountId
final WireTransferCreateParams.Body.Builder accountId(JsonField<String> accountId)
Sets Builder.accountId to an arbitrary JSON value.
You should usually call Builder.accountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
amount
final WireTransferCreateParams.Body.Builder amount(Long amount)
The transfer amount in USD cents.
-
amount
final WireTransferCreateParams.Body.Builder amount(JsonField<Long> amount)
Sets Builder.amount to an arbitrary JSON value.
You should usually call Builder.amount with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryName
final WireTransferCreateParams.Body.Builder beneficiaryName(String beneficiaryName)
The beneficiary's name.
-
beneficiaryName
final WireTransferCreateParams.Body.Builder beneficiaryName(JsonField<String> beneficiaryName)
Sets Builder.beneficiaryName to an arbitrary JSON value.
You should usually call Builder.beneficiaryName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
accountNumber
final WireTransferCreateParams.Body.Builder accountNumber(String accountNumber)
The account number for the destination account.
-
accountNumber
final WireTransferCreateParams.Body.Builder accountNumber(JsonField<String> accountNumber)
Sets Builder.accountNumber to an arbitrary JSON value.
You should usually call Builder.accountNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine1
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine1(String beneficiaryAddressLine1)
The beneficiary's address line 1.
-
beneficiaryAddressLine1
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine1(JsonField<String> beneficiaryAddressLine1)
Sets Builder.beneficiaryAddressLine1 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine2
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine2(String beneficiaryAddressLine2)
The beneficiary's address line 2.
-
beneficiaryAddressLine2
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine2(JsonField<String> beneficiaryAddressLine2)
Sets Builder.beneficiaryAddressLine2 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
beneficiaryAddressLine3
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine3(String beneficiaryAddressLine3)
The beneficiary's address line 3.
-
beneficiaryAddressLine3
final WireTransferCreateParams.Body.Builder beneficiaryAddressLine3(JsonField<String> beneficiaryAddressLine3)
Sets Builder.beneficiaryAddressLine3 to an arbitrary JSON value.
You should usually call Builder.beneficiaryAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
externalAccountId
final WireTransferCreateParams.Body.Builder externalAccountId(String externalAccountId)
The ID of an External Account to initiate a transfer to. If this parameter is provided,
account_numberandrouting_numbermust be absent.
-
externalAccountId
final WireTransferCreateParams.Body.Builder externalAccountId(JsonField<String> externalAccountId)
Sets Builder.externalAccountId to an arbitrary JSON value.
You should usually call Builder.externalAccountId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
inboundWireDrawdownRequestId
final WireTransferCreateParams.Body.Builder inboundWireDrawdownRequestId(String inboundWireDrawdownRequestId)
The ID of an Inbound Wire Drawdown Request in response to which this transfer is being sent.
-
inboundWireDrawdownRequestId
final WireTransferCreateParams.Body.Builder inboundWireDrawdownRequestId(JsonField<String> inboundWireDrawdownRequestId)
Sets Builder.inboundWireDrawdownRequestId to an arbitrary JSON value.
You should usually call Builder.inboundWireDrawdownRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine1
final WireTransferCreateParams.Body.Builder originatorAddressLine1(String originatorAddressLine1)
The originator's address line 1. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine1
final WireTransferCreateParams.Body.Builder originatorAddressLine1(JsonField<String> originatorAddressLine1)
Sets Builder.originatorAddressLine1 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine1 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine2
final WireTransferCreateParams.Body.Builder originatorAddressLine2(String originatorAddressLine2)
The originator's address line 2. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine2
final WireTransferCreateParams.Body.Builder originatorAddressLine2(JsonField<String> originatorAddressLine2)
Sets Builder.originatorAddressLine2 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine2 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorAddressLine3
final WireTransferCreateParams.Body.Builder originatorAddressLine3(String originatorAddressLine3)
The originator's address line 3. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorAddressLine3
final WireTransferCreateParams.Body.Builder originatorAddressLine3(JsonField<String> originatorAddressLine3)
Sets Builder.originatorAddressLine3 to an arbitrary JSON value.
You should usually call Builder.originatorAddressLine3 with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
originatorName
final WireTransferCreateParams.Body.Builder originatorName(String originatorName)
The originator's name. This is only necessary if you're transferring from a commingled account. Otherwise, we'll use the associated entity's details.
-
originatorName
final WireTransferCreateParams.Body.Builder originatorName(JsonField<String> originatorName)
Sets Builder.originatorName to an arbitrary JSON value.
You should usually call Builder.originatorName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
remittance
final WireTransferCreateParams.Body.Builder remittance(WireTransferCreateParams.Remittance remittance)
Additional remittance information related to the wire transfer.
-
remittance
final WireTransferCreateParams.Body.Builder remittance(JsonField<WireTransferCreateParams.Remittance> remittance)
Sets Builder.remittance to an arbitrary JSON value.
You should usually call Builder.remittance with a well-typed Remittance value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requireApproval
final WireTransferCreateParams.Body.Builder requireApproval(Boolean requireApproval)
Whether the transfer requires explicit approval via the dashboard or API.
-
requireApproval
final WireTransferCreateParams.Body.Builder requireApproval(JsonField<Boolean> requireApproval)
Sets Builder.requireApproval to an arbitrary JSON value.
You should usually call Builder.requireApproval with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
routingNumber
final WireTransferCreateParams.Body.Builder routingNumber(String routingNumber)
The American Bankers' Association (ABA) Routing Transit Number (RTN) for the destination account.
-
routingNumber
final WireTransferCreateParams.Body.Builder routingNumber(JsonField<String> routingNumber)
Sets Builder.routingNumber to an arbitrary JSON value.
You should usually call Builder.routingNumber with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceAccountNumberId
final WireTransferCreateParams.Body.Builder sourceAccountNumberId(String sourceAccountNumberId)
The ID of an Account Number that will be passed to the wire's recipient
-
sourceAccountNumberId
final WireTransferCreateParams.Body.Builder sourceAccountNumberId(JsonField<String> sourceAccountNumberId)
Sets Builder.sourceAccountNumberId to an arbitrary JSON value.
You should usually call Builder.sourceAccountNumberId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final WireTransferCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final WireTransferCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final WireTransferCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final WireTransferCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final WireTransferCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final WireTransferCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.accountId() .amount() .beneficiaryName()
-
-
-
-