Class WireTransferCreateParams.Remittance
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.RemittanceAdditional remittance information related to the wire transfer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Remittance.BuilderA builder for Remittance.
public final classWireTransferCreateParams.Remittance.CategoryThe type of remittance information being passed.
public final classWireTransferCreateParams.Remittance.TaxInternal Revenue Service (IRS) tax repayment information. Required if
categoryis equal totax.public final classWireTransferCreateParams.Remittance.UnstructuredUnstructured remittance information. Required if
categoryis equal tounstructured.
-
Method Summary
-
-
Method Detail
-
category
final WireTransferCreateParams.Remittance.Category category()
The type of remittance information being passed.
-
tax
final Optional<WireTransferCreateParams.Remittance.Tax> tax()
Internal Revenue Service (IRS) tax repayment information. Required if
categoryis equal totax.
-
unstructured
final Optional<WireTransferCreateParams.Remittance.Unstructured> unstructured()
Unstructured remittance information. Required if
categoryis equal tounstructured.
-
_category
final JsonField<WireTransferCreateParams.Remittance.Category> _category()
Returns the raw JSON value of category.
Unlike category, this method doesn't throw if the JSON field has an unexpected type.
-
_tax
final JsonField<WireTransferCreateParams.Remittance.Tax> _tax()
Returns the raw JSON value of tax.
Unlike tax, this method doesn't throw if the JSON field has an unexpected type.
-
_unstructured
final JsonField<WireTransferCreateParams.Remittance.Unstructured> _unstructured()
Returns the raw JSON value of unstructured.
Unlike unstructured, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Remittance.Builder toBuilder()
-
validate
final WireTransferCreateParams.Remittance validate()
-
builder
final static WireTransferCreateParams.Remittance.Builder builder()
Returns a mutable builder for constructing an instance of Remittance.
The following fields are required:
.category()
-
-
-
-