Class WireTransferCreateParams.Remittance.Tax
-
- All Implemented Interfaces:
public final class WireTransferCreateParams.Remittance.TaxInternal Revenue Service (IRS) tax repayment information. Required if
categoryis equal totax.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferCreateParams.Remittance.Tax.BuilderA builder for Tax.
-
Method Summary
Modifier and Type Method Description final LocalDatedate()The month and year the tax payment is for, in YYYY-MM-DD format. final StringidentificationNumber()The 9-digit Tax Identification Number (TIN) or Employer Identification Number (EIN). final StringtypeCode()The 5-character tax type code. final JsonField<LocalDate>_date()Returns the raw JSON value of date. final JsonField<String>_identificationNumber()Returns the raw JSON value of identificationNumber. final JsonField<String>_typeCode()Returns the raw JSON value of typeCode. final Map<String, JsonValue>_additionalProperties()final WireTransferCreateParams.Remittance.Tax.BuildertoBuilder()final WireTransferCreateParams.Remittance.Taxvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferCreateParams.Remittance.Tax.Builderbuilder()Returns a mutable builder for constructing an instance of Tax. -
-
Method Detail
-
date
final LocalDate date()
The month and year the tax payment is for, in YYYY-MM-DD format. The day is ignored.
-
identificationNumber
final String identificationNumber()
The 9-digit Tax Identification Number (TIN) or Employer Identification Number (EIN).
-
_date
final JsonField<LocalDate> _date()
Returns the raw JSON value of date.
Unlike date, this method doesn't throw if the JSON field has an unexpected type.
-
_identificationNumber
final JsonField<String> _identificationNumber()
Returns the raw JSON value of identificationNumber.
Unlike identificationNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_typeCode
final JsonField<String> _typeCode()
Returns the raw JSON value of typeCode.
Unlike typeCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferCreateParams.Remittance.Tax.Builder toBuilder()
-
validate
final WireTransferCreateParams.Remittance.Tax validate()
-
builder
final static WireTransferCreateParams.Remittance.Tax.Builder builder()
Returns a mutable builder for constructing an instance of Tax.
The following fields are required:
.date() .identificationNumber() .typeCode()
-
-
-
-