Class WireTransferListPageAsync
-
- All Implemented Interfaces:
public final class WireTransferListPageAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferListPageAsync.BuilderA builder for WireTransferListPageAsync.
public final classWireTransferListPageAsync.AutoPager
-
Method Summary
Modifier and Type Method Description final List<WireTransfer>data()Delegates to WireTransferListPageResponse, but gracefully handles missing data. final Optional<String>nextCursor()Delegates to WireTransferListPageResponse, but gracefully handles missing data. final BooleanhasNextPage()final Optional<WireTransferListParams>getNextPageParams()final CompletableFuture<Optional<WireTransferListPageAsync>>getNextPage()final WireTransferListPageAsync.AutoPagerautoPager()final WireTransferListParamsparams()The parameters that were used to request this page. final WireTransferListPageResponseresponse()The response that this page was parsed from. final WireTransferListPageAsync.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferListPageAsync.Builderbuilder()Returns a mutable builder for constructing an instance of WireTransferListPageAsync. -
-
Method Detail
-
data
final List<WireTransfer> data()
Delegates to WireTransferListPageResponse, but gracefully handles missing data.
-
nextCursor
final Optional<String> nextCursor()
Delegates to WireTransferListPageResponse, but gracefully handles missing data.
-
hasNextPage
final Boolean hasNextPage()
-
getNextPageParams
final Optional<WireTransferListParams> getNextPageParams()
-
getNextPage
final CompletableFuture<Optional<WireTransferListPageAsync>> getNextPage()
-
autoPager
final WireTransferListPageAsync.AutoPager autoPager()
-
params
final WireTransferListParams params()
The parameters that were used to request this page.
-
response
final WireTransferListPageResponse response()
The response that this page was parsed from.
-
toBuilder
final WireTransferListPageAsync.Builder toBuilder()
-
builder
final static WireTransferListPageAsync.Builder builder()
Returns a mutable builder for constructing an instance of WireTransferListPageAsync.
The following fields are required:
.service() .params() .response()
-
-
-
-