Class WireTransferListPageResponse
-
- All Implemented Interfaces:
public final class WireTransferListPageResponseA list of Wire Transfer objects.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferListPageResponse.BuilderA builder for WireTransferListPageResponse.
-
Method Summary
Modifier and Type Method Description final List<WireTransfer>data()The contents of the list. final Optional<String>nextCursor()A pointer to a place in the list. final JsonField<List<WireTransfer>>_data()Returns the raw JSON value of data. final JsonField<String>_nextCursor()Returns the raw JSON value of nextCursor. final Map<String, JsonValue>_additionalProperties()final WireTransferListPageResponse.BuildertoBuilder()final WireTransferListPageResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WireTransferListPageResponse.Builderbuilder()Returns a mutable builder for constructing an instance of WireTransferListPageResponse. -
-
Method Detail
-
data
final List<WireTransfer> data()
The contents of the list.
-
nextCursor
final Optional<String> nextCursor()
A pointer to a place in the list.
-
_data
final JsonField<List<WireTransfer>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_nextCursor
final JsonField<String> _nextCursor()
Returns the raw JSON value of nextCursor.
Unlike nextCursor, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WireTransferListPageResponse.Builder toBuilder()
-
validate
final WireTransferListPageResponse validate()
-
builder
final static WireTransferListPageResponse.Builder builder()
Returns a mutable builder for constructing an instance of WireTransferListPageResponse.
The following fields are required:
.data() .nextCursor()
-
-
-
-