Package com.increase.api.services.async
Class AccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AccountServiceAsync
public final class AccountServiceAsyncImpl implements AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Account>create(AccountCreateParams params, RequestOptions requestOptions)Create an Account CompletableFuture<Account>retrieve(AccountRetrieveParams params, RequestOptions requestOptions)Retrieve an Account CompletableFuture<Account>update(AccountUpdateParams params, RequestOptions requestOptions)Update an Account CompletableFuture<AccountListPageAsync>list(AccountListParams params, RequestOptions requestOptions)List Accounts CompletableFuture<BalanceLookup>balance(AccountBalanceParams params, RequestOptions requestOptions)Retrieve the current and available balances for an account in minor units of the account's currency. CompletableFuture<Account>close(AccountCloseParams params, RequestOptions requestOptions)Close an Account -
-
Method Detail
-
withRawResponse
AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Account> create(AccountCreateParams params, RequestOptions requestOptions)
Create an Account
-
retrieve
CompletableFuture<Account> retrieve(AccountRetrieveParams params, RequestOptions requestOptions)
Retrieve an Account
-
update
CompletableFuture<Account> update(AccountUpdateParams params, RequestOptions requestOptions)
Update an Account
-
list
CompletableFuture<AccountListPageAsync> list(AccountListParams params, RequestOptions requestOptions)
List Accounts
-
balance
CompletableFuture<BalanceLookup> balance(AccountBalanceParams params, RequestOptions requestOptions)
Retrieve the current and available balances for an account in minor units of the account's currency. Learn more about /documentation/balance.
-
close
CompletableFuture<Account> close(AccountCloseParams params, RequestOptions requestOptions)
Close an Account
-
-
-
-