Package com.increase.api.services.async
Interface AccountStatementServiceAsync
-
- All Implemented Interfaces:
public interface AccountStatementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountStatementServiceAsync.WithRawResponseA view of AccountStatementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountStatementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AccountStatement>retrieve(AccountStatementRetrieveParams params)Retrieve an Account Statement abstract CompletableFuture<AccountStatement>retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)CompletableFuture<AccountStatementListPageAsync>list()List Account Statements abstract CompletableFuture<AccountStatementListPageAsync>list(AccountStatementListParams params, RequestOptions requestOptions)CompletableFuture<AccountStatementListPageAsync>list(AccountStatementListParams params)CompletableFuture<AccountStatementListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountStatementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<AccountStatement> retrieve(AccountStatementRetrieveParams params)
Retrieve an Account Statement
-
retrieve
abstract CompletableFuture<AccountStatement> retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountStatementListPageAsync> list()
List Account Statements
-
list
abstract CompletableFuture<AccountStatementListPageAsync> list(AccountStatementListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AccountStatementListPageAsync> list(RequestOptions requestOptions)
-
-
-
-