Package com.increase.api.services.async
Class AchPrenotificationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.AchPrenotificationServiceAsync
public final class AchPrenotificationServiceAsyncImpl implements AchPrenotificationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotificationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchPrenotificationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AchPrenotification>create(AchPrenotificationCreateParams params, RequestOptions requestOptions)CompletableFuture<AchPrenotification>retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<AchPrenotificationListPageAsync>list(AchPrenotificationListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AchPrenotificationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<AchPrenotification> create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<AchPrenotification> retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<AchPrenotificationListPageAsync> list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
-
-
-