Package com.increase.api.services.async
Class BookkeepingAccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingAccountServiceAsync
public final class BookkeepingAccountServiceAsyncImpl implements BookkeepingAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingAccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<BookkeepingAccount>create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingAccount>update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingAccountListPageAsync>list(BookkeepingAccountListParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingBalanceLookup>balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BookkeepingAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<BookkeepingAccount> create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<BookkeepingAccount> update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingAccountListPageAsync> list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
-
-
-