Package com.increase.api.services.async
Class BookkeepingAccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingAccountServiceAsync
public final class BookkeepingAccountServiceAsyncImpl implements BookkeepingAccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingAccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<BookkeepingAccount>create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)Create a Bookkeeping Account CompletableFuture<BookkeepingAccount>update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)Update a Bookkeeping Account CompletableFuture<BookkeepingAccountListPageAsync>list(BookkeepingAccountListParams params, RequestOptions requestOptions)List Bookkeeping Accounts CompletableFuture<BookkeepingBalanceLookup>balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)Retrieve a Bookkeeping Account Balance -
-
Method Detail
-
withRawResponse
BookkeepingAccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<BookkeepingAccount> create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
Create a Bookkeeping Account
-
update
CompletableFuture<BookkeepingAccount> update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
Update a Bookkeeping Account
-
list
CompletableFuture<BookkeepingAccountListPageAsync> list(BookkeepingAccountListParams params, RequestOptions requestOptions)
List Bookkeeping Accounts
-
balance
CompletableFuture<BookkeepingBalanceLookup> balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
Retrieve a Bookkeeping Account Balance
-
-
-
-