Package com.increase.api.services.async
Interface BookkeepingEntryServiceAsync
-
- All Implemented Interfaces:
public interface BookkeepingEntryServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingEntryServiceAsync.WithRawResponseA view of BookkeepingEntryServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BookkeepingEntryServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<BookkeepingEntry>retrieve(BookkeepingEntryRetrieveParams params)Retrieve a Bookkeeping Entry abstract CompletableFuture<BookkeepingEntry>retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingEntryListPageAsync>list()List Bookkeeping Entries abstract CompletableFuture<BookkeepingEntryListPageAsync>list(BookkeepingEntryListParams params, RequestOptions requestOptions)CompletableFuture<BookkeepingEntryListPageAsync>list(BookkeepingEntryListParams params)CompletableFuture<BookkeepingEntryListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BookkeepingEntryServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<BookkeepingEntry> retrieve(BookkeepingEntryRetrieveParams params)
Retrieve a Bookkeeping Entry
-
retrieve
abstract CompletableFuture<BookkeepingEntry> retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntryListPageAsync> list()
List Bookkeeping Entries
-
list
abstract CompletableFuture<BookkeepingEntryListPageAsync> list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<BookkeepingEntryListPageAsync> list(RequestOptions requestOptions)
-
-
-
-