Package com.increase.api.services.async
Class BookkeepingEntrySetServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.BookkeepingEntrySetServiceAsync
public final class BookkeepingEntrySetServiceAsyncImpl implements BookkeepingEntrySetServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingEntrySetServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<BookkeepingEntrySet>create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)Create a Bookkeeping Entry Set CompletableFuture<BookkeepingEntrySet>retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)Retrieve a Bookkeeping Entry Set CompletableFuture<BookkeepingEntrySetListPageAsync>list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)List Bookkeeping Entry Sets -
-
Method Detail
-
withRawResponse
BookkeepingEntrySetServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<BookkeepingEntrySet> create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
Create a Bookkeeping Entry Set
-
retrieve
CompletableFuture<BookkeepingEntrySet> retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
Retrieve a Bookkeeping Entry Set
-
list
CompletableFuture<BookkeepingEntrySetListPageAsync> list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
List Bookkeeping Entry Sets
-
-
-
-