Package com.increase.api.services.async
Interface CardPaymentServiceAsync
-
- All Implemented Interfaces:
public interface CardPaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPaymentServiceAsync.WithRawResponseA view of CardPaymentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardPaymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CardPayment>retrieve(CardPaymentRetrieveParams params)Retrieve a Card Payment abstract CompletableFuture<CardPayment>retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CardPaymentListPageAsync>list()List Card Payments abstract CompletableFuture<CardPaymentListPageAsync>list(CardPaymentListParams params, RequestOptions requestOptions)CompletableFuture<CardPaymentListPageAsync>list(CardPaymentListParams params)CompletableFuture<CardPaymentListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardPaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<CardPayment> retrieve(CardPaymentRetrieveParams params)
Retrieve a Card Payment
-
retrieve
abstract CompletableFuture<CardPayment> retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPaymentListPageAsync> list()
List Card Payments
-
list
abstract CompletableFuture<CardPaymentListPageAsync> list(CardPaymentListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardPaymentListPageAsync> list(CardPaymentListParams params)
-
list
CompletableFuture<CardPaymentListPageAsync> list(RequestOptions requestOptions)
-
-
-
-