Package com.increase.api.services.async
Class CardPaymentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardPaymentServiceAsync
public final class CardPaymentServiceAsyncImpl implements CardPaymentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPaymentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPaymentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CardPayment>retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)Retrieve a Card Payment CompletableFuture<CardPaymentListPageAsync>list(CardPaymentListParams params, RequestOptions requestOptions)List Card Payments -
-
Method Detail
-
withRawResponse
CardPaymentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<CardPayment> retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
Retrieve a Card Payment
-
list
CompletableFuture<CardPaymentListPageAsync> list(CardPaymentListParams params, RequestOptions requestOptions)
List Card Payments
-
-
-
-