Package com.increase.api.services.async
Class CardServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardServiceAsync
public final class CardServiceAsyncImpl implements CardServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Card>create(CardCreateParams params, RequestOptions requestOptions)CompletableFuture<Card>retrieve(CardRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Card>update(CardUpdateParams params, RequestOptions requestOptions)CompletableFuture<CardListPageAsync>list(CardListParams params, RequestOptions requestOptions)CompletableFuture<CardIframeUrl>createDetailsIframe(CardCreateDetailsIframeParams params, RequestOptions requestOptions)CompletableFuture<CardDetails>details(CardDetailsParams params, RequestOptions requestOptions)-
Methods inherited from class com.increase.api.services.async.CardServiceAsync
create, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, createDetailsIframe, details, details, details, details, details, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CardServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CardServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Card> create(CardCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Card> retrieve(CardRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<Card> update(CardUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CardListPageAsync> list(CardListParams params, RequestOptions requestOptions)
-
createDetailsIframe
CompletableFuture<CardIframeUrl> createDetailsIframe(CardCreateDetailsIframeParams params, RequestOptions requestOptions)
-
details
CompletableFuture<CardDetails> details(CardDetailsParams params, RequestOptions requestOptions)
-
-
-
-