Package com.increase.api.services.async
Class CardServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CardServiceAsync
public final class CardServiceAsyncImpl implements CardServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Card>create(CardCreateParams params, RequestOptions requestOptions)Create a Card CompletableFuture<Card>retrieve(CardRetrieveParams params, RequestOptions requestOptions)Retrieve a Card CompletableFuture<Card>update(CardUpdateParams params, RequestOptions requestOptions)Update a Card CompletableFuture<CardListPageAsync>list(CardListParams params, RequestOptions requestOptions)List Cards CompletableFuture<CardDetails>details(CardDetailsParams params, RequestOptions requestOptions)Retrieve sensitive details for a Card -
-
Method Detail
-
withRawResponse
CardServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Card> create(CardCreateParams params, RequestOptions requestOptions)
Create a Card
-
retrieve
CompletableFuture<Card> retrieve(CardRetrieveParams params, RequestOptions requestOptions)
Retrieve a Card
-
update
CompletableFuture<Card> update(CardUpdateParams params, RequestOptions requestOptions)
Update a Card
-
list
CompletableFuture<CardListPageAsync> list(CardListParams params, RequestOptions requestOptions)
List Cards
-
details
CompletableFuture<CardDetails> details(CardDetailsParams params, RequestOptions requestOptions)
Retrieve sensitive details for a Card
-
-
-
-