Package com.increase.api.services.async
Class CheckTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.CheckTransferServiceAsync
public final class CheckTransferServiceAsyncImpl implements CheckTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CheckTransfer>create(CheckTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<CheckTransferListPageAsync>list(CheckTransferListParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>approve(CheckTransferApproveParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>cancel(CheckTransferCancelParams params, RequestOptions requestOptions)CompletableFuture<CheckTransfer>stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CheckTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<CheckTransfer> create(CheckTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<CheckTransfer> retrieve(CheckTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<CheckTransferListPageAsync> list(CheckTransferListParams params, RequestOptions requestOptions)
-
approve
CompletableFuture<CheckTransfer> approve(CheckTransferApproveParams params, RequestOptions requestOptions)
-
cancel
CompletableFuture<CheckTransfer> cancel(CheckTransferCancelParams params, RequestOptions requestOptions)
-
stopPayment
CompletableFuture<CheckTransfer> stopPayment(CheckTransferStopPaymentParams params, RequestOptions requestOptions)
-
-
-
-