Package com.increase.api.services.async
Class DeclinedTransactionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.DeclinedTransactionServiceAsync
public final class DeclinedTransactionServiceAsyncImpl implements DeclinedTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDeclinedTransactionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DeclinedTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<DeclinedTransaction>retrieve(DeclinedTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<DeclinedTransactionListPageAsync>list(DeclinedTransactionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DeclinedTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<DeclinedTransaction> retrieve(DeclinedTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DeclinedTransactionListPageAsync> list(DeclinedTransactionListParams params, RequestOptions requestOptions)
-
-
-
-