Package com.increase.api.services.async
Class DigitalCardProfileServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.DigitalCardProfileServiceAsync
public final class DigitalCardProfileServiceAsyncImpl implements DigitalCardProfileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigitalCardProfileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigitalCardProfileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<DigitalCardProfile>create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)Create a Digital Card Profile CompletableFuture<DigitalCardProfile>retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)Retrieve a Digital Card Profile CompletableFuture<DigitalCardProfileListPageAsync>list(DigitalCardProfileListParams params, RequestOptions requestOptions)List Card Profiles CompletableFuture<DigitalCardProfile>archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)Archive a Digital Card Profile CompletableFuture<DigitalCardProfile>clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)Clones a Digital Card Profile -
-
Method Detail
-
withRawResponse
DigitalCardProfileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<DigitalCardProfile> create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)
Create a Digital Card Profile
-
retrieve
CompletableFuture<DigitalCardProfile> retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)
Retrieve a Digital Card Profile
-
list
CompletableFuture<DigitalCardProfileListPageAsync> list(DigitalCardProfileListParams params, RequestOptions requestOptions)
List Card Profiles
-
archive
CompletableFuture<DigitalCardProfile> archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)
Archive a Digital Card Profile
-
clone
CompletableFuture<DigitalCardProfile> clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)
Clones a Digital Card Profile
-
-
-
-