Package com.increase.api.services.async
Interface DigitalWalletTokenServiceAsync
-
- All Implemented Interfaces:
public interface DigitalWalletTokenServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalWalletTokenServiceAsync.WithRawResponseA view of DigitalWalletTokenServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<DigitalWalletToken>retrieve(DigitalWalletTokenRetrieveParams params)Retrieve a Digital Wallet Token abstract CompletableFuture<DigitalWalletToken>retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)CompletableFuture<DigitalWalletTokenListPageAsync>list()List Digital Wallet Tokens abstract CompletableFuture<DigitalWalletTokenListPageAsync>list(DigitalWalletTokenListParams params, RequestOptions requestOptions)CompletableFuture<DigitalWalletTokenListPageAsync>list(DigitalWalletTokenListParams params)CompletableFuture<DigitalWalletTokenListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DigitalWalletTokenServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<DigitalWalletToken> retrieve(DigitalWalletTokenRetrieveParams params)
Retrieve a Digital Wallet Token
-
retrieve
abstract CompletableFuture<DigitalWalletToken> retrieve(DigitalWalletTokenRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalWalletTokenListPageAsync> list()
List Digital Wallet Tokens
-
list
abstract CompletableFuture<DigitalWalletTokenListPageAsync> list(DigitalWalletTokenListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DigitalWalletTokenListPageAsync> list(RequestOptions requestOptions)
-
-
-
-