Package com.increase.api.services.async
Interface DocumentServiceAsync
-
- All Implemented Interfaces:
public interface DocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentServiceAsync.WithRawResponseA view of DocumentServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<Document>retrieve(DocumentRetrieveParams params, RequestOptions requestOptions)Retrieve a Document abstract CompletableFuture<Document>retrieve(DocumentRetrieveParams params)Retrieve a Document abstract CompletableFuture<DocumentListPageAsync>list(DocumentListParams params, RequestOptions requestOptions)List Documents abstract CompletableFuture<DocumentListPageAsync>list(DocumentListParams params)List Documents abstract CompletableFuture<DocumentListPageAsync>list()List Documents CompletableFuture<DocumentListPageAsync>list(RequestOptions requestOptions)List Documents -
-
Method Detail
-
withRawResponse
abstract DocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract CompletableFuture<Document> retrieve(DocumentRetrieveParams params, RequestOptions requestOptions)
Retrieve a Document
-
retrieve
abstract CompletableFuture<Document> retrieve(DocumentRetrieveParams params)
Retrieve a Document
-
list
abstract CompletableFuture<DocumentListPageAsync> list(DocumentListParams params, RequestOptions requestOptions)
List Documents
-
list
abstract CompletableFuture<DocumentListPageAsync> list(DocumentListParams params)
List Documents
-
list
abstract CompletableFuture<DocumentListPageAsync> list()
List Documents
-
list
CompletableFuture<DocumentListPageAsync> list(RequestOptions requestOptions)
List Documents
-
-
-
-