Package com.increase.api.services.async
Class DocumentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.DocumentServiceAsync
public final class DocumentServiceAsyncImpl implements DocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDocumentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Document>retrieve(DocumentRetrieveParams params, RequestOptions requestOptions)CompletableFuture<DocumentListPageAsync>list(DocumentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
DocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Document> retrieve(DocumentRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<DocumentListPageAsync> list(DocumentListParams params, RequestOptions requestOptions)
-
-
-
-