Package com.increase.api.services.async
Class EntityServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EntityServiceAsync
public final class EntityServiceAsyncImpl implements EntityServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EntityServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Entity>create(EntityCreateParams params, RequestOptions requestOptions)Create an Entity CompletableFuture<Entity>retrieve(EntityRetrieveParams params, RequestOptions requestOptions)Retrieve an Entity CompletableFuture<EntityListPageAsync>list(EntityListParams params, RequestOptions requestOptions)List Entities CompletableFuture<Entity>archive(EntityArchiveParams params, RequestOptions requestOptions)Archive an Entity CompletableFuture<Entity>archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)Archive a beneficial owner for a corporate Entity CompletableFuture<Entity>confirm(EntityConfirmParams params, RequestOptions requestOptions)Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. CompletableFuture<Entity>createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)Create a beneficial owner for a corporate Entity CompletableFuture<Entity>updateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)Update a Natural Person or Corporation's address CompletableFuture<Entity>updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)Update the address for a beneficial owner belonging to a corporate Entity CompletableFuture<Entity>updateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)Update the industry code for a corporate Entity -
-
Method Detail
-
withRawResponse
EntityServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Entity> create(EntityCreateParams params, RequestOptions requestOptions)
Create an Entity
-
retrieve
CompletableFuture<Entity> retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
Retrieve an Entity
-
list
CompletableFuture<EntityListPageAsync> list(EntityListParams params, RequestOptions requestOptions)
List Entities
-
archive
CompletableFuture<Entity> archive(EntityArchiveParams params, RequestOptions requestOptions)
Archive an Entity
-
archiveBeneficialOwner
CompletableFuture<Entity> archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)
Archive a beneficial owner for a corporate Entity
-
confirm
CompletableFuture<Entity> confirm(EntityConfirmParams params, RequestOptions requestOptions)
Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. After making any required updates, call this endpoint to record that your user confirmed their details.
-
createBeneficialOwner
CompletableFuture<Entity> createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)
Create a beneficial owner for a corporate Entity
-
updateAddress
CompletableFuture<Entity> updateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)
Update a Natural Person or Corporation's address
-
updateBeneficialOwnerAddress
CompletableFuture<Entity> updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)
Update the address for a beneficial owner belonging to a corporate Entity
-
updateIndustryCode
CompletableFuture<Entity> updateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)
Update the industry code for a corporate Entity
-
-
-
-