Package com.increase.api.services.async
Interface EventServiceAsync
-
- All Implemented Interfaces:
public interface EventServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventServiceAsync.WithRawResponseA view of EventServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Event>retrieve(EventRetrieveParams params)Retrieve an Event abstract CompletableFuture<Event>retrieve(EventRetrieveParams params, RequestOptions requestOptions)CompletableFuture<EventListPageAsync>list()List Events abstract CompletableFuture<EventListPageAsync>list(EventListParams params, RequestOptions requestOptions)CompletableFuture<EventListPageAsync>list(EventListParams params)CompletableFuture<EventListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EventServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Event> retrieve(EventRetrieveParams params)
Retrieve an Event
-
retrieve
abstract CompletableFuture<Event> retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventListPageAsync> list()
List Events
-
list
abstract CompletableFuture<EventListPageAsync> list(EventListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventListPageAsync> list(EventListParams params)
-
list
CompletableFuture<EventListPageAsync> list(RequestOptions requestOptions)
-
-
-
-