Package com.increase.api.services.async
Class EventSubscriptionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.EventSubscriptionServiceAsync
public final class EventSubscriptionServiceAsyncImpl implements EventSubscriptionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventSubscriptionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<EventSubscription>create(EventSubscriptionCreateParams params, RequestOptions requestOptions)CompletableFuture<EventSubscription>retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<EventSubscription>update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)CompletableFuture<EventSubscriptionListPageAsync>list(EventSubscriptionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EventSubscriptionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<EventSubscription> create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<EventSubscription> retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<EventSubscription> update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<EventSubscriptionListPageAsync> list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
-
-
-