Package com.increase.api.services.async
Interface ExportServiceAsync
-
- All Implemented Interfaces:
public interface ExportServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportServiceAsync.WithRawResponseA view of ExportServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExportServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Export>create(ExportCreateParams params)Create an Export abstract CompletableFuture<Export>create(ExportCreateParams params, RequestOptions requestOptions)CompletableFuture<Export>retrieve(ExportRetrieveParams params)Retrieve an Export abstract CompletableFuture<Export>retrieve(ExportRetrieveParams params, RequestOptions requestOptions)CompletableFuture<ExportListPageAsync>list()List Exports abstract CompletableFuture<ExportListPageAsync>list(ExportListParams params, RequestOptions requestOptions)CompletableFuture<ExportListPageAsync>list(ExportListParams params)CompletableFuture<ExportListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExportServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Export> create(ExportCreateParams params)
Create an Export
-
create
abstract CompletableFuture<Export> create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Export> retrieve(ExportRetrieveParams params)
Retrieve an Export
-
retrieve
abstract CompletableFuture<Export> retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExportListPageAsync> list()
List Exports
-
list
abstract CompletableFuture<ExportListPageAsync> list(ExportListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ExportListPageAsync> list(ExportListParams params)
-
list
CompletableFuture<ExportListPageAsync> list(RequestOptions requestOptions)
-
-
-
-