Package com.increase.api.services.async
Class ExportServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ExportServiceAsync
public final class ExportServiceAsyncImpl implements ExportServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExportServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ExportServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Export>create(ExportCreateParams params, RequestOptions requestOptions)Create an Export CompletableFuture<Export>retrieve(ExportRetrieveParams params, RequestOptions requestOptions)Retrieve an Export CompletableFuture<ExportListPageAsync>list(ExportListParams params, RequestOptions requestOptions)List Exports -
-
Method Detail
-
withRawResponse
ExportServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Export> create(ExportCreateParams params, RequestOptions requestOptions)
Create an Export
-
retrieve
CompletableFuture<Export> retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
Retrieve an Export
-
list
CompletableFuture<ExportListPageAsync> list(ExportListParams params, RequestOptions requestOptions)
List Exports
-
-
-
-