Package com.increase.api.services.async
Class FileServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.FileServiceAsync
public final class FileServiceAsyncImpl implements FileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<File>create(FileCreateParams params, RequestOptions requestOptions)CompletableFuture<File>retrieve(FileRetrieveParams params, RequestOptions requestOptions)CompletableFuture<FileListPageAsync>list(FileListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<File> create(FileCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<File> retrieve(FileRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<FileListPageAsync> list(FileListParams params, RequestOptions requestOptions)
-
-
-
-