Package com.increase.api.services.async
Class FileServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.FileServiceAsync
public final class FileServiceAsyncImpl implements FileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<File>create(FileCreateParams params, RequestOptions requestOptions)To upload a file to Increase, you'll need to send a request of Content-Type multipart/form-data.CompletableFuture<File>retrieve(FileRetrieveParams params, RequestOptions requestOptions)Retrieve a File CompletableFuture<FileListPageAsync>list(FileListParams params, RequestOptions requestOptions)List Files -
-
Method Detail
-
withRawResponse
FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<File> create(FileCreateParams params, RequestOptions requestOptions)
To upload a file to Increase, you'll need to send a request of Content-Type
multipart/form-data. The request should contain the file you would like to upload, as well as the parameters for creating a file.
-
retrieve
CompletableFuture<File> retrieve(FileRetrieveParams params, RequestOptions requestOptions)
Retrieve a File
-
list
CompletableFuture<FileListPageAsync> list(FileListParams params, RequestOptions requestOptions)
List Files
-
-
-
-