Package com.increase.api.services.async
Interface GroupServiceAsync
-
- All Implemented Interfaces:
public interface GroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupServiceAsync.WithRawResponseA view of GroupServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Group>retrieve()Returns details for the currently authenticated Group. abstract CompletableFuture<Group>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)CompletableFuture<Group>retrieve(GroupRetrieveParams params)CompletableFuture<Group>retrieve(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract GroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Group> retrieve()
Returns details for the currently authenticated Group.
-
retrieve
abstract CompletableFuture<Group> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Group> retrieve(GroupRetrieveParams params)
-
retrieve
CompletableFuture<Group> retrieve(RequestOptions requestOptions)
-
-
-
-