Package com.increase.api.services.async
Interface GroupServiceAsync
-
- All Implemented Interfaces:
public interface GroupServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupServiceAsync.WithRawResponseA view of GroupServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<Group>retrieve(GroupRetrieveParams params, RequestOptions requestOptions)Returns details for the currently authenticated Group. abstract CompletableFuture<Group>retrieve(GroupRetrieveParams params)Returns details for the currently authenticated Group. abstract CompletableFuture<Group>retrieve()Returns details for the currently authenticated Group. CompletableFuture<Group>retrieve(RequestOptions requestOptions)Returns details for the currently authenticated Group. -
-
Method Detail
-
withRawResponse
abstract GroupServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract CompletableFuture<Group> retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
Returns details for the currently authenticated Group.
-
retrieve
abstract CompletableFuture<Group> retrieve(GroupRetrieveParams params)
Returns details for the currently authenticated Group.
-
retrieve
abstract CompletableFuture<Group> retrieve()
Returns details for the currently authenticated Group.
-
retrieve
CompletableFuture<Group> retrieve(RequestOptions requestOptions)
Returns details for the currently authenticated Group.
-
-
-
-