Package com.increase.api.services.async
Interface InboundAchTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundAchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundAchTransferServiceAsync.WithRawResponseA view of InboundAchTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundAchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params)
Retrieve an Inbound ACH Transfer
-
retrieve
abstract CompletableFuture<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundAchTransferListPageAsync> list()
List Inbound ACH Transfers
-
list
abstract CompletableFuture<InboundAchTransferListPageAsync> list(InboundAchTransferListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundAchTransferListPageAsync> list(RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params)
Create a notification of change for an Inbound ACH Transfer
-
createNotificationOfChange
abstract CompletableFuture<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
decline
CompletableFuture<InboundAchTransfer> decline(InboundAchTransferDeclineParams params)
Decline an Inbound ACH Transfer
-
decline
abstract CompletableFuture<InboundAchTransfer> decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
-
transferReturn
CompletableFuture<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params)
Return an Inbound ACH Transfer
-
transferReturn
abstract CompletableFuture<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
-
-
-
-