Package com.increase.api.services.async
Class InboundAchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundAchTransferServiceAsync
public final class InboundAchTransferServiceAsyncImpl implements InboundAchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
-
Method Detail
-
withRawResponse
InboundAchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundAchTransfer> retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
Retrieve an Inbound ACH Transfer
-
list
CompletableFuture<InboundAchTransferListPageAsync> list(InboundAchTransferListParams params, RequestOptions requestOptions)
List Inbound ACH Transfers
-
createNotificationOfChange
CompletableFuture<InboundAchTransfer> createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
Create a notification of change for an Inbound ACH Transfer
-
decline
CompletableFuture<InboundAchTransfer> decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
Decline an Inbound ACH Transfer
-
transferReturn
CompletableFuture<InboundAchTransfer> transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
Return an Inbound ACH Transfer
-
-
-
-