Package com.increase.api.services.async
Interface InboundCheckDepositServiceAsync
-
- All Implemented Interfaces:
public interface InboundCheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundCheckDepositServiceAsync.WithRawResponseA view of InboundCheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundCheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundCheckDeposit> retrieve(InboundCheckDepositRetrieveParams params)
Retrieve an Inbound Check Deposit
-
retrieve
abstract CompletableFuture<InboundCheckDeposit> retrieve(InboundCheckDepositRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundCheckDepositListPageAsync> list()
List Inbound Check Deposits
-
list
abstract CompletableFuture<InboundCheckDepositListPageAsync> list(InboundCheckDepositListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundCheckDepositListPageAsync> list(RequestOptions requestOptions)
-
decline
CompletableFuture<InboundCheckDeposit> decline(InboundCheckDepositDeclineParams params)
Decline an Inbound Check Deposit
-
decline
abstract CompletableFuture<InboundCheckDeposit> decline(InboundCheckDepositDeclineParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<InboundCheckDeposit> return_(InboundCheckDepositReturnParams params)
Return an Inbound Check Deposit
-
return_
abstract CompletableFuture<InboundCheckDeposit> return_(InboundCheckDepositReturnParams params, RequestOptions requestOptions)
-
-
-
-