Package com.increase.api.services.async
Class InboundMailItemServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.InboundMailItemServiceAsync
public final class InboundMailItemServiceAsyncImpl implements InboundMailItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundMailItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundMailItem>retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)Retrieve an Inbound Mail Item CompletableFuture<InboundMailItemListPageAsync>list(InboundMailItemListParams params, RequestOptions requestOptions)List Inbound Mail Items -
-
Method Detail
-
withRawResponse
InboundMailItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundMailItem> retrieve(InboundMailItemRetrieveParams params, RequestOptions requestOptions)
Retrieve an Inbound Mail Item
-
list
CompletableFuture<InboundMailItemListPageAsync> list(InboundMailItemListParams params, RequestOptions requestOptions)
List Inbound Mail Items
-
-
-
-