Package com.increase.api.services.async
Interface InboundWireDrawdownRequestServiceAsync
-
- All Implemented Interfaces:
public interface InboundWireDrawdownRequestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireDrawdownRequestServiceAsync.WithRawResponseA view of InboundWireDrawdownRequestServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireDrawdownRequestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundWireDrawdownRequest>retrieve(InboundWireDrawdownRequestRetrieveParams params)Retrieve an Inbound Wire Drawdown Request abstract CompletableFuture<InboundWireDrawdownRequest>retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)CompletableFuture<InboundWireDrawdownRequestListPageAsync>list()List Inbound Wire Drawdown Requests abstract CompletableFuture<InboundWireDrawdownRequestListPageAsync>list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)CompletableFuture<InboundWireDrawdownRequestListPageAsync>list(InboundWireDrawdownRequestListParams params)CompletableFuture<InboundWireDrawdownRequestListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireDrawdownRequestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundWireDrawdownRequest> retrieve(InboundWireDrawdownRequestRetrieveParams params)
Retrieve an Inbound Wire Drawdown Request
-
retrieve
abstract CompletableFuture<InboundWireDrawdownRequest> retrieve(InboundWireDrawdownRequestRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list()
List Inbound Wire Drawdown Requests
-
list
abstract CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(InboundWireDrawdownRequestListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(InboundWireDrawdownRequestListParams params)
-
list
CompletableFuture<InboundWireDrawdownRequestListPageAsync> list(RequestOptions requestOptions)
-
-
-
-