Package com.increase.api.services.async
Interface InboundWireTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundWireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireTransferServiceAsync.WithRawResponseA view of InboundWireTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundWireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<InboundWireTransfer> retrieve(InboundWireTransferRetrieveParams params)
Retrieve an Inbound Wire Transfer
-
retrieve
abstract CompletableFuture<InboundWireTransfer> retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireTransferListPageAsync> list()
List Inbound Wire Transfers
-
list
abstract CompletableFuture<InboundWireTransferListPageAsync> list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<InboundWireTransferListPageAsync> list(RequestOptions requestOptions)
-
reverse
CompletableFuture<InboundWireTransfer> reverse(InboundWireTransferReverseParams params)
Reverse an Inbound Wire Transfer
-
reverse
abstract CompletableFuture<InboundWireTransfer> reverse(InboundWireTransferReverseParams params, RequestOptions requestOptions)
-
-
-
-