Package com.increase.api.services.async
Class IntrafiBalanceServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiBalanceServiceAsync
public final class IntrafiBalanceServiceAsyncImpl implements IntrafiBalanceServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiBalanceServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiBalanceServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<IntrafiBalance>intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
IntrafiBalanceServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
intrafiBalance
CompletableFuture<IntrafiBalance> intrafiBalance(IntrafiBalanceIntrafiBalanceParams params, RequestOptions requestOptions)
-
-
-
-