Package com.increase.api.services.async
Class IntrafiExclusionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.IntrafiExclusionServiceAsync
public final class IntrafiExclusionServiceAsyncImpl implements IntrafiExclusionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiExclusionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiExclusionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<IntrafiExclusion>create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)CompletableFuture<IntrafiExclusion>retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<IntrafiExclusionListPageAsync>list(IntrafiExclusionListParams params, RequestOptions requestOptions)CompletableFuture<IntrafiExclusion>archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
IntrafiExclusionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<IntrafiExclusion> create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<IntrafiExclusion> retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<IntrafiExclusionListPageAsync> list(IntrafiExclusionListParams params, RequestOptions requestOptions)
-
archive
CompletableFuture<IntrafiExclusion> archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
-
-
-
-