Package com.increase.api.services.async
Class LockboxServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.LockboxServiceAsync
public final class LockboxServiceAsyncImpl implements LockboxServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LockboxServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Lockbox>create(LockboxCreateParams params, RequestOptions requestOptions)Create a Lockbox CompletableFuture<Lockbox>retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)Retrieve a Lockbox CompletableFuture<Lockbox>update(LockboxUpdateParams params, RequestOptions requestOptions)Update a Lockbox CompletableFuture<LockboxListPageAsync>list(LockboxListParams params, RequestOptions requestOptions)List Lockboxes -
-
Method Detail
-
withRawResponse
LockboxServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Lockbox> create(LockboxCreateParams params, RequestOptions requestOptions)
Create a Lockbox
-
retrieve
CompletableFuture<Lockbox> retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
Retrieve a Lockbox
-
update
CompletableFuture<Lockbox> update(LockboxUpdateParams params, RequestOptions requestOptions)
Update a Lockbox
-
list
CompletableFuture<LockboxListPageAsync> list(LockboxListParams params, RequestOptions requestOptions)
List Lockboxes
-
-
-
-