Package com.increase.api.services.async
Interface OAuthApplicationServiceAsync
-
- All Implemented Interfaces:
public interface OAuthApplicationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthApplicationServiceAsync.WithRawResponseA view of OAuthApplicationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthApplicationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<OAuthApplication>retrieve(OAuthApplicationRetrieveParams params)Retrieve an OAuth Application abstract CompletableFuture<OAuthApplication>retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)CompletableFuture<OAuthApplicationListPageAsync>list()List OAuth Applications abstract CompletableFuture<OAuthApplicationListPageAsync>list(OAuthApplicationListParams params, RequestOptions requestOptions)CompletableFuture<OAuthApplicationListPageAsync>list(OAuthApplicationListParams params)CompletableFuture<OAuthApplicationListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthApplicationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params)
Retrieve an OAuth Application
-
retrieve
abstract CompletableFuture<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthApplicationListPageAsync> list()
List OAuth Applications
-
list
abstract CompletableFuture<OAuthApplicationListPageAsync> list(OAuthApplicationListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthApplicationListPageAsync> list(RequestOptions requestOptions)
-
-
-
-