Package com.increase.api.services.async
Class OAuthApplicationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.OAuthApplicationServiceAsync
public final class OAuthApplicationServiceAsyncImpl implements OAuthApplicationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOAuthApplicationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OAuthApplicationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<OAuthApplication>retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)Retrieve an OAuth Application CompletableFuture<OAuthApplicationListPageAsync>list(OAuthApplicationListParams params, RequestOptions requestOptions)List OAuth Applications -
-
Method Detail
-
withRawResponse
OAuthApplicationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<OAuthApplication> retrieve(OAuthApplicationRetrieveParams params, RequestOptions requestOptions)
Retrieve an OAuth Application
-
list
CompletableFuture<OAuthApplicationListPageAsync> list(OAuthApplicationListParams params, RequestOptions requestOptions)
List OAuth Applications
-
-
-
-