Package com.increase.api.services.async
Interface OAuthConnectionServiceAsync
-
- All Implemented Interfaces:
public interface OAuthConnectionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthConnectionServiceAsync.WithRawResponseA view of OAuthConnectionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthConnectionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<OAuthConnection>retrieve(OAuthConnectionRetrieveParams params)Retrieve an OAuth Connection abstract CompletableFuture<OAuthConnection>retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<OAuthConnectionListPageAsync>list()List OAuth Connections abstract CompletableFuture<OAuthConnectionListPageAsync>list(OAuthConnectionListParams params, RequestOptions requestOptions)CompletableFuture<OAuthConnectionListPageAsync>list(OAuthConnectionListParams params)CompletableFuture<OAuthConnectionListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthConnectionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<OAuthConnection> retrieve(OAuthConnectionRetrieveParams params)
Retrieve an OAuth Connection
-
retrieve
abstract CompletableFuture<OAuthConnection> retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthConnectionListPageAsync> list()
List OAuth Connections
-
list
abstract CompletableFuture<OAuthConnectionListPageAsync> list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<OAuthConnectionListPageAsync> list(RequestOptions requestOptions)
-
-
-
-