Package com.increase.api.services.async
Interface PendingTransactionServiceAsync
-
- All Implemented Interfaces:
public interface PendingTransactionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePendingTransactionServiceAsync.WithRawResponseA view of PendingTransactionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PendingTransactionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<PendingTransaction>retrieve(PendingTransactionRetrieveParams params)Retrieve a Pending Transaction abstract CompletableFuture<PendingTransaction>retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<PendingTransactionListPageAsync>list()List Pending Transactions abstract CompletableFuture<PendingTransactionListPageAsync>list(PendingTransactionListParams params, RequestOptions requestOptions)CompletableFuture<PendingTransactionListPageAsync>list(PendingTransactionListParams params)CompletableFuture<PendingTransactionListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PendingTransactionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<PendingTransaction> retrieve(PendingTransactionRetrieveParams params)
Retrieve a Pending Transaction
-
retrieve
abstract CompletableFuture<PendingTransaction> retrieve(PendingTransactionRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PendingTransactionListPageAsync> list()
List Pending Transactions
-
list
abstract CompletableFuture<PendingTransactionListPageAsync> list(PendingTransactionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<PendingTransactionListPageAsync> list(RequestOptions requestOptions)
-
-
-
-