Package com.increase.api.services.async
Class PhysicalCardProfileServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.PhysicalCardProfileServiceAsync
public final class PhysicalCardProfileServiceAsyncImpl implements PhysicalCardProfileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardProfileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardProfileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<PhysicalCardProfile>create(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)Create a Physical Card Profile CompletableFuture<PhysicalCardProfile>retrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)Retrieve a Card Profile CompletableFuture<PhysicalCardProfileListPageAsync>list(PhysicalCardProfileListParams params, RequestOptions requestOptions)List Physical Card Profiles CompletableFuture<PhysicalCardProfile>archive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)Archive a Physical Card Profile CompletableFuture<PhysicalCardProfile>clone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)Clone a Physical Card Profile -
-
Method Detail
-
withRawResponse
PhysicalCardProfileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<PhysicalCardProfile> create(PhysicalCardProfileCreateParams params, RequestOptions requestOptions)
Create a Physical Card Profile
-
retrieve
CompletableFuture<PhysicalCardProfile> retrieve(PhysicalCardProfileRetrieveParams params, RequestOptions requestOptions)
Retrieve a Card Profile
-
list
CompletableFuture<PhysicalCardProfileListPageAsync> list(PhysicalCardProfileListParams params, RequestOptions requestOptions)
List Physical Card Profiles
-
archive
CompletableFuture<PhysicalCardProfile> archive(PhysicalCardProfileArchiveParams params, RequestOptions requestOptions)
Archive a Physical Card Profile
-
clone
CompletableFuture<PhysicalCardProfile> clone(PhysicalCardProfileCloneParams params, RequestOptions requestOptions)
Clone a Physical Card Profile
-
-
-
-