Package com.increase.api.services.async
Interface ProgramServiceAsync
-
- All Implemented Interfaces:
public interface ProgramServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceProgramServiceAsync.WithRawResponseA view of ProgramServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ProgramServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Program>retrieve(ProgramRetrieveParams params)Retrieve a Program abstract CompletableFuture<Program>retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)CompletableFuture<ProgramListPageAsync>list()List Programs abstract CompletableFuture<ProgramListPageAsync>list(ProgramListParams params, RequestOptions requestOptions)CompletableFuture<ProgramListPageAsync>list(ProgramListParams params)CompletableFuture<ProgramListPageAsync>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ProgramServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Program> retrieve(ProgramRetrieveParams params)
Retrieve a Program
-
retrieve
abstract CompletableFuture<Program> retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProgramListPageAsync> list()
List Programs
-
list
abstract CompletableFuture<ProgramListPageAsync> list(ProgramListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<ProgramListPageAsync> list(ProgramListParams params)
-
list
CompletableFuture<ProgramListPageAsync> list(RequestOptions requestOptions)
-
-
-
-