Package com.increase.api.services.async
Class ProgramServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.ProgramServiceAsync
public final class ProgramServiceAsyncImpl implements ProgramServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProgramServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Program>retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)Retrieve a Program CompletableFuture<ProgramListPageAsync>list(ProgramListParams params, RequestOptions requestOptions)List Programs -
-
Method Detail
-
withRawResponse
ProgramServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<Program> retrieve(ProgramRetrieveParams params, RequestOptions requestOptions)
Retrieve a Program
-
list
CompletableFuture<ProgramListPageAsync> list(ProgramListParams params, RequestOptions requestOptions)
List Programs
-
-
-
-