Package com.increase.api.services.async
Class RealTimeDecisionServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RealTimeDecisionServiceAsync
public final class RealTimeDecisionServiceAsyncImpl implements RealTimeDecisionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimeDecisionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimeDecisionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<RealTimeDecision>retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)CompletableFuture<RealTimeDecision>action(RealTimeDecisionActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RealTimeDecisionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CompletableFuture<RealTimeDecision> retrieve(RealTimeDecisionRetrieveParams params, RequestOptions requestOptions)
-
action
CompletableFuture<RealTimeDecision> action(RealTimeDecisionActionParams params, RequestOptions requestOptions)
-
-
-
-