Package com.increase.api.services.async
Class RealTimePaymentsTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.RealTimePaymentsTransferServiceAsync
public final class RealTimePaymentsTransferServiceAsyncImpl implements RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimePaymentsTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<RealTimePaymentsTransfer>create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)CompletableFuture<RealTimePaymentsTransfer>retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)CompletableFuture<RealTimePaymentsTransferListPageAsync>list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<RealTimePaymentsTransfer> create(RealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<RealTimePaymentsTransfer> retrieve(RealTimePaymentsTransferRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RealTimePaymentsTransferListPageAsync> list(RealTimePaymentsTransferListParams params, RequestOptions requestOptions)
-
-
-
-