Package com.increase.api.services.async
Class SupplementalDocumentServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.SupplementalDocumentServiceAsync
public final class SupplementalDocumentServiceAsyncImpl implements SupplementalDocumentServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupplementalDocumentServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SupplementalDocumentServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<EntitySupplementalDocument>create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)Create a supplemental document for an Entity CompletableFuture<SupplementalDocumentListPageAsync>list(SupplementalDocumentListParams params, RequestOptions requestOptions)List Entity Supplemental Document Submissions -
-
Method Detail
-
withRawResponse
SupplementalDocumentServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<EntitySupplementalDocument> create(SupplementalDocumentCreateParams params, RequestOptions requestOptions)
Create a supplemental document for an Entity
-
list
CompletableFuture<SupplementalDocumentListPageAsync> list(SupplementalDocumentListParams params, RequestOptions requestOptions)
List Entity Supplemental Document Submissions
-
-
-
-