Interface AccountTransferServiceAsync
-
- All Implemented Interfaces:
public interface AccountTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountTransferServiceAsync.WithRawResponseA view of AccountTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AccountTransfer>complete(AccountTransferCompleteParams params)If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. abstract CompletableFuture<AccountTransfer>complete(AccountTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
CompletableFuture<AccountTransfer> complete(AccountTransferCompleteParams params)
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
complete
abstract CompletableFuture<AccountTransfer> complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-