Class AccountTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AccountTransferServiceAsync
public final class AccountTransferServiceAsyncImpl implements AccountTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AccountTransfer>complete(SimulationAccountTransferCompleteParams params, RequestOptions requestOptions)If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. -
-
Method Detail
-
withRawResponse
AccountTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
CompletableFuture<AccountTransfer> complete(SimulationAccountTransferCompleteParams params, RequestOptions requestOptions)
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
-
-
-