Interface AchTransferServiceAsync
-
- All Implemented Interfaces:
public interface AchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchTransferServiceAsync.WithRawResponseA view of AchTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract AchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(AchTransferAcknowledgeParams params)
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.
-
acknowledge
abstract CompletableFuture<AchTransfer> acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params)
Simulates receiving a Notification of Change for an #ach-transfers.
-
createNotificationOfChange
abstract CompletableFuture<AchTransfer> createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<AchTransfer> return_(AchTransferReturnParams params)
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
return_
abstract CompletableFuture<AchTransfer> return_(AchTransferReturnParams params, RequestOptions requestOptions)
-
settle
CompletableFuture<AchTransfer> settle(AchTransferSettleParams params)
Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofpending_submissionorsubmitted. For convenience, if the transfer is instatus:pending_submission, the simulation will also submit the transfer. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.
-
settle
abstract CompletableFuture<AchTransfer> settle(AchTransferSettleParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<AchTransfer> submit(AchTransferSubmitParams params)
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
submit
abstract CompletableFuture<AchTransfer> submit(AchTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-