Class AchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AchTransferServiceAsync
public final class AchTransferServiceAsyncImpl implements AchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AchTransfer>acknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>createNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>return_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>settle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)CompletableFuture<AchTransfer>submit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
CompletableFuture<AchTransfer> return_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)
-
settle
CompletableFuture<AchTransfer> settle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<AchTransfer> submit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-