Class AchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.AchTransferServiceAsync
public final class AchTransferServiceAsyncImpl implements AchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<AchTransfer>acknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. CompletableFuture<AchTransfer>createNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)Simulates receiving a Notification of Change for an #ach-transfers. CompletableFuture<AchTransfer>return_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. CompletableFuture<AchTransfer>settle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)Simulates the settlement of an #ach-transfers by the Federal Reserve. CompletableFuture<AchTransfer>submit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)Simulates the submission of an #ach-transfers to the Federal Reserve. -
-
Method Detail
-
withRawResponse
AchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
acknowledge
CompletableFuture<AchTransfer> acknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.
-
createNotificationOfChange
CompletableFuture<AchTransfer> createNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
Simulates receiving a Notification of Change for an #ach-transfers.
-
return_
CompletableFuture<AchTransfer> return_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
settle
CompletableFuture<AchTransfer> settle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)
Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.
-
submit
CompletableFuture<AchTransfer> submit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
-
-
-