Class CardAuthorizationServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardAuthorizationServiceAsync
public final class CardAuthorizationServiceAsyncImpl implements CardAuthorizationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthorizationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<SimulationCardAuthorizationCreateResponse>create(SimulationCardAuthorizationCreateParams params, RequestOptions requestOptions)Simulates a purchase authorization on a #cards. -
-
Method Detail
-
withRawResponse
CardAuthorizationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<SimulationCardAuthorizationCreateResponse> create(SimulationCardAuthorizationCreateParams params, RequestOptions requestOptions)
Simulates a purchase authorization on a #cards. Depending on the balance available to the card and the
amountsubmitted, the authorization activity will result in a #pending-transactions of typecard_authorizationor a #declined-transactions of typecard_decline. You can pass either a Card id or a #digital-wallet-tokens id to simulate the two different ways purchases can be made.
-
-
-
-