Class CardDisputeServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardDisputeServiceAsync
public final class CardDisputeServiceAsyncImpl implements CardDisputeServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardDisputeServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardDisputeServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CardDispute>action(CardDisputeActionParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardDisputeServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
action
CompletableFuture<CardDispute> action(CardDisputeActionParams params, RequestOptions requestOptions)
-
-
-
-