Interface CardFuelConfirmationServiceAsync
-
- All Implemented Interfaces:
public interface CardFuelConfirmationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardFuelConfirmationServiceAsync.WithRawResponseA view of CardFuelConfirmationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardFuelConfirmationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<CardPayment>create(SimulationCardFuelConfirmationCreateParams params, RequestOptions requestOptions)Simulates the fuel confirmation of an authorization by a card acquirer. abstract CompletableFuture<CardPayment>create(SimulationCardFuelConfirmationCreateParams params)Simulates the fuel confirmation of an authorization by a card acquirer. -
-
Method Detail
-
withRawResponse
abstract CardFuelConfirmationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract CompletableFuture<CardPayment> create(SimulationCardFuelConfirmationCreateParams params, RequestOptions requestOptions)
Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.
-
create
abstract CompletableFuture<CardPayment> create(SimulationCardFuelConfirmationCreateParams params)
Simulates the fuel confirmation of an authorization by a card acquirer. This happens asynchronously right after a fuel pump transaction is completed. A fuel confirmation can only happen once per authorization.
-
-
-
-