Interface CardIncrementServiceAsync
-
- All Implemented Interfaces:
public interface CardIncrementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardIncrementServiceAsync.WithRawResponseA view of CardIncrementServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardIncrementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<CardPayment>create(SimulationCardIncrementCreateParams params, RequestOptions requestOptions)Simulates the increment of an authorization by a card acquirer. abstract CompletableFuture<CardPayment>create(SimulationCardIncrementCreateParams params)Simulates the increment of an authorization by a card acquirer. -
-
Method Detail
-
withRawResponse
abstract CardIncrementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract CompletableFuture<CardPayment> create(SimulationCardIncrementCreateParams params, RequestOptions requestOptions)
Simulates the increment of an authorization by a card acquirer. An authorization can be incremented multiple times.
-
create
abstract CompletableFuture<CardPayment> create(SimulationCardIncrementCreateParams params)
Simulates the increment of an authorization by a card acquirer. An authorization can be incremented multiple times.
-
-
-
-