Interface CardReversalServiceAsync
-
- All Implemented Interfaces:
public interface CardReversalServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardReversalServiceAsync.WithRawResponseA view of CardReversalServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardReversalServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<CardPayment>create(SimulationCardReversalCreateParams params, RequestOptions requestOptions)Simulates the reversal of an authorization by a card acquirer. abstract CompletableFuture<CardPayment>create(SimulationCardReversalCreateParams params)Simulates the reversal of an authorization by a card acquirer. -
-
Method Detail
-
withRawResponse
abstract CardReversalServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract CompletableFuture<CardPayment> create(SimulationCardReversalCreateParams params, RequestOptions requestOptions)
Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.
-
create
abstract CompletableFuture<CardPayment> create(SimulationCardReversalCreateParams params)
Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.
-
-
-
-