Class CardSettlementServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.CardSettlementServiceAsync
public final class CardSettlementServiceAsyncImpl implements CardSettlementServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardSettlementServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardSettlementServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<Transaction>create(SimulationCardSettlementCreateParams params, RequestOptions requestOptions)Simulates the settlement of an authorization by a card acquirer. -
-
Method Detail
-
withRawResponse
CardSettlementServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<Transaction> create(SimulationCardSettlementCreateParams params, RequestOptions requestOptions)
Simulates the settlement of an authorization by a card acquirer. After a card authorization is created, the merchant will eventually send a settlement. This simulates that event, which may occur many days after the purchase in production. The amount settled can be different from the amount originally authorized, for example, when adding a tip to a restaurant bill.
-
-
-
-