Interface CheckDepositServiceAsync
-
- All Implemented Interfaces:
public interface CheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckDepositServiceAsync.WithRawResponseA view of CheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CompletableFuture<CheckDeposit>reject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. abstract CompletableFuture<CheckDeposit>reject(SimulationCheckDepositRejectParams params)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. abstract CompletableFuture<CheckDeposit>return_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)Simulates the return of a #check-deposits. abstract CompletableFuture<CheckDeposit>return_(SimulationCheckDepositReturnParams params)Simulates the return of a #check-deposits. abstract CompletableFuture<CheckDeposit>submit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)Simulates the submission of a #check-deposits to the Federal Reserve. abstract CompletableFuture<CheckDeposit>submit(SimulationCheckDepositSubmitParams params)Simulates the submission of a #check-deposits to the Federal Reserve. -
-
Method Detail
-
withRawResponse
abstract CheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reject
abstract CompletableFuture<CheckDeposit> reject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
reject
abstract CompletableFuture<CheckDeposit> reject(SimulationCheckDepositRejectParams params)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
return_
abstract CompletableFuture<CheckDeposit> return_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
return_
abstract CompletableFuture<CheckDeposit> return_(SimulationCheckDepositReturnParams params)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
submit
abstract CompletableFuture<CheckDeposit> submit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
submit
abstract CompletableFuture<CheckDeposit> submit(SimulationCheckDepositSubmitParams params)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
-
-
-