Interface CheckTransferServiceAsync
-
- All Implemented Interfaces:
public interface CheckTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckTransferServiceAsync.WithRawResponseA view of CheckTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<CheckTransfer>mail(CheckTransferMailParams params)Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. abstract CompletableFuture<CheckTransfer>mail(CheckTransferMailParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CheckTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
mail
CompletableFuture<CheckTransfer> mail(CheckTransferMailParams params)
Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. This transfer must first have a
statusofpending_approvalorpending_submission.
-
mail
abstract CompletableFuture<CheckTransfer> mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
-
-
-