Interface EntityServiceAsync
-
- All Implemented Interfaces:
public interface EntityServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityServiceAsync.WithRawResponseA view of EntityServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EntityServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EntityServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Entity>validation(String entityId, EntityValidationParams params)Set the status for an /documentation/api/entities#entity-object. CompletableFuture<Entity>validation(String entityId, EntityValidationParams params, RequestOptions requestOptions)CompletableFuture<Entity>validation(EntityValidationParams params)abstract CompletableFuture<Entity>validation(EntityValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EntityServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EntityServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
validation
CompletableFuture<Entity> validation(String entityId, EntityValidationParams params)
Set the status for an /documentation/api/entities#entity-object.validation. In production, Know Your Customer validations /documentation/entity-validation#entity-validation. While developing, it can be helpful to override the behavior in Sandbox.
-
validation
CompletableFuture<Entity> validation(String entityId, EntityValidationParams params, RequestOptions requestOptions)
-
validation
CompletableFuture<Entity> validation(EntityValidationParams params)
-
validation
abstract CompletableFuture<Entity> validation(EntityValidationParams params, RequestOptions requestOptions)
-
-
-
-