Class InboundAchTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundAchTransferServiceAsync
public final class InboundAchTransferServiceAsyncImpl implements InboundAchTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundAchTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundAchTransfer>create(SimulationInboundAchTransferCreateParams params, RequestOptions requestOptions)Simulates an inbound ACH transfer to your account. -
-
Method Detail
-
withRawResponse
InboundAchTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<InboundAchTransfer> create(SimulationInboundAchTransferCreateParams params, RequestOptions requestOptions)
Simulates an inbound ACH transfer to your account. This imitates initiating a transfer to an Increase account from a different financial institution. The transfer may be either a credit or a debit depending on if the
amountis positive or negative. The result of calling this API will contain the created transfer. You can pass aresolve_atparameter to allow for a window to action on the Inbound ACH Transfer. Alternatively, if you don't pass theresolve_atparameter the result will contain either a #transactions or a #declined-transactions depending on whether or not the transfer is allowed.
-
-
-
-