Interface InboundCheckDepositServiceAsync
-
- All Implemented Interfaces:
public interface InboundCheckDepositServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundCheckDepositServiceAsync.WithRawResponseA view of InboundCheckDepositServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundCheckDepositServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundCheckDepositServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundCheckDeposit>create(InboundCheckDepositCreateParams params)Simulates an Inbound Check Deposit against your account. abstract CompletableFuture<InboundCheckDeposit>create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundCheckDepositServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundCheckDepositServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundCheckDeposit> create(InboundCheckDepositCreateParams params)
Simulates an Inbound Check Deposit against your account. This imitates someone depositing a check at their bank that was issued from your account. It may or may not be associated with a Check Transfer. Increase will evaluate the Check Deposit as we would in production and either create a Transaction or a Declined Transaction as a result. You can inspect the resulting Inbound Check Deposit object to see the result.
-
create
abstract CompletableFuture<InboundCheckDeposit> create(InboundCheckDepositCreateParams params, RequestOptions requestOptions)
-
-
-
-