Interface InboundFundsHoldServiceAsync
-
- All Implemented Interfaces:
public interface InboundFundsHoldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundFundsHoldServiceAsync.WithRawResponseA view of InboundFundsHoldServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InboundFundsHoldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(String inboundFundsHoldId)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(String inboundFundsHoldId, InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(String inboundFundsHoldId, InboundFundsHoldReleaseParams params)
-
release
abstract CompletableFuture<InboundFundsHoldReleaseResponse> release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(InboundFundsHoldReleaseParams params)
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(String inboundFundsHoldId, RequestOptions requestOptions)
-
-
-
-