Interface InboundFundsHoldServiceAsync
-
- All Implemented Interfaces:
public interface InboundFundsHoldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundFundsHoldServiceAsync.WithRawResponseA view of InboundFundsHoldServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundFundsHoldServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundFundsHoldReleaseResponse>release(InboundFundsHoldReleaseParams params)This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit. abstract CompletableFuture<InboundFundsHoldReleaseResponse>release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundFundsHoldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
release
CompletableFuture<InboundFundsHoldReleaseResponse> release(InboundFundsHoldReleaseParams params)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.
-
release
abstract CompletableFuture<InboundFundsHoldReleaseResponse> release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
-
-
-