Class InboundFundsHoldServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundFundsHoldServiceAsync
public final class InboundFundsHoldServiceAsyncImpl implements InboundFundsHoldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundFundsHoldServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundFundsHoldServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<SimulationInboundFundsHoldReleaseResponse>release(SimulationInboundFundsHoldReleaseParams params, RequestOptions requestOptions)This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit. -
-
Method Detail
-
withRawResponse
InboundFundsHoldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
release
CompletableFuture<SimulationInboundFundsHoldReleaseResponse> release(SimulationInboundFundsHoldReleaseParams params, RequestOptions requestOptions)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.
-
-
-
-