Interface InboundMailItemServiceAsync
-
- All Implemented Interfaces:
public interface InboundMailItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundMailItemServiceAsync.WithRawResponseA view of InboundMailItemServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundMailItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundMailItemServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InboundMailItem>create(InboundMailItemCreateParams params)Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes. abstract CompletableFuture<InboundMailItem>create(InboundMailItemCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundMailItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundMailItemServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InboundMailItem> create(InboundMailItemCreateParams params)
Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes.
-
create
abstract CompletableFuture<InboundMailItem> create(InboundMailItemCreateParams params, RequestOptions requestOptions)
-
-
-
-