Class InboundMailItemServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundMailItemServiceAsync
public final class InboundMailItemServiceAsyncImpl implements InboundMailItemServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundMailItemServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundMailItem>create(InboundMailItemCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundMailItemServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<InboundMailItem> create(InboundMailItemCreateParams params, RequestOptions requestOptions)
-
-
-
-