Interface InboundRealTimePaymentsTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundRealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundRealTimePaymentsTransferServiceAsync.WithRawResponseA view of InboundRealTimePaymentsTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundRealTimePaymentsTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundRealTimePaymentsTransfer>create(InboundRealTimePaymentsTransferCreateParams params)Simulates an #inbound-real-time-payments-transfers to your account. abstract CompletableFuture<InboundRealTimePaymentsTransfer>create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundRealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<InboundRealTimePaymentsTransfer> create(InboundRealTimePaymentsTransferCreateParams params)
Simulates an #inbound-real-time-payments-transfers to your account. Real-Time Payments are a beta feature.
-
create
abstract CompletableFuture<InboundRealTimePaymentsTransfer> create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-