Interface InboundWireTransferServiceAsync
-
- All Implemented Interfaces:
public interface InboundWireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireTransferServiceAsync.WithRawResponseA view of InboundWireTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundWireTransfer>create(InboundWireTransferCreateParams params)Simulates an #inbound-wire-transfers to your account. abstract CompletableFuture<InboundWireTransfer>create(InboundWireTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<InboundWireTransfer> create(InboundWireTransferCreateParams params)
Simulates an #inbound-wire-transfers to your account.
-
create
abstract CompletableFuture<InboundWireTransfer> create(InboundWireTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-