Class InboundWireTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.InboundWireTransferServiceAsync
public final class InboundWireTransferServiceAsyncImpl implements InboundWireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<InboundWireTransfer>create(SimulationInboundWireTransferCreateParams params, RequestOptions requestOptions)Simulates an #inbound-wire-transfers to your account. -
-
Method Detail
-
withRawResponse
InboundWireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CompletableFuture<InboundWireTransfer> create(SimulationInboundWireTransferCreateParams params, RequestOptions requestOptions)
Simulates an #inbound-wire-transfers to your account.
-
-
-
-