Class PhysicalCardServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.PhysicalCardServiceAsync
public final class PhysicalCardServiceAsyncImpl implements PhysicalCardServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<PhysicalCard>advanceShipment(SimulationPhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery. -
-
Method Detail
-
withRawResponse
PhysicalCardServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
advanceShipment
CompletableFuture<PhysicalCard> advanceShipment(SimulationPhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery.
-
-
-
-