Interface RealTimePaymentsTransferServiceAsync
-
- All Implemented Interfaces:
public interface RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRealTimePaymentsTransferServiceAsync.WithRawResponseA view of RealTimePaymentsTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RealTimePaymentsTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<RealTimePaymentsTransfer>complete(RealTimePaymentsTransferCompleteParams params)Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. abstract CompletableFuture<RealTimePaymentsTransfer>complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(RealTimePaymentsTransferCompleteParams params)
Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. This transfer must first have a
statusofpending_submission.
-
complete
abstract CompletableFuture<RealTimePaymentsTransfer> complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-