Class RealTimePaymentsTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.RealTimePaymentsTransferServiceAsync
public final class RealTimePaymentsTransferServiceAsyncImpl implements RealTimePaymentsTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealTimePaymentsTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RealTimePaymentsTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<RealTimePaymentsTransfer>complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
RealTimePaymentsTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
CompletableFuture<RealTimePaymentsTransfer> complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-