Interface WireTransferServiceAsync
-
- All Implemented Interfaces:
public interface WireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWireTransferServiceAsync.WithRawResponseA view of WireTransferServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<WireTransfer>reverse(WireTransferReverseParams params)Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. abstract CompletableFuture<WireTransfer>reverse(WireTransferReverseParams params, RequestOptions requestOptions)CompletableFuture<WireTransfer>submit(WireTransferSubmitParams params)Simulates the submission of a #wire-transfers to the Federal Reserve. abstract CompletableFuture<WireTransfer>submit(WireTransferSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reverse
CompletableFuture<WireTransfer> reverse(WireTransferReverseParams params)
Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a
statusofcomplete.
-
reverse
abstract CompletableFuture<WireTransfer> reverse(WireTransferReverseParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<WireTransfer> submit(WireTransferSubmitParams params)
Simulates the submission of a #wire-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_creating.
-
submit
abstract CompletableFuture<WireTransfer> submit(WireTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-