Class WireTransferServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.async.simulations.WireTransferServiceAsync
public final class WireTransferServiceAsyncImpl implements WireTransferServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWireTransferServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WireTransferServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CompletableFuture<WireTransfer>reverse(WireTransferReverseParams params, RequestOptions requestOptions)CompletableFuture<WireTransfer>submit(WireTransferSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
WireTransferServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reverse
CompletableFuture<WireTransfer> reverse(WireTransferReverseParams params, RequestOptions requestOptions)
-
submit
CompletableFuture<WireTransfer> submit(WireTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-