Interface AccountStatementService
-
- All Implemented Interfaces:
public interface AccountStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountStatementService.WithRawResponseA view of AccountStatementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountStatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountStatementretrieve(AccountStatementRetrieveParams params)Retrieve an Account Statement abstract AccountStatementretrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)AccountStatementListPagelist()List Account Statements abstract AccountStatementListPagelist(AccountStatementListParams params, RequestOptions requestOptions)AccountStatementListPagelist(AccountStatementListParams params)AccountStatementListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
AccountStatement retrieve(AccountStatementRetrieveParams params)
Retrieve an Account Statement
-
retrieve
abstract AccountStatement retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
AccountStatementListPage list()
List Account Statements
-
list
abstract AccountStatementListPage list(AccountStatementListParams params, RequestOptions requestOptions)
-
list
AccountStatementListPage list(AccountStatementListParams params)
-
list
AccountStatementListPage list(RequestOptions requestOptions)
-
-
-
-