Class AccountStatementServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.AccountStatementService
public final class AccountStatementServiceImpl implements AccountStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountStatementServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountStatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountStatementretrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)AccountStatementListPagelist(AccountStatementListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AccountStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
AccountStatement retrieve(AccountStatementRetrieveParams params, RequestOptions requestOptions)
-
list
AccountStatementListPage list(AccountStatementListParams params, RequestOptions requestOptions)
-
-
-
-