Interface AchPrenotificationService
-
- All Implemented Interfaces:
public interface AchPrenotificationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchPrenotificationService.WithRawResponseA view of AchPrenotificationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AchPrenotificationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AchPrenotificationcreate(AchPrenotificationCreateParams params)Create an ACH Prenotification abstract AchPrenotificationcreate(AchPrenotificationCreateParams params, RequestOptions requestOptions)AchPrenotificationretrieve(AchPrenotificationRetrieveParams params)Retrieve an ACH Prenotification abstract AchPrenotificationretrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)AchPrenotificationListPagelist()List ACH Prenotifications abstract AchPrenotificationListPagelist(AchPrenotificationListParams params, RequestOptions requestOptions)AchPrenotificationListPagelist(AchPrenotificationListParams params)AchPrenotificationListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AchPrenotificationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
AchPrenotification create(AchPrenotificationCreateParams params)
Create an ACH Prenotification
-
create
abstract AchPrenotification create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
AchPrenotification retrieve(AchPrenotificationRetrieveParams params)
Retrieve an ACH Prenotification
-
retrieve
abstract AchPrenotification retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
list
AchPrenotificationListPage list()
List ACH Prenotifications
-
list
abstract AchPrenotificationListPage list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
list
AchPrenotificationListPage list(AchPrenotificationListParams params)
-
list
AchPrenotificationListPage list(RequestOptions requestOptions)
-
-
-
-