Interface AchPrenotificationService
-
- All Implemented Interfaces:
public interface AchPrenotificationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchPrenotificationService.WithRawResponseA view of AchPrenotificationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AchPrenotificationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AchPrenotificationcreate(AchPrenotificationCreateParams params, RequestOptions requestOptions)Create an ACH Prenotification abstract AchPrenotificationcreate(AchPrenotificationCreateParams params)Create an ACH Prenotification abstract AchPrenotificationretrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)Retrieve an ACH Prenotification abstract AchPrenotificationretrieve(AchPrenotificationRetrieveParams params)Retrieve an ACH Prenotification abstract AchPrenotificationListPagelist(AchPrenotificationListParams params, RequestOptions requestOptions)List ACH Prenotifications abstract AchPrenotificationListPagelist(AchPrenotificationListParams params)List ACH Prenotifications abstract AchPrenotificationListPagelist()List ACH Prenotifications AchPrenotificationListPagelist(RequestOptions requestOptions)List ACH Prenotifications -
-
Method Detail
-
withRawResponse
abstract AchPrenotificationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract AchPrenotification create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
Create an ACH Prenotification
-
create
abstract AchPrenotification create(AchPrenotificationCreateParams params)
Create an ACH Prenotification
-
retrieve
abstract AchPrenotification retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
Retrieve an ACH Prenotification
-
retrieve
abstract AchPrenotification retrieve(AchPrenotificationRetrieveParams params)
Retrieve an ACH Prenotification
-
list
abstract AchPrenotificationListPage list(AchPrenotificationListParams params, RequestOptions requestOptions)
List ACH Prenotifications
-
list
abstract AchPrenotificationListPage list(AchPrenotificationListParams params)
List ACH Prenotifications
-
list
abstract AchPrenotificationListPage list()
List ACH Prenotifications
-
list
AchPrenotificationListPage list(RequestOptions requestOptions)
List ACH Prenotifications
-
-
-
-