Class AchPrenotificationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.AchPrenotificationService
public final class AchPrenotificationServiceImpl implements AchPrenotificationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAchPrenotificationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AchPrenotificationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AchPrenotificationcreate(AchPrenotificationCreateParams params, RequestOptions requestOptions)AchPrenotificationretrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)AchPrenotificationListPagelist(AchPrenotificationListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AchPrenotificationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
AchPrenotification create(AchPrenotificationCreateParams params, RequestOptions requestOptions)
-
retrieve
AchPrenotification retrieve(AchPrenotificationRetrieveParams params, RequestOptions requestOptions)
-
list
AchPrenotificationListPage list(AchPrenotificationListParams params, RequestOptions requestOptions)
-
-
-
-