Interface BookkeepingAccountService
-
- All Implemented Interfaces:
public interface BookkeepingAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingAccountService.WithRawResponseA view of BookkeepingAccountService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BookkeepingAccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BookkeepingAccountcreate(BookkeepingAccountCreateParams params, RequestOptions requestOptions)Create a Bookkeeping Account abstract BookkeepingAccountcreate(BookkeepingAccountCreateParams params)Create a Bookkeeping Account abstract BookkeepingAccountupdate(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)Update a Bookkeeping Account abstract BookkeepingAccountupdate(BookkeepingAccountUpdateParams params)Update a Bookkeeping Account abstract BookkeepingAccountListPagelist(BookkeepingAccountListParams params, RequestOptions requestOptions)List Bookkeeping Accounts abstract BookkeepingAccountListPagelist(BookkeepingAccountListParams params)List Bookkeeping Accounts abstract BookkeepingAccountListPagelist()List Bookkeeping Accounts BookkeepingAccountListPagelist(RequestOptions requestOptions)List Bookkeeping Accounts abstract BookkeepingBalanceLookupbalance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)Retrieve a Bookkeeping Account Balance abstract BookkeepingBalanceLookupbalance(BookkeepingAccountBalanceParams params)Retrieve a Bookkeeping Account Balance -
-
Method Detail
-
withRawResponse
abstract BookkeepingAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract BookkeepingAccount create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
Create a Bookkeeping Account
-
create
abstract BookkeepingAccount create(BookkeepingAccountCreateParams params)
Create a Bookkeeping Account
-
update
abstract BookkeepingAccount update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
Update a Bookkeeping Account
-
update
abstract BookkeepingAccount update(BookkeepingAccountUpdateParams params)
Update a Bookkeeping Account
-
list
abstract BookkeepingAccountListPage list(BookkeepingAccountListParams params, RequestOptions requestOptions)
List Bookkeeping Accounts
-
list
abstract BookkeepingAccountListPage list(BookkeepingAccountListParams params)
List Bookkeeping Accounts
-
list
abstract BookkeepingAccountListPage list()
List Bookkeeping Accounts
-
list
BookkeepingAccountListPage list(RequestOptions requestOptions)
List Bookkeeping Accounts
-
balance
abstract BookkeepingBalanceLookup balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
Retrieve a Bookkeeping Account Balance
-
balance
abstract BookkeepingBalanceLookup balance(BookkeepingAccountBalanceParams params)
Retrieve a Bookkeeping Account Balance
-
-
-
-