Class BookkeepingAccountServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingAccountService
public final class BookkeepingAccountServiceImpl implements BookkeepingAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingAccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingAccountcreate(BookkeepingAccountCreateParams params, RequestOptions requestOptions)BookkeepingAccountupdate(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)BookkeepingAccountListPagelist(BookkeepingAccountListParams params, RequestOptions requestOptions)BookkeepingBalanceLookupbalance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BookkeepingAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
BookkeepingAccount create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
-
update
BookkeepingAccount update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
-
list
BookkeepingAccountListPage list(BookkeepingAccountListParams params, RequestOptions requestOptions)
-
balance
BookkeepingBalanceLookup balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
-
-
-
-