Class BookkeepingAccountServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingAccountService
public final class BookkeepingAccountServiceImpl implements BookkeepingAccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingAccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingAccountcreate(BookkeepingAccountCreateParams params, RequestOptions requestOptions)Create a Bookkeeping Account BookkeepingAccountupdate(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)Update a Bookkeeping Account BookkeepingAccountListPagelist(BookkeepingAccountListParams params, RequestOptions requestOptions)List Bookkeeping Accounts BookkeepingBalanceLookupbalance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)Retrieve a Bookkeeping Account Balance -
-
Method Detail
-
withRawResponse
BookkeepingAccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
BookkeepingAccount create(BookkeepingAccountCreateParams params, RequestOptions requestOptions)
Create a Bookkeeping Account
-
update
BookkeepingAccount update(BookkeepingAccountUpdateParams params, RequestOptions requestOptions)
Update a Bookkeeping Account
-
list
BookkeepingAccountListPage list(BookkeepingAccountListParams params, RequestOptions requestOptions)
List Bookkeeping Accounts
-
balance
BookkeepingBalanceLookup balance(BookkeepingAccountBalanceParams params, RequestOptions requestOptions)
Retrieve a Bookkeeping Account Balance
-
-
-
-