Interface BookkeepingEntryService
-
- All Implemented Interfaces:
public interface BookkeepingEntryService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBookkeepingEntryService.WithRawResponseA view of BookkeepingEntryService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BookkeepingEntryService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingEntryretrieve(BookkeepingEntryRetrieveParams params)Retrieve a Bookkeeping Entry abstract BookkeepingEntryretrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)BookkeepingEntryListPagelist()List Bookkeeping Entries abstract BookkeepingEntryListPagelist(BookkeepingEntryListParams params, RequestOptions requestOptions)BookkeepingEntryListPagelist(BookkeepingEntryListParams params)BookkeepingEntryListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BookkeepingEntryService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
BookkeepingEntry retrieve(BookkeepingEntryRetrieveParams params)
Retrieve a Bookkeeping Entry
-
retrieve
abstract BookkeepingEntry retrieve(BookkeepingEntryRetrieveParams params, RequestOptions requestOptions)
-
list
BookkeepingEntryListPage list()
List Bookkeeping Entries
-
list
abstract BookkeepingEntryListPage list(BookkeepingEntryListParams params, RequestOptions requestOptions)
-
list
BookkeepingEntryListPage list(BookkeepingEntryListParams params)
-
list
BookkeepingEntryListPage list(RequestOptions requestOptions)
-
-
-
-