Class BookkeepingEntrySetServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.BookkeepingEntrySetService
public final class BookkeepingEntrySetServiceImpl implements BookkeepingEntrySetService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBookkeepingEntrySetServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BookkeepingEntrySetService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BookkeepingEntrySetcreate(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)Create a Bookkeeping Entry Set BookkeepingEntrySetretrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)Retrieve a Bookkeeping Entry Set BookkeepingEntrySetListPagelist(BookkeepingEntrySetListParams params, RequestOptions requestOptions)List Bookkeeping Entry Sets -
-
Method Detail
-
withRawResponse
BookkeepingEntrySetService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
BookkeepingEntrySet create(BookkeepingEntrySetCreateParams params, RequestOptions requestOptions)
Create a Bookkeeping Entry Set
-
retrieve
BookkeepingEntrySet retrieve(BookkeepingEntrySetRetrieveParams params, RequestOptions requestOptions)
Retrieve a Bookkeeping Entry Set
-
list
BookkeepingEntrySetListPage list(BookkeepingEntrySetListParams params, RequestOptions requestOptions)
List Bookkeeping Entry Sets
-
-
-
-