Interface CardPaymentService
-
- All Implemented Interfaces:
public interface CardPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPaymentService.WithRawResponseA view of CardPaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardPaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPaymentretrieve(CardPaymentRetrieveParams params)Retrieve a Card Payment abstract CardPaymentretrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)CardPaymentListPagelist()List Card Payments abstract CardPaymentListPagelist(CardPaymentListParams params, RequestOptions requestOptions)CardPaymentListPagelist(CardPaymentListParams params)CardPaymentListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CardPayment retrieve(CardPaymentRetrieveParams params)
Retrieve a Card Payment
-
retrieve
abstract CardPayment retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
list
CardPaymentListPage list()
List Card Payments
-
list
abstract CardPaymentListPage list(CardPaymentListParams params, RequestOptions requestOptions)
-
list
CardPaymentListPage list(CardPaymentListParams params)
-
list
CardPaymentListPage list(RequestOptions requestOptions)
-
-
-
-