Interface CardPaymentService
-
- All Implemented Interfaces:
public interface CardPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardPaymentService.WithRawResponseA view of CardPaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardPaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CardPaymentretrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)Retrieve a Card Payment abstract CardPaymentretrieve(CardPaymentRetrieveParams params)Retrieve a Card Payment abstract CardPaymentListPagelist(CardPaymentListParams params, RequestOptions requestOptions)List Card Payments abstract CardPaymentListPagelist(CardPaymentListParams params)List Card Payments abstract CardPaymentListPagelist()List Card Payments CardPaymentListPagelist(RequestOptions requestOptions)List Card Payments -
-
Method Detail
-
withRawResponse
abstract CardPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract CardPayment retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
Retrieve a Card Payment
-
retrieve
abstract CardPayment retrieve(CardPaymentRetrieveParams params)
Retrieve a Card Payment
-
list
abstract CardPaymentListPage list(CardPaymentListParams params, RequestOptions requestOptions)
List Card Payments
-
list
abstract CardPaymentListPage list(CardPaymentListParams params)
List Card Payments
-
list
abstract CardPaymentListPage list()
List Card Payments
-
list
CardPaymentListPage list(RequestOptions requestOptions)
List Card Payments
-
-
-
-