Class CardPaymentServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardPaymentService
public final class CardPaymentServiceImpl implements CardPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardPaymentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardPaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPaymentretrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)CardPaymentListPagelist(CardPaymentListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
CardPayment retrieve(CardPaymentRetrieveParams params, RequestOptions requestOptions)
-
list
CardPaymentListPage list(CardPaymentListParams params, RequestOptions requestOptions)
-
-
-
-