Interface CardService
-
- All Implemented Interfaces:
public interface CardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardService.WithRawResponseA view of CardService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Cardcreate(CardCreateParams params)Create a Card abstract Cardcreate(CardCreateParams params, RequestOptions requestOptions)Cardretrieve(CardRetrieveParams params)Retrieve a Card abstract Cardretrieve(CardRetrieveParams params, RequestOptions requestOptions)Cardupdate(CardUpdateParams params)Update a Card abstract Cardupdate(CardUpdateParams params, RequestOptions requestOptions)CardListPagelist()List Cards abstract CardListPagelist(CardListParams params, RequestOptions requestOptions)CardListPagelist(CardListParams params)CardListPagelist(RequestOptions requestOptions)CardDetailsdetails(CardDetailsParams params)Retrieve sensitive details for a Card abstract CardDetailsdetails(CardDetailsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Card create(CardCreateParams params)
Create a Card
-
create
abstract Card create(CardCreateParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(CardRetrieveParams params)
Retrieve a Card
-
retrieve
abstract Card retrieve(CardRetrieveParams params, RequestOptions requestOptions)
-
update
Card update(CardUpdateParams params)
Update a Card
-
update
abstract Card update(CardUpdateParams params, RequestOptions requestOptions)
-
list
CardListPage list()
List Cards
-
list
abstract CardListPage list(CardListParams params, RequestOptions requestOptions)
-
list
CardListPage list(CardListParams params)
-
list
CardListPage list(RequestOptions requestOptions)
-
details
CardDetails details(CardDetailsParams params)
Retrieve sensitive details for a Card
-
details
abstract CardDetails details(CardDetailsParams params, RequestOptions requestOptions)
-
-
-
-