Class CardServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.CardService
public final class CardServiceImpl implements CardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Cardcreate(CardCreateParams params, RequestOptions requestOptions)Cardretrieve(CardRetrieveParams params, RequestOptions requestOptions)Cardupdate(CardUpdateParams params, RequestOptions requestOptions)CardListPagelist(CardListParams params, RequestOptions requestOptions)CardDetailsdetails(CardDetailsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Card create(CardCreateParams params, RequestOptions requestOptions)
-
retrieve
Card retrieve(CardRetrieveParams params, RequestOptions requestOptions)
-
update
Card update(CardUpdateParams params, RequestOptions requestOptions)
-
list
CardListPage list(CardListParams params, RequestOptions requestOptions)
-
details
CardDetails details(CardDetailsParams params, RequestOptions requestOptions)
-
-
-
-