Interface DigitalCardProfileService
-
- All Implemented Interfaces:
public interface DigitalCardProfileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalCardProfileService.WithRawResponseA view of DigitalCardProfileService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalCardProfileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract DigitalCardProfilecreate(DigitalCardProfileCreateParams params, RequestOptions requestOptions)Create a Digital Card Profile abstract DigitalCardProfilecreate(DigitalCardProfileCreateParams params)Create a Digital Card Profile abstract DigitalCardProfileretrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)Retrieve a Digital Card Profile abstract DigitalCardProfileretrieve(DigitalCardProfileRetrieveParams params)Retrieve a Digital Card Profile abstract DigitalCardProfileListPagelist(DigitalCardProfileListParams params, RequestOptions requestOptions)List Card Profiles abstract DigitalCardProfileListPagelist(DigitalCardProfileListParams params)List Card Profiles abstract DigitalCardProfileListPagelist()List Card Profiles DigitalCardProfileListPagelist(RequestOptions requestOptions)List Card Profiles abstract DigitalCardProfilearchive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)Archive a Digital Card Profile abstract DigitalCardProfilearchive(DigitalCardProfileArchiveParams params)Archive a Digital Card Profile abstract DigitalCardProfileclone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)Clones a Digital Card Profile abstract DigitalCardProfileclone(DigitalCardProfileCloneParams params)Clones a Digital Card Profile -
-
Method Detail
-
withRawResponse
abstract DigitalCardProfileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract DigitalCardProfile create(DigitalCardProfileCreateParams params, RequestOptions requestOptions)
Create a Digital Card Profile
-
create
abstract DigitalCardProfile create(DigitalCardProfileCreateParams params)
Create a Digital Card Profile
-
retrieve
abstract DigitalCardProfile retrieve(DigitalCardProfileRetrieveParams params, RequestOptions requestOptions)
Retrieve a Digital Card Profile
-
retrieve
abstract DigitalCardProfile retrieve(DigitalCardProfileRetrieveParams params)
Retrieve a Digital Card Profile
-
list
abstract DigitalCardProfileListPage list(DigitalCardProfileListParams params, RequestOptions requestOptions)
List Card Profiles
-
list
abstract DigitalCardProfileListPage list(DigitalCardProfileListParams params)
List Card Profiles
-
list
abstract DigitalCardProfileListPage list()
List Card Profiles
-
list
DigitalCardProfileListPage list(RequestOptions requestOptions)
List Card Profiles
-
archive
abstract DigitalCardProfile archive(DigitalCardProfileArchiveParams params, RequestOptions requestOptions)
Archive a Digital Card Profile
-
archive
abstract DigitalCardProfile archive(DigitalCardProfileArchiveParams params)
Archive a Digital Card Profile
-
clone
abstract DigitalCardProfile clone(DigitalCardProfileCloneParams params, RequestOptions requestOptions)
Clones a Digital Card Profile
-
clone
abstract DigitalCardProfile clone(DigitalCardProfileCloneParams params)
Clones a Digital Card Profile
-
-
-
-