Interface DocumentService
-
- All Implemented Interfaces:
public interface DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentService.WithRawResponseA view of DocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Documentretrieve(DocumentRetrieveParams params, RequestOptions requestOptions)Retrieve a Document abstract Documentretrieve(DocumentRetrieveParams params)Retrieve a Document abstract DocumentListPagelist(DocumentListParams params, RequestOptions requestOptions)List Documents abstract DocumentListPagelist(DocumentListParams params)List Documents abstract DocumentListPagelist()List Documents DocumentListPagelist(RequestOptions requestOptions)List Documents -
-
Method Detail
-
withRawResponse
abstract DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract Document retrieve(DocumentRetrieveParams params, RequestOptions requestOptions)
Retrieve a Document
-
retrieve
abstract Document retrieve(DocumentRetrieveParams params)
Retrieve a Document
-
list
abstract DocumentListPage list(DocumentListParams params, RequestOptions requestOptions)
List Documents
-
list
abstract DocumentListPage list(DocumentListParams params)
List Documents
-
list
abstract DocumentListPage list()
List Documents
-
list
DocumentListPage list(RequestOptions requestOptions)
List Documents
-
-
-
-