Interface EntityService
-
- All Implemented Interfaces:
public interface EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityService.WithRawResponseA view of EntityService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EntityService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Entitycreate(EntityCreateParams params, RequestOptions requestOptions)Create an Entity abstract Entitycreate(EntityCreateParams params)Create an Entity abstract Entityretrieve(EntityRetrieveParams params, RequestOptions requestOptions)Retrieve an Entity abstract Entityretrieve(EntityRetrieveParams params)Retrieve an Entity abstract EntityListPagelist(EntityListParams params, RequestOptions requestOptions)List Entities abstract EntityListPagelist(EntityListParams params)List Entities abstract EntityListPagelist()List Entities EntityListPagelist(RequestOptions requestOptions)List Entities abstract Entityarchive(EntityArchiveParams params, RequestOptions requestOptions)Archive an Entity abstract Entityarchive(EntityArchiveParams params)Archive an Entity abstract EntityarchiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)Archive a beneficial owner for a corporate Entity abstract EntityarchiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params)Archive a beneficial owner for a corporate Entity abstract Entityconfirm(EntityConfirmParams params, RequestOptions requestOptions)Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. abstract Entityconfirm(EntityConfirmParams params)Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. abstract EntitycreateBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)Create a beneficial owner for a corporate Entity abstract EntitycreateBeneficialOwner(EntityCreateBeneficialOwnerParams params)Create a beneficial owner for a corporate Entity abstract EntityupdateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)Update a Natural Person or Corporation's address abstract EntityupdateAddress(EntityUpdateAddressParams params)Update a Natural Person or Corporation's address abstract EntityupdateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)Update the address for a beneficial owner belonging to a corporate Entity abstract EntityupdateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params)Update the address for a beneficial owner belonging to a corporate Entity abstract EntityupdateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)Update the industry code for a corporate Entity abstract EntityupdateIndustryCode(EntityUpdateIndustryCodeParams params)Update the industry code for a corporate Entity -
-
Method Detail
-
withRawResponse
abstract EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract Entity create(EntityCreateParams params, RequestOptions requestOptions)
Create an Entity
-
create
abstract Entity create(EntityCreateParams params)
Create an Entity
-
retrieve
abstract Entity retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
Retrieve an Entity
-
retrieve
abstract Entity retrieve(EntityRetrieveParams params)
Retrieve an Entity
-
list
abstract EntityListPage list(EntityListParams params, RequestOptions requestOptions)
List Entities
-
list
abstract EntityListPage list(EntityListParams params)
List Entities
-
list
abstract EntityListPage list()
List Entities
-
list
EntityListPage list(RequestOptions requestOptions)
List Entities
-
archive
abstract Entity archive(EntityArchiveParams params, RequestOptions requestOptions)
Archive an Entity
-
archive
abstract Entity archive(EntityArchiveParams params)
Archive an Entity
-
archiveBeneficialOwner
abstract Entity archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)
Archive a beneficial owner for a corporate Entity
-
archiveBeneficialOwner
abstract Entity archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params)
Archive a beneficial owner for a corporate Entity
-
confirm
abstract Entity confirm(EntityConfirmParams params, RequestOptions requestOptions)
Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. After making any required updates, call this endpoint to record that your user confirmed their details.
-
confirm
abstract Entity confirm(EntityConfirmParams params)
Depending on your program, you may be required to re-confirm an Entity's details on a recurring basis. After making any required updates, call this endpoint to record that your user confirmed their details.
-
createBeneficialOwner
abstract Entity createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)
Create a beneficial owner for a corporate Entity
-
createBeneficialOwner
abstract Entity createBeneficialOwner(EntityCreateBeneficialOwnerParams params)
Create a beneficial owner for a corporate Entity
-
updateAddress
abstract Entity updateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)
Update a Natural Person or Corporation's address
-
updateAddress
abstract Entity updateAddress(EntityUpdateAddressParams params)
Update a Natural Person or Corporation's address
-
updateBeneficialOwnerAddress
abstract Entity updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)
Update the address for a beneficial owner belonging to a corporate Entity
-
updateBeneficialOwnerAddress
abstract Entity updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params)
Update the address for a beneficial owner belonging to a corporate Entity
-
updateIndustryCode
abstract Entity updateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)
Update the industry code for a corporate Entity
-
updateIndustryCode
abstract Entity updateIndustryCode(EntityUpdateIndustryCodeParams params)
Update the industry code for a corporate Entity
-
-
-
-