Class EntityServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EntityService
public final class EntityServiceImpl implements EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEntityServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.increase.api.services.blocking.EntityService
archive, archive, archive, archive, archive, archiveBeneficialOwner, archiveBeneficialOwner, archiveBeneficialOwner, confirm, confirm, confirm, confirm, confirm, create, createBeneficialOwner, createBeneficialOwner, createBeneficialOwner, list, list, list, retrieve, retrieve, retrieve, retrieve, retrieve, updateAddress, updateAddress, updateAddress, updateBeneficialOwnerAddress, updateBeneficialOwnerAddress, updateBeneficialOwnerAddress, updateIndustryCode, updateIndustryCode, updateIndustryCode -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
EntityService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Entity create(EntityCreateParams params, RequestOptions requestOptions)
-
retrieve
Entity retrieve(EntityRetrieveParams params, RequestOptions requestOptions)
-
list
EntityListPage list(EntityListParams params, RequestOptions requestOptions)
-
archive
Entity archive(EntityArchiveParams params, RequestOptions requestOptions)
-
archiveBeneficialOwner
Entity archiveBeneficialOwner(EntityArchiveBeneficialOwnerParams params, RequestOptions requestOptions)
-
confirm
Entity confirm(EntityConfirmParams params, RequestOptions requestOptions)
-
createBeneficialOwner
Entity createBeneficialOwner(EntityCreateBeneficialOwnerParams params, RequestOptions requestOptions)
-
updateAddress
Entity updateAddress(EntityUpdateAddressParams params, RequestOptions requestOptions)
-
updateBeneficialOwnerAddress
Entity updateBeneficialOwnerAddress(EntityUpdateBeneficialOwnerAddressParams params, RequestOptions requestOptions)
-
updateIndustryCode
Entity updateIndustryCode(EntityUpdateIndustryCodeParams params, RequestOptions requestOptions)
-
-
-
-