Interface EventService
-
- All Implemented Interfaces:
public interface EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Eventretrieve(EventRetrieveParams params)Retrieve an Event abstract Eventretrieve(EventRetrieveParams params, RequestOptions requestOptions)EventListPagelist()List Events abstract EventListPagelist(EventListParams params, RequestOptions requestOptions)EventListPagelist(EventListParams params)EventListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
Event retrieve(EventRetrieveParams params)
Retrieve an Event
-
retrieve
abstract Event retrieve(EventRetrieveParams params, RequestOptions requestOptions)
-
list
EventListPage list()
List Events
-
list
abstract EventListPage list(EventListParams params, RequestOptions requestOptions)
-
list
EventListPage list(EventListParams params)
-
list
EventListPage list(RequestOptions requestOptions)
-
-
-
-