Interface EventService
-
- All Implemented Interfaces:
public interface EventService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEventService.WithRawResponseA view of EventService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EventService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Eventretrieve(EventRetrieveParams params, RequestOptions requestOptions)Retrieve an Event abstract Eventretrieve(EventRetrieveParams params)Retrieve an Event abstract EventListPagelist(EventListParams params, RequestOptions requestOptions)List Events abstract EventListPagelist(EventListParams params)List Events abstract EventListPagelist()List Events EventListPagelist(RequestOptions requestOptions)List Events -
-
Method Detail
-
withRawResponse
abstract EventService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract Event retrieve(EventRetrieveParams params, RequestOptions requestOptions)
Retrieve an Event
-
retrieve
abstract Event retrieve(EventRetrieveParams params)
Retrieve an Event
-
list
abstract EventListPage list(EventListParams params, RequestOptions requestOptions)
List Events
-
list
abstract EventListPage list(EventListParams params)
List Events
-
list
abstract EventListPage list()
List Events
-
list
EventListPage list(RequestOptions requestOptions)
List Events
-
-
-
-