Class EventSubscriptionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EventSubscriptionService
public final class EventSubscriptionServiceImpl implements EventSubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventSubscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventSubscriptioncreate(EventSubscriptionCreateParams params, RequestOptions requestOptions)EventSubscriptionretrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)EventSubscriptionupdate(EventSubscriptionUpdateParams params, RequestOptions requestOptions)EventSubscriptionListPagelist(EventSubscriptionListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
EventSubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
-
update
EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
-
-
-
-