Class EventSubscriptionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.EventSubscriptionService
public final class EventSubscriptionServiceImpl implements EventSubscriptionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEventSubscriptionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description EventSubscriptionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. EventSubscriptioncreate(EventSubscriptionCreateParams params, RequestOptions requestOptions)Create an Event Subscription EventSubscriptionretrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)Retrieve an Event Subscription EventSubscriptionupdate(EventSubscriptionUpdateParams params, RequestOptions requestOptions)Update an Event Subscription EventSubscriptionListPagelist(EventSubscriptionListParams params, RequestOptions requestOptions)List Event Subscriptions -
-
Method Detail
-
withRawResponse
EventSubscriptionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
EventSubscription create(EventSubscriptionCreateParams params, RequestOptions requestOptions)
Create an Event Subscription
-
retrieve
EventSubscription retrieve(EventSubscriptionRetrieveParams params, RequestOptions requestOptions)
Retrieve an Event Subscription
-
update
EventSubscription update(EventSubscriptionUpdateParams params, RequestOptions requestOptions)
Update an Event Subscription
-
list
EventSubscriptionListPage list(EventSubscriptionListParams params, RequestOptions requestOptions)
List Event Subscriptions
-
-
-
-