Interface ExportService
-
- All Implemented Interfaces:
public interface ExportService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportService.WithRawResponseA view of ExportService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExportService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Exportcreate(ExportCreateParams params)Create an Export abstract Exportcreate(ExportCreateParams params, RequestOptions requestOptions)Exportretrieve(ExportRetrieveParams params)Retrieve an Export abstract Exportretrieve(ExportRetrieveParams params, RequestOptions requestOptions)ExportListPagelist()List Exports abstract ExportListPagelist(ExportListParams params, RequestOptions requestOptions)ExportListPagelist(ExportListParams params)ExportListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExportService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Export create(ExportCreateParams params)
Create an Export
-
create
abstract Export create(ExportCreateParams params, RequestOptions requestOptions)
-
retrieve
Export retrieve(ExportRetrieveParams params)
Retrieve an Export
-
retrieve
abstract Export retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
-
list
ExportListPage list()
List Exports
-
list
abstract ExportListPage list(ExportListParams params, RequestOptions requestOptions)
-
list
ExportListPage list(ExportListParams params)
-
list
ExportListPage list(RequestOptions requestOptions)
-
-
-
-