Interface ExportService
-
- All Implemented Interfaces:
public interface ExportService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportService.WithRawResponseA view of ExportService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExportService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Exportcreate(ExportCreateParams params, RequestOptions requestOptions)Create an Export abstract Exportcreate(ExportCreateParams params)Create an Export abstract Exportretrieve(ExportRetrieveParams params, RequestOptions requestOptions)Retrieve an Export abstract Exportretrieve(ExportRetrieveParams params)Retrieve an Export abstract ExportListPagelist(ExportListParams params, RequestOptions requestOptions)List Exports abstract ExportListPagelist(ExportListParams params)List Exports abstract ExportListPagelist()List Exports ExportListPagelist(RequestOptions requestOptions)List Exports -
-
Method Detail
-
withRawResponse
abstract ExportService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract Export create(ExportCreateParams params, RequestOptions requestOptions)
Create an Export
-
create
abstract Export create(ExportCreateParams params)
Create an Export
-
retrieve
abstract Export retrieve(ExportRetrieveParams params, RequestOptions requestOptions)
Retrieve an Export
-
retrieve
abstract Export retrieve(ExportRetrieveParams params)
Retrieve an Export
-
list
abstract ExportListPage list(ExportListParams params, RequestOptions requestOptions)
List Exports
-
list
abstract ExportListPage list(ExportListParams params)
List Exports
-
list
abstract ExportListPage list()
List Exports
-
list
ExportListPage list(RequestOptions requestOptions)
List Exports
-
-
-
-