Interface FileLinkService
-
- All Implemented Interfaces:
public interface FileLinkService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileLinkService.WithRawResponseA view of FileLinkService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FileLinkService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileLinkcreate(FileLinkCreateParams params)Create a File Link abstract FileLinkcreate(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FileLinkService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
FileLink create(FileLinkCreateParams params)
Create a File Link
-
create
abstract FileLink create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-