Class FileLinkServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.FileLinkService
public final class FileLinkServiceImpl implements FileLinkService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileLinkServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileLinkService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileLinkcreate(FileLinkCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileLinkService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
FileLink create(FileLinkCreateParams params, RequestOptions requestOptions)
-
-
-
-