Interface GroupService
-
- All Implemented Interfaces:
public interface GroupService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceGroupService.WithRawResponseA view of GroupService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract GroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Groupretrieve(GroupRetrieveParams params, RequestOptions requestOptions)Returns details for the currently authenticated Group. abstract Groupretrieve(GroupRetrieveParams params)Returns details for the currently authenticated Group. abstract Groupretrieve()Returns details for the currently authenticated Group. Groupretrieve(RequestOptions requestOptions)Returns details for the currently authenticated Group. -
-
Method Detail
-
withRawResponse
abstract GroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
abstract Group retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
Returns details for the currently authenticated Group.
-
retrieve
abstract Group retrieve(GroupRetrieveParams params)
Returns details for the currently authenticated Group.
-
retrieve
Group retrieve(RequestOptions requestOptions)
Returns details for the currently authenticated Group.
-
-
-
-