Class GroupServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.GroupService
public final class GroupServiceImpl implements GroupService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classGroupServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description GroupService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Groupretrieve(GroupRetrieveParams params, RequestOptions requestOptions)Returns details for the currently authenticated Group. -
-
Method Detail
-
withRawResponse
GroupService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
Group retrieve(GroupRetrieveParams params, RequestOptions requestOptions)
Returns details for the currently authenticated Group.
-
-
-
-