Class InboundAchTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundAchTransferService
public final class InboundAchTransferServiceImpl implements InboundAchTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundAchTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundAchTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundAchTransferretrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)Retrieve an Inbound ACH Transfer InboundAchTransferListPagelist(InboundAchTransferListParams params, RequestOptions requestOptions)List Inbound ACH Transfers InboundAchTransfercreateNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)Create a notification of change for an Inbound ACH Transfer InboundAchTransferdecline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)Decline an Inbound ACH Transfer InboundAchTransfertransferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)Return an Inbound ACH Transfer -
-
Method Detail
-
withRawResponse
InboundAchTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
InboundAchTransfer retrieve(InboundAchTransferRetrieveParams params, RequestOptions requestOptions)
Retrieve an Inbound ACH Transfer
-
list
InboundAchTransferListPage list(InboundAchTransferListParams params, RequestOptions requestOptions)
List Inbound ACH Transfers
-
createNotificationOfChange
InboundAchTransfer createNotificationOfChange(InboundAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
Create a notification of change for an Inbound ACH Transfer
-
decline
InboundAchTransfer decline(InboundAchTransferDeclineParams params, RequestOptions requestOptions)
Decline an Inbound ACH Transfer
-
transferReturn
InboundAchTransfer transferReturn(InboundAchTransferTransferReturnParams params, RequestOptions requestOptions)
Return an Inbound ACH Transfer
-
-
-
-