Interface InboundWireTransferService
-
- All Implemented Interfaces:
public interface InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundWireTransferService.WithRawResponseA view of InboundWireTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundWireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransferretrieve(InboundWireTransferRetrieveParams params)Retrieve an Inbound Wire Transfer abstract InboundWireTransferretrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)InboundWireTransferListPagelist()List Inbound Wire Transfers abstract InboundWireTransferListPagelist(InboundWireTransferListParams params, RequestOptions requestOptions)InboundWireTransferListPagelist(InboundWireTransferListParams params)InboundWireTransferListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
InboundWireTransfer retrieve(InboundWireTransferRetrieveParams params)
Retrieve an Inbound Wire Transfer
-
retrieve
abstract InboundWireTransfer retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
InboundWireTransferListPage list()
List Inbound Wire Transfers
-
list
abstract InboundWireTransferListPage list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
list
InboundWireTransferListPage list(InboundWireTransferListParams params)
-
list
InboundWireTransferListPage list(RequestOptions requestOptions)
-
-
-
-