Class InboundWireTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.InboundWireTransferService
public final class InboundWireTransferServiceImpl implements InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransferretrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)InboundWireTransferListPagelist(InboundWireTransferListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
InboundWireTransfer retrieve(InboundWireTransferRetrieveParams params, RequestOptions requestOptions)
-
list
InboundWireTransferListPage list(InboundWireTransferListParams params, RequestOptions requestOptions)
-
-
-
-