Class IntrafiAccountEnrollmentServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.IntrafiAccountEnrollmentService
public final class IntrafiAccountEnrollmentServiceImpl implements IntrafiAccountEnrollmentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiAccountEnrollmentServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiAccountEnrollmentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiAccountEnrollmentcreate(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)Enroll an account in the IntraFi deposit sweep network IntrafiAccountEnrollmentretrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)Get an IntraFi Account Enrollment IntrafiAccountEnrollmentListPagelist(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)List IntraFi Account Enrollments IntrafiAccountEnrollmentunenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)Unenroll an account from IntraFi -
-
Method Detail
-
withRawResponse
IntrafiAccountEnrollmentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
IntrafiAccountEnrollment create(IntrafiAccountEnrollmentCreateParams params, RequestOptions requestOptions)
Enroll an account in the IntraFi deposit sweep network
-
retrieve
IntrafiAccountEnrollment retrieve(IntrafiAccountEnrollmentRetrieveParams params, RequestOptions requestOptions)
Get an IntraFi Account Enrollment
-
list
IntrafiAccountEnrollmentListPage list(IntrafiAccountEnrollmentListParams params, RequestOptions requestOptions)
List IntraFi Account Enrollments
-
unenroll
IntrafiAccountEnrollment unenroll(IntrafiAccountEnrollmentUnenrollParams params, RequestOptions requestOptions)
Unenroll an account from IntraFi
-
-
-
-