Class IntrafiExclusionServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.IntrafiExclusionService
public final class IntrafiExclusionServiceImpl implements IntrafiExclusionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classIntrafiExclusionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description IntrafiExclusionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. IntrafiExclusioncreate(IntrafiExclusionCreateParams params, RequestOptions requestOptions)Create an IntraFi Exclusion IntrafiExclusionretrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)Get an IntraFi Exclusion IntrafiExclusionListPagelist(IntrafiExclusionListParams params, RequestOptions requestOptions)List IntraFi Exclusions IntrafiExclusionarchive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)Archive an IntraFi Exclusion -
-
Method Detail
-
withRawResponse
IntrafiExclusionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
IntrafiExclusion create(IntrafiExclusionCreateParams params, RequestOptions requestOptions)
Create an IntraFi Exclusion
-
retrieve
IntrafiExclusion retrieve(IntrafiExclusionRetrieveParams params, RequestOptions requestOptions)
Get an IntraFi Exclusion
-
list
IntrafiExclusionListPage list(IntrafiExclusionListParams params, RequestOptions requestOptions)
List IntraFi Exclusions
-
archive
IntrafiExclusion archive(IntrafiExclusionArchiveParams params, RequestOptions requestOptions)
Archive an IntraFi Exclusion
-
-
-
-