Class LockboxServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.LockboxService
public final class LockboxServiceImpl implements LockboxService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classLockboxServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description LockboxService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Lockboxcreate(LockboxCreateParams params, RequestOptions requestOptions)Create a Lockbox Lockboxretrieve(LockboxRetrieveParams params, RequestOptions requestOptions)Retrieve a Lockbox Lockboxupdate(LockboxUpdateParams params, RequestOptions requestOptions)Update a Lockbox LockboxListPagelist(LockboxListParams params, RequestOptions requestOptions)List Lockboxes -
-
Method Detail
-
withRawResponse
LockboxService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Lockbox create(LockboxCreateParams params, RequestOptions requestOptions)
Create a Lockbox
-
retrieve
Lockbox retrieve(LockboxRetrieveParams params, RequestOptions requestOptions)
Retrieve a Lockbox
-
update
Lockbox update(LockboxUpdateParams params, RequestOptions requestOptions)
Update a Lockbox
-
list
LockboxListPage list(LockboxListParams params, RequestOptions requestOptions)
List Lockboxes
-
-
-
-