Interface OAuthConnectionService
-
- All Implemented Interfaces:
public interface OAuthConnectionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthConnectionService.WithRawResponseA view of OAuthConnectionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthConnectionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthConnectionretrieve(OAuthConnectionRetrieveParams params)Retrieve an OAuth Connection abstract OAuthConnectionretrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)OAuthConnectionListPagelist()List OAuth Connections abstract OAuthConnectionListPagelist(OAuthConnectionListParams params, RequestOptions requestOptions)OAuthConnectionListPagelist(OAuthConnectionListParams params)OAuthConnectionListPagelist(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthConnectionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
retrieve
OAuthConnection retrieve(OAuthConnectionRetrieveParams params)
Retrieve an OAuth Connection
-
retrieve
abstract OAuthConnection retrieve(OAuthConnectionRetrieveParams params, RequestOptions requestOptions)
-
list
OAuthConnectionListPage list()
List OAuth Connections
-
list
abstract OAuthConnectionListPage list(OAuthConnectionListParams params, RequestOptions requestOptions)
-
list
OAuthConnectionListPage list(OAuthConnectionListParams params)
-
list
OAuthConnectionListPage list(RequestOptions requestOptions)
-
-
-
-