Interface OAuthTokenService
-
- All Implemented Interfaces:
public interface OAuthTokenService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOAuthTokenService.WithRawResponseA view of OAuthTokenService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract OAuthTokenService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OAuthTokencreate(OAuthTokenCreateParams params)Create an OAuth Token abstract OAuthTokencreate(OAuthTokenCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract OAuthTokenService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
OAuthToken create(OAuthTokenCreateParams params)
Create an OAuth Token
-
create
abstract OAuthToken create(OAuthTokenCreateParams params, RequestOptions requestOptions)
-
-
-
-