Class PhysicalCardServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.PhysicalCardService
public final class PhysicalCardServiceImpl implements PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardcreate(PhysicalCardCreateParams params, RequestOptions requestOptions)PhysicalCardretrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)PhysicalCardupdate(PhysicalCardUpdateParams params, RequestOptions requestOptions)PhysicalCardListPagelist(PhysicalCardListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
PhysicalCard create(PhysicalCardCreateParams params, RequestOptions requestOptions)
-
retrieve
PhysicalCard retrieve(PhysicalCardRetrieveParams params, RequestOptions requestOptions)
-
update
PhysicalCard update(PhysicalCardUpdateParams params, RequestOptions requestOptions)
-
list
PhysicalCardListPage list(PhysicalCardListParams params, RequestOptions requestOptions)
-
-
-
-