Class RoutingNumberServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.RoutingNumberService
public final class RoutingNumberServiceImpl implements RoutingNumberService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRoutingNumberServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RoutingNumberService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RoutingNumberListPagelist(RoutingNumberListParams params, RequestOptions requestOptions)You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. -
-
Method Detail
-
withRawResponse
RoutingNumberService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
list
RoutingNumberListPage list(RoutingNumberListParams params, RequestOptions requestOptions)
You can use this API to confirm if a routing number is valid, such as when a user is providing you with bank account details. Since routing numbers uniquely identify a bank, this will always return 0 or 1 entry. In Sandbox, the only valid routing number for this method is 110000000.
-
-
-
-