Interface AccountStatementService
-
- All Implemented Interfaces:
public interface AccountStatementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountStatementService.WithRawResponseA view of AccountStatementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountStatementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountStatementcreate(AccountStatementCreateParams params)Simulates an #account-statements being created for an account. abstract AccountStatementcreate(AccountStatementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountStatementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
AccountStatement create(AccountStatementCreateParams params)
Simulates an #account-statements being created for an account. In production, Account Statements are generated once per month.
-
create
abstract AccountStatement create(AccountStatementCreateParams params, RequestOptions requestOptions)
-
-
-
-