Interface AccountTransferService
-
- All Implemented Interfaces:
public interface AccountTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountTransferService.WithRawResponseA view of AccountTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransfercomplete(String accountTransferId)If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. AccountTransfercomplete(String accountTransferId, AccountTransferCompleteParams params, RequestOptions requestOptions)AccountTransfercomplete(String accountTransferId, AccountTransferCompleteParams params)abstract AccountTransfercomplete(AccountTransferCompleteParams params, RequestOptions requestOptions)AccountTransfercomplete(AccountTransferCompleteParams params)AccountTransfercomplete(String accountTransferId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
AccountTransfer complete(String accountTransferId)
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
complete
AccountTransfer complete(String accountTransferId, AccountTransferCompleteParams params, RequestOptions requestOptions)
-
complete
AccountTransfer complete(String accountTransferId, AccountTransferCompleteParams params)
-
complete
abstract AccountTransfer complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
complete
AccountTransfer complete(AccountTransferCompleteParams params)
-
complete
AccountTransfer complete(String accountTransferId, RequestOptions requestOptions)
-
-
-
-