Interface AccountTransferService
-
- All Implemented Interfaces:
public interface AccountTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountTransferService.WithRawResponseA view of AccountTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransfercomplete(AccountTransferCompleteParams params)If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. abstract AccountTransfercomplete(AccountTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AccountTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
AccountTransfer complete(AccountTransferCompleteParams params)
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
complete
abstract AccountTransfer complete(AccountTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-