Class AccountTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.AccountTransferService
public final class AccountTransferServiceImpl implements AccountTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountTransfercomplete(SimulationAccountTransferCompleteParams params, RequestOptions requestOptions)If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. -
-
Method Detail
-
withRawResponse
AccountTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
AccountTransfer complete(SimulationAccountTransferCompleteParams params, RequestOptions requestOptions)
If your account is configured to require approval for each transfer, this endpoint simulates the approval of an #account-transfers. You can also approve sandbox Account Transfers in the dashboard. This transfer must first have a
statusofpending_approval.
-
-
-
-