Interface AchTransferService
-
- All Implemented Interfaces:
public interface AchTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchTransferService.WithRawResponseA view of AchTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AchTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AchTransferacknowledge(AchTransferAcknowledgeParams params)Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. abstract AchTransferacknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)AchTransfercreateNotificationOfChange(AchTransferCreateNotificationOfChangeParams params)Simulates receiving a Notification of Change for an #ach-transfers. abstract AchTransfercreateNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)AchTransferreturn_(AchTransferReturnParams params)Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. abstract AchTransferreturn_(AchTransferReturnParams params, RequestOptions requestOptions)AchTransfersettle(AchTransferSettleParams params)Simulates the settlement of an #ach-transfers by the Federal Reserve. abstract AchTransfersettle(AchTransferSettleParams params, RequestOptions requestOptions)AchTransfersubmit(AchTransferSubmitParams params)Simulates the submission of an #ach-transfers to the Federal Reserve. abstract AchTransfersubmit(AchTransferSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AchTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
acknowledge
AchTransfer acknowledge(AchTransferAcknowledgeParams params)
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.
-
acknowledge
abstract AchTransfer acknowledge(AchTransferAcknowledgeParams params, RequestOptions requestOptions)
-
createNotificationOfChange
AchTransfer createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params)
Simulates receiving a Notification of Change for an #ach-transfers.
-
createNotificationOfChange
abstract AchTransfer createNotificationOfChange(AchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
-
return_
AchTransfer return_(AchTransferReturnParams params)
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
return_
abstract AchTransfer return_(AchTransferReturnParams params, RequestOptions requestOptions)
-
settle
AchTransfer settle(AchTransferSettleParams params)
Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofpending_submissionorsubmitted. For convenience, if the transfer is instatus:pending_submission, the simulation will also submit the transfer. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.
-
settle
abstract AchTransfer settle(AchTransferSettleParams params, RequestOptions requestOptions)
-
submit
AchTransfer submit(AchTransferSubmitParams params)
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
submit
abstract AchTransfer submit(AchTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-