Interface AchTransferService

    • Constructor Detail

    • Method Detail

      • acknowledge

         abstract AchTransfer acknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)

        Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a status of submitted . In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.

      • acknowledge

         abstract AchTransfer acknowledge(SimulationAchTransferAcknowledgeParams params)

        Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a status of submitted . In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.

      • return_

         abstract AchTransfer return_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)

        Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a status of submitted.

      • return_

         abstract AchTransfer return_(SimulationAchTransferReturnParams params)

        Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a status of submitted.

      • settle

         abstract AchTransfer settle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)

        Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a status of submitted. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.

      • settle

         abstract AchTransfer settle(SimulationAchTransferSettleParams params)

        Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a status of submitted. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.

      • submit

         abstract AchTransfer submit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)

        Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a status of pending_approval or pending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status of submitted.

      • submit

         abstract AchTransfer submit(SimulationAchTransferSubmitParams params)

        Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a status of pending_approval or pending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status of submitted.