Interface AchTransferService
-
- All Implemented Interfaces:
public interface AchTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAchTransferService.WithRawResponseA view of AchTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AchTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AchTransferacknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. abstract AchTransferacknowledge(SimulationAchTransferAcknowledgeParams params)Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. abstract AchTransfercreateNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)Simulates receiving a Notification of Change for an #ach-transfers. abstract AchTransfercreateNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params)Simulates receiving a Notification of Change for an #ach-transfers. abstract AchTransferreturn_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. abstract AchTransferreturn_(SimulationAchTransferReturnParams params)Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. abstract AchTransfersettle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)Simulates the settlement of an #ach-transfers by the Federal Reserve. abstract AchTransfersettle(SimulationAchTransferSettleParams params)Simulates the settlement of an #ach-transfers by the Federal Reserve. abstract AchTransfersubmit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)Simulates the submission of an #ach-transfers to the Federal Reserve. abstract AchTransfersubmit(SimulationAchTransferSubmitParams params)Simulates the submission of an #ach-transfers to the Federal Reserve. -
-
Method Detail
-
withRawResponse
abstract AchTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
acknowledge
abstract AchTransfer acknowledge(SimulationAchTransferAcknowledgeParams params, RequestOptions requestOptions)
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.
-
acknowledge
abstract AchTransfer acknowledge(SimulationAchTransferAcknowledgeParams params)
Simulates the acknowledgement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. In production, the Federal Reserve generally acknowledges submitted ACH files within 30 minutes. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and add the acknowledgment subresource to the ACH Transfer.
-
createNotificationOfChange
abstract AchTransfer createNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params, RequestOptions requestOptions)
Simulates receiving a Notification of Change for an #ach-transfers.
-
createNotificationOfChange
abstract AchTransfer createNotificationOfChange(SimulationAchTransferCreateNotificationOfChangeParams params)
Simulates receiving a Notification of Change for an #ach-transfers.
-
return_
abstract AchTransfer return_(SimulationAchTransferReturnParams params, RequestOptions requestOptions)
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
return_
abstract AchTransfer return_(SimulationAchTransferReturnParams params)
Simulates the return of an #ach-transfers by the Federal Reserve due to an error condition. This will also create a Transaction to account for the returned funds. This transfer must first have a
statusofsubmitted.
-
settle
abstract AchTransfer settle(SimulationAchTransferSettleParams params, RequestOptions requestOptions)
Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.
-
settle
abstract AchTransfer settle(SimulationAchTransferSettleParams params)
Simulates the settlement of an #ach-transfers by the Federal Reserve. This transfer must first have a
statusofsubmitted. Without this simulation the transfer will eventually settle on its own following the same Federal Reserve timeline as in production.
-
submit
abstract AchTransfer submit(SimulationAchTransferSubmitParams params, RequestOptions requestOptions)
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
submit
abstract AchTransfer submit(SimulationAchTransferSubmitParams params)
Simulates the submission of an #ach-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_submission. In production, Increase submits ACH Transfers to the Federal Reserve three times per day on weekdays. Since sandbox ACH Transfers are not submitted to the Federal Reserve, this endpoint allows you to skip that delay and transition the ACH Transfer to a status ofsubmitted.
-
-
-
-