Class CardAuthorizationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardAuthorizationService
public final class CardAuthorizationServiceImpl implements CardAuthorizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthorizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardAuthorizationCreateResponsecreate(CardAuthorizationCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
CardAuthorizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CardAuthorizationCreateResponse create(CardAuthorizationCreateParams params, RequestOptions requestOptions)
-
-
-
-