Class CardAuthorizationServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardAuthorizationService
public final class CardAuthorizationServiceImpl implements CardAuthorizationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardAuthorizationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardAuthorizationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SimulationCardAuthorizationCreateResponsecreate(SimulationCardAuthorizationCreateParams params, RequestOptions requestOptions)Simulates a purchase authorization on a #cards. -
-
Method Detail
-
withRawResponse
CardAuthorizationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
SimulationCardAuthorizationCreateResponse create(SimulationCardAuthorizationCreateParams params, RequestOptions requestOptions)
Simulates a purchase authorization on a #cards. Depending on the balance available to the card and the
amountsubmitted, the authorization activity will result in a #pending-transactions of typecard_authorizationor a #declined-transactions of typecard_decline. You can pass either a Card id or a #digital-wallet-tokens id to simulate the two different ways purchases can be made.
-
-
-
-