Interface CardRefundService
-
- All Implemented Interfaces:
public interface CardRefundService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardRefundService.WithRawResponseA view of CardRefundService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardRefundService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Transactioncreate(SimulationCardRefundCreateParams params, RequestOptions requestOptions)Simulates refunding a card transaction. abstract Transactioncreate(SimulationCardRefundCreateParams params)Simulates refunding a card transaction. -
-
Method Detail
-
withRawResponse
abstract CardRefundService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract Transaction create(SimulationCardRefundCreateParams params, RequestOptions requestOptions)
Simulates refunding a card transaction. The full value of the original sandbox transaction is refunded.
-
create
abstract Transaction create(SimulationCardRefundCreateParams params)
Simulates refunding a card transaction. The full value of the original sandbox transaction is refunded.
-
-
-
-