Interface CardReversalService

    • Constructor Detail

    • Method Detail

      • create

         abstract CardPayment create(SimulationCardReversalCreateParams params, RequestOptions requestOptions)

        Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.

      • create

         abstract CardPayment create(SimulationCardReversalCreateParams params)

        Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.