Class CardReversalServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CardReversalService
public final class CardReversalServiceImpl implements CardReversalService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCardReversalServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CardReversalService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CardPaymentcreate(SimulationCardReversalCreateParams params, RequestOptions requestOptions)Simulates the reversal of an authorization by a card acquirer. -
-
Method Detail
-
withRawResponse
CardReversalService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
CardPayment create(SimulationCardReversalCreateParams params, RequestOptions requestOptions)
Simulates the reversal of an authorization by a card acquirer. An authorization can be partially reversed multiple times, up until the total authorized amount. Marks the pending transaction as complete if the authorization is fully reversed.
-
-
-
-