Interface CardSettlementService
-
- All Implemented Interfaces:
public interface CardSettlementService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCardSettlementService.WithRawResponseA view of CardSettlementService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CardSettlementService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Transactioncreate(CardSettlementCreateParams params)Simulates the settlement of an authorization by a card acquirer. abstract Transactioncreate(CardSettlementCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CardSettlementService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Transaction create(CardSettlementCreateParams params)
Simulates the settlement of an authorization by a card acquirer. After a card authorization is created, the merchant will eventually send a settlement. This simulates that event, which may occur many days after the purchase in production. The amount settled can be different from the amount originally authorized, for example, when adding a tip to a restaurant bill.
-
create
abstract Transaction create(CardSettlementCreateParams params, RequestOptions requestOptions)
-
-
-
-