Interface CheckDepositService
-
- All Implemented Interfaces:
public interface CheckDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckDepositService.WithRawResponseA view of CheckDepositService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CheckDepositreject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. abstract CheckDepositreject(SimulationCheckDepositRejectParams params)Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. abstract CheckDepositreturn_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)Simulates the return of a #check-deposits. abstract CheckDepositreturn_(SimulationCheckDepositReturnParams params)Simulates the return of a #check-deposits. abstract CheckDepositsubmit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)Simulates the submission of a #check-deposits to the Federal Reserve. abstract CheckDepositsubmit(SimulationCheckDepositSubmitParams params)Simulates the submission of a #check-deposits to the Federal Reserve. -
-
Method Detail
-
withRawResponse
abstract CheckDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reject
abstract CheckDeposit reject(SimulationCheckDepositRejectParams params, RequestOptions requestOptions)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
reject
abstract CheckDeposit reject(SimulationCheckDepositRejectParams params)
Simulates the rejection of a #check-deposits by Increase due to factors like poor image quality. This Check Deposit must first have a
statusofpending.
-
return_
abstract CheckDeposit return_(SimulationCheckDepositReturnParams params, RequestOptions requestOptions)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
return_
abstract CheckDeposit return_(SimulationCheckDepositReturnParams params)
Simulates the return of a #check-deposits. This Check Deposit must first have a
statusofsubmitted.
-
submit
abstract CheckDeposit submit(SimulationCheckDepositSubmitParams params, RequestOptions requestOptions)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
submit
abstract CheckDeposit submit(SimulationCheckDepositSubmitParams params)
Simulates the submission of a #check-deposits to the Federal Reserve. This Check Deposit must first have a
statusofpending.
-
-
-
-