Interface CheckTransferService
-
- All Implemented Interfaces:
public interface CheckTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCheckTransferService.WithRawResponseA view of CheckTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CheckTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckTransfermail(CheckTransferMailParams params)Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. abstract CheckTransfermail(CheckTransferMailParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract CheckTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
mail
CheckTransfer mail(CheckTransferMailParams params)
Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. This transfer must first have a
statusofpending_approvalorpending_submission.
-
mail
abstract CheckTransfer mail(CheckTransferMailParams params, RequestOptions requestOptions)
-
-
-
-