Class CheckTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.CheckTransferService
public final class CheckTransferServiceImpl implements CheckTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCheckTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CheckTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CheckTransfermail(SimulationCheckTransferMailParams params, RequestOptions requestOptions)Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. -
-
Method Detail
-
withRawResponse
CheckTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
mail
CheckTransfer mail(SimulationCheckTransferMailParams params, RequestOptions requestOptions)
Simulates the mailing of a #check-transfers, which happens periodically throughout the day in production but can be sped up in sandbox. This transfer must first have a
statusofpending_approvalorpending_submission.
-
-
-
-