Interface DigitalWalletTokenRequestService
-
- All Implemented Interfaces:
public interface DigitalWalletTokenRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDigitalWalletTokenRequestService.WithRawResponseA view of DigitalWalletTokenRequestService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DigitalWalletTokenRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SimulationDigitalWalletTokenRequestCreateResponsecreate(SimulationDigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)Simulates a user attempting add a #cards to a digital wallet such as Apple Pay. abstract SimulationDigitalWalletTokenRequestCreateResponsecreate(SimulationDigitalWalletTokenRequestCreateParams params)Simulates a user attempting add a #cards to a digital wallet such as Apple Pay. -
-
Method Detail
-
withRawResponse
abstract DigitalWalletTokenRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract SimulationDigitalWalletTokenRequestCreateResponse create(SimulationDigitalWalletTokenRequestCreateParams params, RequestOptions requestOptions)
Simulates a user attempting add a #cards to a digital wallet such as Apple Pay.
-
create
abstract SimulationDigitalWalletTokenRequestCreateResponse create(SimulationDigitalWalletTokenRequestCreateParams params)
Simulates a user attempting add a #cards to a digital wallet such as Apple Pay.
-
-
-
-