Interface DocumentService
-
- All Implemented Interfaces:
public interface DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentService.WithRawResponseA view of DocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Documentcreate(DocumentCreateParams params)Simulates an tax document being created for an account. abstract Documentcreate(DocumentCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Document create(DocumentCreateParams params)
Simulates an tax document being created for an account.
-
create
abstract Document create(DocumentCreateParams params, RequestOptions requestOptions)
-
-
-
-