Interface DocumentService
-
- All Implemented Interfaces:
public interface DocumentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceDocumentService.WithRawResponseA view of DocumentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract DocumentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Documentcreate(SimulationDocumentCreateParams params, RequestOptions requestOptions)Simulates an tax document being created for an account. abstract Documentcreate(SimulationDocumentCreateParams params)Simulates an tax document being created for an account. -
-
Method Detail
-
withRawResponse
abstract DocumentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract Document create(SimulationDocumentCreateParams params, RequestOptions requestOptions)
Simulates an tax document being created for an account.
-
create
abstract Document create(SimulationDocumentCreateParams params)
Simulates an tax document being created for an account.
-
-
-
-