Interface EntityService
-
- All Implemented Interfaces:
public interface EntityService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceEntityService.WithRawResponseA view of EntityService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract EntityService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract EntityServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Entityvalidation(String entityId, EntityValidationParams params)Set the status for an /documentation/api/entities#entity-object. Entityvalidation(String entityId, EntityValidationParams params, RequestOptions requestOptions)Entityvalidation(EntityValidationParams params)abstract Entityvalidation(EntityValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract EntityService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract EntityService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
validation
Entity validation(String entityId, EntityValidationParams params)
Set the status for an /documentation/api/entities#entity-object.validation. In production, Know Your Customer validations /documentation/entity-validation#entity-validation. While developing, it can be helpful to override the behavior in Sandbox.
-
validation
Entity validation(String entityId, EntityValidationParams params, RequestOptions requestOptions)
-
validation
Entity validation(EntityValidationParams params)
-
validation
abstract Entity validation(EntityValidationParams params, RequestOptions requestOptions)
-
-
-
-