Interface EntityService.WithRawResponse
-
- All Implemented Interfaces:
public interface EntityService.WithRawResponseA view of EntityService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract EntityService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<Entity>validation(String entityId, EntityValidationParams params)Returns a raw HTTP response for post /simulations/entities/{entity_id}/validation, but is otherwise the same as EntityService.validation.HttpResponseFor<Entity>validation(String entityId, EntityValidationParams params, RequestOptions requestOptions)HttpResponseFor<Entity>validation(EntityValidationParams params)abstract HttpResponseFor<Entity>validation(EntityValidationParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract EntityService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
validation
@MustBeClosed() HttpResponseFor<Entity> validation(String entityId, EntityValidationParams params)
Returns a raw HTTP response for
post /simulations/entities/{entity_id}/validation, but is otherwise the same as EntityService.validation.
-
validation
@MustBeClosed() HttpResponseFor<Entity> validation(String entityId, EntityValidationParams params, RequestOptions requestOptions)
-
validation
@MustBeClosed() HttpResponseFor<Entity> validation(EntityValidationParams params)
-
validation
@MustBeClosed() abstract HttpResponseFor<Entity> validation(EntityValidationParams params, RequestOptions requestOptions)
-
-
-
-