Interface ExportService
-
- All Implemented Interfaces:
public interface ExportService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExportService.WithRawResponseA view of ExportService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ExportService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ExportServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Exportcreate(ExportCreateParams params)Simulates a tax form export being generated. abstract Exportcreate(ExportCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract ExportService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ExportService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Export create(ExportCreateParams params)
Simulates a tax form export being generated.
-
create
abstract Export create(ExportCreateParams params, RequestOptions requestOptions)
-
-
-
-