Class InboundCheckDepositServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundCheckDepositService
public final class InboundCheckDepositServiceImpl implements InboundCheckDepositService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundCheckDepositServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundCheckDepositService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundCheckDepositcreate(SimulationInboundCheckDepositCreateParams params, RequestOptions requestOptions)Simulates an Inbound Check Deposit against your account. -
-
Method Detail
-
withRawResponse
InboundCheckDepositService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
InboundCheckDeposit create(SimulationInboundCheckDepositCreateParams params, RequestOptions requestOptions)
Simulates an Inbound Check Deposit against your account. This imitates someone depositing a check at their bank that was issued from your account. It may or may not be associated with a Check Transfer. Increase will evaluate the Check Deposit as we would in production and either create a Transaction or a Declined Transaction as a result. You can inspect the resulting Inbound Check Deposit object to see the result.
-
-
-
-