Interface InboundFundsHoldService
-
- All Implemented Interfaces:
public interface InboundFundsHoldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundFundsHoldService.WithRawResponseA view of InboundFundsHoldService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundFundsHoldService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundFundsHoldReleaseResponserelease(InboundFundsHoldReleaseParams params)This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit. abstract InboundFundsHoldReleaseResponserelease(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundFundsHoldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
release
InboundFundsHoldReleaseResponse release(InboundFundsHoldReleaseParams params)
This endpoint simulates immediately releasing an Inbound Funds Hold, which might be created as a result of e.g., an ACH debit.
-
release
abstract InboundFundsHoldReleaseResponse release(InboundFundsHoldReleaseParams params, RequestOptions requestOptions)
-
-
-
-