Interface InboundMailItemService
-
- All Implemented Interfaces:
public interface InboundMailItemService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInboundMailItemService.WithRawResponseA view of InboundMailItemService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InboundMailItemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InboundMailItemServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InboundMailItemcreate(InboundMailItemCreateParams params)Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes. abstract InboundMailItemcreate(InboundMailItemCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InboundMailItemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InboundMailItemService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InboundMailItem create(InboundMailItemCreateParams params)
Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes.
-
create
abstract InboundMailItem create(InboundMailItemCreateParams params, RequestOptions requestOptions)
-
-
-
-