Class InboundMailItemServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundMailItemService
public final class InboundMailItemServiceImpl implements InboundMailItemService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundMailItemServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundMailItemService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundMailItemcreate(SimulationInboundMailItemCreateParams params, RequestOptions requestOptions)Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes. -
-
Method Detail
-
withRawResponse
InboundMailItemService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
InboundMailItem create(SimulationInboundMailItemCreateParams params, RequestOptions requestOptions)
Simulates an inbound mail item to your account, as if someone had mailed a physical check to one of your account's Lockboxes.
-
-
-
-