Class InboundRealTimePaymentsTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundRealTimePaymentsTransferService
public final class InboundRealTimePaymentsTransferServiceImpl implements InboundRealTimePaymentsTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundRealTimePaymentsTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundRealTimePaymentsTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundRealTimePaymentsTransfercreate(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InboundRealTimePaymentsTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
InboundRealTimePaymentsTransfer create(InboundRealTimePaymentsTransferCreateParams params, RequestOptions requestOptions)
-
-
-
-