Class InboundWireDrawdownRequestServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundWireDrawdownRequestService
public final class InboundWireDrawdownRequestServiceImpl implements InboundWireDrawdownRequestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireDrawdownRequestServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireDrawdownRequestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireDrawdownRequestcreate(SimulationInboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)Simulates receiving an #inbound-wire-drawdown-requests. -
-
Method Detail
-
withRawResponse
InboundWireDrawdownRequestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
InboundWireDrawdownRequest create(SimulationInboundWireDrawdownRequestCreateParams params, RequestOptions requestOptions)
Simulates receiving an #inbound-wire-drawdown-requests.
-
-
-
-