Class InboundWireTransferServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.InboundWireTransferService
public final class InboundWireTransferServiceImpl implements InboundWireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInboundWireTransferServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InboundWireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InboundWireTransfercreate(SimulationInboundWireTransferCreateParams params, RequestOptions requestOptions)Simulates an #inbound-wire-transfers to your account. -
-
Method Detail
-
withRawResponse
InboundWireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
InboundWireTransfer create(SimulationInboundWireTransferCreateParams params, RequestOptions requestOptions)
Simulates an #inbound-wire-transfers to your account.
-
-
-
-