Interface InterestPaymentService
-
- All Implemented Interfaces:
public interface InterestPaymentService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInterestPaymentService.WithRawResponseA view of InterestPaymentService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InterestPaymentService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract Transactioncreate(SimulationInterestPaymentCreateParams params, RequestOptions requestOptions)Simulates an interest payment to your account. abstract Transactioncreate(SimulationInterestPaymentCreateParams params)Simulates an interest payment to your account. -
-
Method Detail
-
withRawResponse
abstract InterestPaymentService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
abstract Transaction create(SimulationInterestPaymentCreateParams params, RequestOptions requestOptions)
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
create
abstract Transaction create(SimulationInterestPaymentCreateParams params)
Simulates an interest payment to your account. In production, this happens automatically on the first of each month.
-
-
-
-