Interface PhysicalCardService
-
- All Implemented Interfaces:
public interface PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfacePhysicalCardService.WithRawResponseA view of PhysicalCardService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardadvanceShipment(PhysicalCardAdvanceShipmentParams params)This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery. abstract PhysicalCardadvanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
advanceShipment
PhysicalCard advanceShipment(PhysicalCardAdvanceShipmentParams params)
This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery.
-
advanceShipment
abstract PhysicalCard advanceShipment(PhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
-
-
-
-