Class PhysicalCardServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.PhysicalCardService
public final class PhysicalCardServiceImpl implements PhysicalCardService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPhysicalCardServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description PhysicalCardService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. PhysicalCardadvanceShipment(SimulationPhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery. -
-
Method Detail
-
withRawResponse
PhysicalCardService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
advanceShipment
PhysicalCard advanceShipment(SimulationPhysicalCardAdvanceShipmentParams params, RequestOptions requestOptions)
This endpoint allows you to simulate advancing the shipment status of a Physical Card, to simulate e.g., that a physical card was attempted shipped but then failed delivery.
-
-
-
-