Class ProgramServiceImpl
-
- All Implemented Interfaces:
-
com.increase.api.services.blocking.simulations.ProgramService
public final class ProgramServiceImpl implements ProgramService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProgramServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ProgramService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. Programcreate(SimulationProgramCreateParams params, RequestOptions requestOptions)Simulates a #programs being created in your group. -
-
Method Detail
-
withRawResponse
ProgramService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
create
Program create(SimulationProgramCreateParams params, RequestOptions requestOptions)
Simulates a #programs being created in your group. By default, your group has one program called Commercial Banking. Note that when your group operates more than one program,
program_idis a required field when creating accounts.
-
-
-
-