Interface RealTimePaymentsTransferService
-
- All Implemented Interfaces:
public interface RealTimePaymentsTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRealTimePaymentsTransferService.WithRawResponseA view of RealTimePaymentsTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract RealTimePaymentsTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RealTimePaymentsTransfercomplete(RealTimePaymentsTransferCompleteParams params)Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. abstract RealTimePaymentsTransfercomplete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract RealTimePaymentsTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
complete
RealTimePaymentsTransfer complete(RealTimePaymentsTransferCompleteParams params)
Simulates submission of a #real-time-payments-transfers and handling the response from the destination financial institution. This transfer must first have a
statusofpending_submission.
-
complete
abstract RealTimePaymentsTransfer complete(RealTimePaymentsTransferCompleteParams params, RequestOptions requestOptions)
-
-
-
-