Interface WireTransferService
-
- All Implemented Interfaces:
public interface WireTransferService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceWireTransferService.WithRawResponseA view of WireTransferService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract WireTransferService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WireTransferreverse(SimulationWireTransferReverseParams params)Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. abstract WireTransferreverse(SimulationWireTransferReverseParams params, RequestOptions requestOptions)WireTransfersubmit(SimulationWireTransferSubmitParams params)Simulates the submission of a #wire-transfers to the Federal Reserve. abstract WireTransfersubmit(SimulationWireTransferSubmitParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract WireTransferService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
reverse
WireTransfer reverse(SimulationWireTransferReverseParams params)
Simulates the reversal of a #wire-transfers by the Federal Reserve due to error conditions. This will also create a #transaction to account for the returned funds. This Wire Transfer must first have a
statusofcomplete.
-
reverse
abstract WireTransfer reverse(SimulationWireTransferReverseParams params, RequestOptions requestOptions)
-
submit
WireTransfer submit(SimulationWireTransferSubmitParams params)
Simulates the submission of a #wire-transfers to the Federal Reserve. This transfer must first have a
statusofpending_approvalorpending_creating.
-
submit
abstract WireTransfer submit(SimulationWireTransferSubmitParams params, RequestOptions requestOptions)
-
-
-
-